furniture_data = {
    "plant pots": {
        "0": {
            "id": 0,
            "prod_name": "MUSKOT",
            "prod_price": "1",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "11 cm",
                "Outside diameter": "12 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "11 cm"
            },
            "packaging": [
                "MUSKOT",
                "Plant pot",
                "Article no.:",
                "303.082.01",
                "Length: 11 cm",
                "Weight: 0.39 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. May be combined with the other plant pots in the MUSKOT series. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/muskot-plant-pot-white-30308201/muskot-plant-pot-white-30308201-0.JPG",
                "data/plant pots/muskot-plant-pot-white-30308201/muskot-plant-pot-white-30308201-1.JPG",
                "data/plant pots/muskot-plant-pot-white-30308201/muskot-plant-pot-white-30308201-2.JPG",
                "data/plant pots/muskot-plant-pot-white-30308201/muskot-plant-pot-white-30308201-3.JPG",
                "data/plant pots/muskot-plant-pot-white-30308201/muskot-plant-pot-white-30308201-4.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating"
        },
        "1": {
            "id": 1,
            "prod_name": "BOYSENB\u00c4R",
            "prod_price": "4",
            "prod_desc": "Plant pot, in/outdoor light grey",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "BOYSENB\u00c4R",
                "Plant pot",
                "Article no.:",
                "104.592.53",
                "Length: 13 cm",
                "Weight: 1.06 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "This pot is made of concrete with natural air bubbles and variations in the finish that make each pot unique.   The pot has a soft pad underneath that protects the underlaying surface from scratches and moisture. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use. Make a drain hole in the pot with a drill, if needed.",
            "sustainability": "",
            "images": [
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-light-grey-10459253/boysenbaer-plant-pot-in-outdoor-light-grey-10459253-0.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-light-grey-10459253/boysenbaer-plant-pot-in-outdoor-light-grey-10459253-1.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-light-grey-10459253/boysenbaer-plant-pot-in-outdoor-light-grey-10459253-2.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-light-grey-10459253/boysenbaer-plant-pot-in-outdoor-light-grey-10459253-3.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-light-grey-10459253/boysenbaer-plant-pot-in-outdoor-light-grey-10459253-4.JPG"
            ],
            "materials": "Concrete,Wipe clean with a damp cloth."
        },
        "2": {
            "id": 2,
            "prod_name": "GRADVIS",
            "prod_price": "4",
            "prod_desc": "Plant pot, pink",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "13 cm",
                "Max. diameter flowerpot": "12 cm"
            },
            "packaging": [
                "GRADVIS",
                "Plant pot",
                "Article no.:",
                "604.140.78",
                "Length: 13 cm",
                "Weight: 0.74 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Fits flowerpots up to 12 cm in diameter.",
            "sustainability": "",
            "images": [
                "data/plant pots/gradvis-plant-pot-pink-60414078/gradvis-plant-pot-pink-60414078-0.JPG",
                "data/plant pots/gradvis-plant-pot-pink-60414078/gradvis-plant-pot-pink-60414078-1.JPG",
                "data/plant pots/gradvis-plant-pot-pink-60414078/gradvis-plant-pot-pink-60414078-2.JPG",
                "data/plant pots/gradvis-plant-pot-pink-60414078/gradvis-plant-pot-pink-60414078-3.JPG",
                "data/plant pots/gradvis-plant-pot-pink-60414078/gradvis-plant-pot-pink-60414078-4.JPG"
            ],
            "materials": "Stoneware, Coloured glaze,Wipe clean with a damp cloth."
        },
        "4": {
            "id": 4,
            "prod_name": "PERSILLADE",
            "prod_price": "2",
            "prod_desc": "Plant pot, dark grey",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "PERSILLADE",
                "Plant pot",
                "Article no.:",
                "003.157.26",
                "Length: 13 cm",
                "Weight: 0.59 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. To protect the surface from any risk of moisture damage, always use a saucer or put felt pads under the plant pot.",
            "sustainability": "",
            "images": [
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-0.JPG",
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-1.JPG",
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-2.JPG",
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-3.JPG",
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-4.JPG",
                "data/plant pots/persillade-plant-pot-dark-grey-00315726/persillade-plant-pot-dark-grey-00315726-5.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating"
        },
        "5": {
            "id": 5,
            "prod_name": "NYPON",
            "prod_price": "2",
            "prod_desc": "Plant pot, in/outdoor grey",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "NYPON",
                "Plant pot",
                "Article no.:",
                "403.956.17",
                "Length: 12 cm",
                "Weight: 0.26 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Looks like a concrete pot, but is made from recycled plastic. You can drill drain holes in the bottom, for example if you are planning to use the plant pot outside. Can be stacked inside one another to save room when storing. Suitable for both indoor and outdoor use. To protect the surface from any risk of moisture damage, always use a saucer or put felt pads under the plant pot.",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.",
            "images": [
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-0.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-1.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-2.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-3.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-4.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-5.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-6.JPG",
                "data/plant pots/nypon-plant-pot-in-outdoor-grey-40395617/nypon-plant-pot-in-outdoor-grey-40395617-7.JPG"
            ],
            "materials": "Polypropylene plastic (min. 50% recycled),Wipe clean with a damp cloth."
        },
        "6": {
            "id": 6,
            "prod_name": "SAMVERKA",
            "prod_price": "1",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "11 cm",
                "Outside diameter": "10 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "9 cm"
            },
            "packaging": [
                "SAMVERKA",
                "Plant pot",
                "Article no.:",
                "503.887.39",
                "Length: 11 cm",
                "Weight: 0.10 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "The SAMVERKA series has a nice pattern with birds and leaves that adds a romantic touch to your plants and candles. Decorate your home with plants combined with a plant pot to suit your style. To protect the surface from any risk of moisture damage, always use a saucer or put felt pads under the plant pot.",
            "sustainability": "",
            "images": [
                "data/plant pots/samverka-plant-pot-white-50388739/samverka-plant-pot-white-50388739-0.JPG",
                "data/plant pots/samverka-plant-pot-white-50388739/samverka-plant-pot-white-50388739-1.JPG",
                "data/plant pots/samverka-plant-pot-white-50388739/samverka-plant-pot-white-50388739-2.JPG"
            ],
            "materials": "Galvanized steel, Polyester powder coating"
        },
        "7": {
            "id": 7,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "3",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "004.419.04",
                "Length: 10 cm",
                "Weight: 0.50 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-0.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-1.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-2.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-3.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-4.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-5.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-6.JPG",
                "data/plant pots/chiafroen-plant-pot-white-00441904/chiafroen-plant-pot-white-00441904-7.JPG"
            ],
            "materials": "Stoneware"
        },
        "8": {
            "id": 8,
            "prod_name": "F\u00d6RENLIG",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor white",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "10 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "9 cm"
            },
            "packaging": [
                "F\u00d6RENLIG",
                "Plant pot",
                "Article no.:",
                "704.548.13",
                "Length: 10 cm",
                "Weight: 0.10 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Decorate your home with plants combined with a plant pot to suit your style. Suitable for both indoor and outdoor use. You can make a draining hole in the bottom using a drill.",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.",
            "images": [
                "data/plant pots/foerenlig-plant-pot-in-outdoor-white-70454813/foerenlig-plant-pot-in-outdoor-white-70454813-0.JPG",
                "data/plant pots/foerenlig-plant-pot-in-outdoor-white-70454813/foerenlig-plant-pot-in-outdoor-white-70454813-1.JPG",
                "data/plant pots/foerenlig-plant-pot-in-outdoor-white-70454813/foerenlig-plant-pot-in-outdoor-white-70454813-2.JPG",
                "data/plant pots/foerenlig-plant-pot-in-outdoor-white-70454813/foerenlig-plant-pot-in-outdoor-white-70454813-3.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe clean with a damp cloth."
        },
        "9": {
            "id": 9,
            "prod_name": "SMULGUBBE",
            "prod_price": "3",
            "prod_desc": "Plant pot and saucer, concrete effect/outdoor",
            "prod_dimensions": {
                "Length": "9 cm",
                "Height": "11 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "15 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SMULGUBBE",
                "Plant pot and saucer",
                "Article no.:",
                "304.245.83",
                "This product has multiple packages.",
                "Length: 12 cm",
                "Weight: 0.51 kg",
                "Diameter: 16 cm",
                "Package(s): 1",
                "Length: 3 cm",
                "Weight: 0.17 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lightweight, easy to lift and move. It's possible to plant directly in the pot because it has a drain hole in the bottom and a saucer to collect excess water. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-0.JPG",
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-1.JPG",
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-2.JPG",
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-3.JPG",
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-4.JPG",
                "data/plant pots/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583/smulgubbe-plant-pot-and-saucer-concrete-effect-outdoor-30424583-5.JPG"
            ],
            "materials": "Red clay, Pigmented powder coating,Wipe clean with a cloth dampened in water."
        },
        "10": {
            "id": 10,
            "prod_name": "INGEF\u00c4RA",
            "prod_price": "2",
            "prod_desc": "Plant pot with saucer, outdoor/terracotta",
            "prod_dimensions": {
                "Height": "14 cm",
                "Outside diameter": "16 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "15 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "INGEF\u00c4RA",
                "Plant pot with saucer",
                "Article no.:",
                "502.580.40",
                "This product has multiple packages.",
                "Length: 5 cm",
                "Weight: 0.51 kg",
                "Diameter: 15 cm",
                "Package(s): 1",
                "Length: 13 cm",
                "Weight: 0.79 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "The porous terracotta holds excess water, so the plant can draw out moisture when needed. It's possible to plant directly in the pot because it has a drain hole in the bottom and a saucer to collect excess water. Surface-treated top side; makes the saucer waterproof. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. The drain hole in the bottom of the plant pot lets excess water drain off. For outdoor use. As you water the plant, it is common and normal for lime residues and markings to appear over time if you plant directly in the pot. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-0.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-1.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-2.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-3.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-4.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-5.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040/ingefaera-plant-pot-with-saucer-outdoor-terracotta-50258040-6.JPG"
            ],
            "materials": "Basematerial:,Red clay,Saucer:,Silicone treated red clay"
        },
        "11": {
            "id": 11,
            "prod_name": "FRIDFULL",
            "prod_price": "3",
            "prod_desc": "Plant pot, water hyacinth",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "FRIDFULL",
                "Plant pot",
                "Article no.:",
                "901.558.70",
                "Length: 13 cm",
                "Weight: 0.16 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "A plastic inner pot makes the plant pot waterproof. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "Renewable material (water hyacinth).",
            "images": [
                "data/plant pots/fridfull-plant-pot-water-hyacinth-90155870/fridfull-plant-pot-water-hyacinth-90155870-0.JPG",
                "data/plant pots/fridfull-plant-pot-water-hyacinth-90155870/fridfull-plant-pot-water-hyacinth-90155870-1.JPG",
                "data/plant pots/fridfull-plant-pot-water-hyacinth-90155870/fridfull-plant-pot-water-hyacinth-90155870-2.JPG",
                "data/plant pots/fridfull-plant-pot-water-hyacinth-90155870/fridfull-plant-pot-water-hyacinth-90155870-3.JPG",
                "data/plant pots/fridfull-plant-pot-water-hyacinth-90155870/fridfull-plant-pot-water-hyacinth-90155870-4.JPG"
            ],
            "materials": "Water hyacinth, Polypropylene plastic, Clear acrylic lacquer"
        },
        "12": {
            "id": 12,
            "prod_name": "SATSUMAS",
            "prod_price": "25",
            "prod_desc": "Plant stand, bamboo/white",
            "prod_dimensions": {
                "Height": "78 cm",
                "Max. load/shelf": "5 kg"
            },
            "packaging": [
                "SATSUMAS",
                "Plant stand",
                "Article no.:",
                "402.581.54",
                "Width: 23 cm",
                "Height: 9 cm",
                "Length: 80 cm",
                "Weight: 3.63 kg",
                "Package(s): 1"
            ],
            "prod_details": "A plant stand makes it possible to decorate with plants everywhere in the home. You can decorate with plants in a visually interesting way with shelves at different levels. For indoor use.",
            "sustainability": "Renewable material (bamboo).,We want to have a positive impact on the planet. That is why by 2030, we want all materials in our products to be recycled or renewable, and sourced in responsible ways.,Renewable materials, as opposed to fossil and finite materials, come from living sources that can be regenerated at the same rate as they are used up.,By using a fast-growing, renewable material like bamboo in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/satsumas-plant-stand-bamboo-white-40258154/satsumas-plant-stand-bamboo-white-40258154-0.JPG",
                "data/plant pots/satsumas-plant-stand-bamboo-white-40258154/satsumas-plant-stand-bamboo-white-40258154-1.JPG",
                "data/plant pots/satsumas-plant-stand-bamboo-white-40258154/satsumas-plant-stand-bamboo-white-40258154-2.JPG",
                "data/plant pots/satsumas-plant-stand-bamboo-white-40258154/satsumas-plant-stand-bamboo-white-40258154-3.JPG"
            ],
            "materials": "Shelf:,Steel, Powder coating,Leg:,Bamboo, Clear acrylic lacquer,Clean with a duster."
        },
        "13": {
            "id": 13,
            "prod_name": "BITTERGURKA",
            "prod_price": "6",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "15 cm",
                "Height": "15 cm"
            },
            "packaging": [
                "BITTERGURKA",
                "Plant pot",
                "Article no.:",
                "802.857.87",
                "Width: 15 cm",
                "Height: 12 cm",
                "Length: 33 cm",
                "Weight: 0.88 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-0.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-1.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-2.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-3.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-4.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-5.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-6.JPG",
                "data/plant pots/bittergurka-plant-pot-white-80285787/bittergurka-plant-pot-white-80285787-7.JPG"
            ],
            "materials": "Basematerial:,Galvanized steel, Powder coating,Feet:,Bamboo, Clear nitrocellulose lacquer"
        },
        "14": {
            "id": 14,
            "prod_name": "DAIDAI",
            "prod_price": "1",
            "prod_desc": "Plant pot, brass-colour",
            "prod_dimensions": {
                "Height": "9 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "DAIDAI",
                "Plant pot",
                "Article no.:",
                "703.594.01",
                "Length: 10 cm",
                "Weight: 0.10 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-0.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-1.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-2.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-3.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-4.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-5.JPG",
                "data/plant pots/daidai-plant-pot-brass-colour-70359401/daidai-plant-pot-brass-colour-70359401-6.JPG"
            ],
            "materials": "Galvanized steel, Plastic foil,Wipe clean with a cloth dampened in water."
        },
        "15": {
            "id": 15,
            "prod_name": "SOCKER",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor/galvanised",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "12 cm",
                "Max. diameter flowerpot": "10.5 cm",
                "Inside diameter": "11 cm"
            },
            "packaging": [
                "SOCKER",
                "Plant pot",
                "Article no.:",
                "901.556.72",
                "Width: 12 cm",
                "Height: 11 cm",
                "Length: 12 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for both indoor and outdoor use. The plant pot is galvanised to protect against corrosion. May be combined with other plant pots in the SOCKER series. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-90155672/socker-plant-pot-in-outdoor-galvanised-90155672-0.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-90155672/socker-plant-pot-in-outdoor-galvanised-90155672-1.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-90155672/socker-plant-pot-in-outdoor-galvanised-90155672-2.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-90155672/socker-plant-pot-in-outdoor-galvanised-90155672-3.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-90155672/socker-plant-pot-in-outdoor-galvanised-90155672-4.JPG"
            ],
            "materials": "Galvanized steel"
        },
        "16": {
            "id": 16,
            "prod_name": "KAMOMILL",
            "prod_price": "12",
            "prod_desc": "Plant pot, in/outdoor green",
            "prod_dimensions": {
                "Height": "21 cm",
                "Outside diameter": "26 cm",
                "Max. diameter flowerpot": "19 cm",
                "Inside diameter": "24 cm"
            },
            "packaging": [
                "KAMOMILL",
                "Plant pot",
                "Article no.:",
                "404.419.35",
                "Length: 21 cm",
                "Weight: 2.84 kg",
                "Diameter: 27 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-0.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-1.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-2.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-3.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-4.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-5.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-6.JPG",
                "data/plant pots/kamomill-plant-pot-in-outdoor-green-40441935/kamomill-plant-pot-in-outdoor-green-40441935-7.JPG"
            ],
            "materials": "Stoneware"
        },
        "17": {
            "id": 17,
            "prod_name": "UPPVAKTA",
            "prod_price": "4",
            "prod_desc": "Plant pot, white/natural",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "UPPVAKTA",
                "Plant pot",
                "Article no.:",
                "304.419.93",
                "Length: 13 cm",
                "Weight: 0.87 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-0.JPG",
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-1.JPG",
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-2.JPG",
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-3.JPG",
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-4.JPG",
                "data/plant pots/uppvakta-plant-pot-white-natural-30441993/uppvakta-plant-pot-white-natural-30441993-5.JPG"
            ],
            "materials": "Stoneware"
        },
        "18": {
            "id": 18,
            "prod_name": "MIDDAGSSOL",
            "prod_price": "4",
            "prod_desc": "Plant pot hanger, white",
            "prod_dimensions": {
                "Length": "1 m",
                "Max. load": "10 kg"
            },
            "packaging": [
                "MIDDAGSSOL",
                "Plant pot hanger",
                "Article no.:",
                "004.461.38",
                "Width: 12 cm",
                "Height: 7 cm",
                "Length: 20 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "Only for indoor use. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately.",
            "sustainability": "All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.,By using only renewable materials in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/middagssol-plant-pot-hanger-white-00446138/middagssol-plant-pot-hanger-white-00446138-0.JPG",
                "data/plant pots/middagssol-plant-pot-hanger-white-00446138/middagssol-plant-pot-hanger-white-00446138-1.JPG",
                "data/plant pots/middagssol-plant-pot-hanger-white-00446138/middagssol-plant-pot-hanger-white-00446138-2.JPG",
                "data/plant pots/middagssol-plant-pot-hanger-white-00446138/middagssol-plant-pot-hanger-white-00446138-3.JPG"
            ],
            "materials": "100% cotton,Machine wash, max 40\u00b0C, normal process.,Do not bleach.,Tumble drying, low temperature (max 60\u00b0C).,Do not iron.,Do not dryclean."
        },
        "19": {
            "id": 19,
            "prod_name": "KAFFEB\u00d6NA",
            "prod_price": "3",
            "prod_desc": "Plant pot, bamboo",
            "prod_dimensions": {
                "Height": "11 cm",
                "Outside diameter": "12 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "11 cm"
            },
            "packaging": [
                "KAFFEB\u00d6NA",
                "Plant pot",
                "Article no.:",
                "704.236.14",
                "Length: 11 cm",
                "Weight: 0.05 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by skilled craftspeople, making each one unique. Lightweight, easy to lift and move. Decorate your home with plants combined with a plant pot to suit your style. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed.",
            "sustainability": "Renewable material (bamboo).,We want to have a positive impact on the planet. That is why by 2030, we want all materials in our products to be recycled or renewable, and sourced in responsible ways.,Renewable materials, as opposed to fossil and finite materials, come from living sources that can be regenerated at the same rate as they are used up.,By using a fast-growing, renewable material like bamboo in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-0.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-1.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-2.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-3.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-4.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-5.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-6.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-7.JPG",
                "data/plant pots/kaffeboena-plant-pot-bamboo-70423614/kaffeboena-plant-pot-bamboo-70423614-8.JPG"
            ],
            "materials": "Bamboo, PET plastic, Clear acrylic lacquer"
        },
        "20": {
            "id": 20,
            "prod_name": "R\u00c5GKORN",
            "prod_price": "19",
            "prod_desc": "Plant pot, in/outdoor natural",
            "prod_dimensions": {
                "Height": "31 cm",
                "Outside diameter": "28 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "26 cm"
            },
            "packaging": [
                "R\u00c5GKORN",
                "Plant pot",
                "Article no.:",
                "004.075.56",
                "Length: 32 cm",
                "Weight: 0.95 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "The handles make it easier to move the plant pots. A plastic inner pot makes the plant pot waterproof. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-0.JPG",
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-1.JPG",
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-2.JPG",
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-3.JPG",
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-4.JPG",
                "data/plant pots/ragkorn-plant-pot-in-outdoor-natural-00407556/ragkorn-plant-pot-in-outdoor-natural-00407556-5.JPG"
            ],
            "materials": "Pot:,Polyethylene plastic,Other parts:,PET plastic"
        },
        "21": {
            "id": 21,
            "prod_name": "DR\u00d6MSK",
            "prod_price": "5",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "18 cm",
                "Outside diameter": "17 cm",
                "Max. diameter flowerpot": "15 cm",
                "Inside diameter": "16 cm"
            },
            "packaging": [
                "DR\u00d6MSK",
                "Plant pot",
                "Article no.:",
                "804.566.75",
                "Length: 18 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. To protect the surface from any risk of moisture damage, always use a saucer or put felt pads under the plant pot.",
            "sustainability": "",
            "images": [
                "data/plant pots/droemsk-plant-pot-white-80456675/droemsk-plant-pot-white-80456675-0.JPG",
                "data/plant pots/droemsk-plant-pot-white-80456675/droemsk-plant-pot-white-80456675-1.JPG",
                "data/plant pots/droemsk-plant-pot-white-80456675/droemsk-plant-pot-white-80456675-2.JPG",
                "data/plant pots/droemsk-plant-pot-white-80456675/droemsk-plant-pot-white-80456675-3.JPG",
                "data/plant pots/droemsk-plant-pot-white-80456675/droemsk-plant-pot-white-80456675-4.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "22": {
            "id": 22,
            "prod_name": "SOCKER",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor/galvanised",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "SOCKER",
                "Plant pot",
                "Article no.:",
                "101.556.71",
                "Width: 14 cm",
                "Height: 12 cm",
                "Length: 14 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for both indoor and outdoor use. The plant pot is galvanised to protect against corrosion. May be combined with other plant pots in the SOCKER series. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-10155671/socker-plant-pot-in-outdoor-galvanised-10155671-0.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-10155671/socker-plant-pot-in-outdoor-galvanised-10155671-1.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-10155671/socker-plant-pot-in-outdoor-galvanised-10155671-2.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-10155671/socker-plant-pot-in-outdoor-galvanised-10155671-3.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-10155671/socker-plant-pot-in-outdoor-galvanised-10155671-4.JPG"
            ],
            "materials": "Galvanized steel"
        },
        "23": {
            "id": 23,
            "prod_name": "STENB\u00c4R",
            "prod_price": "15",
            "prod_desc": "Plant pot, grey",
            "prod_dimensions": {
                "Height": "24 cm",
                "Outside diameter": "27 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "26 cm"
            },
            "packaging": [
                "STENB\u00c4R",
                "Plant pot",
                "Article no.:",
                "203.432.43",
                "Length: 27 cm",
                "Weight: 0.41 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed.",
            "sustainability": "",
            "images": [
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-0.JPG",
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-1.JPG",
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-2.JPG",
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-3.JPG",
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-4.JPG",
                "data/plant pots/stenbaer-plant-pot-grey-20343243/stenbaer-plant-pot-grey-20343243-5.JPG"
            ],
            "materials": "Rattan, PET plastic, Tinted clear acrylic lacquer, Clear acrylic lacquer"
        },
        "24": {
            "id": 24,
            "prod_name": "BUSKBO",
            "prod_price": "20",
            "prod_desc": "Plant stand, rattan",
            "prod_dimensions": {
                "Height": "43 cm",
                "Max. load/shelf": "5 kg",
                "Length": "29 cm",
                "Width": "29 cm",
                "Diameter": "27 cm"
            },
            "packaging": [
                "BUSKBO",
                "Plant stand",
                "Article no.:",
                "704.553.70",
                "Width: 31 cm",
                "Height: 31 cm",
                "Length: 45 cm",
                "Weight: 1.00 kg",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by skilled craftspeople, making each one unique. A plant stand makes it possible to decorate with plants everywhere in the home. Rattan is a natural material which ages beautifully and gains its own unique character over time. Lightweight, easy to lift and move. Only for indoor use. Rattan is a natural fibre that might change colour over time. Dimensioned for a flowerpot with a max. diameter of 15 cm.",
            "sustainability": "By using a renewable material like rattan in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/buskbo-plant-stand-rattan-70455370/buskbo-plant-stand-rattan-70455370-0.JPG",
                "data/plant pots/buskbo-plant-stand-rattan-70455370/buskbo-plant-stand-rattan-70455370-1.JPG",
                "data/plant pots/buskbo-plant-stand-rattan-70455370/buskbo-plant-stand-rattan-70455370-2.JPG",
                "data/plant pots/buskbo-plant-stand-rattan-70455370/buskbo-plant-stand-rattan-70455370-3.JPG",
                "data/plant pots/buskbo-plant-stand-rattan-70455370/buskbo-plant-stand-rattan-70455370-4.jpg"
            ],
            "materials": "Frame/ Wrapping:,Rattan, Clear acrylic lacquer,Nail:,Steel, Galvanized,Wipe clean with a damp cloth.,Wipe clean with a dry cloth."
        },
        "25": {
            "id": 25,
            "prod_name": "DRUVFL\u00c4DER",
            "prod_price": "5",
            "prod_desc": "Hanging planter, water hyacinth/grey",
            "prod_dimensions": {
                "Height": "18 cm",
                "Outside diameter": "17 cm",
                "Max. diameter flowerpot": "14 cm",
                "Inside diameter": "15 cm"
            },
            "packaging": [
                "DRUVFL\u00c4DER",
                "Hanging planter",
                "Article no.:",
                "002.418.15",
                "Length: 18 cm",
                "Weight: 0.26 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by a skilled craftsman. Use the plant pot hanger to save floor space and create inspiring vertical horticulture. A plastic inner pot makes the plant pot waterproof.",
            "sustainability": "Renewable material (water hyacinth).",
            "images": [
                "data/plant pots/druvflaeder-hanging-planter-water-hyacinth-grey-00241815/druvflaeder-hanging-planter-water-hyacinth-grey-00241815-0.JPG"
            ],
            "materials": "Pot:,Water hyacinth, Polypropylene plastic, Tinted clear acrylic lacquer, Clear acrylic lacquer,Other parts:,100% jute"
        },
        "26": {
            "id": 26,
            "prod_name": "CHILIPULVER",
            "prod_price": "3",
            "prod_desc": "Plant watering sensor, green",
            "prod_dimensions": {
                "Height": "23 cm"
            },
            "packaging": [
                "CHILIPULVER",
                "Plant watering sensor",
                "Article no.:",
                "204.050.28",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 29 cm",
                "Weight: 0.06 kg",
                "Package(s): 1"
            ],
            "prod_details": "Place CHILIPULVER plant watering sensor in the growing media of your potted plants. The sensor flashes blue when it is time to water. When not flashing, do not water. The sensor indicates the need for water based on 3 levels \u2013 rarely, medium frequency and often. Set the sensor according to the amount of water your plant needs. The 3 levels of the sensor correspond to our potted plants levels for water needs. Only recommended for indoor use. Remove the battery when the watering sensor is stored or not in use. Approved for IP44. When the sensor flashes red, you need to change the battery. Battery is sold separately; 1 pc AAA required.",
            "sustainability": "",
            "images": [
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-0.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-1.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-2.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-3.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-4.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-5.JPG",
                "data/plant pots/chilipulver-plant-watering-sensor-green-20405028/chilipulver-plant-watering-sensor-green-20405028-6.JPG"
            ],
            "materials": "Polycarbonate/ABS plastic"
        },
        "27": {
            "id": 27,
            "prod_name": "SOCKER",
            "prod_price": "6",
            "prod_desc": "Plant pot, in/outdoor/galvanised",
            "prod_dimensions": {
                "Height": "24 cm",
                "Outside diameter": "27 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "26 cm"
            },
            "packaging": [
                "SOCKER",
                "Plant pot",
                "Article no.:",
                "301.556.70",
                "Length: 26 cm",
                "Weight: 0.55 kg",
                "Diameter: 26 cm",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for both indoor and outdoor use. The plant pot is galvanised to protect against corrosion. May be combined with other plant pots in the SOCKER series. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-30155670/socker-plant-pot-in-outdoor-galvanised-30155670-0.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-30155670/socker-plant-pot-in-outdoor-galvanised-30155670-1.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-30155670/socker-plant-pot-in-outdoor-galvanised-30155670-2.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-galvanised-30155670/socker-plant-pot-in-outdoor-galvanised-30155670-3.JPG"
            ],
            "materials": "Galvanized steel"
        },
        "28": {
            "id": 28,
            "prod_name": "KRYDDPEPPAR",
            "prod_price": "29",
            "prod_desc": "Plant stand, in/outdoor beige",
            "prod_dimensions": {
                "Length": "66 cm",
                "Width": "29 cm",
                "Height": "65 cm"
            },
            "packaging": [
                "KRYDDPEPPAR",
                "Plant stand",
                "Article no.:",
                "004.219.58",
                "Width: 32 cm",
                "Height: 14 cm",
                "Length: 68 cm",
                "Weight: 3.38 kg",
                "Package(s): 1"
            ],
            "prod_details": "The plant stand can be used to display plants indoors or outdoors on a balcony perhaps, or as a unique room divider. The tray is held firmly in place with clamps, but is still easy to remove so you can drain it from water and clean it. The tray is easy to clean as it can be removed. A plant stand makes it possible to decorate with plants everywhere in the home. Suitable for both indoor and outdoor use. Can also be used as a bedside table.",
            "sustainability": "",
            "images": [
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-0.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-1.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-2.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-3.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-4.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-5.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-6.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-7.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-8.JPG",
                "data/plant pots/kryddpeppar-plant-stand-in-outdoor-beige-00421958/kryddpeppar-plant-stand-in-outdoor-beige-00421958-9.JPG"
            ],
            "materials": "Frame/ Pot:,Steel, Polyester powder coating,Feet:,Polyamide plastic"
        },
        "29": {
            "id": 29,
            "prod_name": "PAPAJA",
            "prod_price": "2",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "19 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "701.866.55",
                "Length: 20 cm",
                "Weight: 0.99 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The shape and height of the pot make it suitable for orchids. Space for air to circulate around the roots. Lacquered interior; makes the plant pot waterproof. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-0.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-1.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-2.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-3.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-4.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-5.JPG",
                "data/plant pots/papaja-plant-pot-white-70186655/papaja-plant-pot-white-70186655-6.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating"
        },
        "30": {
            "id": 30,
            "prod_name": "DRUVFL\u00c4DER",
            "prod_price": "4",
            "prod_desc": "Plant pot, water hyacinth/grey",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "DRUVFL\u00c4DER",
                "Plant pot",
                "Article no.:",
                "802.418.16",
                "Length: 13 cm",
                "Weight: 0.15 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by a skilled craftsman. A plastic inner pot makes the plant pot waterproof. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "Renewable material (water hyacinth).",
            "images": [
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-80241816/druvflaeder-plant-pot-water-hyacinth-grey-80241816-0.JPG",
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-80241816/druvflaeder-plant-pot-water-hyacinth-grey-80241816-1.JPG",
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-80241816/druvflaeder-plant-pot-water-hyacinth-grey-80241816-2.JPG",
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-80241816/druvflaeder-plant-pot-water-hyacinth-grey-80241816-3.JPG"
            ],
            "materials": "Water hyacinth, Polypropylene plastic, Tinted clear acrylic lacquer, Clear acrylic lacquer"
        },
        "31": {
            "id": 31,
            "prod_name": "DRUVFL\u00c4DER",
            "prod_price": "22",
            "prod_desc": "Plant pot, water hyacinth/grey",
            "prod_dimensions": {
                "Height": "29 cm",
                "Outside diameter": "34 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "31 cm"
            },
            "packaging": [
                "DRUVFL\u00c4DER",
                "Plant pot",
                "Article no.:",
                "302.336.11",
                "Length: 29 cm",
                "Weight: 0.98 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by a skilled craftsman. A plastic inner pot makes the plant pot waterproof. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed.",
            "sustainability": "Renewable material (water hyacinth).",
            "images": [
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-30233611/druvflaeder-plant-pot-water-hyacinth-grey-30233611-0.JPG",
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-30233611/druvflaeder-plant-pot-water-hyacinth-grey-30233611-1.JPG",
                "data/plant pots/druvflaeder-plant-pot-water-hyacinth-grey-30233611/druvflaeder-plant-pot-water-hyacinth-grey-30233611-2.JPG"
            ],
            "materials": "Frame:,Steel, Powder coating,Pot:,Water hyacinth, PET plastic, Tinted clear acrylic lacquer, Clear acrylic lacquer,Wipe clean with a damp cloth."
        },
        "32": {
            "id": 32,
            "prod_name": "SOMMARFEST",
            "prod_price": "9",
            "prod_desc": "Flower box with holder, in/outdoor anthracite",
            "prod_dimensions": {
                "Length": "50 cm",
                "Width": "20 cm",
                "Height": "18 cm",
                "Max. load": "5 kg"
            },
            "packaging": [
                "SOMMARFEST",
                "Flower box with holder",
                "Article no.:",
                "904.387.75",
                "Width: 28 cm",
                "Height: 18 cm",
                "Length: 49 cm",
                "Weight: 0.76 kg",
                "Package(s): 1"
            ],
            "prod_details": "Will help your plant to thrive, even if you can't water regularly. The self-watering insert keeps the soil moist. Decorate your home with plants combined with a plant pot to suit your style. Approved for outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/sommarfest-flower-box-with-holder-in-outdoor-anthracite-90438775/sommarfest-flower-box-with-holder-in-outdoor-anthracite-90438775-0.JPG",
                "data/plant pots/sommarfest-flower-box-with-holder-in-outdoor-anthracite-90438775/sommarfest-flower-box-with-holder-in-outdoor-anthracite-90438775-1.JPG"
            ],
            "materials": "Polypropylene plastic, Polyethylene plastic"
        },
        "33": {
            "id": 33,
            "prod_name": "BITTERGURKA",
            "prod_price": "8",
            "prod_desc": "Hanging planter, white",
            "prod_dimensions": {
                "Height": "37 cm",
                "Outside diameter": "29 cm"
            },
            "packaging": [
                "BITTERGURKA",
                "Hanging planter",
                "Article no.:",
                "902.857.82",
                "Length: 11 cm",
                "Weight: 0.88 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "Hang your herbs by a window, then unhook and bring to the table or cooking pot for fresh herbs with every meal. To create a vertical garden, hook one hanging planter to the next by using the bar underneath. Use the plant pot hanger to save floor space and create inspiring vertical horticulture. Can be used hanging or standing to fit in the space available. It\u2019s possible to plant directly into the planter, or to place potted plants inside. Fits 4 potted plants with a maximum diameter of 10.5 cm. Max. load 15 kg spread over one, or more than one connected together, and suspended from the same mounting device.",
            "sustainability": "",
            "images": [
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-0.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-1.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-2.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-3.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-4.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-5.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-6.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-7.JPG",
                "data/plant pots/bittergurka-hanging-planter-white-90285782/bittergurka-hanging-planter-white-90285782-8.JPG"
            ],
            "materials": "Basematerial:,Steel, Powder coating,Pole:,Bamboo, Clear nitrocellulose lacquer"
        },
        "34": {
            "id": 34,
            "prod_name": "ASKHOLMEN",
            "prod_price": "18",
            "prod_desc": "Trellis, light brown stained",
            "prod_dimensions": {
                "Width": "72 cm",
                "Depth": "3 cm",
                "Height": "190 cm"
            },
            "packaging": [
                "ASKHOLMEN",
                "Trellis",
                "Article no.:",
                "702.586.71",
                "Width: 35 cm",
                "Height: 3 cm",
                "Length: 100 cm",
                "Weight: 4.54 kg",
                "Package(s): 1"
            ],
            "prod_details": "The trellis makes it easy to decorate your walls outdoors with climbing plants and gives them the support they need to grow tall. You can mount the trellis vertically or horizontally and adjust it in height or width to perfectly suit your outdoor space. For added durability and so you can enjoy the natural expression of the wood, the furniture has been pre-treated with a layer of semi-transparent wood stain. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. May be completed with ASKHOLMEN flower box. Use V\u00c5RDA wood stain, outdoor use when re-staining the furniture, sold separately. Only recommended for outdoor use.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.,By using a renewable material like wood in this product, we avoid using fossil or finite materials.,We want to have a positive impact on the planet. That is why by 2030, we want all materials in our products to be recycled or renewable, and sourced in responsible ways.",
            "images": [
                "data/plant pots/askholmen-trellis-light-brown-stained-70258671/askholmen-trellis-light-brown-stained-70258671-0.JPG",
                "data/plant pots/askholmen-trellis-light-brown-stained-70258671/askholmen-trellis-light-brown-stained-70258671-1.JPG",
                "data/plant pots/askholmen-trellis-light-brown-stained-70258671/askholmen-trellis-light-brown-stained-70258671-2.JPG",
                "data/plant pots/askholmen-trellis-light-brown-stained-70258671/askholmen-trellis-light-brown-stained-70258671-3.JPG"
            ],
            "materials": "Solid acacia, Acrylic stain,Clean: With a mild soapy solution. Wipe dry with a clean and dry cloth.,Maintenance: To prevent the surface from drying out and cracking and moisture from penetrating into the wood we recommend you to re-stain the furniture on a regular basis, for example once or twice a year."
        },
        "35": {
            "id": 35,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "1",
            "prod_desc": "Plant pot, grey",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "304.419.07",
                "Length: 10 cm",
                "Weight: 0.51 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-grey-30441907/chiafroen-plant-pot-grey-30441907-0.JPG",
                "data/plant pots/chiafroen-plant-pot-grey-30441907/chiafroen-plant-pot-grey-30441907-1.JPG",
                "data/plant pots/chiafroen-plant-pot-grey-30441907/chiafroen-plant-pot-grey-30441907-2.JPG",
                "data/plant pots/chiafroen-plant-pot-grey-30441907/chiafroen-plant-pot-grey-30441907-3.JPG",
                "data/plant pots/chiafroen-plant-pot-grey-30441907/chiafroen-plant-pot-grey-30441907-4.JPG"
            ],
            "materials": "Stoneware"
        },
        "36": {
            "id": 36,
            "prod_name": "DJUNGELGURKA",
            "prod_price": "7",
            "prod_desc": "Plant pot, seagrass",
            "prod_dimensions": {
                "Height": "16 cm",
                "Outside diameter": "18 cm",
                "Max. diameter flowerpot": "15 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "DJUNGELGURKA",
                "Plant pot",
                "Article no.:",
                "104.847.33",
                "Length: 17 cm",
                "Weight: 0.17 kg",
                "Diameter: 18 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lightweight, easy to lift and move. Handmade by skilled craftspeople, making each one unique. Only for indoor use. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed.",
            "sustainability": "By using a renewable material like sedge (or seagrass) in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/djungelgurka-plant-pot-seagrass-10484733/djungelgurka-plant-pot-seagrass-10484733-0.JPG",
                "data/plant pots/djungelgurka-plant-pot-seagrass-10484733/djungelgurka-plant-pot-seagrass-10484733-1.JPG",
                "data/plant pots/djungelgurka-plant-pot-seagrass-10484733/djungelgurka-plant-pot-seagrass-10484733-2.jpg"
            ],
            "materials": "Plant pot:,Seagrass,Inner plant pot:,PET plastic"
        },
        "37": {
            "id": 37,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "4",
            "prod_desc": "Plant pot, in/outdoor light blue",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "004.833.62",
                "Length: 13 cm",
                "Weight: 0.81 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-blue-00483362/chiafroen-plant-pot-in-outdoor-light-blue-00483362-0.JPG",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-blue-00483362/chiafroen-plant-pot-in-outdoor-light-blue-00483362-1.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-blue-00483362/chiafroen-plant-pot-in-outdoor-light-blue-00483362-2.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-blue-00483362/chiafroen-plant-pot-in-outdoor-light-blue-00483362-3.JPG",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-blue-00483362/chiafroen-plant-pot-in-outdoor-light-blue-00483362-4.JPG"
            ],
            "materials": "Stoneware"
        },
        "38": {
            "id": 38,
            "prod_name": "CURRYBLAD",
            "prod_price": "9",
            "prod_desc": "Plant pot, outdoor terracotta",
            "prod_dimensions": {
                "Height": "25 cm",
                "Outside diameter": "30 cm",
                "Inside diameter": "26 cm"
            },
            "packaging": [
                "CURRYBLAD",
                "Plant pot",
                "Article no.:",
                "204.758.46",
                "Length: 23 cm",
                "Weight: 4.88 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "The porous terracotta holds excess water, so the plant can draw out moisture when needed. The drain hole in the bottom lets excess water drain off. For outdoor use only.",
            "sustainability": "",
            "images": [
                "data/plant pots/curryblad-plant-pot-outdoor-terracotta-20475846/curryblad-plant-pot-outdoor-terracotta-20475846-0.JPG",
                "data/plant pots/curryblad-plant-pot-outdoor-terracotta-20475846/curryblad-plant-pot-outdoor-terracotta-20475846-1.jpg",
                "data/plant pots/curryblad-plant-pot-outdoor-terracotta-20475846/curryblad-plant-pot-outdoor-terracotta-20475846-2.jpg",
                "data/plant pots/curryblad-plant-pot-outdoor-terracotta-20475846/curryblad-plant-pot-outdoor-terracotta-20475846-3.JPG"
            ],
            "materials": "Red clay"
        },
        "39": {
            "id": 39,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "13",
            "prod_desc": "Decorate kit 9",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 4 packages.",
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "004.419.04",
                "Length: 10 cm",
                "Weight: 0.50 kg",
                "Diameter: 11 cm",
                "Package(s): 1",
                "FEJKA",
                "Artificial potted plant",
                "Article no.:",
                "002.859.08",
                "Length: 30 cm",
                "Weight: 0.15 kg",
                "Diameter: 22 cm",
                "Package(s): 1",
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "304.419.07",
                "Length: 10 cm",
                "Weight: 0.51 kg",
                "Diameter: 11 cm",
                "Package(s): 1",
                "FEJKA",
                "Artificial potted plant",
                "Article no.:",
                "703.953.00",
                "Length: 12 cm",
                "Weight: 0.14 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 2 CHIAFR\u00d6N plant pots (height 9 cm), 1 FEJKA artificial succulent (height 9 cm) and 1 FEJKA artificial orchid (height 9 cm).",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-decorate-kit-9-s99401169/chiafroen-decorate-kit-9-s99401169-0.JPG"
            ],
            "materials": "Plant pot,Stoneware,Artificial potted plant,Plant:,Polyethylene plastic, Steel,Inner plant pot:,Polypropylene plastic, Concrete,Plant:,EVA plastic, Polyethylene plastic, Paint,Inner plant pot:,Polypropylene plastic, Concrete, Polypropylene plastic"
        },
        "40": {
            "id": 40,
            "prod_name": "SHARONFRUKT",
            "prod_price": "7",
            "prod_desc": "Plant pot, in/outdoor green",
            "prod_dimensions": {
                "Max. diameter flowerpot": "15 cm",
                "Height": "16 cm",
                "Outside diameter": "20 cm",
                "Inside diameter": "19 cm"
            },
            "packaging": [
                "SHARONFRUKT",
                "Plant pot",
                "Article no.:",
                "604.815.86",
                "Length: 16 cm",
                "Weight: 1.29 kg",
                "Diameter: 20 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-0.JPG",
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-1.JPG",
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-2.jpg",
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-3.JPG",
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-4.JPG",
                "data/plant pots/sharonfrukt-plant-pot-in-outdoor-green-60481586/sharonfrukt-plant-pot-in-outdoor-green-60481586-5.JPG"
            ],
            "materials": "Stoneware, Coloured glaze"
        },
        "41": {
            "id": 41,
            "prod_name": "BOYSENB\u00c4R",
            "prod_price": "2",
            "prod_desc": "Plant pot, in/outdoor triangle/white",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "BOYSENB\u00c4R",
                "Plant pot",
                "Article no.:",
                "304.825.92",
                "Length: 13 cm",
                "Weight: 0.96 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "This pot is made of concrete with natural air bubbles and variations in the finish that make each pot unique.   The pot has a soft pad underneath that protects the underlaying surface from scratches and moisture. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Available in different sizes. Available in different colours.",
            "sustainability": "To lower our environmental impact this product is offered without any packaging.",
            "images": [
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-0.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-1.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-2.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-3.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-4.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592/boysenbaer-plant-pot-in-outdoor-triangle-white-30482592-5.JPG"
            ],
            "materials": "Pot:,Concrete, Acrylic paint,Protection pad:,Polyethylene plastic,Wipe clean with a dry cloth."
        },
        "42": {
            "id": 42,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "4",
            "prod_desc": "Plant pot, in/outdoor white",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "504.757.60",
                "Length: 13 cm",
                "Weight: 0.81 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-in-outdoor-white-50475760/chiafroen-plant-pot-in-outdoor-white-50475760-0.JPG",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-white-50475760/chiafroen-plant-pot-in-outdoor-white-50475760-1.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-white-50475760/chiafroen-plant-pot-in-outdoor-white-50475760-2.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-white-50475760/chiafroen-plant-pot-in-outdoor-white-50475760-3.JPG",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-white-50475760/chiafroen-plant-pot-in-outdoor-white-50475760-4.JPG"
            ],
            "materials": "Stoneware"
        },
        "43": {
            "id": 43,
            "prod_name": "KAPKRUSB\u00c4R",
            "prod_price": "6",
            "prod_desc": "Hanging planter, light grey",
            "prod_dimensions": {
                "Max. diameter flowerpot": "12 cm",
                "Height": "14 cm",
                "Outside diameter": "15 cm",
                "Max. load": "3 kg",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "KAPKRUSB\u00c4R",
                "Hanging planter",
                "Article no.:",
                "104.738.95",
                "Length: 14 cm",
                "Weight: 0.75 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Easy to hang up since it comes with string already attached. Can be used hanging or standing to fit in the space available. It\u2019s possible to plant directly into the planter, or to place potted plants inside. Only for indoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/kapkrusbaer-hanging-planter-light-grey-10473895/kapkrusbaer-hanging-planter-light-grey-10473895-0.JPG",
                "data/plant pots/kapkrusbaer-hanging-planter-light-grey-10473895/kapkrusbaer-hanging-planter-light-grey-10473895-1.JPG",
                "data/plant pots/kapkrusbaer-hanging-planter-light-grey-10473895/kapkrusbaer-hanging-planter-light-grey-10473895-2.JPG"
            ],
            "materials": "Plant pot:,Earthenware, Pigmented powder coating,String:,100% jute,Suspension fitting:,Stainless steel,Wipe clean with a damp cloth."
        },
        "44": {
            "id": 44,
            "prod_name": "BOYSENB\u00c4R",
            "prod_price": "3",
            "prod_desc": "Saucer, in/outdoor light grey",
            "prod_dimensions": {
                "Height": "2 cm",
                "Outside diameter": "18.5 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "BOYSENB\u00c4R",
                "Saucer",
                "Article no.:",
                "804.683.86",
                "Length: 2 cm",
                "Weight: 0.51 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "With a saucer, you can plant directly in plant pots with drainage holes since excess water can collect in the saucer. The saucer has a soft pad underneath that protects the underlaying surface from scratches and moisture. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/boysenbaer-saucer-in-outdoor-light-grey-80468386/boysenbaer-saucer-in-outdoor-light-grey-80468386-0.JPG",
                "data/plant pots/boysenbaer-saucer-in-outdoor-light-grey-80468386/boysenbaer-saucer-in-outdoor-light-grey-80468386-1.jpg",
                "data/plant pots/boysenbaer-saucer-in-outdoor-light-grey-80468386/boysenbaer-saucer-in-outdoor-light-grey-80468386-2.jpg"
            ],
            "materials": "Concrete"
        },
        "45": {
            "id": 45,
            "prod_name": "SANSEVIERIA",
            "prod_price": "3",
            "prod_desc": "Potted plant with pot, Snake plant assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "20 cm"
            },
            "packaging": [
                "SANSEVIERIA",
                "Potted plant with pot",
                "Article no.:",
                "304.020.34",
                "Length: 25 cm",
                "Weight: 0.10 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to Ethiopia. Easy care plant. This plant is sensitive to over watering. If it gets too much water there is a risk of root rot.",
            "sustainability": "",
            "images": [
                "data/plant pots/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034-0.JPG",
                "data/plant pots/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034-1.JPG",
                "data/plant pots/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034/sansevieria-potted-plant-with-pot-snake-plant-assorted-colours-30402034-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Temperature,Minimum temperature 15\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "46": {
            "id": 46,
            "prod_name": "VALLMOFR\u00d6N",
            "prod_price": "17",
            "prod_desc": "Plant pot, seagrass",
            "prod_dimensions": {
                "Height": "28 cm",
                "Outside diameter": "30 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "26 cm"
            },
            "packaging": [
                "VALLMOFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "804.737.31",
                "Length: 29 cm",
                "Weight: 0.68 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by skilled craftspeople, making each one unique. Lightweight, easy to lift and move. Decorate your home with plants combined with a plant pot to suit your style. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed. Only recommended for indoor use.",
            "sustainability": "By using a renewable material like sedge (or seagrass) in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/vallmofroen-plant-pot-seagrass-80473731/vallmofroen-plant-pot-seagrass-80473731-0.JPG",
                "data/plant pots/vallmofroen-plant-pot-seagrass-80473731/vallmofroen-plant-pot-seagrass-80473731-1.JPG",
                "data/plant pots/vallmofroen-plant-pot-seagrass-80473731/vallmofroen-plant-pot-seagrass-80473731-2.JPG"
            ],
            "materials": "Seagrass, PET plastic"
        },
        "47": {
            "id": 47,
            "prod_name": "BOYSENB\u00c4R",
            "prod_price": "2",
            "prod_desc": "Plant pot, in/outdoor triangle/gold-colour",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "BOYSENB\u00c4R",
                "Plant pot",
                "Article no.:",
                "704.825.90",
                "Length: 13 cm",
                "Weight: 0.96 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "This pot is made of concrete with natural air bubbles and variations in the finish that make each pot unique.   The pot has a soft pad underneath that protects the underlaying surface from scratches and moisture. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Available in different sizes. Available in different colours.",
            "sustainability": "To lower our environmental impact this product is offered without any packaging.",
            "images": [
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-0.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-1.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-2.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-3.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-4.JPG",
                "data/plant pots/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590/boysenbaer-plant-pot-in-outdoor-triangle-gold-colour-70482590-5.JPG"
            ],
            "materials": "Pot:,Concrete, Acrylic paint,Protection pad:,Polyethylene plastic,Wipe clean with a dry cloth."
        },
        "48": {
            "id": 48,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "5",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "22 cm",
                "Outside diameter": "24 cm",
                "Max. diameter flowerpot": "19 cm",
                "Inside diameter": "22 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "404.419.21",
                "Length: 22 cm",
                "Weight: 2.89 kg",
                "Diameter: 23 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-0.JPG",
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-1.JPG",
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-2.JPG",
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-3.JPG",
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-4.JPG",
                "data/plant pots/chiafroen-plant-pot-white-40441921/chiafroen-plant-pot-white-40441921-5.JPG"
            ],
            "materials": "Stoneware"
        },
        "49": {
            "id": 49,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, dark blue",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "404.217.01",
                "Length: 13 cm",
                "Weight: 0.58 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-dark-blue-40421701/papaja-plant-pot-dark-blue-40421701-0.JPG",
                "data/plant pots/papaja-plant-pot-dark-blue-40421701/papaja-plant-pot-dark-blue-40421701-1.JPG",
                "data/plant pots/papaja-plant-pot-dark-blue-40421701/papaja-plant-pot-dark-blue-40421701-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "50": {
            "id": 50,
            "prod_name": "CITRONSYRA",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor/white",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "CITRONSYRA",
                "Plant pot",
                "Article no.:",
                "603.873.86",
                "Length: 12 cm",
                "Weight: 0.30 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-0.JPG",
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-1.JPG",
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-2.JPG",
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-3.JPG",
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-4.JPG",
                "data/plant pots/citronsyra-plant-pot-in-outdoor-white-60387386/citronsyra-plant-pot-in-outdoor-white-60387386-5.JPG"
            ],
            "materials": "Steel, Enamel,Wipe clean with a damp cloth.,Handwash only."
        },
        "51": {
            "id": 51,
            "prod_name": "VANLIGEN",
            "prod_price": "2",
            "prod_desc": "Plant pot, green",
            "prod_dimensions": {
                "Height": "14 cm",
                "Outside diameter": "18 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "VANLIGEN",
                "Plant pot",
                "Article no.:",
                "904.518.42",
                "Length: 14 cm",
                "Weight: 1.13 kg",
                "Diameter: 18 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. To protect the surface from any risk of moisture damage, always use a saucer or put felt pads under the plant pot.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/vanligen-plant-pot-green-90451842/vanligen-plant-pot-green-90451842-0.JPG",
                "data/plant pots/vanligen-plant-pot-green-90451842/vanligen-plant-pot-green-90451842-1.JPG",
                "data/plant pots/vanligen-plant-pot-green-90451842/vanligen-plant-pot-green-90451842-2.JPG",
                "data/plant pots/vanligen-plant-pot-green-90451842/vanligen-plant-pot-green-90451842-3.JPG",
                "data/plant pots/vanligen-plant-pot-green-90451842/vanligen-plant-pot-green-90451842-4.JPG"
            ],
            "materials": "Stoneware, Coloured glaze,Wipe clean with a damp cloth.,Handwash only."
        },
        "52": {
            "id": 52,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "804.217.04",
                "Length: 13 cm",
                "Weight: 0.58 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-white-80421704/papaja-plant-pot-white-80421704-0.JPG",
                "data/plant pots/papaja-plant-pot-white-80421704/papaja-plant-pot-white-80421704-1.JPG",
                "data/plant pots/papaja-plant-pot-white-80421704/papaja-plant-pot-white-80421704-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "53": {
            "id": 53,
            "prod_name": "SUCCULENT",
            "prod_price": "3",
            "prod_desc": "Potted plant with pot, grey",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "7 cm"
            },
            "packaging": [
                "SUCCULENT",
                "Potted plant with pot",
                "Article no.:",
                "003.432.77",
                "Length: 14 cm",
                "Weight: 0.34 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to dry areas all over the world. Easy care plant. Ideal office plant. This plant is sensitive to cold water and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-0.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-1.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-2.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-3.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-4.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-5.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-00343277/succulent-potted-plant-with-pot-grey-00343277-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Pot:,Stoneware, Coloured glaze,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "54": {
            "id": 54,
            "prod_name": "KAKTUSFIKON",
            "prod_price": "4",
            "prod_desc": "Plant pot, rattan",
            "prod_dimensions": {
                "Max. diameter flowerpot": "12 cm",
                "Height": "15 cm",
                "Outside diameter": "17 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "KAKTUSFIKON",
                "Plant pot",
                "Article no.:",
                "504.548.85",
                "Length: 15 cm",
                "Weight: 0.14 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by skilled craftspeople, making each one unique. Rattan is a natural material which ages beautifully and gains its own unique character over time. Lightweight, easy to lift and move. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed. Rattan is a natural fibre that might change colour over time. Only for indoor use.",
            "sustainability": "By using a renewable material like rattan in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/kaktusfikon-plant-pot-rattan-50454885/kaktusfikon-plant-pot-rattan-50454885-0.JPG",
                "data/plant pots/kaktusfikon-plant-pot-rattan-50454885/kaktusfikon-plant-pot-rattan-50454885-1.JPG",
                "data/plant pots/kaktusfikon-plant-pot-rattan-50454885/kaktusfikon-plant-pot-rattan-50454885-2.JPG",
                "data/plant pots/kaktusfikon-plant-pot-rattan-50454885/kaktusfikon-plant-pot-rattan-50454885-3.JPG",
                "data/plant pots/kaktusfikon-plant-pot-rattan-50454885/kaktusfikon-plant-pot-rattan-50454885-4.JPG"
            ],
            "materials": "Plant pot/ Binding:,Rattan, Clear lacquer,Inner plant pot:,PET plastic"
        },
        "55": {
            "id": 55,
            "prod_name": "SPARRISKNOPP",
            "prod_price": "2",
            "prod_desc": "Plant pot, light blue",
            "prod_dimensions": {
                "Height": "16 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "SPARRISKNOPP",
                "Plant pot",
                "Article no.:",
                "004.419.23",
                "Length: 16 cm",
                "Weight: 1.08 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-0.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-1.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-2.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-3.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-4.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-5.JPG",
                "data/plant pots/sparrisknopp-plant-pot-light-blue-00441923/sparrisknopp-plant-pot-light-blue-00441923-6.JPG"
            ],
            "materials": "Stoneware"
        },
        "56": {
            "id": 56,
            "prod_name": "BINTJE",
            "prod_price": "0",
            "prod_desc": "Plant pot, galvanised",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "BINTJE",
                "Plant pot",
                "Article no.:",
                "803.341.27",
                "Length: 11 cm",
                "Weight: 0.09 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. Decorate your home with plants combined with a plant pot to suit your style. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-0.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-1.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-2.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-3.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-4.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-5.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-6.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-7.JPG",
                "data/plant pots/bintje-plant-pot-galvanised-80334127/bintje-plant-pot-galvanised-80334127-8.JPG"
            ],
            "materials": "Galvanized steel,Wipe clean with a damp cloth."
        },
        "57": {
            "id": 57,
            "prod_name": "DYPSIS LUTESCENS",
            "prod_price": "22",
            "prod_desc": "Potted plant, Areca palm",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "120 cm"
            },
            "packaging": [
                "DYPSIS LUTESCENS",
                "Potted plant",
                "Article no.:",
                "468.040.05",
                "Length: 150 cm",
                "Weight: 5.55 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Madagascar. Ideal office plant. Sensitive to draught.",
            "sustainability": "",
            "images": [
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-46804005/dypsis-lutescens-potted-plant-areca-palm-46804005-0.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-46804005/dypsis-lutescens-potted-plant-areca-palm-46804005-1.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-46804005/dypsis-lutescens-potted-plant-areca-palm-46804005-2.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-46804005/dypsis-lutescens-potted-plant-areca-palm-46804005-3.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-46804005/dypsis-lutescens-potted-plant-areca-palm-46804005-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 15\u00b0C.,Water,Water moderately."
        },
        "58": {
            "id": 58,
            "prod_name": "OMF\u00c5NG",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor dark red",
            "prod_dimensions": {
                "Height": "14 cm",
                "Outside diameter": "16 cm",
                "Max. diameter flowerpot": "15 cm",
                "Inside diameter": "15 cm"
            },
            "packaging": [
                "OMF\u00c5NG",
                "Plant pot",
                "Article no.:",
                "504.638.99",
                "Length: 15 cm",
                "Weight: 0.48 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-0.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-1.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-2.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-3.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-4.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-dark-red-50463899/omfang-plant-pot-in-outdoor-dark-red-50463899-5.JPG"
            ],
            "materials": "Steel, Polyester powder coating,Wipe clean with a damp cloth."
        },
        "59": {
            "id": 59,
            "prod_name": "CHAMAEDOREA ELEGANS",
            "prod_price": "1",
            "prod_desc": "Potted plant, Parlour palm",
            "prod_dimensions": {
                "Diameter of plant pot": "9 cm",
                "Height of plant": "20 cm"
            },
            "packaging": [
                "CHAMAEDOREA ELEGANS",
                "Potted plant",
                "Article no.:",
                "903.927.63",
                "Length: 37 cm",
                "Weight: 0.21 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Central America. Easy care plant. This plant is sensitive to over watering. This may be the cause if the leaves start to turn brown.",
            "sustainability": "",
            "images": [
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-0.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-1.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-2.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-3.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-4.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-5.JPG",
                "data/plant pots/chamaedorea-elegans-potted-plant-parlour-palm-90392763/chamaedorea-elegans-potted-plant-parlour-palm-90392763-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "60": {
            "id": 60,
            "prod_name": "SUCCULENT",
            "prod_price": "9",
            "prod_desc": "Potted plant with pot, pink",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "7 cm"
            },
            "packaging": [
                "SUCCULENT",
                "Potted plant with pot",
                "Article no.:",
                "203.432.76",
                "Length: 17 cm",
                "Weight: 1.54 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to dry areas all over the world. Easy care plant. Ideal office plant. This plant is sensitive to cold water and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/succulent-potted-plant-with-pot-pink-20343276/succulent-potted-plant-with-pot-pink-20343276-0.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-pink-20343276/succulent-potted-plant-with-pot-pink-20343276-1.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-pink-20343276/succulent-potted-plant-with-pot-pink-20343276-2.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-pink-20343276/succulent-potted-plant-with-pot-pink-20343276-3.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-pink-20343276/succulent-potted-plant-with-pot-pink-20343276-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Pot:,Stoneware, Coloured glaze,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "61": {
            "id": 61,
            "prod_name": "OMF\u00c5NG",
            "prod_price": "0",
            "prod_desc": "Plant pot, in/outdoor/pink",
            "prod_dimensions": {
                "Height": "9 cm",
                "Outside diameter": "10 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "9 cm"
            },
            "packaging": [
                "OMF\u00c5NG",
                "Plant pot",
                "Article no.:",
                "304.638.95",
                "Length: 9 cm",
                "Weight: 0.20 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-0.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-1.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-2.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-3.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-4.JPG",
                "data/plant pots/omfang-plant-pot-in-outdoor-pink-30463895/omfang-plant-pot-in-outdoor-pink-30463895-5.JPG"
            ],
            "materials": "Steel, Polyester powder coating,Wipe clean with a damp cloth."
        },
        "62": {
            "id": 62,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, white",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "004.216.99",
                "Length: 10 cm",
                "Weight: 0.30 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-white-00421699/papaja-plant-pot-white-00421699-0.JPG",
                "data/plant pots/papaja-plant-pot-white-00421699/papaja-plant-pot-white-00421699-1.JPG",
                "data/plant pots/papaja-plant-pot-white-00421699/papaja-plant-pot-white-00421699-2.JPG",
                "data/plant pots/papaja-plant-pot-white-00421699/papaja-plant-pot-white-00421699-3.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "63": {
            "id": 63,
            "prod_name": "CASHEW\u00c4PPLE",
            "prod_price": "2",
            "prod_desc": "Hanging planter, in/outdoor white",
            "prod_dimensions": {
                "Height": "12 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "12 cm",
                "Max. load": "2 kg",
                "Inside diameter": "13 cm"
            },
            "packaging": [
                "CASHEW\u00c4PPLE",
                "Hanging planter",
                "Article no.:",
                "804.683.53",
                "Length: 14 cm",
                "Weight: 0.21 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Can be used hanging or standing to fit in the space available. It\u2019s possible to plant directly into the planter, or to place potted plants inside. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered.",
            "sustainability": "",
            "images": [
                "data/plant pots/cashewaepple-hanging-planter-in-outdoor-white-80468353/cashewaepple-hanging-planter-in-outdoor-white-80468353-0.JPG",
                "data/plant pots/cashewaepple-hanging-planter-in-outdoor-white-80468353/cashewaepple-hanging-planter-in-outdoor-white-80468353-1.jpg",
                "data/plant pots/cashewaepple-hanging-planter-in-outdoor-white-80468353/cashewaepple-hanging-planter-in-outdoor-white-80468353-2.jpg"
            ],
            "materials": "Plant pot:,Galvanized steel, Polyester powder coating,Chain:,Steel, Galvanized,Wipe clean with a damp cloth."
        },
        "64": {
            "id": 64,
            "prod_name": "HEDERA HELIX",
            "prod_price": "3",
            "prod_desc": "Potted plant, Ivy",
            "prod_dimensions": {
                "Diameter of plant pot": "13 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "HEDERA HELIX",
                "Potted plant",
                "Article no.:",
                "668.040.47",
                "Length: 23 cm",
                "Weight: 0.60 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Europe. Climbing plant. Fast growing. Sensitive to draught. Wear gloves and protect your eyes when handling, as parts of the plant can cause a reaction.",
            "sustainability": "",
            "images": [
                "data/plant pots/hedera-helix-potted-plant-ivy-66804047/hedera-helix-potted-plant-ivy-66804047-0.JPG",
                "data/plant pots/hedera-helix-potted-plant-ivy-66804047/hedera-helix-potted-plant-ivy-66804047-1.JPG",
                "data/plant pots/hedera-helix-potted-plant-ivy-66804047/hedera-helix-potted-plant-ivy-66804047-2.JPG",
                "data/plant pots/hedera-helix-potted-plant-ivy-66804047/hedera-helix-potted-plant-ivy-66804047-3.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 0\u00b0C.,Water,Water moderately."
        },
        "65": {
            "id": 65,
            "prod_name": "PILEA PEPEROMIOIDES",
            "prod_price": "6",
            "prod_desc": "Potted plant, Pilea",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "20 cm"
            },
            "packaging": [
                "PILEA PEPEROMIOIDES",
                "Potted plant",
                "Article no.:",
                "804.607.76",
                "Length: 25 cm",
                "Weight: 0.44 kg",
                "Diameter: 32 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/pilea-peperomioides-potted-plant-pilea-80460776/pilea-peperomioides-potted-plant-pilea-80460776-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "66": {
            "id": 66,
            "prod_name": "MONSTERA",
            "prod_price": "15",
            "prod_desc": "Potted plant, Swiss cheese plant",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "65 cm"
            },
            "packaging": [
                "MONSTERA",
                "Potted plant",
                "Article no.:",
                "303.494.90",
                "Length: 85 cm",
                "Weight: 2.74 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. The plant can cause allergies or skin irritation if you are allergic or sensitive in other ways. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/monstera-potted-plant-swiss-cheese-plant-30349490/monstera-potted-plant-swiss-cheese-plant-30349490-0.JPG",
                "data/plant pots/monstera-potted-plant-swiss-cheese-plant-30349490/monstera-potted-plant-swiss-cheese-plant-30349490-1.JPG",
                "data/plant pots/monstera-potted-plant-swiss-cheese-plant-30349490/monstera-potted-plant-swiss-cheese-plant-30349490-2.JPG",
                "data/plant pots/monstera-potted-plant-swiss-cheese-plant-30349490/monstera-potted-plant-swiss-cheese-plant-30349490-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "67": {
            "id": 67,
            "prod_name": "RHIPSALIS",
            "prod_price": "8",
            "prod_desc": "Potted plant, Mistletoe cactus assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "22 cm"
            },
            "packaging": [
                "RHIPSALIS",
                "Potted plant",
                "Article no.:",
                "204.607.84",
                "Length: 34 cm",
                "Weight: 1.30 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South America. Sensitive to low temperatures.",
            "sustainability": "",
            "images": [
                "data/plant pots/rhipsalis-potted-plant-mistletoe-cactus-assorted-20460784/rhipsalis-potted-plant-mistletoe-cactus-assorted-20460784-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "68": {
            "id": 68,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, light pink",
            "prod_dimensions": {
                "Height": "9.5 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "9 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "203.313.39",
                "Length: 10 cm",
                "Weight: 0.30 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-light-pink-20331339/papaja-plant-pot-light-pink-20331339-0.JPG",
                "data/plant pots/papaja-plant-pot-light-pink-20331339/papaja-plant-pot-light-pink-20331339-1.JPG",
                "data/plant pots/papaja-plant-pot-light-pink-20331339/papaja-plant-pot-light-pink-20331339-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "69": {
            "id": 69,
            "prod_name": "SANSEVIERIA TRIFASCIATA",
            "prod_price": "7",
            "prod_desc": "Potted plant, Mother-in-law's tongue",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "SANSEVIERIA TRIFASCIATA",
                "Potted plant",
                "Article no.:",
                "004.210.29",
                "Length: 50 cm",
                "Weight: 1.19 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South Africa and Asia. Slow growing. Easy care plant. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant. Ideal office plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029-0.JPG",
                "data/plant pots/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029-1.JPG",
                "data/plant pots/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029/sansevieria-trifasciata-potted-plant-mother-in-laws-tongue-00421029-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "70": {
            "id": 70,
            "prod_name": "CACTACEAE",
            "prod_price": "4",
            "prod_desc": "Potted plant with pot, Cactus/assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "7 cm",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "CACTACEAE",
                "Potted plant with pot",
                "Article no.:",
                "704.020.32",
                "Width: 18 cm",
                "Height: 7 cm",
                "Length: 18 cm",
                "Weight: 0.81 kg",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Attention: prickly! Wear gloves and protect your eyes when handling, as the plant has thorns. Native to Mexico. Slow growing. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/cactaceae-potted-plant-with-pot-cactus-assorted-70402032/cactaceae-potted-plant-with-pot-cactus-assorted-70402032-0.JPG",
                "data/plant pots/cactaceae-potted-plant-with-pot-cactus-assorted-70402032/cactaceae-potted-plant-with-pot-cactus-assorted-70402032-1.JPG",
                "data/plant pots/cactaceae-potted-plant-with-pot-cactus-assorted-70402032/cactaceae-potted-plant-with-pot-cactus-assorted-70402032-2.JPG",
                "data/plant pots/cactaceae-potted-plant-with-pot-cactus-assorted-70402032/cactaceae-potted-plant-with-pot-cactus-assorted-70402032-3.JPG"
            ],
            "materials": "Basematerial:,Tempered glass,Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "71": {
            "id": 71,
            "prod_name": "HIMALAYAMIX",
            "prod_price": "4",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "15 cm"
            },
            "packaging": [
                "HIMALAYAMIX",
                "Potted plant",
                "Article no.:",
                "602.345.34",
                "Length: 18 cm",
                "Weight: 0.41 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Africa and America. Easy care plant. Sensitive to repotting.",
            "sustainability": "",
            "images": [
                "data/plant pots/himalayamix-potted-plant-assorted-60234534/himalayamix-potted-plant-assorted-60234534-0.JPG",
                "data/plant pots/himalayamix-potted-plant-assorted-60234534/himalayamix-potted-plant-assorted-60234534-1.JPG",
                "data/plant pots/himalayamix-potted-plant-assorted-60234534/himalayamix-potted-plant-assorted-60234534-2.JPG",
                "data/plant pots/himalayamix-potted-plant-assorted-60234534/himalayamix-potted-plant-assorted-60234534-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "72": {
            "id": 72,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, light blue",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "504.216.92",
                "Length: 13 cm",
                "Weight: 0.58 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-light-blue-50421692/papaja-plant-pot-light-blue-50421692-0.JPG",
                "data/plant pots/papaja-plant-pot-light-blue-50421692/papaja-plant-pot-light-blue-50421692-1.JPG",
                "data/plant pots/papaja-plant-pot-light-blue-50421692/papaja-plant-pot-light-blue-50421692-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "73": {
            "id": 73,
            "prod_name": "COROKIA",
            "prod_price": "6",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "13 cm",
                "Height of plant": "23 cm"
            },
            "packaging": [
                "COROKIA",
                "Potted plant",
                "Article no.:",
                "203.418.28",
                "Length: 43 cm",
                "Weight: 0.37 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to New Zealand. Suitable for both indoor and outdoor use. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-0.JPG",
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-1.JPG",
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-2.JPG",
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-3.JPG",
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-4.JPG",
                "data/plant pots/corokia-potted-plant-20341828/corokia-potted-plant-20341828-5.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature -14\u00b0C.,Water,Check moisture every day, soil must not get dry.,Water moderately.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight."
        },
        "74": {
            "id": 74,
            "prod_name": "SUCCULENT",
            "prod_price": "9",
            "prod_desc": "Potted plant with pot, grey",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "7 cm"
            },
            "packaging": [
                "SUCCULENT",
                "Potted plant with pot",
                "Article no.:",
                "403.432.75",
                "Length: 17 cm",
                "Weight: 1.35 kg",
                "Diameter: 20 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to dry areas all over the world. Easy care plant. Ideal office plant. This plant is sensitive to cold water and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/succulent-potted-plant-with-pot-grey-40343275/succulent-potted-plant-with-pot-grey-40343275-0.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-40343275/succulent-potted-plant-with-pot-grey-40343275-1.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-40343275/succulent-potted-plant-with-pot-grey-40343275-2.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-40343275/succulent-potted-plant-with-pot-grey-40343275-3.JPG",
                "data/plant pots/succulent-potted-plant-with-pot-grey-40343275/succulent-potted-plant-with-pot-grey-40343275-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Pot:,Stoneware, Coloured glaze,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "75": {
            "id": 75,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, green",
            "prod_dimensions": {
                "Height": "13 cm",
                "Outside diameter": "15 cm",
                "Max. diameter flowerpot": "12 cm",
                "Inside diameter": "14 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "504.216.87",
                "Length: 13 cm",
                "Weight: 0.58 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-green-50421687/papaja-plant-pot-green-50421687-0.JPG",
                "data/plant pots/papaja-plant-pot-green-50421687/papaja-plant-pot-green-50421687-1.JPG",
                "data/plant pots/papaja-plant-pot-green-50421687/papaja-plant-pot-green-50421687-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "76": {
            "id": 76,
            "prod_name": "NEPHROLEPIS",
            "prod_price": "8",
            "prod_desc": "Potted plant, fern",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "NEPHROLEPIS",
                "Potted plant",
                "Article no.:",
                "304.607.74",
                "Length: 41 cm",
                "Weight: 0.81 kg",
                "Diameter: 63 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/nephrolepis-potted-plant-fern-30460774/nephrolepis-potted-plant-fern-30460774-0.JPG",
                "data/plant pots/nephrolepis-potted-plant-fern-30460774/nephrolepis-potted-plant-fern-30460774-1.JPG",
                "data/plant pots/nephrolepis-potted-plant-fern-30460774/nephrolepis-potted-plant-fern-30460774-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 18\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "77": {
            "id": 77,
            "prod_name": "LAVANDULA",
            "prod_price": "3",
            "prod_desc": "Potted plant, Lavender",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "LAVANDULA",
                "Potted plant",
                "Article no.:",
                "303.154.09",
                "Length: 30 cm",
                "Weight: 0.75 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to western Mediterranean region. Perennial plant; lasts for 3 years or more. Scented flowers. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/lavandula-potted-plant-lavender-30315409/lavandula-potted-plant-lavender-30315409-0.JPG",
                "data/plant pots/lavandula-potted-plant-lavender-30315409/lavandula-potted-plant-lavender-30315409-1.JPG",
                "data/plant pots/lavandula-potted-plant-lavender-30315409/lavandula-potted-plant-lavender-30315409-2.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,For outdoor use.,Place in a bright and sunny area.,Temperature,Minimum temperature -5\u00b0C.,Water,Water moderately."
        },
        "78": {
            "id": 78,
            "prod_name": "DYPSIS LUTESCENS",
            "prod_price": "17",
            "prod_desc": "Potted plant, Areca palm",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "90 cm"
            },
            "packaging": [
                "DYPSIS LUTESCENS",
                "Potted plant",
                "Article no.:",
                "701.598.45",
                "Length: 112 cm",
                "Weight: 3.27 kg",
                "Diameter: 82 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to Madagascar. Ideal office plant. Sensitive to draught.",
            "sustainability": "",
            "images": [
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-70159845/dypsis-lutescens-potted-plant-areca-palm-70159845-0.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-70159845/dypsis-lutescens-potted-plant-areca-palm-70159845-1.JPG",
                "data/plant pots/dypsis-lutescens-potted-plant-areca-palm-70159845/dypsis-lutescens-potted-plant-areca-palm-70159845-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Water,Water moderately."
        },
        "79": {
            "id": 79,
            "prod_name": "ALOE VERA",
            "prod_price": "3",
            "prod_desc": "Potted plant, Aloe",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "ALOE VERA",
                "Potted plant",
                "Article no.:",
                "702.766.51",
                "Length: 40 cm",
                "Weight: 0.95 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South Africa. Easy care plant. Slow growing.",
            "sustainability": "",
            "images": [
                "data/plant pots/aloe-vera-potted-plant-aloe-70276651/aloe-vera-potted-plant-aloe-70276651-0.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-70276651/aloe-vera-potted-plant-aloe-70276651-1.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-70276651/aloe-vera-potted-plant-aloe-70276651-2.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-70276651/aloe-vera-potted-plant-aloe-70276651-3.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-70276651/aloe-vera-potted-plant-aloe-70276651-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Can withstand dry surroundings.,Minimum temperature 12\u00b0C.,Placement,Prefers warm surroundings.,For indoor use,Place in a bright and sunny area."
        },
        "80": {
            "id": 80,
            "prod_name": "ASKHOLMEN",
            "prod_price": "25",
            "prod_desc": "Flower box, light brown stained",
            "prod_dimensions": {
                "Length": "62 cm",
                "Width": "39 cm",
                "Height": "38 cm"
            },
            "packaging": [
                "ASKHOLMEN",
                "Flower box",
                "Article no.:",
                "302.586.73",
                "Width: 42 cm",
                "Height: 9 cm",
                "Length: 75 cm",
                "Weight: 7.70 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can place the shelf at the bottom of the flower box or higher up, depending on how you want to display your plants. For added durability and so you can enjoy the natural expression of the wood, the furniture has been pre-treated with a layer of semi-transparent wood stain. May be completed with ASKHOLMEN trellis. Use V\u00c5RDA wood stain, outdoor use when re-staining the furniture, sold separately. Only recommended for outdoor use.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.,By using a renewable material like wood in this product, we avoid using fossil or finite materials.,We want to have a positive impact on the planet. That is why by 2030, we want all materials in our products to be recycled or renewable, and sourced in responsible ways.",
            "images": [
                "data/plant pots/askholmen-flower-box-light-brown-stained-30258673/askholmen-flower-box-light-brown-stained-30258673-0.JPG",
                "data/plant pots/askholmen-flower-box-light-brown-stained-30258673/askholmen-flower-box-light-brown-stained-30258673-1.JPG",
                "data/plant pots/askholmen-flower-box-light-brown-stained-30258673/askholmen-flower-box-light-brown-stained-30258673-2.JPG",
                "data/plant pots/askholmen-flower-box-light-brown-stained-30258673/askholmen-flower-box-light-brown-stained-30258673-3.JPG",
                "data/plant pots/askholmen-flower-box-light-brown-stained-30258673/askholmen-flower-box-light-brown-stained-30258673-4.JPG"
            ],
            "materials": "Solid acacia, Acrylic stain,Clean: With a mild soapy solution. Wipe dry with a clean and dry cloth.,Maintenance: To prevent the surface from drying out and cracking and moisture from penetrating into the wood we recommend you to re-stain the furniture on a regular basis, for example once or twice a year."
        },
        "81": {
            "id": 81,
            "prod_name": "SUCCULENT",
            "prod_price": "2",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "9 cm",
                "Height of plant": "15 cm"
            },
            "packaging": [
                "SUCCULENT",
                "Potted plant",
                "Article no.:",
                "103.110.06",
                "Length: 16 cm",
                "Weight: 0.24 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to dry areas all over the world. Easy care plant. Ideal office plant. This plant is sensitive to cold water and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-0.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-1.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-2.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-3.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-4.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-5.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-6.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-7.JPG",
                "data/plant pots/succulent-potted-plant-assorted-10311006/succulent-potted-plant-assorted-10311006-8.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a bright and sunny area.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "82": {
            "id": 82,
            "prod_name": "LANTLIV",
            "prod_price": "40",
            "prod_desc": "Plant stand, white",
            "prod_dimensions": {
                "Length": "74 cm",
                "Width": "32 cm",
                "Height": "68 cm",
                "Max. load": "100 kg"
            },
            "packaging": [
                "LANTLIV",
                "Plant stand",
                "Article no.:",
                "701.861.13",
                "Width: 33 cm",
                "Height: 12 cm",
                "Length: 77 cm",
                "Weight: 7.32 kg",
                "Package(s): 1"
            ],
            "prod_details": "A plant stand makes it possible to decorate with plants everywhere in the home. For several plants in a row, which also makes it suitable to use as a room divider.",
            "sustainability": "Renewable material (wood).",
            "images": [
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-0.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-1.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-2.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-3.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-4.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-5.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-6.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-7.JPG",
                "data/plant pots/lantliv-plant-stand-white-70186113/lantliv-plant-stand-white-70186113-8.JPG"
            ],
            "materials": "Rail:,Solid beech or birch, Paint,Shelf:,Fibreboard, Acrylic paint,Wipe clean with a damp cloth."
        },
        "83": {
            "id": 83,
            "prod_name": "CALATHEA",
            "prod_price": "9",
            "prod_desc": "Potted plant, Calathea/assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "85 cm"
            },
            "packaging": [
                "CALATHEA",
                "Potted plant",
                "Article no.:",
                "102.588.29",
                "Length: 75 cm",
                "Weight: 2.08 kg",
                "Diameter: 24 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Brazil. Slow growing. Sensitive to draught. This plant is sensitive to temperature changes.",
            "sustainability": "",
            "images": [
                "data/plant pots/calathea-potted-plant-calathea-assorted-10258829/calathea-potted-plant-calathea-assorted-10258829-0.JPG",
                "data/plant pots/calathea-potted-plant-calathea-assorted-10258829/calathea-potted-plant-calathea-assorted-10258829-1.JPG",
                "data/plant pots/calathea-potted-plant-calathea-assorted-10258829/calathea-potted-plant-calathea-assorted-10258829-2.JPG",
                "data/plant pots/calathea-potted-plant-calathea-assorted-10258829/calathea-potted-plant-calathea-assorted-10258829-3.JPG",
                "data/plant pots/calathea-potted-plant-calathea-assorted-10258829/calathea-potted-plant-calathea-assorted-10258829-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "84": {
            "id": 84,
            "prod_name": "VINTER 2020",
            "prod_price": "0",
            "prod_desc": "Plant pot, red",
            "prod_dimensions": {
                "Height": "9 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "VINTER 2020",
                "Plant pot",
                "Article no.:",
                "504.663.79",
                "Length: 10 cm",
                "Weight: 0.11 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/vinter-2020-plant-pot-red-50466379/vinter-2020-plant-pot-red-50466379-0.JPG"
            ],
            "materials": "Galvanized steel, Powder coating,Wipe clean with a damp cloth."
        },
        "85": {
            "id": 85,
            "prod_name": "DRACAENA MARGINATA",
            "prod_price": "10",
            "prod_desc": "Potted plant, Dragon tree/2-stem",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "120 cm"
            },
            "packaging": [
                "DRACAENA MARGINATA",
                "Potted plant",
                "Article no.:",
                "404.084.55",
                "Length: 136 cm",
                "Weight: 2.67 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Do not lift the plant by the stem. Easy care plant. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455-0.JPG",
                "data/plant pots/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455-1.JPG",
                "data/plant pots/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455-2.JPG",
                "data/plant pots/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455-3.JPG",
                "data/plant pots/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455/dracaena-marginata-potted-plant-dragon-tree-2-stem-40408455-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "86": {
            "id": 86,
            "prod_name": "DRACAENA",
            "prod_price": "1",
            "prod_desc": "Plant, Lucky bamboo/spiral",
            "prod_dimensions": {
                "Height": "45 cm"
            },
            "packaging": [
                "DRACAENA",
                "Plant",
                "Article no.:",
                "500.645.89",
                "Length: 54 cm",
                "Weight: 1.00 kg",
                "Diameter: 5 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to West and Central Africa. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-plant-lucky-bamboo-spiral-50064589/dracaena-plant-lucky-bamboo-spiral-50064589-0.JPG",
                "data/plant pots/dracaena-plant-lucky-bamboo-spiral-50064589/dracaena-plant-lucky-bamboo-spiral-50064589-1.JPG",
                "data/plant pots/dracaena-plant-lucky-bamboo-spiral-50064589/dracaena-plant-lucky-bamboo-spiral-50064589-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Keep the roots in water.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Remove plastic tube before placing the flower in a vase with 5 cm fresh water, change water every second week.,Only for decoration, not suitable for consumption."
        },
        "87": {
            "id": 87,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, blue",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "304.217.06",
                "Length: 10 cm",
                "Weight: 0.30 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-blue-30421706/papaja-plant-pot-blue-30421706-0.JPG",
                "data/plant pots/papaja-plant-pot-blue-30421706/papaja-plant-pot-blue-30421706-1.JPG",
                "data/plant pots/papaja-plant-pot-blue-30421706/papaja-plant-pot-blue-30421706-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "88": {
            "id": 88,
            "prod_name": "MUSA BANANA",
            "prod_price": "9",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "95 cm"
            },
            "packaging": [
                "MUSA BANANA",
                "Potted plant",
                "Article no.:",
                "900.963.62",
                "Length: 110 cm",
                "Weight: 3.01 kg",
                "Diameter: 39 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South East Asia. Easy care plant. Fast growing. This plant is sensitive to low humidity. This means that there is a risk of leaves with brown edges if the air is too dry. Sensitive to repotting.",
            "sustainability": "",
            "images": [
                "data/plant pots/musa-banana-potted-plant-90096362/musa-banana-potted-plant-90096362-0.JPG",
                "data/plant pots/musa-banana-potted-plant-90096362/musa-banana-potted-plant-90096362-1.JPG",
                "data/plant pots/musa-banana-potted-plant-90096362/musa-banana-potted-plant-90096362-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Placement,For indoor use,Place in a bright and sunny area.,Temperature,Minimum temperature 15\u00b0C."
        },
        "89": {
            "id": 89,
            "prod_name": "FICUS",
            "prod_price": "29",
            "prod_desc": "Potted plant with pot, bonsai/twisted assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "22 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "FICUS",
                "Potted plant with pot",
                "Article no.:",
                "204.800.70",
                "Length: 67 cm",
                "Weight: 3.23 kg",
                "Diameter: 41 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-twisted-assorted-colours-20480070/ficus-potted-plant-with-pot-bonsai-twisted-assorted-colours-20480070-0.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-twisted-assorted-colours-20480070/ficus-potted-plant-with-pot-bonsai-twisted-assorted-colours-20480070-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Main parts:,Earthenware, Pigmented powder coating,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "90": {
            "id": 90,
            "prod_name": "DRACAENA FRAGRANS 'COMPACTA'",
            "prod_price": "1",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "9 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "DRACAENA FRAGRANS 'COMPACTA'",
                "Potted plant",
                "Article no.:",
                "605.045.35",
                "Length: 21 cm",
                "Weight: 0.23 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-fragrans-compacta-potted-plant-60504535/dracaena-fragrans-compacta-potted-plant-60504535-0.jpg"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "91": {
            "id": 91,
            "prod_name": "ALOCASIA AMAZONICA",
            "prod_price": "7",
            "prod_desc": "Potted plant, Elephant ear",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "50 cm"
            },
            "packaging": [
                "ALOCASIA AMAZONICA",
                "Potted plant",
                "Article no.:",
                "903.494.87",
                "Length: 60 cm",
                "Weight: 1.61 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South East Asia. Sensitive to low temperatures. This plant will dry out if placed too close to a heat source such as a radiator.",
            "sustainability": "",
            "images": [
                "data/plant pots/alocasia-amazonica-potted-plant-elephant-ear-90349487/alocasia-amazonica-potted-plant-elephant-ear-90349487-0.JPG",
                "data/plant pots/alocasia-amazonica-potted-plant-elephant-ear-90349487/alocasia-amazonica-potted-plant-elephant-ear-90349487-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "92": {
            "id": 92,
            "prod_name": "PAPAJA",
            "prod_price": "1",
            "prod_desc": "Plant pot, red",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "PAPAJA",
                "Plant pot",
                "Article no.:",
                "304.216.93",
                "Length: 10 cm",
                "Weight: 0.30 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "Lacquered interior; makes the plant pot waterproof.",
            "sustainability": "",
            "images": [
                "data/plant pots/papaja-plant-pot-red-30421693/papaja-plant-pot-red-30421693-0.JPG",
                "data/plant pots/papaja-plant-pot-red-30421693/papaja-plant-pot-red-30421693-1.JPG",
                "data/plant pots/papaja-plant-pot-red-30421693/papaja-plant-pot-red-30421693-2.JPG"
            ],
            "materials": "Earthenware, Pigmented powder coating,Wipe clean with a damp cloth."
        },
        "93": {
            "id": 93,
            "prod_name": "SPATHIPHYLLUM",
            "prod_price": "2",
            "prod_desc": "Potted plant, Peace lily",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "45 cm"
            },
            "packaging": [
                "SPATHIPHYLLUM",
                "Potted plant",
                "Article no.:",
                "601.449.01",
                "Length: 42 cm",
                "Weight: 0.92 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Colombia and Venezuela. Easy care plant. This plant will dry out if placed too close to a heat source such as a radiator.",
            "sustainability": "",
            "images": [
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-0.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-1.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-2.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-3.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-4.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-60144901/spathiphyllum-potted-plant-peace-lily-60144901-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 15\u00b0C.,Water,Water often."
        },
        "94": {
            "id": 94,
            "prod_name": "PACHIRA AQUATICA",
            "prod_price": "35",
            "prod_desc": "Potted plant, Guinea chestnut",
            "prod_dimensions": {
                "Diameter of plant pot": "27 cm",
                "Height of plant": "150 cm"
            },
            "packaging": [
                "PACHIRA AQUATICA",
                "Potted plant",
                "Article no.:",
                "001.185.23",
                "Length: 183 cm",
                "Weight: 6.38 kg",
                "Diameter: 34 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Do not lift the plant by the stem. Native to Mexico. Easy care plant. Ideal office plant. Fast growing. This plant is sensitive to over watering. If it gets too much water there is a risk of stem and root rot, and that the leaves turn yellow and fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-0.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-1.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-2.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-3.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-4.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-00118523/pachira-aquatica-potted-plant-guinea-chestnut-00118523-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a bright and sunny area.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "95": {
            "id": 95,
            "prod_name": "PEPEROMIA POLYBOTRYA",
            "prod_price": "4",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "23 cm"
            },
            "packaging": [
                "PEPEROMIA POLYBOTRYA",
                "Potted plant",
                "Article no.:",
                "504.085.44",
                "Length: 24 cm",
                "Weight: 0.58 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-0.JPG",
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-1.JPG",
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-2.JPG",
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-3.JPG",
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-4.JPG",
                "data/plant pots/peperomia-polybotrya-potted-plant-50408544/peperomia-polybotrya-potted-plant-50408544-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "96": {
            "id": 96,
            "prod_name": "STRELITZIA",
            "prod_price": "45",
            "prod_desc": "Potted plant, Bird of paradise",
            "prod_dimensions": {
                "Diameter of plant pot": "27 cm",
                "Height of plant": "140 cm"
            },
            "packaging": [
                "STRELITZIA",
                "Potted plant",
                "Article no.:",
                "204.662.53",
                "Length: 151 cm",
                "Weight: 9.10 kg",
                "Diameter: 63 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South Africa. Easy care plant. Sensitive to low temperatures.",
            "sustainability": "",
            "images": [
                "data/plant pots/strelitzia-potted-plant-bird-of-paradise-20466253/strelitzia-potted-plant-bird-of-paradise-20466253-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "97": {
            "id": 97,
            "prod_name": "YUCCA ELEPHANTIPES",
            "prod_price": "22",
            "prod_desc": "Potted plant, Spineless yucca/2-stem",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "135 cm"
            },
            "packaging": [
                "YUCCA ELEPHANTIPES",
                "Potted plant",
                "Article no.:",
                "103.293.08",
                "Length: 150 cm",
                "Weight: 8.40 kg",
                "Diameter: 60 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Central and South America. Easy care plant. Ideal office plant. Slow growing. Do not lift the plant by the stem.",
            "sustainability": "",
            "images": [
                "data/plant pots/yucca-elephantipes-potted-plant-spineless-yucca-2-stem-10329308/yucca-elephantipes-potted-plant-spineless-yucca-2-stem-10329308-0.JPG",
                "data/plant pots/yucca-elephantipes-potted-plant-spineless-yucca-2-stem-10329308/yucca-elephantipes-potted-plant-spineless-yucca-2-stem-10329308-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 0\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "98": {
            "id": 98,
            "prod_name": "FICUS BENJAMINA",
            "prod_price": "29",
            "prod_desc": "Potted plant, weeping fig assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "90 cm"
            },
            "packaging": [
                "FICUS BENJAMINA",
                "Potted plant",
                "Article no.:",
                "804.488.45",
                "Length: 106 cm",
                "Weight: 5.33 kg",
                "Diameter: 61 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-80448845/ficus-benjamina-potted-plant-weeping-fig-assorted-80448845-0.JPG",
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-80448845/ficus-benjamina-potted-plant-weeping-fig-assorted-80448845-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 15\u00b0C.,Others,Only for decoration, not suitable for consumption."
        },
        "99": {
            "id": 99,
            "prod_name": "DRACAENA MASSANGEANA",
            "prod_price": "22",
            "prod_desc": "Potted plant, Dom plant/2-stem",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "130 cm"
            },
            "packaging": [
                "DRACAENA MASSANGEANA",
                "Potted plant",
                "Article no.:",
                "704.084.68",
                "Length: 150 cm",
                "Weight: 8.00 kg",
                "Diameter: 44 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Do not lift the plant by the stem.",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468-0.JPG",
                "data/plant pots/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468-1.JPG",
                "data/plant pots/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468/dracaena-massangeana-potted-plant-dom-plant-2-stem-70408468-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Do not place in draughty area.,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 15\u00b0C.,Water,Water moderately."
        },
        "100": {
            "id": 100,
            "prod_name": "CACTACEAE",
            "prod_price": "4",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "20 cm"
            },
            "packaging": [
                "CACTACEAE",
                "Potted plant",
                "Article no.:",
                "003.109.60",
                "Length: 27 cm",
                "Weight: 0.80 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Attention: prickly! Wear gloves and protect your eyes when handling, as the plant has thorns. Native to Mexico. Slow growing. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-0.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-1.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-2.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-3.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-4.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-5.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-6.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-00310960/cactaceae-potted-plant-assorted-00310960-7.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "101": {
            "id": 101,
            "prod_name": "STOLLIG",
            "prod_price": "3",
            "prod_desc": "Potted plant with pot, Kalanchoe",
            "prod_dimensions": {
                "Length of plant pot": "12 cm",
                "Width of plant pot": "12 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "STOLLIG",
                "Potted plant with pot",
                "Article no.:",
                "501.598.65",
                "Length: 32 cm",
                "Weight: 0.80 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Easy care plant. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant. Ideal office plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/stollig-potted-plant-with-pot-kalanchoe-50159865/stollig-potted-plant-with-pot-kalanchoe-50159865-0.JPG",
                "data/plant pots/stollig-potted-plant-with-pot-kalanchoe-50159865/stollig-potted-plant-with-pot-kalanchoe-50159865-1.JPG",
                "data/plant pots/stollig-potted-plant-with-pot-kalanchoe-50159865/stollig-potted-plant-with-pot-kalanchoe-50159865-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "102": {
            "id": 102,
            "prod_name": "ZAMIOCULCAS",
            "prod_price": "15",
            "prod_desc": "Potted plant, Aroid palm",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "75 cm"
            },
            "packaging": [
                "ZAMIOCULCAS",
                "Potted plant",
                "Article no.:",
                "602.170.11",
                "Length: 77 cm",
                "Weight: 2.91 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to East Africa. Slow growing. Easy care plant. Ideal office plant. This plant is sensitive to over watering. This may be the cause if the leaves start to turn yellow. The plant can cause allergies or skin irritation if you are allergic or sensitive in other ways.",
            "sustainability": "",
            "images": [
                "data/plant pots/zamioculcas-potted-plant-aroid-palm-60217011/zamioculcas-potted-plant-aroid-palm-60217011-0.JPG",
                "data/plant pots/zamioculcas-potted-plant-aroid-palm-60217011/zamioculcas-potted-plant-aroid-palm-60217011-1.JPG",
                "data/plant pots/zamioculcas-potted-plant-aroid-palm-60217011/zamioculcas-potted-plant-aroid-palm-60217011-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use"
        },
        "103": {
            "id": 103,
            "prod_name": "STRELITZIA",
            "prod_price": "19",
            "prod_desc": "Potted plant, Bird of paradise",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "90 cm"
            },
            "packaging": [
                "STRELITZIA",
                "Potted plant",
                "Article no.:",
                "104.267.19",
                "Length: 105 cm",
                "Weight: 2.38 kg",
                "Diameter: 56 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South Africa. Easy care plant. Sensitive to low temperatures.",
            "sustainability": "",
            "images": [
                "data/plant pots/strelitzia-potted-plant-bird-of-paradise-10426719/strelitzia-potted-plant-bird-of-paradise-10426719-0.JPG",
                "data/plant pots/strelitzia-potted-plant-bird-of-paradise-10426719/strelitzia-potted-plant-bird-of-paradise-10426719-1.JPG",
                "data/plant pots/strelitzia-potted-plant-bird-of-paradise-10426719/strelitzia-potted-plant-bird-of-paradise-10426719-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "104": {
            "id": 104,
            "prod_name": "CAMPANULA PORTENSCHLAGIANA",
            "prod_price": "5",
            "prod_desc": "Potted plant, Bell flower",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "CAMPANULA PORTENSCHLAGIANA",
                "Potted plant",
                "Article no.:",
                "404.607.78",
                "Length: 26 cm",
                "Weight: 0.35 kg",
                "Diameter: 23 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Fast growing. Perennial plant; lasts for 3 years or more. Creeping plant; can also climb if supported. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-40460778/campanula-portenschlagiana-potted-plant-bell-flower-40460778-0.JPG",
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-40460778/campanula-portenschlagiana-potted-plant-bell-flower-40460778-1.JPG"
            ],
            "materials": "Cultivated potted plant,Water,Water moderately.,Temperature,Minimum temperature 5\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "105": {
            "id": 105,
            "prod_name": "PACHIRA AQUATICA",
            "prod_price": "5",
            "prod_desc": "Potted plant, Guinea chestnut",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "45 cm"
            },
            "packaging": [
                "PACHIRA AQUATICA",
                "Potted plant",
                "Article no.:",
                "604.607.77",
                "Length: 44 cm",
                "Weight: 0.68 kg",
                "Diameter: 32 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Mexico. Easy care plant. Ideal office plant. Fast growing. This plant is sensitive to over watering. If it gets too much water there is a risk of stem and root rot, and that the leaves turn yellow and fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-60460777/pachira-aquatica-potted-plant-guinea-chestnut-60460777-0.JPG",
                "data/plant pots/pachira-aquatica-potted-plant-guinea-chestnut-60460777/pachira-aquatica-potted-plant-guinea-chestnut-60460777-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly.,Placement,For indoor use,Place in a bright and sunny area.,Others,Only for decoration, not suitable for consumption."
        },
        "106": {
            "id": 106,
            "prod_name": "KALANCHOE",
            "prod_price": "1",
            "prod_desc": "Potted plant with pot, Kalanchoe assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "11 cm"
            },
            "packaging": [
                "KALANCHOE",
                "Potted plant with pot",
                "Article no.:",
                "504.020.33",
                "Length: 18 cm",
                "Weight: 0.21 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia and Africa. Slow growing. This plant is sensitive to over watering. If it gets too much water there is a risk of root rot and that the leaves turn soft. This plant is sensitive to under watering. This may be the cause if the plant starts to wilt. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033-0.JPG",
                "data/plant pots/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033-1.JPG",
                "data/plant pots/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033-2.JPG",
                "data/plant pots/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033/kalanchoe-potted-plant-with-pot-kalanchoe-assorted-colours-50402033-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "107": {
            "id": 107,
            "prod_name": "DRACAENA BURLEY",
            "prod_price": "22",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "80 cm"
            },
            "packaging": [
                "DRACAENA BURLEY",
                "Potted plant",
                "Article no.:",
                "702.170.39",
                "Length: 84 cm",
                "Weight: 3.99 kg",
                "Diameter: 34 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Ideal office plant. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-0.JPG",
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-1.JPG",
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-2.JPG",
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-3.JPG",
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-4.JPG",
                "data/plant pots/dracaena-burley-potted-plant-70217039/dracaena-burley-potted-plant-70217039-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "108": {
            "id": 108,
            "prod_name": "GR\u00d6NSKAN",
            "prod_price": "7",
            "prod_desc": "Potted plant, carnivorous/assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "20 cm"
            },
            "packaging": [
                "GR\u00d6NSKAN",
                "Potted plant",
                "Article no.:",
                "302.453.79",
                "Length: 14 cm",
                "Weight: 0.24 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style.",
            "sustainability": "",
            "images": [
                "data/plant pots/groenskan-potted-plant-carnivorous-assorted-30245379/groenskan-potted-plant-carnivorous-assorted-30245379-0.JPG",
                "data/plant pots/groenskan-potted-plant-carnivorous-assorted-30245379/groenskan-potted-plant-carnivorous-assorted-30245379-1.JPG",
                "data/plant pots/groenskan-potted-plant-carnivorous-assorted-30245379/groenskan-potted-plant-carnivorous-assorted-30245379-2.JPG",
                "data/plant pots/groenskan-potted-plant-carnivorous-assorted-30245379/groenskan-potted-plant-carnivorous-assorted-30245379-3.JPG",
                "data/plant pots/groenskan-potted-plant-carnivorous-assorted-30245379/groenskan-potted-plant-carnivorous-assorted-30245379-4.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature -5\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a bright and sunny area.,Water,Water often."
        },
        "109": {
            "id": 109,
            "prod_name": "HOWEA FORSTERIANA",
            "prod_price": "40",
            "prod_desc": "Potted plant, Kentia palm",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "190 cm"
            },
            "packaging": [
                "HOWEA FORSTERIANA",
                "Potted plant",
                "Article no.:",
                "700.380.09",
                "Length: 197 cm",
                "Weight: 5.94 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Do not lift the plant by the stem. Native to Australian Lord Howe Island. Ideal office plant. Slow growing. Sensitive to draught. It is natural for the lower leaves to turn brown and dry out. Sensitive to low temperatures. This plant is sensitive to over watering. This may be the cause if the leaves start to turn brown. Sensitive to touch. Sensitive to repotting.",
            "sustainability": "",
            "images": [
                "data/plant pots/howea-forsteriana-potted-plant-kentia-palm-70038009/howea-forsteriana-potted-plant-kentia-palm-70038009-0.JPG",
                "data/plant pots/howea-forsteriana-potted-plant-kentia-palm-70038009/howea-forsteriana-potted-plant-kentia-palm-70038009-1.JPG",
                "data/plant pots/howea-forsteriana-potted-plant-kentia-palm-70038009/howea-forsteriana-potted-plant-kentia-palm-70038009-2.JPG",
                "data/plant pots/howea-forsteriana-potted-plant-kentia-palm-70038009/howea-forsteriana-potted-plant-kentia-palm-70038009-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately."
        },
        "110": {
            "id": 110,
            "prod_name": "CLUSIA",
            "prod_price": "3",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "CLUSIA",
                "Potted plant",
                "Article no.:",
                "702.345.62",
                "Length: 34 cm",
                "Weight: 0.48 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South America. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-0.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-1.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-2.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-3.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-4.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-5.JPG",
                "data/plant pots/clusia-potted-plant-70234562/clusia-potted-plant-70234562-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "111": {
            "id": 111,
            "prod_name": "CODIAEUM",
            "prod_price": "15",
            "prod_desc": "Potted plant, Croton",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "55 cm"
            },
            "packaging": [
                "CODIAEUM",
                "Potted plant",
                "Article no.:",
                "904.085.56",
                "Length: 59 cm",
                "Weight: 1.48 kg",
                "Diameter: 31 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Indonesia, Polynesia and Malaysia. Sensitive to draught. This plant will dry out if placed too close to a heat source such as a radiator. Easy care plant. This plant is sensitive to under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/codiaeum-potted-plant-croton-90408556/codiaeum-potted-plant-croton-90408556-0.JPG",
                "data/plant pots/codiaeum-potted-plant-croton-90408556/codiaeum-potted-plant-croton-90408556-1.JPG",
                "data/plant pots/codiaeum-potted-plant-croton-90408556/codiaeum-potted-plant-croton-90408556-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "112": {
            "id": 112,
            "prod_name": "ASPLENIUM 'CRISPY WAVE'",
            "prod_price": "5",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "ASPLENIUM 'CRISPY WAVE'",
                "Potted plant",
                "Article no.:",
                "004.607.80",
                "Length: 32 cm",
                "Weight: 0.41 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/asplenium-crispy-wave-potted-plant-00460780/asplenium-crispy-wave-potted-plant-00460780-0.JPG",
                "data/plant pots/asplenium-crispy-wave-potted-plant-00460780/asplenium-crispy-wave-potted-plant-00460780-1.JPG",
                "data/plant pots/asplenium-crispy-wave-potted-plant-00460780/asplenium-crispy-wave-potted-plant-00460780-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "113": {
            "id": 113,
            "prod_name": "EUPHORBIA ACRURENSIS",
            "prod_price": "45",
            "prod_desc": "Potted plant",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "85 cm"
            },
            "packaging": [
                "EUPHORBIA ACRURENSIS",
                "Potted plant",
                "Article no.:",
                "401.448.84",
                "Length: 96 cm",
                "Weight: 4.45 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant can cause allergies or skin irritation if you are allergic or sensitive in other ways.",
            "sustainability": "",
            "images": [
                "data/plant pots/euphorbia-acrurensis-potted-plant-40144884/euphorbia-acrurensis-potted-plant-40144884-0.JPG",
                "data/plant pots/euphorbia-acrurensis-potted-plant-40144884/euphorbia-acrurensis-potted-plant-40144884-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "114": {
            "id": 114,
            "prod_name": "FICUS",
            "prod_price": "12",
            "prod_desc": "Potted plant with pot, bonsai/assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "FICUS",
                "Potted plant with pot",
                "Article no.:",
                "404.327.28",
                "Length: 36 cm",
                "Weight: 1.41 kg",
                "Diameter: 22 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to South East Africa. Slow growing. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728-0.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728-1.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728/ficus-potted-plant-with-pot-bonsai-assorted-colours-40432728-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Main parts:,Earthenware, Pigmented powder coating,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "115": {
            "id": 115,
            "prod_name": "PHLEBODIUM AUREUM",
            "prod_price": "5",
            "prod_desc": "Potted plant, Hare-foot fern",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "38 cm"
            },
            "packaging": [
                "PHLEBODIUM AUREUM",
                "Potted plant",
                "Article no.:",
                "604.607.82",
                "Length: 44 cm",
                "Weight: 0.63 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/phlebodium-aureum-potted-plant-hare-foot-fern-60460782/phlebodium-aureum-potted-plant-hare-foot-fern-60460782-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "116": {
            "id": 116,
            "prod_name": "FICUS ELASTICA",
            "prod_price": "12",
            "prod_desc": "Potted plant, stem",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "55 cm"
            },
            "packaging": [
                "FICUS ELASTICA",
                "Potted plant",
                "Article no.:",
                "201.598.62",
                "Length: 68 cm",
                "Weight: 2.48 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Easy care plant. Ideal office plant. Slow growing. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off. This plant is sensitive to over and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-elastica-potted-plant-stem-20159862/ficus-elastica-potted-plant-stem-20159862-0.JPG",
                "data/plant pots/ficus-elastica-potted-plant-stem-20159862/ficus-elastica-potted-plant-stem-20159862-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Water,Water moderately."
        },
        "117": {
            "id": 117,
            "prod_name": "ALOE ARBORESCENS",
            "prod_price": "12",
            "prod_desc": "Potted plant, Candelabra Aloe",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "ALOE ARBORESCENS",
                "Potted plant",
                "Article no.:",
                "603.507.50",
                "Length: 39 cm",
                "Weight: 2.22 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style.",
            "sustainability": "",
            "images": [
                "data/plant pots/aloe-arborescens-potted-plant-candelabra-aloe-60350750/aloe-arborescens-potted-plant-candelabra-aloe-60350750-0.JPG",
                "data/plant pots/aloe-arborescens-potted-plant-candelabra-aloe-60350750/aloe-arborescens-potted-plant-candelabra-aloe-60350750-1.JPG",
                "data/plant pots/aloe-arborescens-potted-plant-candelabra-aloe-60350750/aloe-arborescens-potted-plant-candelabra-aloe-60350750-2.JPG",
                "data/plant pots/aloe-arborescens-potted-plant-candelabra-aloe-60350750/aloe-arborescens-potted-plant-candelabra-aloe-60350750-3.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,Suitable for in- and outdoor use.,Place in a bright and sunny area.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C."
        },
        "118": {
            "id": 118,
            "prod_name": "ASKHOLMEN",
            "prod_price": "43",
            "prod_desc": "Flower box w trellis, outdoor, grey-brown stained",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 2 packages.",
                "ASKHOLMEN",
                "Flower box",
                "Article no.:",
                "302.586.73",
                "Width: 42 cm",
                "Height: 9 cm",
                "Length: 75 cm",
                "Weight: 7.70 kg",
                "Package(s): 1",
                "ASKHOLMEN",
                "Trellis",
                "Article no.:",
                "702.586.71",
                "Width: 35 cm",
                "Height: 3 cm",
                "Length: 100 cm",
                "Weight: 4.54 kg",
                "Package(s): 1"
            ],
            "prod_details": "Only recommended for outdoor use. Use V\u00c5RDA wood stain, outdoor use when re-staining the furniture, sold separately.",
            "sustainability": "Flower box/trellis,Product is possible to recycle or use for energy recovery, if available in your community.,By using a renewable material like wood in this product, we avoid using fossil or finite materials.,We want to have a positive impact on the planet. That is why by 2030, we want all materials in our products to be recycled or renewable, and sourced in responsible ways.",
            "images": [
                "data/plant pots/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925-0.JPG",
                "data/plant pots/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925-1.JPG",
                "data/plant pots/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925/askholmen-flower-box-w-trellis-outdoor-grey-brown-stained-s59053925-2.JPG"
            ],
            "materials": "Solid acacia, Acrylic stain"
        },
        "119": {
            "id": 119,
            "prod_name": "SANSEVIERIA",
            "prod_price": "6",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "SANSEVIERIA",
                "Potted plant",
                "Article no.:",
                "003.116.05",
                "Length: 42 cm",
                "Weight: 1.18 kg",
                "Diameter: 18 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Ethiopia. Easy care plant. This plant is sensitive to over watering. If it gets too much water there is a risk of root rot.",
            "sustainability": "",
            "images": [
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-0.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-1.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-2.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-3.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-4.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-5.JPG",
                "data/plant pots/sansevieria-potted-plant-assorted-00311605/sansevieria-potted-plant-assorted-00311605-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Temperature,Minimum temperature 15\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "120": {
            "id": 120,
            "prod_name": "FICUS BENGHALENSIS",
            "prod_price": "35",
            "prod_desc": "Potted plant, banyan",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "95 cm"
            },
            "packaging": [
                "FICUS BENGHALENSIS",
                "Potted plant",
                "Article no.:",
                "004.281.15",
                "Length: 115 cm",
                "Weight: 4.77 kg",
                "Diameter: 53 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Sensitive to repotting. For indoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-benghalensis-potted-plant-banyan-00428115/ficus-benghalensis-potted-plant-banyan-00428115-0.JPG",
                "data/plant pots/ficus-benghalensis-potted-plant-banyan-00428115/ficus-benghalensis-potted-plant-banyan-00428115-1.JPG",
                "data/plant pots/ficus-benghalensis-potted-plant-banyan-00428115/ficus-benghalensis-potted-plant-banyan-00428115-2.JPG",
                "data/plant pots/ficus-benghalensis-potted-plant-banyan-00428115/ficus-benghalensis-potted-plant-banyan-00428115-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "121": {
            "id": 121,
            "prod_name": "FICUS MICROCARPA GINSENG",
            "prod_price": "75",
            "prod_desc": "Potted plant with pot, bonsai/assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "40 cm",
                "Height of plant": "90 cm"
            },
            "packaging": [
                "FICUS MICROCARPA GINSENG",
                "Potted plant with pot",
                "Article no.:",
                "004.327.25",
                "Length: 105 cm",
                "Weight: 18.00 kg",
                "Diameter: 51 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South East Africa. Slow growing. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-microcarpa-ginseng-potted-plant-with-pot-bonsai-assorted-colours-00432725/ficus-microcarpa-ginseng-potted-plant-with-pot-bonsai-assorted-colours-00432725-0.JPG",
                "data/plant pots/ficus-microcarpa-ginseng-potted-plant-with-pot-bonsai-assorted-colours-00432725/ficus-microcarpa-ginseng-potted-plant-with-pot-bonsai-assorted-colours-00432725-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Main parts:,Earthenware, Pigmented powder coating,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "122": {
            "id": 122,
            "prod_name": "PHALAENOPSIS",
            "prod_price": "6",
            "prod_desc": "Potted plant, Orchid/2 stems",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "PHALAENOPSIS",
                "Potted plant",
                "Article no.:",
                "103.033.65",
                "Length: 70 cm",
                "Weight: 0.55 kg",
                "Diameter: 16 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Sensitive to draught. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-0.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-1.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-2.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-3.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-4.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-5.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-6.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-7.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-2-stems-10303365/phalaenopsis-potted-plant-orchid-2-stems-10303365-8.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Cut flower-stalk after flowering period, to help the plant to re-flower.,Temperature,Minimum temperature 18\u00b0C.,Water,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "123": {
            "id": 123,
            "prod_name": "SPATHIPHYLLUM",
            "prod_price": "7",
            "prod_desc": "Potted plant, Peace lily",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "70 cm"
            },
            "packaging": [
                "SPATHIPHYLLUM",
                "Potted plant",
                "Article no.:",
                "168.040.78",
                "Length: 85 cm",
                "Weight: 1.51 kg",
                "Diameter: 31 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Colombia and Venezuela. Easy care plant. This plant will dry out if placed too close to a heat source such as a radiator.",
            "sustainability": "",
            "images": [
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-0.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-1.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-2.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-3.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-4.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-16804078/spathiphyllum-potted-plant-peace-lily-16804078-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 15\u00b0C.,Water,Water often."
        },
        "124": {
            "id": 124,
            "prod_name": "CALATHEA",
            "prod_price": "29",
            "prod_desc": "Potted plant, Calathea",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "130 cm"
            },
            "packaging": [
                "CALATHEA",
                "Potted plant",
                "Article no.:",
                "704.853.72",
                "Length: 150 cm",
                "Weight: 5.00 kg",
                "Diameter: 24 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Brazil. Slow growing. Sensitive to draught. This plant is sensitive to temperature changes.",
            "sustainability": "",
            "images": [],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Water,Water moderately.,Others,Only for decoration, not suitable for consumption."
        },
        "125": {
            "id": 125,
            "prod_name": "STEPHANOTIS",
            "prod_price": "6",
            "prod_desc": "Potted plant, Madagascar Jasmine",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "37 cm"
            },
            "packaging": [
                "STEPHANOTIS",
                "Potted plant",
                "Article no.:",
                "404.607.83",
                "Length: 42 cm",
                "Weight: 0.57 kg",
                "Diameter: 31 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Madagascar. Climbing plant. Scented flowers. Sensitive to draught.",
            "sustainability": "",
            "images": [
                "data/plant pots/stephanotis-potted-plant-madagascar-jasmine-40460783/stephanotis-potted-plant-madagascar-jasmine-40460783-0.JPG",
                "data/plant pots/stephanotis-potted-plant-madagascar-jasmine-40460783/stephanotis-potted-plant-madagascar-jasmine-40460783-1.JPG",
                "data/plant pots/stephanotis-potted-plant-madagascar-jasmine-40460783/stephanotis-potted-plant-madagascar-jasmine-40460783-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 18\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "126": {
            "id": 126,
            "prod_name": "FICUS BENJAMINA",
            "prod_price": "8",
            "prod_desc": "Potted plant, Weeping fig",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "FICUS BENJAMINA",
                "Potted plant",
                "Article no.:",
                "504.607.73",
                "Length: 65 cm",
                "Weight: 1.25 kg",
                "Diameter: 41 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-50460773/ficus-benjamina-potted-plant-weeping-fig-50460773-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "127": {
            "id": 127,
            "prod_name": "SCHEFFLERA ACTINOPHYLLA",
            "prod_price": "25",
            "prod_desc": "Potted plant, Umbrella Tree",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "90 cm"
            },
            "packaging": [
                "SCHEFFLERA ACTINOPHYLLA",
                "Potted plant",
                "Article no.:",
                "604.488.46",
                "Length: 113 cm",
                "Weight: 3.38 kg",
                "Diameter: 75 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/schefflera-actinophylla-potted-plant-umbrella-tree-60448846/schefflera-actinophylla-potted-plant-umbrella-tree-60448846-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 12\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water moderately."
        },
        "128": {
            "id": 128,
            "prod_name": "DRACAENA DEREMENSIS",
            "prod_price": "45",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "27 cm",
                "Height of plant": "180 cm"
            },
            "packaging": [
                "DRACAENA DEREMENSIS",
                "Potted plant",
                "Article no.:",
                "802.170.34",
                "Length: 179 cm",
                "Weight: 7.86 kg",
                "Diameter: 34 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Ideal office plant. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/dracaena-deremensis-potted-plant-assorted-80217034/dracaena-deremensis-potted-plant-assorted-80217034-0.JPG",
                "data/plant pots/dracaena-deremensis-potted-plant-assorted-80217034/dracaena-deremensis-potted-plant-assorted-80217034-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Water,Water moderately.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "129": {
            "id": 129,
            "prod_name": "FICUS BENJAMINA",
            "prod_price": "60",
            "prod_desc": "Potted plant, Weeping fig/assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "32 cm",
                "Height of plant": "130 cm"
            },
            "packaging": [
                "FICUS BENJAMINA",
                "Potted plant",
                "Article no.:",
                "902.170.19",
                "Length: 150 cm",
                "Weight: 9.66 kg",
                "Diameter: 34 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to Malaysia. Fast growing. Sensitive to draught. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off. This plant is sensitive to over and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019-0.JPG",
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019-1.JPG",
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019-2.JPG",
                "data/plant pots/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019/ficus-benjamina-potted-plant-weeping-fig-assorted-90217019-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Water,Water moderately."
        },
        "130": {
            "id": 130,
            "prod_name": "POLYSCIAS FABIAN",
            "prod_price": "22",
            "prod_desc": "Potted plant, Aralia",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "105 cm"
            },
            "packaging": [
                "POLYSCIAS FABIAN",
                "Potted plant",
                "Article no.:",
                "203.874.11",
                "Length: 106 cm",
                "Weight: 4.52 kg",
                "Diameter: 42 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. This plant is sensitive to dry surroundings. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-0.JPG",
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-1.JPG",
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-2.JPG",
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-3.JPG",
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-4.JPG",
                "data/plant pots/polyscias-fabian-potted-plant-aralia-20387411/polyscias-fabian-potted-plant-aralia-20387411-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "131": {
            "id": 131,
            "prod_name": "PHALAENOPSIS",
            "prod_price": "6",
            "prod_desc": "Potted plant, Orchid/multiflora 2 stems",
            "prod_dimensions": {
                "Diameter of plant pot": "9 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "PHALAENOPSIS",
                "Potted plant",
                "Article no.:",
                "204.503.65",
                "Length: 43 cm",
                "Weight: 0.28 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Sensitive to draught. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-0.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-1.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-2.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-3.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-4.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-5.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365/phalaenopsis-potted-plant-orchid-multiflora-2-stems-20450365-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Cut flower-stalk after flowering period, to help the plant to re-flower.,Temperature,Minimum temperature 18\u00b0C.,Water,Water by immersing into a water-bath.,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "132": {
            "id": 132,
            "prod_name": "CLIVIA MINIATA",
            "prod_price": "6",
            "prod_desc": "Potted plant, Bush lily",
            "prod_dimensions": {
                "Diameter of plant pot": "13 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "CLIVIA MINIATA",
                "Potted plant",
                "Article no.:",
                "304.607.69",
                "Length: 54 cm",
                "Weight: 0.80 kg",
                "Diameter: 50 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/clivia-miniata-potted-plant-bush-lily-30460769/clivia-miniata-potted-plant-bush-lily-30460769-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water sparingly.,Temperature,Minimum temperature 5\u00b0C.,Placement,For indoor use,Place in a shady area.,Others,Only for decoration, not suitable for consumption."
        },
        "133": {
            "id": 133,
            "prod_name": "SPATHIPHYLLUM",
            "prod_price": "19",
            "prod_desc": "Potted plant, Peace lily",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "110 cm"
            },
            "packaging": [
                "SPATHIPHYLLUM",
                "Potted plant",
                "Article no.:",
                "701.448.49",
                "Length: 120 cm",
                "Weight: 4.20 kg",
                "Diameter: 60 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Colombia and Venezuela. Easy care plant. This plant will dry out if placed too close to a heat source such as a radiator.",
            "sustainability": "",
            "images": [
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-0.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-1.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-2.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-3.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-4.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-5.JPG",
                "data/plant pots/spathiphyllum-potted-plant-peace-lily-70144849/spathiphyllum-potted-plant-peace-lily-70144849-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a shady area.,Temperature,Minimum temperature 15\u00b0C.,Water,Water often."
        },
        "134": {
            "id": 134,
            "prod_name": "CHRYSANTHEMUM",
            "prod_price": "6",
            "prod_desc": "Potted plant, Chrysanthemums assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "CHRYSANTHEMUM",
                "Potted plant",
                "Article no.:",
                "204.607.79",
                "Length: 50 cm",
                "Weight: 2.00 kg",
                "Diameter: 45 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to China. Flowering plants bloom between a few days and several months depending on the quality of the care. Easy care plant. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779-0.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779-1.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779-2.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779/chrysanthemum-potted-plant-chrysanthemums-assorted-20460779-3.JPG"
            ],
            "materials": "Cultivated potted plant,Temperature,Minimum temperature 0\u00b0C.,Water,Water moderately.,Placement,For outdoor use.,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "135": {
            "id": 135,
            "prod_name": "FICUS ELASTICA",
            "prod_price": "10",
            "prod_desc": "Potted plant, Rubber plant assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "53 cm"
            },
            "packaging": [
                "FICUS ELASTICA",
                "Potted plant",
                "Article no.:",
                "904.788.32",
                "Length: 68 cm",
                "Weight: 2.00 kg",
                "Diameter: 48 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Easy care plant. Ideal office plant. Slow growing. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off. This plant is sensitive to over and under watering. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-elastica-potted-plant-rubber-plant-assorted-90478832/ficus-elastica-potted-plant-rubber-plant-assorted-90478832-0.JPG",
                "data/plant pots/ficus-elastica-potted-plant-rubber-plant-assorted-90478832/ficus-elastica-potted-plant-rubber-plant-assorted-90478832-1.JPG",
                "data/plant pots/ficus-elastica-potted-plant-rubber-plant-assorted-90478832/ficus-elastica-potted-plant-rubber-plant-assorted-90478832-2.JPG",
                "data/plant pots/ficus-elastica-potted-plant-rubber-plant-assorted-90478832/ficus-elastica-potted-plant-rubber-plant-assorted-90478832-3.JPG",
                "data/plant pots/ficus-elastica-potted-plant-rubber-plant-assorted-90478832/ficus-elastica-potted-plant-rubber-plant-assorted-90478832-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "136": {
            "id": 136,
            "prod_name": "BUXUS SEMPERVIRENS",
            "prod_price": "12",
            "prod_desc": "Potted plant, Box/pyramid",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "45 cm"
            },
            "packaging": [
                "BUXUS SEMPERVIRENS",
                "Potted plant",
                "Article no.:",
                "301.598.66",
                "Length: 69 cm",
                "Weight: 4.37 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Europe. Slow growing. The plant can cause allergies or skin irritation if you are allergic or sensitive in other ways.",
            "sustainability": "",
            "images": [
                "data/plant pots/buxus-sempervirens-potted-plant-box-pyramid-30159866/buxus-sempervirens-potted-plant-box-pyramid-30159866-0.JPG",
                "data/plant pots/buxus-sempervirens-potted-plant-box-pyramid-30159866/buxus-sempervirens-potted-plant-box-pyramid-30159866-1.JPG",
                "data/plant pots/buxus-sempervirens-potted-plant-box-pyramid-30159866/buxus-sempervirens-potted-plant-box-pyramid-30159866-2.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Repot in bigger pot every year.,By trimming the plant a better foliage can be achieved.,Water,Water moderately.,Temperature,Minimum temperature -14\u00b0C.,Placement,For outdoor use.,Place in a light area, out of direct sunlight."
        },
        "137": {
            "id": 137,
            "prod_name": "SUCCULENT",
            "prod_price": "6",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "17 cm"
            },
            "packaging": [
                "SUCCULENT",
                "Potted plant",
                "Article no.:",
                "503.646.58",
                "Length: 30 cm",
                "Weight: 0.95 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to dry areas all over the world. Easy care plant. Ideal office plant. This plant is sensitive to cold water and under watering. This may be the cause if the leaves start to fall off. Sensitive to repotting.",
            "sustainability": "",
            "images": [
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-0.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-1.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-2.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-3.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-4.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-5.JPG",
                "data/plant pots/succulent-potted-plant-assorted-50364658/succulent-potted-plant-assorted-50364658-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "138": {
            "id": 138,
            "prod_name": "FICUS BENJAMINA 'NATASJA'",
            "prod_price": "8",
            "prod_desc": "Potted plant, Weeping fig",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "FICUS BENJAMINA 'NATASJA'",
                "Potted plant",
                "Article no.:",
                "568.046.13",
                "Length: 41 cm",
                "Weight: 0.63 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South East Asia, Australia and Africa. Fast growing. Sensitive to draught. Sensitive to placement changes. This plant is sensitive to low light and placement changes. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613-0.JPG",
                "data/plant pots/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613-1.JPG",
                "data/plant pots/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613-2.JPG",
                "data/plant pots/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613/ficus-benjamina-natasja-potted-plant-weeping-fig-56804613-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 15\u00b0C.,Water,Water moderately."
        },
        "139": {
            "id": 139,
            "prod_name": "ALOE VERA",
            "prod_price": "7",
            "prod_desc": "Potted plant, Aloe",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "ALOE VERA",
                "Potted plant",
                "Article no.:",
                "803.874.08",
                "Length: 55 cm",
                "Weight: 0.88 kg",
                "Diameter: 32 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South Africa. Easy care plant. Slow growing.",
            "sustainability": "",
            "images": [
                "data/plant pots/aloe-vera-potted-plant-aloe-80387408/aloe-vera-potted-plant-aloe-80387408-0.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-80387408/aloe-vera-potted-plant-aloe-80387408-1.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-80387408/aloe-vera-potted-plant-aloe-80387408-2.JPG",
                "data/plant pots/aloe-vera-potted-plant-aloe-80387408/aloe-vera-potted-plant-aloe-80387408-3.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Temperature,Prefers warm surroundings.,Minimum temperature 12\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a bright and sunny area."
        },
        "140": {
            "id": 140,
            "prod_name": "PRIMULA OBCONICA",
            "prod_price": "4",
            "prod_desc": "Potted plant, primula assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "PRIMULA OBCONICA",
                "Potted plant",
                "Article no.:",
                "903.687.96",
                "Length: 30 cm",
                "Weight: 0.78 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to China. Perennial.",
            "sustainability": "",
            "images": [
                "data/plant pots/primula-obconica-potted-plant-primula-assorted-colours-90368796/primula-obconica-potted-plant-primula-assorted-colours-90368796-0.JPG",
                "data/plant pots/primula-obconica-potted-plant-primula-assorted-colours-90368796/primula-obconica-potted-plant-primula-assorted-colours-90368796-1.JPG",
                "data/plant pots/primula-obconica-potted-plant-primula-assorted-colours-90368796/primula-obconica-potted-plant-primula-assorted-colours-90368796-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "141": {
            "id": 141,
            "prod_name": "SCHEFFLERA ARBORICOLA",
            "prod_price": "15",
            "prod_desc": "Potted plant, Umbrella tree/twisted stem",
            "prod_dimensions": {
                "Diameter of plant pot": "19 cm",
                "Height of plant": "68 cm"
            },
            "packaging": [
                "SCHEFFLERA ARBORICOLA",
                "Potted plant",
                "Article no.:",
                "904.085.42",
                "Length: 84 cm",
                "Weight: 2.47 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to China. Easy care plant. Evergreen plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542-0.JPG",
                "data/plant pots/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542-1.JPG",
                "data/plant pots/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542/schefflera-arboricola-potted-plant-umbrella-tree-twisted-stem-90408542-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "142": {
            "id": 142,
            "prod_name": "ANTHURIUM",
            "prod_price": "5",
            "prod_desc": "Potted plant, Flamingo plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "ANTHURIUM",
                "Potted plant",
                "Article no.:",
                "204.449.06",
                "Length: 50 cm",
                "Weight: 0.92 kg",
                "Diameter: 37 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Colombia. Slow growing. Scented flowers.",
            "sustainability": "",
            "images": [
                "data/plant pots/anthurium-potted-plant-flamingo-plant-20444906/anthurium-potted-plant-flamingo-plant-20444906-0.JPG",
                "data/plant pots/anthurium-potted-plant-flamingo-plant-20444906/anthurium-potted-plant-flamingo-plant-20444906-1.JPG",
                "data/plant pots/anthurium-potted-plant-flamingo-plant-20444906/anthurium-potted-plant-flamingo-plant-20444906-2.JPG",
                "data/plant pots/anthurium-potted-plant-flamingo-plant-20444906/anthurium-potted-plant-flamingo-plant-20444906-3.JPG",
                "data/plant pots/anthurium-potted-plant-flamingo-plant-20444906/anthurium-potted-plant-flamingo-plant-20444906-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 18\u00b0C.,Water,Water moderately."
        },
        "143": {
            "id": 143,
            "prod_name": "PHALAENOPSIS",
            "prod_price": "12",
            "prod_desc": "Potted plant, Orchid/cascade 1 stem",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "PHALAENOPSIS",
                "Potted plant",
                "Article no.:",
                "803.291.64",
                "Length: 60 cm",
                "Weight: 0.57 kg",
                "Diameter: 13 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Sensitive to draught. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/phalaenopsis-potted-plant-orchid-cascade-1-stem-80329164/phalaenopsis-potted-plant-orchid-cascade-1-stem-80329164-0.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-cascade-1-stem-80329164/phalaenopsis-potted-plant-orchid-cascade-1-stem-80329164-1.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Cut flower-stalk after flowering period, to help the plant to re-flower.,Temperature,Minimum temperature 18\u00b0C.,Water,Water by immersing into a water-bath.,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "144": {
            "id": 144,
            "prod_name": "CUPRESSUS MACROCARPA",
            "prod_price": "3",
            "prod_desc": "Potted plant, cypress",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "50 cm"
            },
            "packaging": [
                "CUPRESSUS MACROCARPA",
                "Potted plant",
                "Article no.:",
                "904.607.71",
                "Length: 64 cm",
                "Weight: 0.86 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to California. Fast growing. Evergreen plant. Easy care plant. A scent is released when the plant is cut or crushed.",
            "sustainability": "",
            "images": [
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-90460771/cupressus-macrocarpa-potted-plant-cypress-90460771-0.JPG",
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-90460771/cupressus-macrocarpa-potted-plant-cypress-90460771-1.JPG",
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-90460771/cupressus-macrocarpa-potted-plant-cypress-90460771-2.JPG"
            ],
            "materials": "Cultivated potted plant,Water,Water moderately.,Temperature,Minimum temperature 0\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption."
        },
        "145": {
            "id": 145,
            "prod_name": "CACTACEAE",
            "prod_price": "8",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "17 cm"
            },
            "packaging": [
                "CACTACEAE",
                "Potted plant",
                "Article no.:",
                "403.489.75",
                "Length: 31 cm",
                "Weight: 0.94 kg",
                "Diameter: 24 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Attention: prickly! Wear gloves and protect your eyes when handling, as the plant has thorns. Native to Mexico. Slow growing. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/cactaceae-potted-plant-assorted-40348975/cactaceae-potted-plant-assorted-40348975-0.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-40348975/cactaceae-potted-plant-assorted-40348975-1.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-40348975/cactaceae-potted-plant-assorted-40348975-2.JPG",
                "data/plant pots/cactaceae-potted-plant-assorted-40348975/cactaceae-potted-plant-assorted-40348975-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Attention: prickly!,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly.,Placement,For indoor use,Place in a bright and sunny area."
        },
        "146": {
            "id": 146,
            "prod_name": "KALANCHOE",
            "prod_price": "2",
            "prod_desc": "Potted plant, Flaming Katy",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "27 cm"
            },
            "packaging": [
                "KALANCHOE",
                "Potted plant",
                "Article no.:",
                "601.771.66",
                "Length: 24 cm",
                "Weight: 0.54 kg",
                "Diameter: 20 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia and Africa. Slow growing. This plant is sensitive to over watering. If it gets too much water there is a risk of root rot and that the leaves turn soft. This plant is sensitive to under watering. This may be the cause if the plant starts to wilt. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-0.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-1.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-2.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-3.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-4.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-5.JPG",
                "data/plant pots/kalanchoe-potted-plant-flaming-katy-60177166/kalanchoe-potted-plant-flaming-katy-60177166-6.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 12\u00b0C.,Water,Water moderately.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight."
        },
        "147": {
            "id": 147,
            "prod_name": "PHALAENOPSIS",
            "prod_price": "5",
            "prod_desc": "Potted plant, Orchid/1 stem assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "65 cm"
            },
            "packaging": [
                "PHALAENOPSIS",
                "Potted plant",
                "Article no.:",
                "303.202.17",
                "Length: 70 cm",
                "Weight: 0.47 kg",
                "Diameter: 32 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Sensitive to draught. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-0.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-1.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-2.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-3.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-4.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-5.JPG",
                "data/plant pots/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217/phalaenopsis-potted-plant-orchid-1-stem-assorted-colours-30320217-6.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Cut flower-stalk after flowering period, to help the plant to re-flower.,Temperature,Minimum temperature 18\u00b0C.,Water,Water by immersing into a water-bath.,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "148": {
            "id": 148,
            "prod_name": "FICUS",
            "prod_price": "22",
            "prod_desc": "Potted plant with pot, bonsai/assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "22 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "FICUS",
                "Potted plant with pot",
                "Article no.:",
                "304.327.24",
                "Length: 46 cm",
                "Weight: 3.70 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to South East Africa. Slow growing. This plant is sensitive to temperature changes. This may be the cause if the leaves start to fall off.",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724-0.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724-1.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724-2.JPG",
                "data/plant pots/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724/ficus-potted-plant-with-pot-bonsai-assorted-colours-30432724-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Main parts:,Earthenware, Pigmented powder coating,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "149": {
            "id": 149,
            "prod_name": "CUCUMIS SATIVUS",
            "prod_price": "9",
            "prod_desc": "Potted plant, cucumber",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "CUCUMIS SATIVUS",
                "Potted plant",
                "Article no.:",
                "503.154.13",
                "Length: 68 cm",
                "Weight: 0.98 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Climbing plant. Fruits are edible.",
            "sustainability": "",
            "images": [
                "data/plant pots/cucumis-sativus-potted-plant-cucumber-50315413/cucumis-sativus-potted-plant-cucumber-50315413-0.JPG",
                "data/plant pots/cucumis-sativus-potted-plant-cucumber-50315413/cucumis-sativus-potted-plant-cucumber-50315413-1.JPG"
            ],
            "materials": "Cultivated potted plant,Edible.,Water,Water often.,Temperature,Minimum temperature 15\u00b0C.,Placement,For outdoor use.,Place in a bright and sunny area."
        },
        "150": {
            "id": 150,
            "prod_name": "BROMELIACEAE",
            "prod_price": "6",
            "prod_desc": "Potted plant, Bromeliad/assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "BROMELIACEAE",
                "Potted plant",
                "Article no.:",
                "102.546.85",
                "Length: 43 cm",
                "Weight: 0.57 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South America. Slow growing. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant. Sensitive to repotting.",
            "sustainability": "",
            "images": [
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-0.JPG",
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-1.JPG",
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-2.JPG",
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-3.JPG",
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-4.JPG",
                "data/plant pots/bromeliaceae-potted-plant-bromeliad-assorted-10254685/bromeliaceae-potted-plant-bromeliad-assorted-10254685-5.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Sprinkle once a week.,Water into the rosette.,Water moderately.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "151": {
            "id": 151,
            "prod_name": "ANIGOZANTHOS",
            "prod_price": "6",
            "prod_desc": "Potted plant, Kangaroo paw",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "40 cm"
            },
            "packaging": [
                "ANIGOZANTHOS",
                "Potted plant",
                "Article no.:",
                "504.607.68",
                "Length: 40 cm",
                "Weight: 0.70 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Water,Water often.,Temperature,Minimum temperature 5\u00b0C.,Placement,For indoor use,Place in a bright and sunny area.,Others,Only for decoration, not suitable for consumption."
        },
        "152": {
            "id": 152,
            "prod_name": "HAWORTHIA",
            "prod_price": "1",
            "prod_desc": "Potted plant, assorted",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "8 cm"
            },
            "packaging": [
                "HAWORTHIA",
                "Potted plant",
                "Article no.:",
                "504.923.78",
                "Length: 11 cm",
                "Weight: 0.24 kg",
                "Diameter: 8 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/haworthia-potted-plant-assorted-50492378/haworthia-potted-plant-assorted-50492378-0.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Temperature,Minimum temperature 12\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water sparingly.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "153": {
            "id": 153,
            "prod_name": "CHIAFR\u00d6N",
            "prod_price": "3",
            "prod_desc": "Plant pot, in/outdoor light pink",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "11 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "10 cm"
            },
            "packaging": [
                "CHIAFR\u00d6N",
                "Plant pot",
                "Article no.:",
                "304.833.65",
                "Length: 10 cm",
                "Weight: 0.47 kg",
                "Diameter: 11 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-pink-30483365/chiafroen-plant-pot-in-outdoor-light-pink-30483365-0.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-pink-30483365/chiafroen-plant-pot-in-outdoor-light-pink-30483365-1.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-pink-30483365/chiafroen-plant-pot-in-outdoor-light-pink-30483365-2.jpg",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-pink-30483365/chiafroen-plant-pot-in-outdoor-light-pink-30483365-3.JPG",
                "data/plant pots/chiafroen-plant-pot-in-outdoor-light-pink-30483365/chiafroen-plant-pot-in-outdoor-light-pink-30483365-4.JPG"
            ],
            "materials": "Stoneware"
        },
        "154": {
            "id": 154,
            "prod_name": "MUSKOTBLOMMA",
            "prod_price": "5",
            "prod_desc": "Plant pot with saucer, in/outdoor terracotta",
            "prod_dimensions": {
                "Max. diameter flowerpot": "15 cm",
                "Height": "16 cm",
                "Outside diameter": "20 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "MUSKOTBLOMMA",
                "Plant pot with saucer",
                "Article no.:",
                "304.548.91",
                "This product has multiple packages.",
                "Length: 3 cm",
                "Weight: 0.60 kg",
                "Diameter: 19 cm",
                "Package(s): 1",
                "Length: 15 cm",
                "Weight: 1.11 kg",
                "Diameter: 20 cm",
                "Package(s): 1"
            ],
            "prod_details": "It's possible to plant directly in the pot because it has a drain hole in the bottom and a saucer to collect excess water. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-0.JPG",
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-1.jpg",
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-2.jpg",
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-3.jpg",
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-4.JPG",
                "data/plant pots/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891/muskotblomma-plant-pot-with-saucer-in-outdoor-terracotta-30454891-5.JPG"
            ],
            "materials": "Red clay, Silicone treatment"
        },
        "155": {
            "id": 155,
            "prod_name": "BACKSMULTRON",
            "prod_price": "6",
            "prod_desc": "Plant pot, in/outdoor beige/grey",
            "prod_dimensions": {
                "Height": "16 cm",
                "Outside diameter": "18 cm",
                "Max. diameter flowerpot": "15 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "BACKSMULTRON",
                "Plant pot",
                "Article no.:",
                "504.757.84",
                "Length: 16 cm",
                "Weight: 1.41 kg",
                "Diameter: 18 cm",
                "Package(s): 1"
            ],
            "prod_details": "The stoneware clay is mixed in a way that creates unique patterns on each plant pot. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50475784/backsmultron-plant-pot-in-outdoor-beige-grey-50475784-0.JPG",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50475784/backsmultron-plant-pot-in-outdoor-beige-grey-50475784-1.jpg",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50475784/backsmultron-plant-pot-in-outdoor-beige-grey-50475784-2.jpg",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50475784/backsmultron-plant-pot-in-outdoor-beige-grey-50475784-3.JPG"
            ],
            "materials": "Stoneware"
        },
        "156": {
            "id": 156,
            "prod_name": "FNITTRIG",
            "prod_price": "2",
            "prod_desc": "Plant pot, in/outdoor pink",
            "prod_dimensions": {
                "Height": "10 cm",
                "Outside diameter": "14 cm",
                "Max. diameter flowerpot": "9 cm",
                "Inside diameter": "11 cm"
            },
            "packaging": [
                "FNITTRIG",
                "Plant pot",
                "Article no.:",
                "004.795.34",
                "Length: 10 cm",
                "Weight: 0.50 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/fnittrig-plant-pot-in-outdoor-pink-00479534/fnittrig-plant-pot-in-outdoor-pink-00479534-0.JPG",
                "data/plant pots/fnittrig-plant-pot-in-outdoor-pink-00479534/fnittrig-plant-pot-in-outdoor-pink-00479534-1.JPG",
                "data/plant pots/fnittrig-plant-pot-in-outdoor-pink-00479534/fnittrig-plant-pot-in-outdoor-pink-00479534-2.jpg",
                "data/plant pots/fnittrig-plant-pot-in-outdoor-pink-00479534/fnittrig-plant-pot-in-outdoor-pink-00479534-3.JPG",
                "data/plant pots/fnittrig-plant-pot-in-outdoor-pink-00479534/fnittrig-plant-pot-in-outdoor-pink-00479534-4.JPG"
            ],
            "materials": "Stoneware, Glaze"
        },
        "157": {
            "id": 157,
            "prod_name": "VITL\u00d6K",
            "prod_price": "13",
            "prod_desc": "Plant stand, in/outdoor beige",
            "prod_dimensions": {
                "Length": "62 cm",
                "Width": "28 cm",
                "Height": "38 cm",
                "Max. load/shelf": "20 kg"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant stand",
                "Article no.:",
                "904.757.58",
                "Width: 41 cm",
                "Height: 6 cm",
                "Length: 57 cm",
                "Weight: 2.88 kg",
                "Package(s): 1"
            ],
            "prod_details": "The plant stand can be used to display plants indoors or outdoors on a balcony perhaps, or as a unique room divider. The plant stand is made of galvanised steel, which provides good protection against rust. . Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-stand-in-outdoor-beige-90475758/vitloek-plant-stand-in-outdoor-beige-90475758-0.JPG",
                "data/plant pots/vitloek-plant-stand-in-outdoor-beige-90475758/vitloek-plant-stand-in-outdoor-beige-90475758-1.JPG",
                "data/plant pots/vitloek-plant-stand-in-outdoor-beige-90475758/vitloek-plant-stand-in-outdoor-beige-90475758-2.jpg",
                "data/plant pots/vitloek-plant-stand-in-outdoor-beige-90475758/vitloek-plant-stand-in-outdoor-beige-90475758-3.JPG"
            ],
            "materials": "Steel, Polyester powder coating"
        },
        "158": {
            "id": 158,
            "prod_name": "VITL\u00d6K",
            "prod_price": "7",
            "prod_desc": "Plant pot, in/outdoor beige",
            "prod_dimensions": {
                "Height": "25 cm",
                "Outside diameter": "26 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "25 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot",
                "Article no.:",
                "304.758.41",
                "Length: 26 cm",
                "Weight: 0.66 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-in-outdoor-beige-30475841/vitloek-plant-pot-in-outdoor-beige-30475841-0.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-beige-30475841/vitloek-plant-pot-in-outdoor-beige-30475841-1.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-beige-30475841/vitloek-plant-pot-in-outdoor-beige-30475841-2.jpg",
                "data/plant pots/vitloek-plant-pot-in-outdoor-beige-30475841/vitloek-plant-pot-in-outdoor-beige-30475841-3.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-beige-30475841/vitloek-plant-pot-in-outdoor-beige-30475841-4.JPG"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "159": {
            "id": 159,
            "prod_name": "VATTENMELON",
            "prod_price": "7",
            "prod_desc": "Plant pot, bamboo natural/black",
            "prod_dimensions": {
                "Max. diameter flowerpot": "15 cm",
                "Height": "17 cm",
                "Outside diameter": "18 cm",
                "Inside diameter": "17 cm"
            },
            "packaging": [
                "VATTENMELON",
                "Plant pot",
                "Article no.:",
                "604.758.49",
                "Length: 17 cm",
                "Weight: 0.12 kg",
                "Diameter: 18 cm",
                "Package(s): 1"
            ],
            "prod_details": "Handmade by skilled craftspeople, making each one unique. Lightweight, easy to lift and move. Decorate your home with plants combined with a plant pot to suit your style. The underlying surface is protected from water and dirt since the pot has a plastic insert that can be easily removed if needed. Only for indoor use.",
            "sustainability": "Renewable material (bamboo).,By using a fast-growing, renewable material like bamboo in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/plant pots/vattenmelon-plant-pot-bamboo-natural-black-60475849/vattenmelon-plant-pot-bamboo-natural-black-60475849-0.JPG",
                "data/plant pots/vattenmelon-plant-pot-bamboo-natural-black-60475849/vattenmelon-plant-pot-bamboo-natural-black-60475849-1.JPG",
                "data/plant pots/vattenmelon-plant-pot-bamboo-natural-black-60475849/vattenmelon-plant-pot-bamboo-natural-black-60475849-2.JPG"
            ],
            "materials": "Weaving:,Bamboo, Stain, Clear lacquer,Ring:,Bamboo, Clear lacquer,Inner plant pot:,PET plastic"
        },
        "160": {
            "id": 160,
            "prod_name": "INGEF\u00c4RA",
            "prod_price": "19",
            "prod_desc": "Plant pot with saucer, outdoor terracotta",
            "prod_dimensions": {
                "Height": "34 cm",
                "Outside diameter": "39 cm",
                "Max. diameter flowerpot": "32 cm",
                "Inside diameter": "37 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "INGEF\u00c4RA",
                "Plant pot with saucer",
                "Article no.:",
                "404.758.26",
                "This product has multiple packages.",
                "Length: 8 cm",
                "Weight: 3.45 kg",
                "Diameter: 35 cm",
                "Package(s): 1",
                "Length: 33 cm",
                "Weight: 8.10 kg",
                "Diameter: 39 cm",
                "Package(s): 1"
            ],
            "prod_details": "The porous terracotta holds excess water, so the plant can draw out moisture when needed. It's possible to plant directly in the pot because it has a drain hole in the bottom and a saucer to collect excess water. Surface-treated top side; makes the saucer waterproof. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Decorate your home with plants combined with a plant pot to suit your style. For outdoor use. As you water the plant, it is common and normal for lime residues and markings to appear over time if you plant directly in the pot. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826-0.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826-1.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826-2.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826-3.JPG",
                "data/plant pots/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826/ingefaera-plant-pot-with-saucer-outdoor-terracotta-40475826-4.JPG"
            ],
            "materials": "Basematerial:,Red clay,Saucer:,Silicone treated red clay"
        },
        "161": {
            "id": 161,
            "prod_name": "BACKSMULTRON",
            "prod_price": "10",
            "prod_desc": "Plant pot, in/outdoor beige/grey",
            "prod_dimensions": {
                "Height": "21 cm",
                "Outside diameter": "23 cm",
                "Max. diameter flowerpot": "19 cm",
                "Inside diameter": "21 cm"
            },
            "packaging": [
                "BACKSMULTRON",
                "Plant pot",
                "Article no.:",
                "504.810.06",
                "Length: 21 cm",
                "Weight: 2.74 kg",
                "Diameter: 23 cm",
                "Package(s): 1"
            ],
            "prod_details": "The stoneware clay is mixed in a way that creates unique patterns on each plant pot. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use. To protect the surface from any risk of moisture damage, always use a plant mover or put felt pads under the plant pot or saucer.",
            "sustainability": "",
            "images": [
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50481006/backsmultron-plant-pot-in-outdoor-beige-grey-50481006-0.jpg",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50481006/backsmultron-plant-pot-in-outdoor-beige-grey-50481006-1.jpg",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50481006/backsmultron-plant-pot-in-outdoor-beige-grey-50481006-2.jpg",
                "data/plant pots/backsmultron-plant-pot-in-outdoor-beige-grey-50481006/backsmultron-plant-pot-in-outdoor-beige-grey-50481006-3.jpg"
            ],
            "materials": "Stoneware"
        },
        "162": {
            "id": 162,
            "prod_name": "SOCKER",
            "prod_price": "6",
            "prod_desc": "Plant pot, in/outdoor beige",
            "prod_dimensions": {
                "Max. diameter flowerpot": "24 cm",
                "Height": "24 cm",
                "Outside diameter": "26 cm",
                "Inside diameter": "25 cm"
            },
            "packaging": [
                "SOCKER",
                "Plant pot",
                "Article no.:",
                "604.757.50",
                "Width: 26 cm",
                "Height: 22 cm",
                "Length: 26 cm",
                "Weight: 0.61 kg",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/socker-plant-pot-in-outdoor-beige-60475750/socker-plant-pot-in-outdoor-beige-60475750-0.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-beige-60475750/socker-plant-pot-in-outdoor-beige-60475750-1.JPG",
                "data/plant pots/socker-plant-pot-in-outdoor-beige-60475750/socker-plant-pot-in-outdoor-beige-60475750-2.JPG"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "163": {
            "id": 163,
            "prod_name": "CHILIPEPPAR",
            "prod_price": "25",
            "prod_desc": "Plant pot, in/outdoor beige",
            "prod_dimensions": {
                "Height": "41 cm",
                "Outside diameter": "38 cm",
                "Inside diameter": "32 cm"
            },
            "packaging": [
                "CHILIPEPPAR",
                "Plant pot",
                "Article no.:",
                "204.758.13",
                "Length: 41 cm",
                "Weight: 1.02 kg",
                "Diameter: 38 cm",
                "Package(s): 1"
            ],
            "prod_details": "Larger plant pots are wonderful for framing many dfferent spaces and creating room-in-room solutions both outdoors and indoors. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. You can drill drain holes in the bottom, for example if you are planning to use the plant pot outside. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-0.JPG",
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-1.JPG",
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-2.jpg",
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-3.JPG",
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-4.JPG",
                "data/plant pots/chilipeppar-plant-pot-in-outdoor-beige-20475813/chilipeppar-plant-pot-in-outdoor-beige-20475813-5.JPG"
            ],
            "materials": "Polyethylene plastic"
        },
        "164": {
            "id": 164,
            "prod_name": "CITRUSKRYDDA",
            "prod_price": "17",
            "prod_desc": "Plant pot, in/outdoor grey",
            "prod_dimensions": {
                "Height": "17 cm",
                "Outside diameter": "36 cm",
                "Inside diameter": "33 cm"
            },
            "packaging": [
                "CITRUSKRYDDA",
                "Plant pot",
                "Article no.:",
                "604.809.78",
                "Length: 17 cm",
                "Weight: 0.58 kg",
                "Diameter: 37 cm",
                "Package(s): 1"
            ],
            "prod_details": "Larger plant pots are wonderful for framing many dfferent spaces and creating room-in-room solutions both outdoors and indoors. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. You can drill drain holes in the bottom, for example if you are planning to use the plant pot outside. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/citruskrydda-plant-pot-in-outdoor-grey-60480978/citruskrydda-plant-pot-in-outdoor-grey-60480978-0.JPG",
                "data/plant pots/citruskrydda-plant-pot-in-outdoor-grey-60480978/citruskrydda-plant-pot-in-outdoor-grey-60480978-1.jpg",
                "data/plant pots/citruskrydda-plant-pot-in-outdoor-grey-60480978/citruskrydda-plant-pot-in-outdoor-grey-60480978-2.JPG"
            ],
            "materials": "Polyethylene plastic"
        },
        "165": {
            "id": 165,
            "prod_name": "SOCKER",
            "prod_price": "9",
            "prod_desc": "Bucket/plant pot, in/outdoor orange-pink",
            "prod_dimensions": {
                "Height": "27 cm",
                "Outside diameter": "28 cm",
                "Inside diameter": "27 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "SOCKER",
                "Bucket/plant pot",
                "Article no.:",
                "104.760.35",
                "Length: 28 cm",
                "Weight: 1.05 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "The handles make it easier to move the plant pots. The plant pot is galvanised to protect against corrosion. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035-0.JPG",
                "data/plant pots/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035-1.JPG",
                "data/plant pots/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035/socker-bucket-plant-pot-in-outdoor-orange-pink-10476035-2.JPG"
            ],
            "materials": "Plant pot:,Galvanized steel, Powder coating,Handle:,Stainless steel, Solid beech, Oil"
        },
        "166": {
            "id": 166,
            "prod_name": "VITL\u00d6K",
            "prod_price": "4",
            "prod_desc": "Plant pot with holder, in/outdoor beige",
            "prod_dimensions": {
                "Height": "15 cm",
                "Outside diameter": "17 cm",
                "Max. diameter flowerpot": "15 cm",
                "Inside diameter": "16 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot with holder",
                "Article no.:",
                "104.757.62",
                "Width: 21 cm",
                "Height: 17 cm",
                "Length: 24 cm",
                "Weight: 0.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762-0.jpg",
                "data/plant pots/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762-1.jpg",
                "data/plant pots/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762/vitloek-plant-pot-with-holder-in-outdoor-beige-10475762-2.jpg"
            ],
            "materials": "Plant pot:,Galvanized steel, Powder coating,Holder:,Steel, Powder coating"
        },
        "167": {
            "id": 167,
            "prod_name": "VITL\u00d6K",
            "prod_price": "7",
            "prod_desc": "Plant pot, in/outdoor dark grey",
            "prod_dimensions": {
                "Height": "25 cm",
                "Outside diameter": "26 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "25 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot",
                "Article no.:",
                "204.851.95",
                "Length: 26 cm",
                "Weight: 0.66 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-20485195/vitloek-plant-pot-in-outdoor-dark-grey-20485195-0.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-20485195/vitloek-plant-pot-in-outdoor-dark-grey-20485195-1.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-20485195/vitloek-plant-pot-in-outdoor-dark-grey-20485195-2.jpg"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "168": {
            "id": 168,
            "prod_name": "VITL\u00d6K",
            "prod_price": "9",
            "prod_desc": "Plant pot, in/outdoor light green",
            "prod_dimensions": {
                "Height": "33 cm",
                "Outside diameter": "35 cm",
                "Max. diameter flowerpot": "32 cm",
                "Inside diameter": "34 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot",
                "Article no.:",
                "604.851.98",
                "Length: 33 cm",
                "Weight: 1.53 kg",
                "Diameter: 35 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-60485198/vitloek-plant-pot-in-outdoor-light-green-60485198-0.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-60485198/vitloek-plant-pot-in-outdoor-light-green-60485198-1.jpg",
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-60485198/vitloek-plant-pot-in-outdoor-light-green-60485198-2.jpg"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "169": {
            "id": 169,
            "prod_name": "GR\u00c4DD\u00c4PPLE",
            "prod_price": "1",
            "prod_desc": "Plant pot, in/outdoor pink/white",
            "prod_dimensions": {
                "Height": "6 cm",
                "Outside diameter": "8 cm",
                "Max. diameter flowerpot": "6 cm",
                "Inside diameter": "7 cm"
            },
            "packaging": [
                "GR\u00c4DD\u00c4PPLE",
                "Plant pot",
                "Article no.:",
                "804.758.29",
                "Length: 6 cm",
                "Weight: 0.14 kg",
                "Diameter: 8 cm",
                "Package(s): 1"
            ],
            "prod_details": "Each pot has a unique look since it is covered with several layers of glaze that react in different ways with each other during firing. Decorate your home with plants combined with a plant pot to suit your style. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/graeddaepple-plant-pot-in-outdoor-pink-white-80475829/graeddaepple-plant-pot-in-outdoor-pink-white-80475829-0.JPG",
                "data/plant pots/graeddaepple-plant-pot-in-outdoor-pink-white-80475829/graeddaepple-plant-pot-in-outdoor-pink-white-80475829-1.JPG",
                "data/plant pots/graeddaepple-plant-pot-in-outdoor-pink-white-80475829/graeddaepple-plant-pot-in-outdoor-pink-white-80475829-2.JPG"
            ],
            "materials": "Stoneware, Pigmented glaze"
        },
        "170": {
            "id": 170,
            "prod_name": "VITL\u00d6K",
            "prod_price": "9",
            "prod_desc": "Plant pot, in/outdoor dark grey",
            "prod_dimensions": {
                "Height": "33 cm",
                "Outside diameter": "35 cm",
                "Max. diameter flowerpot": "32 cm",
                "Inside diameter": "34 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot",
                "Article no.:",
                "804.758.34",
                "Length: 33 cm",
                "Weight: 1.53 kg",
                "Diameter: 35 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-80475834/vitloek-plant-pot-in-outdoor-dark-grey-80475834-0.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-80475834/vitloek-plant-pot-in-outdoor-dark-grey-80475834-1.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-dark-grey-80475834/vitloek-plant-pot-in-outdoor-dark-grey-80475834-2.jpg"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "171": {
            "id": 171,
            "prod_name": "VITL\u00d6K",
            "prod_price": "7",
            "prod_desc": "Plant pot, in/outdoor light green",
            "prod_dimensions": {
                "Height": "25 cm",
                "Outside diameter": "26 cm",
                "Max. diameter flowerpot": "24 cm",
                "Inside diameter": "25 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Plant pot",
                "Article no.:",
                "904.757.82",
                "Length: 26 cm",
                "Weight: 0.66 kg",
                "Diameter: 25 cm",
                "Package(s): 1"
            ],
            "prod_details": "The plant pot is galvanised to protect against corrosion. The plant pot is frost-resistant and can be kept outdoors at temperatures below zero if emptied of soil or covered. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-90475782/vitloek-plant-pot-in-outdoor-light-green-90475782-0.JPG",
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-90475782/vitloek-plant-pot-in-outdoor-light-green-90475782-1.jpg",
                "data/plant pots/vitloek-plant-pot-in-outdoor-light-green-90475782/vitloek-plant-pot-in-outdoor-light-green-90475782-2.jpg"
            ],
            "materials": "Galvanized steel, Powder coating"
        },
        "172": {
            "id": 172,
            "prod_name": "VITL\u00d6K",
            "prod_price": "13",
            "prod_desc": "Flower box with holder, in/outdoor beige",
            "prod_dimensions": {
                "Length": "56 cm",
                "Width": "20 cm",
                "Height": "17 cm"
            },
            "packaging": [
                "VITL\u00d6K",
                "Flower box with holder",
                "Article no.:",
                "104.757.95",
                "Width: 29 cm",
                "Height: 22 cm",
                "Length: 56 cm",
                "Weight: 1.81 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can hang the flower box and plant pot from a balcony rail and create a decorative garden, even on a small space.  The plant pot is galvanised to protect against corrosion. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/vitloek-flower-box-with-holder-in-outdoor-beige-10475795/vitloek-flower-box-with-holder-in-outdoor-beige-10475795-0.JPG",
                "data/plant pots/vitloek-flower-box-with-holder-in-outdoor-beige-10475795/vitloek-flower-box-with-holder-in-outdoor-beige-10475795-1.JPG",
                "data/plant pots/vitloek-flower-box-with-holder-in-outdoor-beige-10475795/vitloek-flower-box-with-holder-in-outdoor-beige-10475795-2.jpg",
                "data/plant pots/vitloek-flower-box-with-holder-in-outdoor-beige-10475795/vitloek-flower-box-with-holder-in-outdoor-beige-10475795-3.JPG"
            ],
            "materials": "Plant pot:,Galvanized steel, Powder coating,Holder:,Steel, Powder coating"
        },
        "173": {
            "id": 173,
            "prod_name": "GALIAMELON",
            "prod_price": "13",
            "prod_desc": "Flower box with holder, in/outdoor white",
            "prod_dimensions": {
                "Length": "51 cm",
                "Width": "18 cm",
                "Height": "18 cm"
            },
            "packaging": [
                "GALIAMELON",
                "Flower box with holder",
                "Article no.:",
                "104.758.23",
                "Width: 26 cm",
                "Height: 20 cm",
                "Length: 52 cm",
                "Weight: 1.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can hang the flower box from a balcony rail and create a decorative garden, even on a small space.  Handmade by skilled craftspeople, making each one unique. A plastic inner pot makes the plant pot waterproof. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/galiamelon-flower-box-with-holder-in-outdoor-white-10475823/galiamelon-flower-box-with-holder-in-outdoor-white-10475823-0.JPG",
                "data/plant pots/galiamelon-flower-box-with-holder-in-outdoor-white-10475823/galiamelon-flower-box-with-holder-in-outdoor-white-10475823-1.JPG",
                "data/plant pots/galiamelon-flower-box-with-holder-in-outdoor-white-10475823/galiamelon-flower-box-with-holder-in-outdoor-white-10475823-2.jpg",
                "data/plant pots/galiamelon-flower-box-with-holder-in-outdoor-white-10475823/galiamelon-flower-box-with-holder-in-outdoor-white-10475823-3.JPG",
                "data/plant pots/galiamelon-flower-box-with-holder-in-outdoor-white-10475823/galiamelon-flower-box-with-holder-in-outdoor-white-10475823-4.JPG"
            ],
            "materials": "Plant pot:,PET plastic,Metal part:,Steel, Polyester powder coating"
        },
        "174": {
            "id": 174,
            "prod_name": "GALIAMELON",
            "prod_price": "9",
            "prod_desc": "Hanging planter, in/outdoor white",
            "prod_dimensions": {
                "Height": "14 cm",
                "Outside diameter": "29 cm",
                "Inside diameter": "27 cm",
                "Height including hanger": "86 cm"
            },
            "packaging": [
                "GALIAMELON",
                "Hanging planter",
                "Article no.:",
                "304.757.99",
                "Length: 17 cm",
                "Weight: 0.59 kg",
                "Diameter: 30 cm",
                "Package(s): 1"
            ],
            "prod_details": "Makes it possible to grow plants vertically, giving room for more plants in less space. It\u2019s possible to plant directly into the planter, or to place potted plants inside. Handmade by skilled craftspeople, making each one unique. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/galiamelon-hanging-planter-in-outdoor-white-30475799/galiamelon-hanging-planter-in-outdoor-white-30475799-0.JPG",
                "data/plant pots/galiamelon-hanging-planter-in-outdoor-white-30475799/galiamelon-hanging-planter-in-outdoor-white-30475799-1.JPG",
                "data/plant pots/galiamelon-hanging-planter-in-outdoor-white-30475799/galiamelon-hanging-planter-in-outdoor-white-30475799-2.jpg"
            ],
            "materials": "Rope:,100% polypropylene,Inner plant pot:,PET plastic,Inside frame:,Steel, Powder coating"
        },
        "175": {
            "id": 175,
            "prod_name": "CITRUS",
            "prod_price": "25",
            "prod_desc": "Potted plant, lemon",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm",
                "Height of plant": "60 cm"
            },
            "packaging": [
                "CITRUS",
                "Potted plant",
                "Article no.:",
                "004.917.72",
                "Length: 87 cm",
                "Weight: 6.55 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South and South East Asia. Sensitive to low temperatures. Scented flowers and fruits. Sensitive to draught.",
            "sustainability": "",
            "images": [
                "data/plant pots/citrus-potted-plant-lemon-00491772/citrus-potted-plant-lemon-00491772-0.JPG",
                "data/plant pots/citrus-potted-plant-lemon-00491772/citrus-potted-plant-lemon-00491772-1.JPG",
                "data/plant pots/citrus-potted-plant-lemon-00491772/citrus-potted-plant-lemon-00491772-2.JPG",
                "data/plant pots/citrus-potted-plant-lemon-00491772/citrus-potted-plant-lemon-00491772-3.JPG"
            ],
            "materials": "Cultivated potted plant,Edible.,Water,Water moderately.,Temperature,Minimum temperature 0\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a bright and sunny area."
        },
        "176": {
            "id": 176,
            "prod_name": "L\u00d6KARYD",
            "prod_price": "2",
            "prod_desc": "Potted plant, assorted/Hyacinth",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "L\u00d6KARYD",
                "Potted plant",
                "Article no.:",
                "004.923.90",
                "Length: 17 cm",
                "Weight: 0.63 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Perennial. Scented flowers.",
            "sustainability": "",
            "images": [
                "data/plant pots/loekaryd-potted-plant-assorted-hyacinth-00492390/loekaryd-potted-plant-assorted-hyacinth-00492390-0.jpg"
            ],
            "materials": "Cultivated potted plant,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 0\u00b0C."
        },
        "177": {
            "id": 177,
            "prod_name": "CRASSULA",
            "prod_price": "19",
            "prod_desc": "Potted plant with pot, Money tree",
            "prod_dimensions": {
                "Diameter of plant pot": "22 cm"
            },
            "packaging": [
                "CRASSULA",
                "Potted plant with pot",
                "Article no.:",
                "104.853.70",
                "Length: 35 cm",
                "Weight: 3.50 kg",
                "Diameter: 35 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to Asia. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/crassula-potted-plant-with-pot-money-tree-10485370/crassula-potted-plant-with-pot-money-tree-10485370-0.jpg"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Basematerial:,Earthenware, Pigmented epoxy/polyester powder coating,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "178": {
            "id": 178,
            "prod_name": "CHRYSANTHEMUM",
            "prod_price": "2",
            "prod_desc": "Potted plant, Chrysanthemums assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "14 cm",
                "Height of plant": "27 cm"
            },
            "packaging": [
                "CHRYSANTHEMUM",
                "Potted plant",
                "Article no.:",
                "104.918.75",
                "Length: 30 cm",
                "Weight: 0.76 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to China. Easy care plant. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant. This plant is sensitive to temperature changes. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875-0.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875-1.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875-2.JPG",
                "data/plant pots/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875/chrysanthemum-potted-plant-chrysanthemums-assorted-colours-10491875-3.JPG"
            ],
            "materials": "Cultivated potted plant,Temperature,Minimum temperature 0\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight."
        },
        "179": {
            "id": 179,
            "prod_name": "MONSTERA ADASONII",
            "prod_price": "5",
            "prod_desc": "Potted plant, Swiss cheese plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "MONSTERA ADASONII",
                "Potted plant",
                "Article no.:",
                "104.923.75",
                "Length: 40 cm",
                "Weight: 0.50 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Easy care plant. Ideal office plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/monstera-adasonii-potted-plant-swiss-cheese-plant-10492375/monstera-adasonii-potted-plant-swiss-cheese-plant-10492375-0.jpg"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 15\u00b0C.,Water,Water moderately."
        },
        "180": {
            "id": 180,
            "prod_name": "SVARTPEPPAR",
            "prod_price": "4",
            "prod_desc": "Plant pot holder, in/outdoor black",
            "prod_dimensions": {
                "Height": "12 cm",
                "Inside diameter": "14 cm",
                "Diameter": "16 cm",
                "Max. load": "2 kg"
            },
            "packaging": [
                "SVARTPEPPAR",
                "Plant pot holder",
                "Article no.:",
                "204.757.52",
                "Width: 16 cm",
                "Height: 16 cm",
                "Length: 22 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Even with limited space, you can create a small garden by hanging this plant pot holder on a balcony railing. Fits plant pots with a max. outer diameter of 15 cm and height of 14 cm. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475752/svartpeppar-plant-pot-holder-in-outdoor-black-20475752-0.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475752/svartpeppar-plant-pot-holder-in-outdoor-black-20475752-1.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475752/svartpeppar-plant-pot-holder-in-outdoor-black-20475752-2.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475752/svartpeppar-plant-pot-holder-in-outdoor-black-20475752-3.JPG"
            ],
            "materials": "Steel, Polyester powder coating"
        },
        "181": {
            "id": 181,
            "prod_name": "SVARTPEPPAR",
            "prod_price": "8",
            "prod_desc": "Plant pot holder, in/outdoor black",
            "prod_dimensions": {
                "Length": "45 cm",
                "Width": "16 cm",
                "Height": "12 cm",
                "Max. load": "5 kg"
            },
            "packaging": [
                "SVARTPEPPAR",
                "Plant pot holder",
                "Article no.:",
                "204.757.71",
                "Width: 21 cm",
                "Height: 16 cm",
                "Length: 45 cm",
                "Weight: 0.37 kg",
                "Package(s): 1"
            ],
            "prod_details": "Even with limited space, you can create a small garden by hanging this plant pot holder on a balcony railing. Fits 3 plant pots with a max. outer diameter of 14 cm. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-0.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-1.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-2.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-3.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-4.JPG",
                "data/plant pots/svartpeppar-plant-pot-holder-in-outdoor-black-20475771/svartpeppar-plant-pot-holder-in-outdoor-black-20475771-5.JPG"
            ],
            "materials": "Steel, Polyester powder coating"
        },
        "182": {
            "id": 182,
            "prod_name": "HOYA",
            "prod_price": "6",
            "prod_desc": "Potted plant, Wax plant",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "HOYA",
                "Potted plant",
                "Article no.:",
                "304.918.55",
                "Length: 40 cm",
                "Weight: 0.45 kg",
                "Diameter: 28 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style.",
            "sustainability": "",
            "images": [
                "data/plant pots/hoya-potted-plant-wax-plant-30491855/hoya-potted-plant-wax-plant-30491855-0.JPG",
                "data/plant pots/hoya-potted-plant-wax-plant-30491855/hoya-potted-plant-wax-plant-30491855-1.JPG",
                "data/plant pots/hoya-potted-plant-wax-plant-30491855/hoya-potted-plant-wax-plant-30491855-2.JPG",
                "data/plant pots/hoya-potted-plant-wax-plant-30491855/hoya-potted-plant-wax-plant-30491855-3.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "183": {
            "id": 183,
            "prod_name": "CAMPANULA PORTENSCHLAGIANA",
            "prod_price": "2",
            "prod_desc": "Potted plant, Bell flower",
            "prod_dimensions": {
                "Diameter of plant pot": "10.5 cm",
                "Height of plant": "22 cm"
            },
            "packaging": [
                "CAMPANULA PORTENSCHLAGIANA",
                "Potted plant",
                "Article no.:",
                "304.918.60",
                "Length: 21 cm",
                "Weight: 0.35 kg",
                "Diameter: 20 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Fast growing. Creeping plant; can also climb if supported. Perennial plant; lasts for 3 years or more. Flowering plants bloom between a few days and several months depending on the quality of the care.",
            "sustainability": "",
            "images": [
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-30491860/campanula-portenschlagiana-potted-plant-bell-flower-30491860-0.JPG",
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-30491860/campanula-portenschlagiana-potted-plant-bell-flower-30491860-1.JPG",
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-30491860/campanula-portenschlagiana-potted-plant-bell-flower-30491860-2.JPG",
                "data/plant pots/campanula-portenschlagiana-potted-plant-bell-flower-30491860/campanula-portenschlagiana-potted-plant-bell-flower-30491860-3.JPG"
            ],
            "materials": "Cultivated potted plant,Temperature,Minimum temperature 5\u00b0C.,Others,Only for decoration, not suitable for consumption.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Water,Water moderately."
        },
        "184": {
            "id": 184,
            "prod_name": "HYDRANGEA",
            "prod_price": "6",
            "prod_desc": "Potted plant, Hydrangea assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "35 cm"
            },
            "packaging": [
                "HYDRANGEA",
                "Potted plant",
                "Article no.:",
                "504.918.21",
                "Length: 44 cm",
                "Weight: 1.02 kg",
                "Diameter: 21 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Flowering plants bloom between a few days and several months depending on the quality of the care. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-0.JPG",
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-1.JPG",
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-2.JPG",
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-3.JPG",
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-4.JPG",
                "data/plant pots/hydrangea-potted-plant-hydrangea-assorted-colours-50491821/hydrangea-potted-plant-hydrangea-assorted-colours-50491821-5.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 0\u00b0C.,Water,Water often."
        },
        "185": {
            "id": 185,
            "prod_name": "FATSIA JAPONICA",
            "prod_price": "5",
            "prod_desc": "Potted plant, Aralia",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm",
                "Height of plant": "53 cm"
            },
            "packaging": [
                "FATSIA JAPONICA",
                "Potted plant",
                "Article no.:",
                "504.918.59",
                "Length: 57 cm",
                "Weight: 0.91 kg",
                "Diameter: 44 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Fast growing. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/fatsia-japonica-potted-plant-aralia-50491859/fatsia-japonica-potted-plant-aralia-50491859-0.JPG",
                "data/plant pots/fatsia-japonica-potted-plant-aralia-50491859/fatsia-japonica-potted-plant-aralia-50491859-1.JPG",
                "data/plant pots/fatsia-japonica-potted-plant-aralia-50491859/fatsia-japonica-potted-plant-aralia-50491859-2.JPG",
                "data/plant pots/fatsia-japonica-potted-plant-aralia-50491859/fatsia-japonica-potted-plant-aralia-50491859-3.JPG",
                "data/plant pots/fatsia-japonica-potted-plant-aralia-50491859/fatsia-japonica-potted-plant-aralia-50491859-4.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Water,Water moderately.,Temperature,Minimum temperature 12\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight."
        },
        "186": {
            "id": 186,
            "prod_name": "MUSCARI",
            "prod_price": "2",
            "prod_desc": "Potted plant, assorted Grape hyacinth",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm",
                "Height of plant": "15 cm"
            },
            "packaging": [
                "MUSCARI",
                "Potted plant",
                "Article no.:",
                "504.960.17",
                "Length: 18 cm",
                "Weight: 0.50 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style.",
            "sustainability": "",
            "images": [
                "data/plant pots/muscari-potted-plant-assorted-grape-hyacinth-50496017/muscari-potted-plant-assorted-grape-hyacinth-50496017-0.JPG",
                "data/plant pots/muscari-potted-plant-assorted-grape-hyacinth-50496017/muscari-potted-plant-assorted-grape-hyacinth-50496017-1.JPG",
                "data/plant pots/muscari-potted-plant-assorted-grape-hyacinth-50496017/muscari-potted-plant-assorted-grape-hyacinth-50496017-2.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 0\u00b0C.,Water,Water moderately."
        },
        "187": {
            "id": 187,
            "prod_name": "L\u00d6KARYD",
            "prod_price": "2",
            "prod_desc": "Potted plant, assorted/Narcissus",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "L\u00d6KARYD",
                "Potted plant",
                "Article no.:",
                "704.923.77",
                "Length: 14 cm",
                "Weight: 0.63 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Perennial. Scented flowers.",
            "sustainability": "",
            "images": [
                "data/plant pots/loekaryd-potted-plant-assorted-narcissus-70492377/loekaryd-potted-plant-assorted-narcissus-70492377-0.jpg"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 0\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Water,Water moderately."
        },
        "188": {
            "id": 188,
            "prod_name": "CITRUS",
            "prod_price": "13",
            "prod_desc": "Potted plant, Calamondin",
            "prod_dimensions": {
                "Diameter of plant pot": "15 cm",
                "Height of plant": "30 cm"
            },
            "packaging": [
                "CITRUS",
                "Potted plant",
                "Article no.:",
                "804.917.68",
                "Length: 36 cm",
                "Weight: 1.20 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to South and South East Asia. Sensitive to low temperatures. Scented flowers and fruits. Sensitive to draught.",
            "sustainability": "",
            "images": [
                "data/plant pots/citrus-potted-plant-calamondin-80491768/citrus-potted-plant-calamondin-80491768-0.JPG",
                "data/plant pots/citrus-potted-plant-calamondin-80491768/citrus-potted-plant-calamondin-80491768-1.JPG",
                "data/plant pots/citrus-potted-plant-calamondin-80491768/citrus-potted-plant-calamondin-80491768-2.JPG",
                "data/plant pots/citrus-potted-plant-calamondin-80491768/citrus-potted-plant-calamondin-80491768-3.JPG",
                "data/plant pots/citrus-potted-plant-calamondin-80491768/citrus-potted-plant-calamondin-80491768-4.JPG"
            ],
            "materials": "Cultivated potted plant,Edible.,Temperature,Minimum temperature 5\u00b0C.,Placement,Suitable for in- and outdoor use.,Place in a bright and sunny area.,Water,Water moderately."
        },
        "189": {
            "id": 189,
            "prod_name": "CUPRESSUS MACROCARPA",
            "prod_price": "10",
            "prod_desc": "Potted plant, cypress",
            "prod_dimensions": {
                "Diameter of plant pot": "24 cm",
                "Height of plant": "95 cm"
            },
            "packaging": [
                "CUPRESSUS MACROCARPA",
                "Potted plant",
                "Article no.:",
                "804.917.92",
                "Length: 96 cm",
                "Weight: 3.79 kg",
                "Diameter: 27 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Native to California. Evergreen plant. Fast growing. A scent is released when the plant is cut or crushed. Easy care plant.",
            "sustainability": "",
            "images": [
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-80491792/cupressus-macrocarpa-potted-plant-cypress-80491792-0.JPG",
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-80491792/cupressus-macrocarpa-potted-plant-cypress-80491792-1.JPG",
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-80491792/cupressus-macrocarpa-potted-plant-cypress-80491792-2.JPG",
                "data/plant pots/cupressus-macrocarpa-potted-plant-cypress-80491792/cupressus-macrocarpa-potted-plant-cypress-80491792-3.JPG"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 0\u00b0C.,Water,Water moderately."
        },
        "190": {
            "id": 190,
            "prod_name": "L\u00d6KARYD",
            "prod_price": "2",
            "prod_desc": "Potted plant, assorted/Tulip",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "L\u00d6KARYD",
                "Potted plant",
                "Article no.:",
                "804.923.91",
                "Length: 18 cm",
                "Weight: 0.50 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Decorate your home with plants combined with a plant pot to suit your style. Perennial. Scented flowers.",
            "sustainability": "",
            "images": [
                "data/plant pots/loekaryd-potted-plant-assorted-tulip-80492391/loekaryd-potted-plant-assorted-tulip-80492391-0.jpg"
            ],
            "materials": "Cultivated potted plant,Placement,Suitable for in- and outdoor use.,Place in a light area, out of direct sunlight.,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 0\u00b0C.,Water,Water moderately."
        },
        "191": {
            "id": 191,
            "prod_name": "FICUS LYRATA BAMBINO",
            "prod_price": "5",
            "prod_desc": "Potted plant, fiddle-leaf fig",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "FICUS LYRATA BAMBINO",
                "Potted plant",
                "Article no.:",
                "104.853.65",
                "Length: 33 cm",
                "Weight: 0.47 kg",
                "Diameter: 24 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365-0.JPG",
                "data/plant pots/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365-1.JPG",
                "data/plant pots/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365/ficus-lyrata-bambino-potted-plant-fiddle-leaf-fig-10485365-2.JPG"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 12\u00b0C.,Others,Only for decoration, not suitable for consumption.,Water,Water moderately."
        },
        "192": {
            "id": 192,
            "prod_name": "TILLANDSIA",
            "prod_price": "7",
            "prod_desc": "Potted plant, Curly slim ",
            "prod_dimensions": {
                "Diameter of plant pot": "12 cm"
            },
            "packaging": [
                "TILLANDSIA",
                "Potted plant",
                "Article no.:",
                "204.924.07",
                "Length: 36 cm",
                "Weight: 0.50 kg",
                "Diameter: 26 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/tillandsia-potted-plant-curly-slim-20492407/tillandsia-potted-plant-curly-slim-20492407-0.jpg"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Placement,For indoor use,Place in a bright and sunny area.,Temperature,Minimum temperature 12\u00b0C.,Water,Water sparingly."
        },
        "193": {
            "id": 193,
            "prod_name": "PHALAENOPSIS",
            "prod_price": "6",
            "prod_desc": "Potted plant with pot, Orchid/assorted colours",
            "prod_dimensions": {
                "Diameter of plant pot": "6 cm",
                "Height of plant": "25 cm"
            },
            "packaging": [
                "PHALAENOPSIS",
                "Potted plant with pot",
                "Article no.:",
                "205.050.18",
                "Length: 27 cm",
                "Weight: 0.28 kg",
                "Diameter: 9 cm",
                "Package(s): 1"
            ],
            "prod_details": "Native to Asia. Sensitive to draught. This plant is sensitive to temperature changes. This plant is sensitive to over watering. Too much water in the pot can restrict the oxygen flow to the roots, causing damage to the plant.",
            "sustainability": "",
            "images": [],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Main parts:,Earthenware, Pigmented powder coating,Placement,For indoor use,Place in a light area, out of direct sunlight.,Temperature,Minimum temperature 18\u00b0C.,Water,Water by immersing into a water-bath.,Water sparingly.,Others,Only for decoration, not suitable for consumption.,Cut flower-stalk after flowering period, to help the plant to re-flower."
        },
        "194": {
            "id": 194,
            "prod_name": "ILEX",
            "prod_price": "17",
            "prod_desc": "Potted plant, Holly",
            "prod_dimensions": {
                "Diameter of plant pot": "21 cm"
            },
            "packaging": [
                "ILEX",
                "Potted plant",
                "Article no.:",
                "304.924.40",
                "Length: 50 cm",
                "Weight: 6.00 kg",
                "Diameter: 23 cm",
                "Package(s): 1"
            ],
            "prod_details": "This plant is a real tough one \u2013 it that stands strong against both cold winter weather and diseases.",
            "sustainability": "",
            "images": [
                "data/plant pots/ilex-potted-plant-holly-30492440/ilex-potted-plant-holly-30492440-0.jpg"
            ],
            "materials": "Cultivated potted plant,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature -5\u00b0C.,Water,Water moderately.,Placement,For outdoor use.,Place in a bright and sunny area."
        },
        "195": {
            "id": 195,
            "prod_name": "ASPIDISTRA ELATIOR",
            "prod_price": "17",
            "prod_desc": "Potted plant, Cast iron plant",
            "prod_dimensions": {
                "Diameter of plant pot": "17 cm"
            },
            "packaging": [
                "ASPIDISTRA ELATIOR",
                "Potted plant",
                "Article no.:",
                "404.924.49",
                "Length: 75 cm",
                "Weight: 0.97 kg",
                "Diameter: 44 cm",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/plant pots/aspidistra-elatior-potted-plant-cast-iron-plant-40492449/aspidistra-elatior-potted-plant-cast-iron-plant-40492449-0.jpg"
            ],
            "materials": "Plant/ Substrate:,Cultivated potted plant,Pot:,Polypropylene plastic,Others,Only for decoration, not suitable for consumption.,Temperature,Minimum temperature 15\u00b0C.,Placement,For indoor use,Place in a light area, out of direct sunlight.,Water,Water sparingly."
        },
        "196": {
            "id": 196,
            "prod_name": "CURRYBLAD",
            "prod_price": "17",
            "prod_desc": "Flower box, outdoor terracotta",
            "prod_dimensions": {
                "Length": "55 cm",
                "Width": "24 cm",
                "Height": "20 cm"
            },
            "packaging": [
                "CURRYBLAD",
                "Flower box",
                "Article no.:",
                "004.758.14",
                "Width: 25 cm",
                "Height: 20 cm",
                "Length: 55 cm",
                "Weight: 8.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The porous terracotta holds excess water, so the plant can draw out moisture when needed. The drain hole in the bottom lets excess water drain off. For outdoor use only.",
            "sustainability": "",
            "images": [
                "data/plant pots/curryblad-flower-box-outdoor-terracotta-00475814/curryblad-flower-box-outdoor-terracotta-00475814-0.JPG",
                "data/plant pots/curryblad-flower-box-outdoor-terracotta-00475814/curryblad-flower-box-outdoor-terracotta-00475814-1.jpg",
                "data/plant pots/curryblad-flower-box-outdoor-terracotta-00475814/curryblad-flower-box-outdoor-terracotta-00475814-2.jpg",
                "data/plant pots/curryblad-flower-box-outdoor-terracotta-00475814/curryblad-flower-box-outdoor-terracotta-00475814-3.JPG"
            ],
            "materials": "Red clay"
        },
        "197": {
            "id": 197,
            "prod_name": "STJ\u00c4RNANIS",
            "prod_price": "25",
            "prod_desc": "Flower box, outdoor acacia",
            "prod_dimensions": {
                "Length": "75 cm",
                "Width": "27 cm",
                "Height": "27 cm"
            },
            "packaging": [
                "STJ\u00c4RNANIS",
                "Flower box",
                "Article no.:",
                "004.757.53",
                "Width: 26 cm",
                "Height: 12 cm",
                "Length: 75 cm",
                "Weight: 5.20 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can connect the flower boxes by stacking one on top of two others \u2012 extend your flower garden horizontally and make your own creative design. For added durability and so you can enjoy the natural expression of the wood, the furniture has been pre-treated with a layer of semi-transparent wood stain. Made of acacia, which is a hard and durable material suitable for outdoor use. For outdoor use only.",
            "sustainability": "Renewable material (wood).,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475753/stjaernanis-flower-box-outdoor-acacia-00475753-0.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475753/stjaernanis-flower-box-outdoor-acacia-00475753-1.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475753/stjaernanis-flower-box-outdoor-acacia-00475753-2.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475753/stjaernanis-flower-box-outdoor-acacia-00475753-3.JPG"
            ],
            "materials": "Basematerial:,Solid acacia, Acrylic stain,Plastic part:,PET plastic"
        },
        "198": {
            "id": 198,
            "prod_name": "STJ\u00c4RNANIS",
            "prod_price": "15",
            "prod_desc": "Flower box, outdoor acacia",
            "prod_dimensions": {
                "Length": "43 cm",
                "Width": "15 cm",
                "Height": "14 cm"
            },
            "packaging": [
                "STJ\u00c4RNANIS",
                "Flower box",
                "Article no.:",
                "004.757.86",
                "Width: 13 cm",
                "Height: 10 cm",
                "Length: 43 cm",
                "Weight: 1.85 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can connect the flower boxes by stacking one on top of two others \u2012 extend your flower garden horizontally and make your own creative design. Can be also hanged on the wall with the included hooks. For added durability and so you can enjoy the natural expression of the wood, the furniture has been pre-treated with a layer of semi-transparent wood stain. Made of acacia, which is a hard and durable material suitable for outdoor use. For outdoor use only.",
            "sustainability": "Renewable material (wood).,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475786/stjaernanis-flower-box-outdoor-acacia-00475786-0.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475786/stjaernanis-flower-box-outdoor-acacia-00475786-1.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475786/stjaernanis-flower-box-outdoor-acacia-00475786-2.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475786/stjaernanis-flower-box-outdoor-acacia-00475786-3.JPG",
                "data/plant pots/stjaernanis-flower-box-outdoor-acacia-00475786/stjaernanis-flower-box-outdoor-acacia-00475786-4.JPG"
            ],
            "materials": "Basematerial:,Solid acacia, Acrylic stain,Plastic part:,PET plastic"
        },
        "199": {
            "id": 199,
            "prod_name": "BLOMSTERB\u00d6NA",
            "prod_price": "1",
            "prod_desc": "Decoration stick, set of 2, in/outdoor/bird black",
            "prod_dimensions": {},
            "packaging": [
                "BLOMSTERB\u00d6NA",
                "Decoration stick, set of 2",
                "Article no.:",
                "304.663.23",
                "Width: 16 cm",
                "Height: 0 cm",
                "Length: 24 cm",
                "Weight: 0.08 kg",
                "Package(s): 1"
            ],
            "prod_details": "Stick the birds in to the soil/growing media of your plants as an extra decoration.   Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323-0.JPG",
                "data/plant pots/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323-1.JPG",
                "data/plant pots/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323/blomsterboena-decoration-stick-set-of-2-in-outdoor-bird-black-30466323-2.JPG"
            ],
            "materials": "Steel, Powder coating"
        },
        "200": {
            "id": 200,
            "prod_name": "GR\u00c4SMAR\u00d6",
            "prod_price": "3",
            "prod_desc": "3-piece gardening set, in/outdoor beige/light turquoise",
            "prod_dimensions": {
                "Length": "22 cm"
            },
            "packaging": [
                "GR\u00c4SMAR\u00d6",
                "3-piece gardening set",
                "Article no.:",
                "504.760.19",
                "Width: 14 cm",
                "Height: 7 cm",
                "Length: 24 cm",
                "Weight: 0.24 kg",
                "Package(s): 1"
            ],
            "prod_details": "The gardening tools are made of very hard wearing and durable plastic, reinforced with fibreglass. If you keep your gardening tools together on the included ring, then they will be easier to find. Comprises: 3 garden tools; 1 trowel, 1 hand rake and 1 bulb trowel. Suitable for both indoor and outdoor use.",
            "sustainability": "",
            "images": [
                "data/plant pots/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019-0.JPG",
                "data/plant pots/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019-1.JPG",
                "data/plant pots/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019-2.JPG",
                "data/plant pots/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019/graesmaroe-3-piece-gardening-set-in-outdoor-beige-light-turquoise-50476019-3.JPG"
            ],
            "materials": "Basematerial:,Reinforced polyamide plastic,End cap:,Polyamide plastic,Ring:,Acetal plastic"
        },
        "201": {
            "id": 201,
            "prod_name": "SVARTPEPPAR",
            "prod_price": "4",
            "prod_desc": "Plant stand, in/outdoor black",
            "prod_dimensions": {
                "Height": "21 cm",
                "Diameter": "19 cm",
                "Max. load/shelf": "5 kg"
            },
            "packaging": [
                "SVARTPEPPAR",
                "Plant stand",
                "Article no.:",
                "504.758.16",
                "Length: 21 cm",
                "Weight: 0.25 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "A plant stand makes it possible to decorate with plants everywhere in the home. The pot stand fits both large and small pots. All you need to do is turn the stand over. Fits pots with a max. outer diameter of 17 cm or 13.5 cm depending on which side of the stand is used. Suitable for both indoor and outdoor use.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/plant pots/svartpeppar-plant-stand-in-outdoor-black-50475816/svartpeppar-plant-stand-in-outdoor-black-50475816-0.JPG",
                "data/plant pots/svartpeppar-plant-stand-in-outdoor-black-50475816/svartpeppar-plant-stand-in-outdoor-black-50475816-1.JPG",
                "data/plant pots/svartpeppar-plant-stand-in-outdoor-black-50475816/svartpeppar-plant-stand-in-outdoor-black-50475816-2.JPG",
                "data/plant pots/svartpeppar-plant-stand-in-outdoor-black-50475816/svartpeppar-plant-stand-in-outdoor-black-50475816-3.jpg",
                "data/plant pots/svartpeppar-plant-stand-in-outdoor-black-50475816/svartpeppar-plant-stand-in-outdoor-black-50475816-4.JPG"
            ],
            "materials": "Steel, Polyester powder coating"
        }
    },
    "bin": {
        "0": {
            "id": 0,
            "prod_name": "EKOLN",
            "prod_price": "9",
            "prod_desc": "Waste bin, beige",
            "prod_dimensions": {
                "Height": "24 cm",
                "Diameter": "17 cm",
                "Volume": "3 l"
            },
            "packaging": [
                "EKOLN",
                "Waste bin",
                "Article no.:",
                "704.930.13",
                "Width: 17 cm",
                "Height: 17 cm",
                "Length: 25 cm",
                "Weight: 0.68 kg",
                "Package(s): 1"
            ],
            "prod_details": "There\u2019s no slamming when you throw out waste \u2013 the soft-closing lid closes smoothly and quietly. The waste bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this waste bin anywhere in your home, even in damp areas like the kitchen and bathroom. Combines with other products in EKOLN series.",
            "sustainability": "",
            "images": [
                "data/bin/ekoln-waste-bin-beige-70493013/ekoln-waste-bin-beige-70493013-0.JPG",
                "data/bin/ekoln-waste-bin-beige-70493013/ekoln-waste-bin-beige-70493013-1.JPG",
                "data/bin/ekoln-waste-bin-beige-70493013/ekoln-waste-bin-beige-70493013-2.JPG"
            ],
            "materials": "Bin:,Galvanized steel, Powder coating, Clear polyurethane lacquer,Lid:,Stainless steel, Clear lacquer,Lid holder/ Bucket/ Pedal/ Bottom part:,Polypropylene plastic (min. 20% recycled),Handle/ Metal handle/ Bar/ Screw:,Stainless steel,Soft closing device:,Acetal plastic, Stainless steel,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "1": {
            "id": 1,
            "prod_name": "FNISS",
            "prod_price": "1",
            "prod_desc": "Waste bin, black",
            "prod_dimensions": {
                "Height": "28 cm",
                "Diameter": "28 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "FNISS",
                "Waste bin",
                "Article no.:",
                "602.954.38",
                "Height: 28 cm",
                "Weight: 0.36 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "Plastic is a durable material which is simple to wipe clean.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/fniss-waste-bin-black-60295438/fniss-waste-bin-black-60295438-0.JPG",
                "data/bin/fniss-waste-bin-black-60295438/fniss-waste-bin-black-60295438-1.JPG",
                "data/bin/fniss-waste-bin-black-60295438/fniss-waste-bin-black-60295438-2.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "2": {
            "id": 2,
            "prod_name": "GIGANTISK",
            "prod_price": "25",
            "prod_desc": "Touch top bin, dark grey",
            "prod_dimensions": {
                "Width": "40 cm",
                "Height": "61 cm",
                "Volume": "60 l",
                "Depth": "40 cm"
            },
            "packaging": [
                "GIGANTISK",
                "Touch top bin",
                "Article no.:",
                "203.140.71",
                "Width: 41 cm",
                "Height: 31 cm",
                "Length: 51 cm",
                "Weight: 5.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "You open the waste bin easily by pressing lightly on the top of the lid. The square shape makes the waste bin easy to place - in a corner, along a kitchen worktop, or several in a row. When the bag is full, you just lift the lid and remove the ring that keeps the bag in place. Practical if you need more space for bulky waste like cartons or bottles. The waste bin should be used with a waste bag.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/gigantisk-touch-top-bin-dark-grey-20314071/gigantisk-touch-top-bin-dark-grey-20314071-0.JPG",
                "data/bin/gigantisk-touch-top-bin-dark-grey-20314071/gigantisk-touch-top-bin-dark-grey-20314071-1.JPG",
                "data/bin/gigantisk-touch-top-bin-dark-grey-20314071/gigantisk-touch-top-bin-dark-grey-20314071-2.JPG"
            ],
            "materials": "Polypropylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "4": {
            "id": 4,
            "prod_name": "FILUR",
            "prod_price": "9",
            "prod_desc": "Bin with lid, white",
            "prod_dimensions": {
                "Width": "29 cm",
                "Depth": "38 cm",
                "Height": "55 cm",
                "Volume": "42 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "FILUR",
                "Bin with lid",
                "Article no.:",
                "201.938.99",
                "This product has multiple packages.",
                "Width: 38 cm",
                "Height: 28 cm",
                "Length: 55 cm",
                "Weight: 1.88 kg",
                "Package(s): 1",
                "Width: 29 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.36 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to clean as the corners are rounded.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-0.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-1.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-2.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-3.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-4.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-5.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-6.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-7.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-8.JPG",
                "data/bin/filur-bin-with-lid-white-20193899/filur-bin-with-lid-white-20193899-9.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "5": {
            "id": 5,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "5",
            "prod_desc": "Bin with lid, light grey",
            "prod_dimensions": {
                "Lower outer measure, depth": "14.7 cm",
                "Lower outer measure, width": "20.1 cm",
                "Upper outer measure, depth": "21.2 cm",
                "Upper outer measure, width": "26.3 cm",
                "Height": "32.6 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting tin cans, small packages such as hygiene products or to store paper rolls or shopping bags.    H\u00c5LLBAR bins are stackable to save space. Place same-size bins on top of each other or place smaller bins on top of the larger ones.  The bins can be placed freestanding anywhere in your home or integrated in a cabinet or drawer.  A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   By mounting H\u00c5LLBAR pull out frame for waste sorting bins in a cabinet or H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer, the bins stay in place, and you get good access and overview.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. The bin is designed with rounded corners to make it easier to clean. The folding handle makes it easy to carry the bin with you to the waste station. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.  ",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.",
            "images": [
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-0.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-1.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-2.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-3.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-4.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-5.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-6.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-7.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-80398058/hallbar-bin-with-lid-light-grey-80398058-8.JPG"
            ],
            "materials": "Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "6": {
            "id": 6,
            "prod_name": "DR\u00d6NJ\u00d6NS",
            "prod_price": "3",
            "prod_desc": "Wastepaper basket, white",
            "prod_dimensions": {
                "Width": "26 cm",
                "Depth": "26 cm",
                "Height": "35 cm"
            },
            "packaging": [
                "DR\u00d6NJ\u00d6NS",
                "Wastepaper basket",
                "Article no.:",
                "604.601.07",
                "Width: 26 cm",
                "Height: 26 cm",
                "Length: 35 cm",
                "Weight: 0.93 kg",
                "Package(s): 1"
            ],
            "prod_details": "The included plastic feet protect the floor against scratching. Protective pads underneath.",
            "sustainability": "",
            "images": [
                "data/bin/droenjoens-wastepaper-basket-white-60460107/droenjoens-wastepaper-basket-white-60460107-0.JPG",
                "data/bin/droenjoens-wastepaper-basket-white-60460107/droenjoens-wastepaper-basket-white-60460107-1.JPG",
                "data/bin/droenjoens-wastepaper-basket-white-60460107/droenjoens-wastepaper-basket-white-60460107-2.JPG"
            ],
            "materials": "Mesh/ Bottom panel:,Steel, Epoxy/polyester powder coating,Scratch protection:,PET plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary.,Wipe dry with a clean cloth."
        },
        "7": {
            "id": 7,
            "prod_name": "BROGRUND",
            "prod_price": "12",
            "prod_desc": "Touch top bin, stainless steel",
            "prod_dimensions": {
                "Width": "21 cm",
                "Depth": "14 cm",
                "Height": "27 cm",
                "Volume": "4 l"
            },
            "packaging": [
                "BROGRUND",
                "Touch top bin",
                "Article no.:",
                "704.333.64",
                "Width: 22 cm",
                "Height: 14 cm",
                "Length: 28 cm",
                "Weight: 1.11 kg",
                "Package(s): 1"
            ],
            "prod_details": "You open the waste bin easily by pressing lightly on the top of the lid. Easy to keep clean, thanks to the fingerprint-proof surface. The slim design allows the bin to fit into narrow spaces. You can stand the bin on the floor or mount it to the wall. The bin is easy to move since it has a handle on the back. The waste bag can be easily secured around the handles of the inner bucket, so the bag is less visible from the outside. Handles make it easier to remove the inner bucket. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom. The waste bin should be used with a waste bag. Fittings for wall mounting included. Screws for wall mounting not included. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. If you are uncertain about what type of fixing devices to use, please contact your local hardware store. Combines with other products in the BROGRUND series.",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Special waste handling may be required. Please contact your local authorities for more information.",
            "images": [
                "data/bin/brogrund-touch-top-bin-stainless-steel-70433364/brogrund-touch-top-bin-stainless-steel-70433364-0.JPG",
                "data/bin/brogrund-touch-top-bin-stainless-steel-70433364/brogrund-touch-top-bin-stainless-steel-70433364-1.JPG",
                "data/bin/brogrund-touch-top-bin-stainless-steel-70433364/brogrund-touch-top-bin-stainless-steel-70433364-2.JPG",
                "data/bin/brogrund-touch-top-bin-stainless-steel-70433364/brogrund-touch-top-bin-stainless-steel-70433364-3.JPG",
                "data/bin/brogrund-touch-top-bin-stainless-steel-70433364/brogrund-touch-top-bin-stainless-steel-70433364-4.JPG"
            ],
            "materials": "Bin:,Stainless steel, Paint,Lid:,Stainless steel, Polypropylene plastic (min. 20% recycled), Paint,Bucket/ Bottom:,Polypropylene plastic (min. 20% recycled),Connector:,Reinforced polyamide plastic,Handle:,Stainless steel,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "8": {
            "id": 8,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "12",
            "prod_desc": "Bin with lid, light grey",
            "prod_dimensions": {
                "Lower outer measure, depth": "30.3 cm",
                "Lower outer measure, width": "18.3 cm",
                "Upper outer measure, depth": "38.8 cm",
                "Upper outer measure, width": "25.1 cm",
                "Height": "55.0 cm",
                "Volume": "35 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "504.202.06",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 26 cm",
                "Length: 55 cm",
                "Weight: 1.63 kg",
                "Package(s): 1",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 38 cm",
                "Weight: 0.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting things like cartons, bottles and newspapers or to give bulkier items their own space. H\u00c5LLBAR bins are stackable to save space. Place same-size bins on top of each other or place smaller bins on top of the larger ones.  A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   The bins can be placed freestanding anywhere in your home or integrated in a cabinet or drawer.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. The bin is designed with rounded corners to make it easier to clean. The folding handle makes it easy to carry the bin with you to the waste station. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.  ",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.",
            "images": [
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-0.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-1.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-2.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-3.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-4.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-5.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-6.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-50420206/hallbar-bin-with-lid-light-grey-50420206-7.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "9": {
            "id": 9,
            "prod_name": "TOFTAN",
            "prod_price": "3",
            "prod_desc": "Waste bin, white",
            "prod_dimensions": {
                "Height": "27 cm",
                "Diameter": "19 cm",
                "Volume": "4 l"
            },
            "packaging": [
                "TOFTAN",
                "Waste bin",
                "Article no.:",
                "303.447.70",
                "Width: 23 cm",
                "Height: 19 cm",
                "Length: 27 cm",
                "Weight: 0.91 kg",
                "Package(s): 1"
            ],
            "prod_details": "There\u2019s no slamming when you throw out waste \u2013 the soft-closing lid closes smoothly and quietly. The waste bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this waste bin anywhere in your home, even in damp areas like the kitchen and bathroom. Combines with other products in TOFTAN series.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/toftan-waste-bin-white-30344770/toftan-waste-bin-white-30344770-0.JPG",
                "data/bin/toftan-waste-bin-white-30344770/toftan-waste-bin-white-30344770-1.JPG",
                "data/bin/toftan-waste-bin-white-30344770/toftan-waste-bin-white-30344770-2.JPG"
            ],
            "materials": "Bin/ Lid:,Stainless steel, Powder coating,Bottom:,Reinforced polypropylene plastic (min. 20% recycled),Connector/ Pedal/ Bucket:,Polypropylene plastic (min. 20% recycled),Handle/ Bar/ Support/ Plate:,Stainless steel,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "10": {
            "id": 10,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "28",
            "prod_desc": "Waste sorting solution, with pull-out/light grey",
            "prod_dimensions": {
                "Volume": "20 l"
            },
            "packaging": [
                "This product comes as 5 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 2",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 2",
                "H\u00c5LLBAR",
                "Pull-out frame for waste sorting",
                "Article no.:",
                "204.228.53",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 49 cm",
                "Weight: 2.82 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This narrow combination is suitable if you have limited space and choose to sort your waste at the recycling station. A combination with 2 bins that is perfect for sorting your tin cans and smaller packages. You can also use the bins for practical storage of, for example, toilet paper rolls or shopping bags. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   Mount this pull-out frame inside your cabinet to hide your waste sorting behind a door. Easy to mount and use in cabinets throughout the home. The pull-out frame gives you quick access and a good overview of your waste sorting and keeps your bin stable. Pull it out to sort and push it back when you are done. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. To be mounted at the bottom of a cabinet.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Pull-out frame for waste sorting,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803/hallbar-waste-sorting-solution-with-pull-out-light-grey-s79308803-3.JPG"
            ],
            "materials": "Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Pull-out frame for waste sorting,Tray/ Frame:,Polypropylene plastic (min. 20% recycled),Corner fitting:,Reinforced polypropylene plastic (min. 20% recycled),Runners:,Steel"
        },
        "11": {
            "id": 11,
            "prod_name": "MJ\u00d6SA",
            "prod_price": "29",
            "prod_desc": "Pedal bin, dark grey",
            "prod_dimensions": {
                "Height": "68 cm",
                "Diameter": "33.5 cm",
                "Volume": "30 l"
            },
            "packaging": [
                "MJ\u00d6SA",
                "Pedal bin",
                "Article no.:",
                "004.228.54",
                "Width: 35 cm",
                "Height: 35 cm",
                "Length: 71 cm",
                "Weight: 4.51 kg",
                "Package(s): 1"
            ],
            "prod_details": "The lid has soft-closing gas hinges, which prevents the risk of getting your fingers caught when closing it. Easy to empty and clean as the inner bucket can be removed. The bin is easy to move since it has a handle on the back. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "",
            "images": [
                "data/bin/mjoesa-pedal-bin-dark-grey-00422854/mjoesa-pedal-bin-dark-grey-00422854-0.JPG",
                "data/bin/mjoesa-pedal-bin-dark-grey-00422854/mjoesa-pedal-bin-dark-grey-00422854-1.JPG",
                "data/bin/mjoesa-pedal-bin-dark-grey-00422854/mjoesa-pedal-bin-dark-grey-00422854-2.JPG"
            ],
            "materials": "Body:,Steel, Galvanized steel, Powder coating,Lid/ Handle/ Screw/ Plate:,Stainless steel,Lid holder/ Bucket/ Connector:,Polypropylene plastic,Bar:,Steel, Galvanized,Bottom part:,Stainless steel, Synthetic rubber,Closing device:,Acetal plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "12": {
            "id": 12,
            "prod_name": "SORTERA",
            "prod_price": "9",
            "prod_desc": "Waste sorting bin with lid, white",
            "prod_dimensions": {
                "Width": "41 cm",
                "Depth": "55 cm",
                "Height": "45 cm",
                "Volume": "60 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SORTERA",
                "Waste sorting bin with lid",
                "Article no.:",
                "702.558.99",
                "This product has multiple packages.",
                "Width: 45 cm",
                "Height: 40 cm",
                "Length: 56 cm",
                "Weight: 1.94 kg",
                "Package(s): 1",
                "Width: 41 cm",
                "Height: 5 cm",
                "Length: 59 cm",
                "Weight: 0.81 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can easily access the contents of a bin, even when stacked, because it has a folding lid. Suitable for waste sorting of glass, metal, plastic, newspapers, etc. Not suitable for outdoor use. To avoid tipping, do not stack more than 2 SORTERA 60 l bins on top of each other. Store heavier things at the bottom.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/sortera-waste-sorting-bin-with-lid-white-70255899/sortera-waste-sorting-bin-with-lid-white-70255899-0.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-70255899/sortera-waste-sorting-bin-with-lid-white-70255899-1.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-70255899/sortera-waste-sorting-bin-with-lid-white-70255899-2.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-70255899/sortera-waste-sorting-bin-with-lid-white-70255899-3.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-70255899/sortera-waste-sorting-bin-with-lid-white-70255899-4.JPG"
            ],
            "materials": "Polypropylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "13": {
            "id": 13,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "9",
            "prod_desc": "Bin with lid, light grey",
            "prod_dimensions": {
                "Lower outer measure, depth": "32.1 cm",
                "Lower outer measure, width": "20.1 cm",
                "Upper outer measure, depth": "38.6 cm",
                "Upper outer measure, width": "26.3 cm",
                "Height": "32.6 cm",
                "Volume": "22 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 1",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting things like cardboard, plastic, paper, bottles, glass, tin cans, envelopes and advertising mail. H\u00c5LLBAR bins are stackable to save space. Place same-size bins on top of each other or place smaller bins on top of the larger ones.  It is easy to access the bin even when stacked thanks to the included lid. It is hinged and can be opened in two ways.   A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   The bins can be placed freestanding anywhere in your home or integrated in a cabinet or drawer.  The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. By mounting H\u00c5LLBAR pull out frame for waste sorting bins in a cabinet or H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer, the bins stay in place, and you get good access and overview.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The bin is designed with rounded corners to make it easier to clean. The folding handle makes it easy to carry the bin with you to the waste station. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.  ",
            "sustainability": "By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.",
            "images": [
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-0.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-1.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-2.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-3.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-4.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-5.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-6.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-7.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-20420203/hallbar-bin-with-lid-light-grey-20420203-8.JPG"
            ],
            "materials": "Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "14": {
            "id": 14,
            "prod_name": "KNODD",
            "prod_price": "15",
            "prod_desc": "Bin with lid, grey",
            "prod_dimensions": {
                "Height": "51 cm",
                "Diameter": "41 cm",
                "Volume": "40 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KNODD",
                "Bin with lid",
                "Article no.:",
                "903.153.12",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 40 cm",
                "Length: 45 cm",
                "Weight: 2.44 kg",
                "Package(s): 1",
                "Width: 41 cm",
                "Height: 4 cm",
                "Length: 41 cm",
                "Weight: 0.61 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to fill up and empty as you can secure the lid on the edge of the bin. Can be used anywhere in your home, even in damp areas like the bathroom and under covered balconies. Only recommended for indoor use.",
            "sustainability": "",
            "images": [
                "data/bin/knodd-bin-with-lid-grey-90315312/knodd-bin-with-lid-grey-90315312-0.JPG",
                "data/bin/knodd-bin-with-lid-grey-90315312/knodd-bin-with-lid-grey-90315312-1.JPG",
                "data/bin/knodd-bin-with-lid-grey-90315312/knodd-bin-with-lid-grey-90315312-2.JPG",
                "data/bin/knodd-bin-with-lid-grey-90315312/knodd-bin-with-lid-grey-90315312-3.JPG"
            ],
            "materials": "Bin/ Lid:,Steel, Epoxy/polyester powder coating,Handle/ Hook:,Steel, Galvanized,Scratch protection:,Polyethylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary.,Wipe dry with a clean cloth."
        },
        "15": {
            "id": 15,
            "prod_name": "SN\u00c4PP",
            "prod_price": "7",
            "prod_desc": "Pedal bin, white",
            "prod_dimensions": {
                "Height": "29 cm",
                "Diameter": "26 cm",
                "Volume": "5 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SN\u00c4PP",
                "Pedal bin",
                "Article no.:",
                "002.454.27",
                "This product has multiple packages.",
                "Length: 25 cm",
                "Weight: 0.77 kg",
                "Diameter: 26 cm",
                "Package(s): 1",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 30 cm",
                "Weight: 0.65 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. If you tuck the edges of the plastic bag into the handle of the inside container, it won\u2019t be visible when the pedal bin is closed. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-0.JPG",
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-1.JPG",
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-2.JPG",
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-3.JPG",
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-4.JPG",
                "data/bin/snaepp-pedal-bin-white-00245427/snaepp-pedal-bin-white-00245427-5.JPG"
            ],
            "materials": "Basematerial/ Basematerial:,Polypropylene plastic,Pedal/ Pedal:,Reinforced polypropylene plastic,Handle/ Handle:,Stainless steel,Feet/ Feet:,Synthetic rubber"
        },
        "16": {
            "id": 16,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "4",
            "prod_desc": "Bin with lid, light grey",
            "prod_dimensions": {
                "Lower outer measure, depth": "11.7 cm",
                "Lower outer measure, width": "16.6 cm",
                "Upper outer measure, depth": "16.2 cm",
                "Upper outer measure, width": "20.0 cm",
                "Height": "17.1 cm",
                "Volume": "3 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "904.321.94",
                "This product has multiple packages.",
                "Width: 17 cm",
                "Height: 15 cm",
                "Length: 20 cm",
                "Weight: 0.25 kg",
                "Package(s): 1",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting used batteries and light bulbs, or to store smaller items like sponges, cloths, tea lights and crayons. H\u00c5LLBAR bins are stackable to save space. Place same-size bins on top of each other or place smaller bins on top of the larger ones.  The bins can be placed freestanding anywhere in your home or integrated in a cabinet or drawer.  By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer 80x45 cm or 80x60 cm, the bins stay in place, and you get good access and overview.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin.",
            "sustainability": "By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.",
            "images": [
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-0.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-1.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-2.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-3.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-4.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-5.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-6.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-7.JPG",
                "data/bin/hallbar-bin-with-lid-light-grey-90432194/hallbar-bin-with-lid-light-grey-90432194-8.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "17": {
            "id": 17,
            "prod_name": "PLEJA",
            "prod_price": "8",
            "prod_desc": "Wastepaper basket, black",
            "prod_dimensions": {
                "Height": "31 cm",
                "Volume": "20 l"
            },
            "packaging": [
                "PLEJA",
                "Wastepaper basket",
                "Article no.:",
                "604.114.66",
                "Width: 29 cm",
                "Height: 29 cm",
                "Length: 31 cm",
                "Weight: 0.71 kg",
                "Package(s): 1"
            ],
            "prod_details": "Can be used anywhere in your home, even in damp areas like the bathroom. Your things lie steady since the bottom is made of cork.  The plastic feet protect the surface against scratching. 4 plastic feet included.",
            "sustainability": "",
            "images": [
                "data/bin/pleja-wastepaper-basket-black-60411466/pleja-wastepaper-basket-black-60411466-0.JPG",
                "data/bin/pleja-wastepaper-basket-black-60411466/pleja-wastepaper-basket-black-60411466-1.JPG",
                "data/bin/pleja-wastepaper-basket-black-60411466/pleja-wastepaper-basket-black-60411466-2.JPG"
            ],
            "materials": "Basematerial:,Steel, Powder coating,Bottom part:,Cork,Foot:,Synthetic rubber,Wipe clean with a damp cloth.,Wipe dry with a clean cloth."
        },
        "18": {
            "id": 18,
            "prod_name": "STRAPATS",
            "prod_price": "7",
            "prod_desc": "Pedal bin, stainless steel",
            "prod_dimensions": {
                "Height": "28 cm",
                "Diameter": "20 cm",
                "Volume": "4.6 l"
            },
            "packaging": [
                "STRAPATS",
                "Pedal bin",
                "Article no.:",
                "402.454.11",
                "Width: 23 cm",
                "Height: 22 cm",
                "Length: 29 cm",
                "Weight: 1.18 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "Possible to separate for recycling or energy recovery if available in your community.",
            "images": [
                "data/bin/strapats-pedal-bin-stainless-steel-40245411/strapats-pedal-bin-stainless-steel-40245411-0.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-40245411/strapats-pedal-bin-stainless-steel-40245411-1.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-40245411/strapats-pedal-bin-stainless-steel-40245411-2.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-40245411/strapats-pedal-bin-stainless-steel-40245411-3.JPG"
            ],
            "materials": "Body/ Lid/ Handle/ Metal handle:,Stainless steel,Lid holder/ Bucket/ Bottom part:,Polypropylene plastic,Bar:,Steel, Galvanized,Mechanism:,Stainless steel, EVA plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "19": {
            "id": 19,
            "prod_name": "KNODD",
            "prod_price": "15",
            "prod_desc": "Bin with lid, white",
            "prod_dimensions": {
                "Height": "51 cm",
                "Diameter": "41 cm",
                "Volume": "40 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KNODD",
                "Bin with lid",
                "Article no.:",
                "600.456.56",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 40 cm",
                "Length: 45 cm",
                "Weight: 2.44 kg",
                "Package(s): 1",
                "Width: 41 cm",
                "Height: 4 cm",
                "Length: 41 cm",
                "Weight: 0.61 kg",
                "Package(s): 1"
            ],
            "prod_details": "Can be used anywhere in your home, even in damp areas like the bathroom and under covered balconies. Only recommended for indoor use.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/knodd-bin-with-lid-white-60045656/knodd-bin-with-lid-white-60045656-0.JPG",
                "data/bin/knodd-bin-with-lid-white-60045656/knodd-bin-with-lid-white-60045656-1.JPG",
                "data/bin/knodd-bin-with-lid-white-60045656/knodd-bin-with-lid-white-60045656-2.JPG",
                "data/bin/knodd-bin-with-lid-white-60045656/knodd-bin-with-lid-white-60045656-3.JPG"
            ],
            "materials": "Bin/ Lid:,Steel, Epoxy/polyester powder coating,Handle/ Hook:,Steel, Galvanized,Scratch protection:,Polyethylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary.,Wipe dry with a clean cloth."
        },
        "20": {
            "id": 20,
            "prod_name": "SORTERA",
            "prod_price": "6",
            "prod_desc": "Waste sorting bin with lid, white",
            "prod_dimensions": {
                "Width": "41 cm",
                "Depth": "55 cm",
                "Height": "28 cm",
                "Volume": "37 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SORTERA",
                "Waste sorting bin with lid",
                "Article no.:",
                "102.558.97",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 28 cm",
                "Length: 56 cm",
                "Weight: 1.36 kg",
                "Package(s): 1",
                "Width: 41 cm",
                "Height: 5 cm",
                "Length: 59 cm",
                "Weight: 0.79 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can easily access the contents of a bin, even when stacked, because it has a folding lid. Suitable for waste sorting of glass, metal, plastic, newspapers, etc. Not suitable for outdoor use. To avoid tipping, do not stack more than 3 SORTERA 37 l bins on top of each other. Store heavier things at the bottom.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-0.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-1.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-2.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-3.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-4.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-5.JPG",
                "data/bin/sortera-waste-sorting-bin-with-lid-white-10255897/sortera-waste-sorting-bin-with-lid-white-10255897-6.JPG"
            ],
            "materials": "Polypropylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "21": {
            "id": 21,
            "prod_name": "KNODD",
            "prod_price": "10",
            "prod_desc": "Bin with lid, white",
            "prod_dimensions": {
                "Height": "32 cm",
                "Diameter": "34 cm",
                "Volume": "16 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KNODD",
                "Bin with lid",
                "Article no.:",
                "900.990.49",
                "This product has multiple packages.",
                "Width: 32 cm",
                "Height: 29 cm",
                "Length: 32 cm",
                "Weight: 1.14 kg",
                "Package(s): 1",
                "Width: 34 cm",
                "Height: 3 cm",
                "Length: 34 cm",
                "Weight: 0.35 kg",
                "Package(s): 1"
            ],
            "prod_details": "Can be used anywhere in your home, even in damp areas like the bathroom and under covered balconies. Only recommended for indoor use.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/knodd-bin-with-lid-white-90099049/knodd-bin-with-lid-white-90099049-0.JPG",
                "data/bin/knodd-bin-with-lid-white-90099049/knodd-bin-with-lid-white-90099049-1.JPG",
                "data/bin/knodd-bin-with-lid-white-90099049/knodd-bin-with-lid-white-90099049-2.JPG",
                "data/bin/knodd-bin-with-lid-white-90099049/knodd-bin-with-lid-white-90099049-3.JPG"
            ],
            "materials": "Bin/ Lid:,Steel, Epoxy/polyester powder coating,Handle/ Hook:,Steel, Galvanized,Scratch protection:,Polyethylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary.,Wipe dry with a clean cloth."
        },
        "22": {
            "id": 22,
            "prod_name": "SN\u00c4PP",
            "prod_price": "7",
            "prod_desc": "Pedal bin, grey",
            "prod_dimensions": {
                "Height": "29 cm",
                "Diameter": "26 cm",
                "Volume": "5 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SN\u00c4PP",
                "Pedal bin",
                "Article no.:",
                "302.454.21",
                "This product has multiple packages.",
                "Length: 25 cm",
                "Weight: 0.77 kg",
                "Diameter: 26 cm",
                "Package(s): 1",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 30 cm",
                "Weight: 0.65 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. If you tuck the edges of the plastic bag into the handle of the inside container, it won\u2019t be visible when the pedal bin is closed. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/snaepp-pedal-bin-grey-30245421/snaepp-pedal-bin-grey-30245421-0.JPG",
                "data/bin/snaepp-pedal-bin-grey-30245421/snaepp-pedal-bin-grey-30245421-1.JPG",
                "data/bin/snaepp-pedal-bin-grey-30245421/snaepp-pedal-bin-grey-30245421-2.JPG",
                "data/bin/snaepp-pedal-bin-grey-30245421/snaepp-pedal-bin-grey-30245421-3.JPG"
            ],
            "materials": "Basematerial/ Basematerial:,Polypropylene plastic,Pedal/ Pedal:,Reinforced polypropylene plastic,Handle/ Handle:,Stainless steel,Feet/ Feet:,Synthetic rubber"
        },
        "23": {
            "id": 23,
            "prod_name": "KNODD",
            "prod_price": "10",
            "prod_desc": "Bin with lid, grey",
            "prod_dimensions": {
                "Height": "32 cm",
                "Diameter": "34 cm",
                "Volume": "16 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KNODD",
                "Bin with lid",
                "Article no.:",
                "603.122.49",
                "This product has multiple packages.",
                "Width: 32 cm",
                "Height: 29 cm",
                "Length: 32 cm",
                "Weight: 1.14 kg",
                "Package(s): 1",
                "Width: 34 cm",
                "Height: 3 cm",
                "Length: 34 cm",
                "Weight: 0.35 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to fill up and empty as you can secure the lid on the edge of the bin. Can be used anywhere in your home, even in damp areas like the bathroom and under covered balconies. Only recommended for indoor use.",
            "sustainability": "",
            "images": [
                "data/bin/knodd-bin-with-lid-grey-60312249/knodd-bin-with-lid-grey-60312249-0.JPG",
                "data/bin/knodd-bin-with-lid-grey-60312249/knodd-bin-with-lid-grey-60312249-1.JPG",
                "data/bin/knodd-bin-with-lid-grey-60312249/knodd-bin-with-lid-grey-60312249-2.JPG",
                "data/bin/knodd-bin-with-lid-grey-60312249/knodd-bin-with-lid-grey-60312249-3.JPG",
                "data/bin/knodd-bin-with-lid-grey-60312249/knodd-bin-with-lid-grey-60312249-4.JPG"
            ],
            "materials": "Bin/ Lid:,Steel, Epoxy/polyester powder coating,Handle/ Hook:,Steel, Galvanized,Scratch protection:,Polyethylene plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary.,Wipe dry with a clean cloth."
        },
        "24": {
            "id": 24,
            "prod_name": "VARIERA",
            "prod_price": "3",
            "prod_desc": "Waste bin, white",
            "prod_dimensions": {
                "Length": "27 cm",
                "Width": "16 cm",
                "Height": "46 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "VARIERA",
                "Waste bin",
                "Article no.:",
                "801.822.37",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 82 cm",
                "Weight: 0.44 kg",
                "Package(s): 1"
            ],
            "prod_details": "Rounded corners for easy cleaning. VARIERA waste bins are designed to suit different people's needs and homes when it comes to waste sorting. Choose the sizes of VARIERA waste bins that suit you best.",
            "sustainability": "",
            "images": [
                "data/bin/variera-waste-bin-white-80182237/variera-waste-bin-white-80182237-0.JPG",
                "data/bin/variera-waste-bin-white-80182237/variera-waste-bin-white-80182237-1.JPG",
                "data/bin/variera-waste-bin-white-80182237/variera-waste-bin-white-80182237-2.JPG"
            ],
            "materials": "Polypropylene plastic,Wipe clean with a damp cloth.,Wipe dry with a clean cloth."
        },
        "25": {
            "id": 25,
            "prod_name": "STRAPATS",
            "prod_price": "12",
            "prod_desc": "Pedal bin, stainless steel",
            "prod_dimensions": {
                "Height": "41 cm",
                "Diameter": "25 cm",
                "Volume": "11.5 l"
            },
            "packaging": [
                "STRAPATS",
                "Pedal bin",
                "Article no.:",
                "502.454.15",
                "Width: 27 cm",
                "Height: 27 cm",
                "Length: 41 cm",
                "Weight: 1.98 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "Possible to separate for recycling or energy recovery if available in your community.",
            "images": [
                "data/bin/strapats-pedal-bin-stainless-steel-50245415/strapats-pedal-bin-stainless-steel-50245415-0.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-50245415/strapats-pedal-bin-stainless-steel-50245415-1.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-50245415/strapats-pedal-bin-stainless-steel-50245415-2.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-50245415/strapats-pedal-bin-stainless-steel-50245415-3.JPG",
                "data/bin/strapats-pedal-bin-stainless-steel-50245415/strapats-pedal-bin-stainless-steel-50245415-4.JPG"
            ],
            "materials": "Body/ Lid/ Handle/ Metal handle:,Stainless steel,Lid holder/ Bucket/ Bottom part:,Polypropylene plastic,Bar:,Steel, Galvanized,Mechanism:,Stainless steel, EVA plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "26": {
            "id": 26,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "28",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer/light grey",
            "prod_dimensions": {
                "Volume": "44 l"
            },
            "packaging": [
                "This product comes as 5 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 2",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 2",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "804.228.69",
                "Width: 12 cm",
                "Height: 2 cm",
                "Length: 55 cm",
                "Weight: 0.87 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This narrow combination is suitable if you have limited space and choose to sort your waste at the recycling station. A combination with 2 bins for sorting your cartons, plastic, paper, bottles, glass, jars, envelopes and advertising mail. You can also use the bins for practical storage of, for example, toilet paper rolls or shopping bags. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 60x60 cm or in MAXIMERA high drawer 60x45 cm to allow space for pipes behind the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-4.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s19308839-5.JPG"
            ],
            "materials": "Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "27": {
            "id": 27,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "28",
            "prod_desc": "Waste sorting solution, with pull-out ventilated/light grey",
            "prod_dimensions": {
                "Volume": "20 l"
            },
            "packaging": [
                "This product comes as 5 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Pull-out frame for waste sorting",
                "Article no.:",
                "204.228.53",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 49 cm",
                "Weight: 2.82 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This narrow combination is suitable if you have limited space and choose to sort your waste at the recycling station. A combination with 1 bin for sorting your tin cans and smaller packages and 1 for dry and wet organic waste. You can also use the bins for practical storage of, for example, toilet paper rolls or shopping bags. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   Mount this pull-out frame inside your cabinet to hide your waste sorting behind a door. Easy to mount and use in cabinets throughout the home. The pull-out frame gives you quick access and a good overview of your waste sorting and keeps your bin stable. Pull it out to sort and push it back when you are done. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. To be mounted at the bottom of a cabinet.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Bin with lid for organic waste,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Pull-out frame for waste sorting,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816/hallbar-waste-sorting-solution-with-pull-out-ventilated-light-grey-s99308816-2.JPG"
            ],
            "materials": "Bin with lid for organic waste,Polypropylene plastic (min. 20% recycled),Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Pull-out frame for waste sorting,Tray/ Frame:,Polypropylene plastic (min. 20% recycled),Corner fitting:,Reinforced polypropylene plastic (min. 20% recycled),Runners:,Steel"
        },
        "28": {
            "id": 28,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "27",
            "prod_desc": "Waste sorting solution, with pull-out/light grey",
            "prod_dimensions": {
                "Volume": "22 l"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 1",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Pull-out frame for waste sorting",
                "Article no.:",
                "204.228.53",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 49 cm",
                "Weight: 2.82 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting things like cardboard, plastic, paper, bottles, glass, tin cans, envelopes and advertising mail. A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   Mount this pull-out frame inside your cabinet to hide your waste sorting behind a door. Easy to mount and use in cabinets throughout the home. The pull-out frame gives you quick access and a good overview of your waste sorting and keeps your bin stable. Pull it out to sort and push it back when you are done. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. To be mounted at the bottom of a cabinet.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Pull-out frame for waste sorting,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825/hallbar-waste-sorting-solution-with-pull-out-light-grey-s09308825-3.JPG"
            ],
            "materials": "Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Pull-out frame for waste sorting,Tray/ Frame:,Polypropylene plastic (min. 20% recycled),Corner fitting:,Reinforced polypropylene plastic (min. 20% recycled),Runners:,Steel"
        },
        "29": {
            "id": 29,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "5",
            "prod_desc": "Bin with lid for organic waste, light grey",
            "prod_dimensions": {
                "Lower outer measure, depth": "14.7 cm",
                "Lower outer measure, width": "20.1 cm",
                "Upper outer measure, depth": "21.2 cm",
                "Upper outer measure, width": "26.3 cm",
                "Height": "32.6 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This bin is perfect for sorting dry and wet organic waste such as coffee grounds and peels from fruits or vegetables.    The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  H\u00c5LLBAR bins are stackable to save space. Place same-size bins on top of each other or place smaller bins on top of the larger ones.  The bins can be placed freestanding anywhere in your home or integrated in a cabinet or drawer.  By mounting H\u00c5LLBAR pull out frame for waste sorting bins in a cabinet or H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer, the bins stay in place, and you get good access and overview.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  A lid is included to hide your waste. It\u2019s removeable for easy cleaning or if you prefer to keep your bin open.   The bin is designed with rounded corners to make it easier to clean. The folding handle makes it easy to carry the bin with you to the waste station. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin.",
            "sustainability": "By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.",
            "images": [
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-0.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-1.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-2.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-3.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-4.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-5.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-6.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-7.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-8.JPG",
                "data/bin/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882/hallbar-bin-with-lid-for-organic-waste-light-grey-80433882-9.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "30": {
            "id": 30,
            "prod_name": "TOFTAN",
            "prod_price": "8",
            "prod_desc": "Waste bin, grey",
            "prod_dimensions": {
                "Height": "27 cm",
                "Diameter": "19 cm",
                "Volume": "4 l"
            },
            "packaging": [
                "TOFTAN",
                "Waste bin",
                "Article no.:",
                "604.939.66",
                "Width: 23 cm",
                "Height: 19 cm",
                "Length: 27 cm",
                "Weight: 0.93 kg",
                "Package(s): 1"
            ],
            "prod_details": "There\u2019s no slamming when you throw out waste \u2013 the soft-closing lid closes smoothly and quietly. The waste bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this waste bin anywhere in your home, even in damp areas like the kitchen and bathroom. Combines with other products in TOFTAN series.",
            "sustainability": "",
            "images": [
                "data/bin/toftan-waste-bin-grey-60493966/toftan-waste-bin-grey-60493966-0.JPG",
                "data/bin/toftan-waste-bin-grey-60493966/toftan-waste-bin-grey-60493966-1.JPG"
            ],
            "materials": "Bin/ Lid:,Galvanized steel, Powder coating,Bottom:,Reinforced polypropylene plastic (min. 20% recycled),Connector/ Pedal/ Bucket:,Polypropylene plastic (min. 20% recycled),Handle/ Bar/ Support/ Plate:,Stainless steel,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "31": {
            "id": 31,
            "prod_name": "MJ\u00d6SA",
            "prod_price": "29",
            "prod_desc": "Pedal bin, red",
            "prod_dimensions": {
                "Height": "68 cm",
                "Diameter": "33.5 cm",
                "Volume": "30 l"
            },
            "packaging": [
                "MJ\u00d6SA",
                "Pedal bin",
                "Article no.:",
                "504.620.60",
                "Width: 34 cm",
                "Height: 34 cm",
                "Length: 70 cm",
                "Weight: 4.41 kg",
                "Package(s): 1"
            ],
            "prod_details": "The waste bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this waste bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "",
            "images": [
                "data/bin/mjoesa-pedal-bin-red-50462060/mjoesa-pedal-bin-red-50462060-0.JPG",
                "data/bin/mjoesa-pedal-bin-red-50462060/mjoesa-pedal-bin-red-50462060-1.JPG",
                "data/bin/mjoesa-pedal-bin-red-50462060/mjoesa-pedal-bin-red-50462060-2.JPG"
            ],
            "materials": "Body:,Steel, Galvanized steel, Powder coating,Lid/ Handle/ Screw/ Plate:,Stainless steel,Lid holder/ Bucket/ Connector:,Polypropylene plastic,Bar:,Steel, Galvanized,Bottom part:,Stainless steel, Synthetic rubber,Closing device:,Acetal plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "32": {
            "id": 32,
            "prod_name": "TOFTAN",
            "prod_price": "8",
            "prod_desc": "Waste bin, white",
            "prod_dimensions": {
                "Height": "27 cm",
                "Diameter": "19 cm",
                "Volume": "4 l"
            },
            "packaging": [
                "TOFTAN",
                "Waste bin",
                "Article no.:",
                "004.940.25",
                "Width: 20 cm",
                "Height: 20 cm",
                "Length: 27 cm",
                "Weight: 0.91 kg",
                "Package(s): 1"
            ],
            "prod_details": "There\u2019s no slamming when you throw out waste \u2013 the soft-closing lid closes smoothly and quietly. The waste bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this waste bin anywhere in your home, even in damp areas like the kitchen and bathroom. Combines with other products in TOFTAN series.",
            "sustainability": "",
            "images": [
                "data/bin/toftan-waste-bin-white-00494025/toftan-waste-bin-white-00494025-0.JPG",
                "data/bin/toftan-waste-bin-white-00494025/toftan-waste-bin-white-00494025-1.JPG",
                "data/bin/toftan-waste-bin-white-00494025/toftan-waste-bin-white-00494025-2.JPG"
            ],
            "materials": "Bin/ Lid:,Galvanized steel, Powder coating,Bottom:,Reinforced polypropylene plastic (min. 20% recycled),Connector/ Pedal/ Bucket:,Polypropylene plastic (min. 20% recycled),Handle/ Bar/ Support/ Plate:,Stainless steel,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "33": {
            "id": 33,
            "prod_name": "SN\u00c4PP",
            "prod_price": "12",
            "prod_desc": "Pedal bin, grey",
            "prod_dimensions": {
                "Height": "37 cm",
                "Diameter": "32 cm",
                "Volume": "12 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SN\u00c4PP",
                "Pedal bin",
                "Article no.:",
                "102.454.22",
                "This product has multiple packages.",
                "Length: 32 cm",
                "Weight: 1.40 kg",
                "Diameter: 32 cm",
                "Package(s): 1",
                "Width: 34 cm",
                "Height: 9 cm",
                "Length: 37 cm",
                "Weight: 0.99 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. If you tuck the edges of the plastic bag into the handle of the inside container, it won\u2019t be visible when the pedal bin is closed. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/snaepp-pedal-bin-grey-10245422/snaepp-pedal-bin-grey-10245422-0.JPG",
                "data/bin/snaepp-pedal-bin-grey-10245422/snaepp-pedal-bin-grey-10245422-1.JPG",
                "data/bin/snaepp-pedal-bin-grey-10245422/snaepp-pedal-bin-grey-10245422-2.JPG",
                "data/bin/snaepp-pedal-bin-grey-10245422/snaepp-pedal-bin-grey-10245422-3.JPG"
            ],
            "materials": "Basematerial:,Polypropylene plastic,Pedal:,Reinforced polypropylene plastic,Handle:,Stainless steel,Feet:,Synthetic rubber"
        },
        "34": {
            "id": 34,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "29",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer ventilated/light grey",
            "prod_dimensions": {
                "Volume": "42 l"
            },
            "packaging": [
                "This product comes as 7 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "804.228.69",
                "Width: 12 cm",
                "Height: 2 cm",
                "Length: 55 cm",
                "Weight: 0.87 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 1",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This narrow combination is suitable if you have limited space and choose to sort your waste at the recycling station. A combination with 1 bin for sorting your cans and smaller packages, 1 for cartons, plastic, bottles, jars and advertising mail, and 1 for dry and wet organic waste. You can also use the bins for practical storage of, for example, toilet paper rolls or shopping bags. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 60x60 cm or in MAXIMERA high drawer 60x45 cm to allow space for pipes behind the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Bin with lid for organic waste,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-4.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-5.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s29308829-6.JPG"
            ],
            "materials": "Bin with lid for organic waste,Polypropylene plastic (min. 20% recycled),Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "35": {
            "id": 35,
            "prod_name": "PLUGGIS",
            "prod_price": "10",
            "prod_desc": "Waste sorting bin, white",
            "prod_dimensions": {
                "Volume": "14 l",
                "Length": "35 cm",
                "Width": "31 cm",
                "Height": "22 cm"
            },
            "packaging": [
                "PLUGGIS",
                "Waste sorting bin",
                "Article no.:",
                "802.347.07",
                "Width: 31 cm",
                "Height: 22 cm",
                "Length: 35 cm",
                "Weight: 1.20 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can save space by stacking 2 boxes on top of one another.  Note! For your child's safety, do not stack these bins higher than 60 cm.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/pluggis-waste-sorting-bin-white-80234707/pluggis-waste-sorting-bin-white-80234707-0.JPG",
                "data/bin/pluggis-waste-sorting-bin-white-80234707/pluggis-waste-sorting-bin-white-80234707-1.JPG",
                "data/bin/pluggis-waste-sorting-bin-white-80234707/pluggis-waste-sorting-bin-white-80234707-2.JPG",
                "data/bin/pluggis-waste-sorting-bin-white-80234707/pluggis-waste-sorting-bin-white-80234707-3.JPG"
            ],
            "materials": "PET plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "36": {
            "id": 36,
            "prod_name": "KNALLA",
            "prod_price": "2",
            "prod_desc": "Bag, black/white",
            "prod_dimensions": {
                "Length": "40 cm",
                "Depth": "25 cm",
                "Height": "47 cm",
                "Max. load": "10 kg",
                "Volume": "47 l"
            },
            "packaging": [
                "KNALLA",
                "Bag",
                "Article no.:",
                "004.736.93",
                "Width: 35 cm",
                "Height: 0 cm",
                "Length: 49 cm",
                "Weight: 0.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "Perfect for transporting most things, from laundry and groceries to recyclable items. The contents won\u2019t fall out even if the bag drops, since the top zips closed. You can do something good for the environment by using this bag instead of disposable bags. Easy to clean by just wiping with a cloth dampened in water.",
            "sustainability": "",
            "images": [
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-0.JPG",
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-1.JPG",
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-2.JPG",
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-3.JPG",
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-4.JPG",
                "data/bin/knalla-bag-black-white-00473693/knalla-bag-black-white-00473693-5.JPG"
            ],
            "materials": "Fabric/ Webbing:,100% polypropylene,Zipper:,Zinc,Hand wash, cold (30\u00b0C).,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean."
        },
        "37": {
            "id": 37,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "30",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer ventilated/light grey",
            "prod_dimensions": {
                "Volume": "40 l"
            },
            "packaging": [
                "This product comes as 9 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 3",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 3",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "804.228.69",
                "Width: 12 cm",
                "Height: 2 cm",
                "Length: 55 cm",
                "Weight: 0.87 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This combination is suitable if you want to make it easy to sort our waste at home. A combination with 3 bins for sorting your cans and smaller packages such as hygiene products, and 1 for sorting dry and wet organic waste. You can also use the bins for practical storage of, for example, toilet paper rolls or shopping bags. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   Mount this pull-out frame inside your cabinet to hide your waste sorting behind a door. Easy to mount and use in cabinets throughout the home. The pull-out frame gives you quick access and a good overview of your waste sorting and keeps your bin stable. Pull it out to sort and push it back when you are done. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 60x60 cm or in MAXIMERA high drawer 60x45 cm to allow space for pipes behind the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,Bin with lid for organic waste,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s39308923-4.JPG"
            ],
            "materials": "Bin with lid for organic waste,Polypropylene plastic (min. 20% recycled),Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "38": {
            "id": 38,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "18",
            "prod_desc": "Pull-out frame for waste sorting, light grey",
            "prod_dimensions": {
                "Width": "26.5 cm",
                "Depth": "45 cm",
                "Height": "31.5 cm"
            },
            "packaging": [
                "H\u00c5LLBAR",
                "Pull-out frame for waste sorting",
                "Article no.:",
                "204.228.53",
                "Width: 27 cm",
                "Height: 8 cm",
                "Length: 49 cm",
                "Weight: 2.82 kg",
                "Package(s): 1"
            ],
            "prod_details": "Mount this pull-out frame inside your cabinet to hide your waste sorting behind a door. Easy to mount and use in cabinets throughout the home. The pull-out frame gives you quick access and a good overview of your waste sorting and keeps your bin stable. Pull it out to sort and push it back when you are done. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  25 year guarantee. Read about the terms in the guarantee brochure. Screws included. To be mounted at the bottom of a cabinet.",
            "sustainability": "By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853-0.JPG",
                "data/bin/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853-1.JPG",
                "data/bin/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853-2.JPG",
                "data/bin/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853/hallbar-pull-out-frame-for-waste-sorting-light-grey-20422853-3.JPG"
            ],
            "materials": "Tray/ Frame:,Polypropylene plastic (min. 20% recycled),Corner fitting:,Reinforced polypropylene plastic (min. 20% recycled),Runners:,Steel,Wipe dry with a clean cloth.,Wipe clean with a soft cloth dampened in water and a mild non-abrasive washing-up detergent or soap, if necessary."
        },
        "39": {
            "id": 39,
            "prod_name": "UTRUSTA",
            "prod_price": "6",
            "prod_desc": "Push opener",
            "prod_dimensions": {
                "Package quantity": "2 pack"
            },
            "packaging": [
                "UTRUSTA",
                "Push opener",
                "Article no.:",
                "802.302.24",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 23 cm",
                "Weight: 0.07 kg",
                "Package(s): 1"
            ],
            "prod_details": "Push to open; no handles needed.",
            "sustainability": "",
            "images": [
                "data/bin/utrusta-push-opener-80230224/utrusta-push-opener-80230224-0.JPG",
                "data/bin/utrusta-push-opener-80230224/utrusta-push-opener-80230224-1.JPG"
            ],
            "materials": "Body/ Slide:,Acetal plastic,Cover:,Steel, Brush finish nickel-plated,Spring/ Hook:,Steel,Adjustment pin/ Pin:,Polyamide plastic,Protection pad:,Synthetic rubber,Mounting plate:,Polyester,Wipe clean with a damp cloth.,Wipe dry with a clean cloth."
        },
        "40": {
            "id": 40,
            "prod_name": "STORSTOMMA",
            "prod_price": "1",
            "prod_desc": "Carrier bag, large, multicolour",
            "prod_dimensions": {
                "Width": "55 cm",
                "Depth": "35 cm",
                "Height": "37 cm",
                "Volume": "71 l"
            },
            "packaging": [
                "STORSTOMMA",
                "Carrier bag, large",
                "Article no.:",
                "104.832.10",
                "Width: 35 cm",
                "Height: 1 cm",
                "Length: 50 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to keep clean \u2013 just rinse and dry. Takes little room to store as it folds flat. Also suitable for waste sorting.",
            "sustainability": "",
            "images": [
                "data/bin/storstomma-carrier-bag-large-multicolour-10483210/storstomma-carrier-bag-large-multicolour-10483210-0.JPG",
                "data/bin/storstomma-carrier-bag-large-multicolour-10483210/storstomma-carrier-bag-large-multicolour-10483210-1.JPG"
            ],
            "materials": "100% polypropylene,Do not wash.,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean.,Wipe dry with a clean cloth."
        },
        "41": {
            "id": 41,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "42",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer/light grey",
            "prod_dimensions": {
                "Volume": "55 l"
            },
            "packaging": [
                "This product comes as 9 packages.",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "604.228.70",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 70 cm",
                "Weight: 1.12 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 2",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 2",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "904.321.94",
                "This product has multiple packages.",
                "Width: 17 cm",
                "Height: 15 cm",
                "Length: 20 cm",
                "Weight: 0.25 kg",
                "Package(s): 1",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This combination is suitable if you want to make it easy to sort our waste at home. A combination with 4 bins for sorting everything from cartons, bottles, cans and smaller packages to lightbulbs and batteries. You can also use the bins for practical storage of, for example, toilet paper rolls, shopping bags, sponges or tealights. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 80x60 cm or in MAXIMERA high drawer 80x45 cm to allow space for pipes the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-4.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-light-grey-s99309694-5.JPG"
            ],
            "materials": "Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Polypropylene plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "42": {
            "id": 42,
            "prod_name": "DIMPA",
            "prod_price": "3",
            "prod_desc": "Storage bag, transparent",
            "prod_dimensions": {
                "Length": "65 cm",
                "Depth": "22 cm",
                "Height": "65 cm"
            },
            "packaging": [
                "DIMPA",
                "Storage bag",
                "Article no.:",
                "100.567.70",
                "Width: 35 cm",
                "Height: 0 cm",
                "Length: 48 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "In this spacious bag there is plenty of room for what you want to save and store \u2013 and the contents are well-protected thanks to the zipper. Easy to keep clean \u2013 just rinse and dry. Takes little room to store as it folds flat. Also suitable for waste sorting. The bag can hold a maximum of 1 wheel with a diameter of 62 cm and a width of 20 cm. If the diameter is smaller, the wheel can be wider.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/dimpa-storage-bag-transparent-10056770/dimpa-storage-bag-transparent-10056770-0.JPG",
                "data/bin/dimpa-storage-bag-transparent-10056770/dimpa-storage-bag-transparent-10056770-1.JPG",
                "data/bin/dimpa-storage-bag-transparent-10056770/dimpa-storage-bag-transparent-10056770-2.JPG",
                "data/bin/dimpa-storage-bag-transparent-10056770/dimpa-storage-bag-transparent-10056770-3.JPG"
            ],
            "materials": "100% polypropylene,Do not wash.,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean.,Wipe clean with a damp cloth."
        },
        "43": {
            "id": 43,
            "prod_name": "\u00d6NSKLIG",
            "prod_price": "7",
            "prod_desc": "Stor baskets changing tbl set of 4, white",
            "prod_dimensions": {
                "Width": "27 cm",
                "Depth": "23 cm",
                "Height": "26 cm"
            },
            "packaging": [
                "\u00d6NSKLIG",
                "Stor baskets changing tbl set of 4",
                "Article no.:",
                "301.992.83",
                "Width: 25 cm",
                "Height: 21 cm",
                "Length: 27 cm",
                "Weight: 0.97 kg",
                "Package(s): 1"
            ],
            "prod_details": "With these storage baskets you can have everything from nappies and washcloths to skin care products and towels close at hand by the changing table. Perfect when you have a lively baby who requires all of your attention. The baskets save space as they hang on the edge of the changing table. You can choose to hang the waste bin on the edge of the changing table or stand it on the floor. The hooks give you a handy place for towels, washcloths or sleep suits. You can hang the hooks on the edge of the table or fasten them on the wall. Comprises: 4 storage baskets and 2 hooks, of which 1 hook is needed to hang up the largest storage basket.",
            "sustainability": "BPA (Bisphenol A) free,IKEA has banned BPA (Bisphenol A) in plastic products in the children\u2019s range (0-7 years) and in all food-contact products. IKEA phased out BPA already in 2006.,IKEA has strict requirements for the use of phthalates in all our products, and we have totally banned them in children\u2019s and food-contact products.,Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283-0.JPG",
                "data/bin/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283-1.JPG",
                "data/bin/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283-2.JPG",
                "data/bin/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283/oensklig-stor-baskets-changing-tbl-set-of-4-white-30199283-3.JPG"
            ],
            "materials": "Basematerial:,Polypropylene plastic,Hook:,Polyamide plastic,Wipe clean regularly with a cloth dampened in a mild cleaner."
        },
        "44": {
            "id": 44,
            "prod_name": "FRAKTA",
            "prod_price": "0",
            "prod_desc": "Carrier bag, large, blue",
            "prod_dimensions": {
                "Length": "55 cm",
                "Depth": "37 cm",
                "Height": "35 cm",
                "Max. load": "25 kg",
                "Volume": "71 l"
            },
            "packaging": [
                "FRAKTA",
                "Carrier bag, large",
                "Article no.:",
                "172.283.40",
                "Width: 23 cm",
                "Height: 1 cm",
                "Length: 35 cm",
                "Weight: 0.13 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to keep clean \u2013 just rinse and dry. Takes little room to store as it folds flat. Also suitable for waste sorting.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/frakta-carrier-bag-large-blue-17228340/frakta-carrier-bag-large-blue-17228340-0.JPG",
                "data/bin/frakta-carrier-bag-large-blue-17228340/frakta-carrier-bag-large-blue-17228340-1.JPG",
                "data/bin/frakta-carrier-bag-large-blue-17228340/frakta-carrier-bag-large-blue-17228340-2.JPG",
                "data/bin/frakta-carrier-bag-large-blue-17228340/frakta-carrier-bag-large-blue-17228340-3.JPG",
                "data/bin/frakta-carrier-bag-large-blue-17228340/frakta-carrier-bag-large-blue-17228340-4.JPG"
            ],
            "materials": "Basematerial:,100% polypropylene (min. 60% recycled),Handle:,100% polypropylene,Wipe clean with a cloth dampened in water."
        },
        "45": {
            "id": 45,
            "prod_name": "PLUGGIS",
            "prod_price": "7",
            "prod_desc": "Waste sorting bin, white",
            "prod_dimensions": {
                "Width": "31 cm",
                "Height": "15 cm",
                "Volume": "8 l",
                "Length": "34 cm"
            },
            "packaging": [
                "PLUGGIS",
                "Waste sorting bin",
                "Article no.:",
                "402.347.09",
                "Width: 31 cm",
                "Height: 15 cm",
                "Length: 34 cm",
                "Weight: 0.85 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can save space by stacking 2 boxes on top of one another.  Note! For your child's safety, do not stack these bins higher than 60 cm.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/pluggis-waste-sorting-bin-white-40234709/pluggis-waste-sorting-bin-white-40234709-0.JPG",
                "data/bin/pluggis-waste-sorting-bin-white-40234709/pluggis-waste-sorting-bin-white-40234709-1.JPG",
                "data/bin/pluggis-waste-sorting-bin-white-40234709/pluggis-waste-sorting-bin-white-40234709-2.JPG"
            ],
            "materials": "PET plastic,Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "46": {
            "id": 46,
            "prod_name": "UTRUSTA",
            "prod_price": "99",
            "prod_desc": "Push opener, electrical",
            "prod_dimensions": {
                "Length": "97 mm",
                "Width": "220 mm",
                "Height": "100 mm"
            },
            "packaging": [
                "UTRUSTA",
                "Push opener, electrical",
                "Article no.:",
                "302.386.99",
                "Width: 11 cm",
                "Height: 10 cm",
                "Length: 24 cm",
                "Weight: 0.78 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can open the waste sorting bin with the push of a finger \u2013 or use your hip, knee or foot if your hands are busy. Makes your waste sorting drawer open and close silently and effortlessly. You can open the waste sorting bin manually as needed, such as during a power failure. You can easily deactivate the motor when you want to clean the drawer front. The sensitive collision detection feature assures safety by interrupting opening if an obstruction is detected. Standby power consumption is very minimal (only 3,5 kWh per year). 5 year guarantee. Read about the terms in the guarantee brochure. Simple to install; all you need is MAXIMERA deep fully-extending drawer 45 cm and a power outlet.",
            "sustainability": "",
            "images": [
                "data/bin/utrusta-push-opener-electrical-30238699/utrusta-push-opener-electrical-30238699-0.JPG",
                "data/bin/utrusta-push-opener-electrical-30238699/utrusta-push-opener-electrical-30238699-1.JPG"
            ],
            "materials": "Basematerial:,Polyamide plastic,Hook:,Steel, Brush finish nickel-plated,Remove the plug from the socket, then wipe with a damp cloth."
        },
        "47": {
            "id": 47,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "44",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer ventilated/light grey",
            "prod_dimensions": {
                "Volume": "53 l"
            },
            "packaging": [
                "This product comes as 13 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 4",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 4",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "604.228.70",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 70 cm",
                "Weight: 1.12 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "904.321.94",
                "This product has multiple packages.",
                "Width: 17 cm",
                "Height: 15 cm",
                "Length: 20 cm",
                "Weight: 0.25 kg",
                "Package(s): 1",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This combination is suitable if you want to make it easy to sort our waste at home. A combination with 5 bins for sorting everything from cans and smaller packages to lightbulbs and batteries, and 1 for sorting dry and wet organic waste. You can also use the bins for practical storage of, for example, toilet paper rolls, shopping bags, sponges or tealights. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 80x60 cm or in MAXIMERA high drawer 80x45 cm to allow space for pipes the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Bin with lid for organic waste,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s09309698-4.JPG"
            ],
            "materials": "Bin with lid for organic waste/ bin with lid,Polypropylene plastic (min. 20% recycled),Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "48": {
            "id": 48,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "43",
            "prod_desc": "Waste sorting solution, for METOD kitchen drawer ventilated/light grey",
            "prod_dimensions": {
                "Volume": "55 l"
            },
            "packaging": [
                "This product comes as 11 packages.",
                "H\u00c5LLBAR",
                "Bin with lid for organic waste",
                "Article no.:",
                "804.338.82",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.56 kg",
                "Package(s): 1",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.14 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "803.980.58",
                "This product has multiple packages.",
                "Width: 26 cm",
                "Height: 21 cm",
                "Length: 32 cm",
                "Weight: 0.62 kg",
                "Package(s): 2",
                "Width: 20 cm",
                "Height: 3 cm",
                "Length: 25 cm",
                "Weight: 0.19 kg",
                "Package(s): 2",
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "604.228.70",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 70 cm",
                "Weight: 1.12 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "204.202.03",
                "This product has multiple packages.",
                "Width: 33 cm",
                "Height: 26 cm",
                "Length: 40 cm",
                "Weight: 0.96 kg",
                "Package(s): 1",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 39 cm",
                "Weight: 0.34 kg",
                "Package(s): 1",
                "H\u00c5LLBAR",
                "Bin with lid",
                "Article no.:",
                "904.321.94",
                "This product has multiple packages.",
                "Width: 17 cm",
                "Height: 15 cm",
                "Length: 20 cm",
                "Weight: 0.25 kg",
                "Package(s): 1",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "H\u00c5LLBAR bins are designed to meet different waste sorting needs. This combination is suitable if you want to make it easy to sort our waste at home. A combination with 4 bins for sorting everything from cartons, bottles and cans to smaller packages, lightbulbs and batteries, and 1 for sorting dry and wet organic waste. You can also use the bins for practical storage of, for example, toilet paper rolls, shopping bags, sponges or tealights. Lids are included so you can hide your waste. They are removeable for easy cleaning, or if you prefer using your bins without lids. The bin\u2019s ventilation holes and the form of the bottom allow the air to circulate and dry out the organic waste. This minimises unwanted odours.  A ring on the top edge of the bin hides the waste bag and keeps it in place. It\u2019s removable either for easy cleaning or if not being used.   By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  The folding handle makes it easy to carry the bin with you to the waste station. The bin is designed with rounded corners to make it easier to clean. The included sticker can be attached to the bin to mark what you are sorting. Draw or write on the sticker to make it clear what goes in the bin. Mount in MAXIMERA high drawer 80x60 cm or in MAXIMERA high drawer 80x45 cm to allow space for pipes the drawer. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins.",
            "sustainability": "Bin with lid,By using recycled plastic in this product, we consume less new raw materials and lower our environmental footprint.,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Bin with lid for organic waste,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.,By using recycled plastic in this product, we consume less new raw materials and lower our environmental impact while existing materials get new life.,Support frame f waste sorting bins,By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-0.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-1.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-2.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-3.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-4.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-5.JPG",
                "data/bin/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926/hallbar-waste-sorting-solution-for-metod-kitchen-drawer-ventilated-light-grey-s69308926-6.JPG"
            ],
            "materials": "Bin with lid for organic waste/ bin with lid,Polypropylene plastic (min. 20% recycled),Bin with lid,Bucket/ Lid/ Hinge/ Ring:,Polypropylene plastic (min. 20% recycled),Handle:,Reinforced polyamide plastic (min. 20% recycled),Support frame f waste sorting bins,Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic"
        },
        "49": {
            "id": 49,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "10",
            "prod_desc": "Support frame f waste sorting bins, white",
            "prod_dimensions": {
                "Width": "60 cm"
            },
            "packaging": [
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "804.228.69",
                "Width: 12 cm",
                "Height: 2 cm",
                "Length: 55 cm",
                "Weight: 0.87 kg",
                "Package(s): 1"
            ],
            "prod_details": "By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  Choose the sizes of the bins that best meet the needs and habits of your household. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  25 year guarantee. Read about the terms in the guarantee brochure. Dimensioned for H\u00c5LLBAR bins, excluding 3 l and 35 l bins. Mount in MAXIMERA high drawer 60x60 cm or in MAXIMERA high drawer 60x45 cm to allow space for pipes behind the drawer.",
            "sustainability": "By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-80422869/hallbar-support-frame-f-waste-sorting-bins-white-80422869-0.JPG",
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-80422869/hallbar-support-frame-f-waste-sorting-bins-white-80422869-1.JPG",
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-80422869/hallbar-support-frame-f-waste-sorting-bins-white-80422869-2.JPG"
            ],
            "materials": "Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "50": {
            "id": 50,
            "prod_name": "H\u00c5LLBAR",
            "prod_price": "15",
            "prod_desc": "Support frame f waste sorting bins, white",
            "prod_dimensions": {
                "Width": "80 cm"
            },
            "packaging": [
                "H\u00c5LLBAR",
                "Support frame f waste sorting bins",
                "Article no.:",
                "604.228.70",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 70 cm",
                "Weight: 1.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "By mounting H\u00c5LLBAR support frame for waste sorting bins in MAXIMERA high drawer you can hide your waste sorting.  The support frame provides quick access and a good overview of your waste sorting and keeps your bins stable. Pull it out to sort and push it in when you are done.  Choose the sizes of the bins that best meet the needs and habits of your household. In the kitchen, mount your waste sorting as close to the sink as possible since this is where most waste is produced and to avoid spills.  25 year guarantee. Read about the terms in the guarantee brochure. Dimensioned for H\u00c5LLBAR bins, excluding the 35 l bin. Mount in MAXIMERA high drawer 80x60 cm or in MAXIMERA high drawer 80x45 cm to allow space for pipes the drawer.",
            "sustainability": "By creating products that help people minimize and manage waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-60422870/hallbar-support-frame-f-waste-sorting-bins-white-60422870-0.JPG",
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-60422870/hallbar-support-frame-f-waste-sorting-bins-white-60422870-1.JPG",
                "data/bin/hallbar-support-frame-f-waste-sorting-bins-white-60422870/hallbar-support-frame-f-waste-sorting-bins-white-60422870-2.JPG"
            ],
            "materials": "Tube/ Middle part:,Steel, Powder coating,Stand/ Joint/ Front fixing:,Polyamide plastic,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "51": {
            "id": 51,
            "prod_name": "FNISS",
            "prod_price": "1",
            "prod_desc": "Waste bin, white",
            "prod_dimensions": {
                "Height": "28 cm",
                "Diameter": "28 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "FNISS",
                "Waste bin",
                "Article no.:",
                "402.954.39",
                "Height: 28 cm",
                "Weight: 0.36 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "Plastic is a durable material which is simple to wipe clean.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/bin/fniss-waste-bin-white-40295439/fniss-waste-bin-white-40295439-0.JPG",
                "data/bin/fniss-waste-bin-white-40295439/fniss-waste-bin-white-40295439-1.JPG",
                "data/bin/fniss-waste-bin-white-40295439/fniss-waste-bin-white-40295439-2.JPG"
            ],
            "materials": "Polypropylene plastic (min. 20% recycled),Wipe clean with a soft cloth dampened in water and a mild washing-up detergent or soap, if necessary."
        },
        "52": {
            "id": 52,
            "prod_name": "RACKEL",
            "prod_price": "20",
            "prod_desc": "Pedal bin, stainless steel",
            "prod_dimensions": {
                "Height": "64 cm",
                "Diameter": "30 cm",
                "Volume": "30 l"
            },
            "packaging": [
                "RACKEL",
                "Pedal bin",
                "Article no.:",
                "903.244.63",
                "Width: 31 cm",
                "Height: 30 cm",
                "Length: 65 cm",
                "Weight: 3.73 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "",
            "images": [
                "data/bin/rackel-pedal-bin-stainless-steel-90324463/rackel-pedal-bin-stainless-steel-90324463-0.JPG"
            ],
            "materials": "Body/ Lid/ Metal handle/ Screw:,Stainless steel,Lid holder/ Handle/ Bucket/ Bottom part:,Polypropylene plastic,Bar:,Steel, Galvanized,Pedal:,Polypropylene plastic, Stainless steel,Wipe clean regularly with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "53": {
            "id": 53,
            "prod_name": "SN\u00c4PP",
            "prod_price": "12",
            "prod_desc": "Pedal bin, white",
            "prod_dimensions": {
                "Height": "37 cm",
                "Diameter": "32 cm",
                "Volume": "12 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SN\u00c4PP",
                "Pedal bin",
                "Article no.:",
                "902.454.23",
                "This product has multiple packages.",
                "Length: 32 cm",
                "Weight: 1.35 kg",
                "Diameter: 32 cm",
                "Package(s): 1",
                "Width: 34 cm",
                "Height: 9 cm",
                "Length: 37 cm",
                "Weight: 1.08 kg",
                "Package(s): 1"
            ],
            "prod_details": "The bin is easy to move since it has a handle on the back. If you tuck the edges of the plastic bag into the handle of the inside container, it won\u2019t be visible when the pedal bin is closed. Easy to empty and clean as the inner bucket can be removed. You can use this bin anywhere in your home, even in damp areas like the kitchen and bathroom.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/bin/snaepp-pedal-bin-white-90245423/snaepp-pedal-bin-white-90245423-0.JPG",
                "data/bin/snaepp-pedal-bin-white-90245423/snaepp-pedal-bin-white-90245423-1.JPG",
                "data/bin/snaepp-pedal-bin-white-90245423/snaepp-pedal-bin-white-90245423-2.JPG",
                "data/bin/snaepp-pedal-bin-white-90245423/snaepp-pedal-bin-white-90245423-3.JPG"
            ],
            "materials": "Basematerial:,Polypropylene plastic,Pedal:,Reinforced polypropylene plastic,Handle:,Stainless steel,Feet:,Synthetic rubber"
        },
        "54": {
            "id": 54,
            "prod_name": "SKUBBEN",
            "prod_price": "1",
            "prod_desc": "Carrier bag, large, blue",
            "prod_dimensions": {
                "Width": "55 cm",
                "Depth": "35 cm",
                "Height": "37 cm",
                "Volume": "71 l"
            },
            "packaging": [
                "SKUBBEN",
                "Carrier bag, large",
                "Article no.:",
                "305.100.38",
                "Width: 30 cm",
                "Height: 1 cm",
                "Length: 38 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to keep clean \u2013 just rinse and dry. Takes little room to store as it folds flat. Also suitable for waste sorting.",
            "sustainability": "",
            "images": [
                "data/bin/skubben-carrier-bag-large-blue-30510038/skubben-carrier-bag-large-blue-30510038-0.JPG",
                "data/bin/skubben-carrier-bag-large-blue-30510038/skubben-carrier-bag-large-blue-30510038-1.JPG",
                "data/bin/skubben-carrier-bag-large-blue-30510038/skubben-carrier-bag-large-blue-30510038-2.JPG",
                "data/bin/skubben-carrier-bag-large-blue-30510038/skubben-carrier-bag-large-blue-30510038-3.JPG"
            ],
            "materials": "Basematerial:,100% polypropylene, 100% polypropylene,Handle:,100% polypropylene,Do not wash.,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean.,Clean with lukewarm water.,Wipe dry with a clean cloth."
        }
    },
    "cookware": {
        "0": {
            "id": 0,
            "prod_name": "ANNONS",
            "prod_price": "7",
            "prod_desc": "5-piece cookware set, glass/stainless steel",
            "prod_dimensions": {},
            "packaging": [
                "ANNONS",
                "5-piece cookware set",
                "Article no.:",
                "902.074.02",
                "Width: 22 cm",
                "Height: 13 cm",
                "Length: 31 cm",
                "Weight: 1.87 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. The glass lid allows you to monitor the contents of the pot during the cooking process.  Works well on all types of hobs, including induction hob. Made of stainless steel, which makes the pan durable and easy to clean. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Steam vent reduces pressure so that food does not easily boil over. Comprises: Saucepan 0.9 l, saucepan with lid 1.7 l and pot with lid 2.8 l. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/annons-5-piece-cookware-set-glass-stainless-steel-90207402/annons-5-piece-cookware-set-glass-stainless-steel-90207402-0.JPG",
                "data/cookware/annons-5-piece-cookware-set-glass-stainless-steel-90207402/annons-5-piece-cookware-set-glass-stainless-steel-90207402-1.JPG",
                "data/cookware/annons-5-piece-cookware-set-glass-stainless-steel-90207402/annons-5-piece-cookware-set-glass-stainless-steel-90207402-2.JPG",
                "data/cookware/annons-5-piece-cookware-set-glass-stainless-steel-90207402/annons-5-piece-cookware-set-glass-stainless-steel-90207402-3.JPG",
                "data/cookware/annons-5-piece-cookware-set-glass-stainless-steel-90207402/annons-5-piece-cookware-set-glass-stainless-steel-90207402-4.JPG"
            ],
            "materials": "Basematerial:,Stainless steel, Tempered glass, Aluminium,Knob:,Phenolic plastic,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "1": {
            "id": 1,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "45",
            "prod_desc": "7-piece cookware set",
            "prod_dimensions": {},
            "packaging": [
                "OUMB\u00c4RLIG",
                "7-piece cookware set",
                "Article no.:",
                "302.864.16",
                "Width: 31 cm",
                "Height: 19 cm",
                "Length: 53 cm",
                "Weight: 5.01 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Frying pan with Teflon\u00ae Platinum Plus a non-stick coating is very hardwearing and suitable for everyday use. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Comprises: Pot with lid 5 l, pot with lid 3 l, saucepan with lid 2 l and frying pan dia. 28 cm. Wash this product before using it for the first time.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-0.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-1.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-2.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-3.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-4.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-5.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-6.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-7.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-8.JPG",
                "data/cookware/oumbaerlig-7-piece-cookware-set-30286416/oumbaerlig-7-piece-cookware-set-30286416-9.JPG"
            ],
            "materials": "Lid/ Basematerial/ Handle/ Bottom/ Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,The pots and the saucepan are dishwasher-safe. The frying pan should be washed by hand.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "2": {
            "id": 2,
            "prod_name": "VARDAGEN",
            "prod_price": "17",
            "prod_desc": "Pot with lid, enamelled steel",
            "prod_dimensions": {
                "Height": "11 cm",
                "Diameter": "21 cm",
                "Volume": "3 l",
                "Length including handles": "28 cm",
                "Height including lid": "15 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pot with lid",
                "Article no.:",
                "903.911.22",
                "Width: 22 cm",
                "Height: 12 cm",
                "Length: 28 cm",
                "Weight: 1.30 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can use this pot with lid both on the stove and in the oven, and bring it to the table and serve from it.  An easy way to take care of your leftovers since the pot is ideal to store in the fridge.  Made of enamelled steel, which is durable, easy to clean and conducts heat quickly and evenly, making it easy for you to control the temperature. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Works well on all types of hobs, including induction hob. 5 year guarantee. Read about the terms in the guarantee brochure. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-0.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-1.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-2.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-3.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-4.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-5.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-6.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-90391122/vardagen-pot-with-lid-enamelled-steel-90391122-7.JPG"
            ],
            "materials": "Steel, Enamel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "4": {
            "id": 4,
            "prod_name": "SNITSIG",
            "prod_price": "27",
            "prod_desc": "7-piece cookware set, stainless steel",
            "prod_dimensions": {},
            "packaging": [
                "SNITSIG",
                "7-piece cookware set",
                "Article no.:",
                "601.393.63",
                "Width: 33 cm",
                "Height: 18 cm",
                "Length: 50 cm",
                "Weight: 4.38 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Made of stainless steel, which makes the pan durable and easy to clean. Frying pan with non-stick coating reduces the risk of food burning and sticking, and is easier to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Comprises: Saucepan with lid 1 l, pot with lid 3 l, pot with lid 5 l and frying pan dia. 24 cm. STABIL lid dia. 24 cm fits the frying pan. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/snitsig-7-piece-cookware-set-stainless-steel-60139363/snitsig-7-piece-cookware-set-stainless-steel-60139363-0.JPG",
                "data/cookware/snitsig-7-piece-cookware-set-stainless-steel-60139363/snitsig-7-piece-cookware-set-stainless-steel-60139363-1.JPG",
                "data/cookware/snitsig-7-piece-cookware-set-stainless-steel-60139363/snitsig-7-piece-cookware-set-stainless-steel-60139363-2.JPG"
            ],
            "materials": "Handle:,Phenolic plastic,Basematerial:,Stainless steel,Bottom:,Stainless steel, Aluminium,Frying pan:,Stainless steel, Non-stick coating,The pots and the saucepan are dishwasher-safe. The frying pan should be washed by hand.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "5": {
            "id": 5,
            "prod_name": "LYCKAD",
            "prod_price": "8",
            "prod_desc": "Oven/serving dish set of 2, dark grey",
            "prod_dimensions": {},
            "packaging": [
                "LYCKAD",
                "Oven/serving dish set of 2",
                "Article no.:",
                "004.644.29",
                "Width: 22 cm",
                "Height: 6 cm",
                "Length: 31 cm",
                "Weight: 2.55 kg",
                "Package(s): 1"
            ],
            "prod_details": "Sizes: 31x21x6 cm and 23x15x5 cm.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429-0.JPG",
                "data/cookware/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429-1.JPG",
                "data/cookware/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429-2.JPG",
                "data/cookware/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429/lyckad-oven-serving-dish-set-of-2-dark-grey-00464429-3.JPG"
            ],
            "materials": "Stoneware, Coloured glaze,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "6": {
            "id": 6,
            "prod_name": "FULL\u00c4NDAD",
            "prod_price": "3",
            "prod_desc": "5-piece kitchen utensil set, grey",
            "prod_dimensions": {},
            "packaging": [
                "FULL\u00c4NDAD",
                "5-piece kitchen utensil set",
                "Article no.:",
                "804.359.42",
                "Width: 12 cm",
                "Height: 10 cm",
                "Length: 35 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Kind to pots and pans with non-stick coating. Comprises: Turner (32 cm), spoon (33 cm), soup ladle (29 cm), pasta server (31 cm) and cooking tweezers (28 cm).",
            "sustainability": "",
            "images": [
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-0.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-1.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-2.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-3.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-4.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-5.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-6.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-7.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-8.JPG",
                "data/cookware/fullaendad-5-piece-kitchen-utensil-set-grey-80435942/fullaendad-5-piece-kitchen-utensil-set-grey-80435942-9.JPG"
            ],
            "materials": "Reinforced polyamide plastic,Dishwasher-safe.,Withstands temperatures up to 220\u00b0C."
        },
        "7": {
            "id": 7,
            "prod_name": "ANNONS",
            "prod_price": "4",
            "prod_desc": "Pot with lid, glass/stainless steel",
            "prod_dimensions": {
                "Height": "10 cm",
                "Diameter": "21 cm",
                "Volume": "2.8 l"
            },
            "packaging": [
                "ANNONS",
                "Pot with lid",
                "Article no.:",
                "802.984.74",
                "Width: 21 cm",
                "Height: 13 cm",
                "Length: 32 cm",
                "Weight: 0.99 kg",
                "Package(s): 1"
            ],
            "prod_details": "The glass lid allows you to monitor the contents of the pot during the cooking process.  Works well on all types of hobs, including induction hob. Made of stainless steel, which makes the pan durable and easy to clean. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Steam vent reduces pressure so that food does not easily boil over. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-80298474/annons-pot-with-lid-glass-stainless-steel-80298474-0.JPG",
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-80298474/annons-pot-with-lid-glass-stainless-steel-80298474-1.JPG",
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-80298474/annons-pot-with-lid-glass-stainless-steel-80298474-2.JPG",
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-80298474/annons-pot-with-lid-glass-stainless-steel-80298474-3.JPG"
            ],
            "materials": "Basematerial:,Stainless steel, Tempered glass, Aluminium,Knob:,Phenolic plastic,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "8": {
            "id": 8,
            "prod_name": "HEMLAGAD",
            "prod_price": "45",
            "prod_desc": "6-piece cookware set, blue",
            "prod_dimensions": {},
            "packaging": [
                "HEMLAGAD",
                "6-piece cookware set",
                "Article no.:",
                "004.628.78",
                "Width: 30 cm",
                "Height: 18 cm",
                "Length: 32 cm",
                "Weight: 4.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. Made from aluminium, which spreads heat evenly and energy efficiently, and makes it easier to regulate heat so the food does not burn and stick. Comfortable handles make the cookware easy to lift. The pan has extra thick walls and base, which distribute the heat evenly and give good cooking results. The 5-litre pot has a lid with a catch which makes it possible to pour out water through the holes in the lid. The pan has two spouts and is therefore easy to use for both right- and left-handed cooks. The lid to the 3-litre pot has a steam vent which reduces pressure so that food does not easily boil over. With Teflon\u00ae Select, a hardwearing non-stick coating that allows cooking with little fat and makes cleaning easy. The pan's low weight makes it easy to handle when filled with food. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Comprises: Pot with lid 3 l and 5 l, saucepan 1 l and frying pan dia. 28 cm.",
            "sustainability": "",
            "images": [
                "data/cookware/hemlagad-6-piece-cookware-set-blue-00462878/hemlagad-6-piece-cookware-set-blue-00462878-0.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-blue-00462878/hemlagad-6-piece-cookware-set-blue-00462878-1.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-blue-00462878/hemlagad-6-piece-cookware-set-blue-00462878-2.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-blue-00462878/hemlagad-6-piece-cookware-set-blue-00462878-3.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-blue-00462878/hemlagad-6-piece-cookware-set-blue-00462878-4.JPG"
            ],
            "materials": "Basematerial:,Aluminium, Coated with Teflon(R) Select, Non-stick coating,Handle:,Phenolic plastic, Polyurethane plastic,Fire protector:,Aluminium, Powder coating,Disc/ Lid/ Screw:,Stainless steel,Knob:,Reinforced polyamide plastic, Polyurethane plastic,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "9": {
            "id": 9,
            "prod_name": "KONCIS",
            "prod_price": "4",
            "prod_desc": "Roasting tin, stainless steel",
            "prod_dimensions": {
                "Length": "26 cm",
                "Width": "20 cm",
                "Height": "5.5 cm"
            },
            "packaging": [
                "KONCIS",
                "Roasting tin",
                "Article no.:",
                "500.558.63",
                "Width: 20 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.55 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/koncis-roasting-tin-stainless-steel-50055863/koncis-roasting-tin-stainless-steel-50055863-0.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-50055863/koncis-roasting-tin-stainless-steel-50055863-1.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-50055863/koncis-roasting-tin-stainless-steel-50055863-2.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-50055863/koncis-roasting-tin-stainless-steel-50055863-3.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Oven-safe."
        },
        "10": {
            "id": 10,
            "prod_name": "VARDAGEN",
            "prod_price": "22",
            "prod_desc": "Pot with lid, enamelled steel",
            "prod_dimensions": {
                "Height": "12 cm",
                "Diameter": "29 cm",
                "Volume": "5 l",
                "Length including handles": "36 cm",
                "Height including lid": "16 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pot with lid",
                "Article no.:",
                "703.911.23",
                "Width: 24 cm",
                "Height: 13 cm",
                "Length: 36 cm",
                "Weight: 2.11 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can use this pot with lid both on the stove and in the oven, and bring it to the table and serve from it.  An easy way to take care of your leftovers since the pot is ideal to store in the fridge.  Made of enamelled steel, which is durable, easy to clean and conducts heat quickly and evenly, making it easy for you to control the temperature. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Works well on all types of hobs, including induction hob. 5 year guarantee. Read about the terms in the guarantee brochure. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.,No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-0.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-1.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-2.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-3.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-4.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-5.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-6.JPG",
                "data/cookware/vardagen-pot-with-lid-enamelled-steel-70391123/vardagen-pot-with-lid-enamelled-steel-70391123-7.JPG"
            ],
            "materials": "Steel, Enamel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "11": {
            "id": 11,
            "prod_name": "DUKTIG",
            "prod_price": "6",
            "prod_desc": "5-piece toy cookware set, stainless steel colour",
            "prod_dimensions": {},
            "packaging": [
                "DUKTIG",
                "5-piece toy cookware set",
                "Article no.:",
                "001.301.67",
                "Width: 15 cm",
                "Height: 8 cm",
                "Length: 22 cm",
                "Weight: 0.61 kg",
                "Package(s): 1"
            ],
            "prod_details": "Mini cookware for play. Made of durable material and stainless steel. Encourages role play which helps children to develop social skills by imitating grown-ups and inventing their own roles. Recommended for ages from 3 years. This is a toy and not suitable for cooking. This product bears the CE mark. In the DUKTIG series, there is everything that a little chef needs to succeed in the kitchen.",
            "sustainability": "Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/cookware/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167-0.JPG",
                "data/cookware/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167-1.JPG",
                "data/cookware/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167-2.JPG",
                "data/cookware/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167/duktig-5-piece-toy-cookware-set-stainless-steel-colour-00130167-3.JPG"
            ],
            "materials": "Stainless steel,Handwash only.,Not microwave-safe.,Not oven-safe."
        },
        "12": {
            "id": 12,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "15",
            "prod_desc": "Pot with lid",
            "prod_dimensions": {
                "Height": "15 cm",
                "Diameter": "23 cm",
                "Volume": "5 l"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Pot with lid",
                "Article no.:",
                "902.864.23",
                "Width: 24 cm",
                "Height: 16 cm",
                "Length: 33 cm",
                "Weight: 1.26 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-0.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-1.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-2.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-3.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-4.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-90286423/oumbaerlig-pot-with-lid-90286423-5.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "13": {
            "id": 13,
            "prod_name": "IKEA 365+",
            "prod_price": "13",
            "prod_desc": "Cooking kit 4",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 4 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "803.931.31",
                "Width: 21 cm",
                "Height: 8 cm",
                "Length: 32 cm",
                "Weight: 1.58 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.930.63",
                "Width: 27 cm",
                "Height: 1 cm",
                "Length: 37 cm",
                "Weight: 0.23 kg",
                "Package(s): 1",
                "SANDVIVA",
                "Oven glove",
                "Article no.:",
                "104.643.82",
                "Width: 11 cm",
                "Height: 8 cm",
                "Length: 19 cm",
                "Weight: 0.11 kg",
                "Package(s): 1",
                "GRUNKA",
                "4-piece kitchen utensil set",
                "Article no.:",
                "300.833.34",
                "Width: 8 cm",
                "Height: 8 cm",
                "Length: 28 cm",
                "Weight: 0.49 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ food container with lid (3.1 l), 1 SANDVIVA oven glove and GRUNKA 5-piece kitchen utensil set.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,BPA (Bisphenol A) free,4-piece kitchen utensil set,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-cooking-kit-4-s89401283/ikea-365-cooking-kit-4-s89401283-0.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Oven glove,Silicone rubber,4-piece kitchen utensil set,Stainless steel"
        },
        "14": {
            "id": 14,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "17",
            "prod_desc": "Saut\u00e9 pan with lid",
            "prod_dimensions": {
                "Height": "7 cm",
                "Diameter": "24 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Saut\u00e9 pan with lid",
                "Article no.:",
                "803.436.50",
                "Width: 25 cm",
                "Height: 9 cm",
                "Length: 45 cm",
                "Weight: 1.37 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/oumbaerlig-saute-pan-with-lid-80343650/oumbaerlig-saute-pan-with-lid-80343650-0.JPG",
                "data/cookware/oumbaerlig-saute-pan-with-lid-80343650/oumbaerlig-saute-pan-with-lid-80343650-1.JPG",
                "data/cookware/oumbaerlig-saute-pan-with-lid-80343650/oumbaerlig-saute-pan-with-lid-80343650-2.JPG",
                "data/cookware/oumbaerlig-saute-pan-with-lid-80343650/oumbaerlig-saute-pan-with-lid-80343650-3.JPG"
            ],
            "materials": "Lid/ Basematerial/ Protector/ Handle:,Stainless steel,Disc:,Aluminium,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "15": {
            "id": 15,
            "prod_name": "KONCIS",
            "prod_price": "10",
            "prod_desc": "Roasting tin with grill rack, stainless steel",
            "prod_dimensions": {
                "Length": "40 cm",
                "Width": "32 cm",
                "Height": "6.5 cm"
            },
            "packaging": [
                "KONCIS",
                "Roasting tin with grill rack",
                "Article no.:",
                "100.990.53",
                "Width: 32 cm",
                "Height: 7 cm",
                "Length: 40 cm",
                "Weight: 1.69 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-0.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-1.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-2.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-3.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-4.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-5.JPG",
                "data/cookware/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053/koncis-roasting-tin-with-grill-rack-stainless-steel-10099053-6.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Oven-safe."
        },
        "16": {
            "id": 16,
            "prod_name": "VARDAGEN",
            "prod_price": "35",
            "prod_desc": "Pot with lid, cast iron",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "22 cm",
                "Volume": "5 l",
                "Length including handles": "30 cm",
                "Height including lid": "20 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pot with lid",
                "Article no.:",
                "004.370.54",
                "Width: 27 cm",
                "Height: 18 cm",
                "Length: 28 cm",
                "Weight: 5.44 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. Made from cast iron, which spreads heat evenly through the pan and retains the heat for a long time. This makes it ideal, for example, for slower cooking such as roasts and casseroles. Works well on all types of hobs, including induction hob. Steam collects on the inside of the lid and drips down from the knobs. In this way the food bastes itself, which gives a succulent and tasty result. Can also be used in the oven since it is made entirely of metal. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. To season a cast iron pot/pan, rub all surfaces with oil. Then heat the pot/pan in the oven or on the hob to max. 150 \u00b0C for a minimum of one hour. Leave it to cool and wipe off excess oil. If corrosion or food stains arise, or if food burns and sticks, the pot/pan can be cleaned with steel wool or an abrasive sponge and then re-seasoned. Use a hob with the same or a smaller diameter to save energy. The pot/pan gets hot during use. Therefore, always use pot holders when moving it. Do not expose the pot/pan to great variations in temperature, e.g. by placing it directly on a hot hob. This product is pre-treated with vegetable soybean oil.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-0.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-1.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-2.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-3.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-4.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-5.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-6.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-7.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-8.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-00437054/vardagen-pot-with-lid-cast-iron-00437054-9.JPG"
            ],
            "materials": "Body/ Lid:,Cast iron, Oil,Screw:,Stainless steel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe.,Wash this product before using it for the first time."
        },
        "17": {
            "id": 17,
            "prod_name": "IKEA 365+",
            "prod_price": "60",
            "prod_desc": "5-piece cookware set",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "5-piece cookware set",
                "Article no.:",
                "103.688.75",
                "Width: 30 cm",
                "Height: 16 cm",
                "Length: 53 cm",
                "Weight: 5.13 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. 15 and 5 year guarantee. Read about the terms in the guarantee brochure. Frying pan with Teflon\u00ae Professional, our best non-stick coating; for you who place high demands on your pans. Heat spreads evenly over the bottom and sides, since the frying pan has a layer of aluminium between two layers of stainless steel which are equally thick across the entire pan. The graduated interior of the pot and saucepan makes it easy to measure up liquid directly in the pans. The pot and saucepan have a thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pans durable and easy to clean. Comprises: Pot with lid 5 l, saucepan with lid 2 l and frying pan dia. 28 cm. Wash this product before using it for the first time.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-0.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-1.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-2.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-3.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-4.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-5.JPG",
                "data/cookware/ikea-365-5-piece-cookware-set-10368875/ikea-365-5-piece-cookware-set-10368875-6.JPG"
            ],
            "materials": "Handle/ Handle/ Cover/ Body:,Stainless steel,Basematerial:,Stainless steel, Aluminium, Coated with Teflon(R) Professional,Lid:,Heat resistant glass,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe.,The pot and the saucepan are dishwasher-safe. The frying pan should be washed by hand."
        },
        "18": {
            "id": 18,
            "prod_name": "SENSUELL",
            "prod_price": "90",
            "prod_desc": "4-piece cookware set, stainless steel/grey",
            "prod_dimensions": {},
            "packaging": [
                "SENSUELL",
                "4-piece cookware set",
                "Article no.:",
                "203.245.41",
                "Width: 33 cm",
                "Height: 17 cm",
                "Length: 57 cm",
                "Weight: 5.94 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. Tilted, easy to grip handles make it comfortable and safe to pour out the contents of the pot. The lid has a glass window that allows you to monitor the contents of the pot during the cooking process. The handle of the frying pan and sauteuse provides a comfortable and secure grip because it follows the contours of your hand and has silicon on the underside. The entire pan, including the base and sides, has one layer of aluminium between two layers of stainless steel. This distributes heat evenly and energy efficiently from several directions and makes it easy to regulate. The base of the frying pan is extra thick, which browns food beautifully and minimises the risk of food sticking  to the surface. The graduated interior makes it easy to measure up liquid directly in the pot and sauteuse. You can cook food on a low heat and save energy because the stainless steel in the pan absorbs heat well and retains it for a long time. Works well on all types of hobs, including induction hob. The lid is slanted on the inside so that condensation drips down into the pot during cooking \u2013 instead of landing on the worktop when you remove the lid. Made of high-quality stainless steel, which makes the pan very durable and easy to clean. Steam vent reduces pressure so that food does not easily boil over. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Comprises: Pot with lid 5.5 l, sauteuse 3 l and frying pan dia. 28 cm. The lid for SENSUELL pot also fit the sauteuse in the same series. To brown foods and prevent them from sticking, first heat up the pan then lower the temperature when you start to cook. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-0.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-1.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-2.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-3.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-4.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-5.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-6.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-7.JPG",
                "data/cookware/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541/sensuell-4-piece-cookware-set-stainless-steel-grey-20324541-8.JPG"
            ],
            "materials": "Body/ Body:,Stainless steel, Aluminium,Handle:,Stainless steel, Silicone rubber,Lid:,Stainless steel, Tempered glass, Silicone rubber,Handle:,Stainless steel,The frying pan and the sauteuse are oven-safe, but the pot with lid is not.,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "19": {
            "id": 19,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "403.591.48",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.12 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s19269079/ikea-365-food-container-with-lid-rectangular-plastic-s19269079-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s19269079/ikea-365-food-container-with-lid-rectangular-plastic-s19269079-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s19269079/ikea-365-food-container-with-lid-rectangular-plastic-s19269079-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s19269079/ikea-365-food-container-with-lid-rectangular-plastic-s19269079-3.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "20": {
            "id": 20,
            "prod_name": "ISTAD",
            "prod_price": "2",
            "prod_desc": "Resealable bag, grey/white",
            "prod_dimensions": {
                "Package quantity": "50 pack"
            },
            "packaging": [
                "ISTAD",
                "Resealable bag",
                "Article no.:",
                "503.422.37",
                "Width: 8 cm",
                "Height: 5 cm",
                "Length: 26 cm",
                "Weight: 0.44 kg",
                "Package(s): 1"
            ],
            "prod_details": "Can be used over and over again since it can be re-sealed. ISTAD bags have a double seal which keeps the contents fresh for longer \u2013 and even tightly seals in liquids without leaking. Comprises: 25 bags 2.5 l (24x26.5 cm) and 25 bags 1.2 l (20.5x20.5 cm).",
            "sustainability": "Made from plastic which contains at least 20% renewable content. The material can be recycled together with common plastic, if this possibility is available in your community.,No BPA (Bisphenol A) added.,By using a renewable material like sugar cane in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-0.JPG",
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-1.JPG",
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-2.JPG",
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-3.JPG",
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-4.JPG",
                "data/cookware/istad-resealable-bag-grey-white-50342237/istad-resealable-bag-grey-white-50342237-5.JPG"
            ],
            "materials": "Polyethylene plastic,Freezer-safe.,Withstands temperatures up to 50\u00b0C."
        },
        "21": {
            "id": 21,
            "prod_name": "HEMLAGAD",
            "prod_price": "12",
            "prod_desc": "Pot with lid, black",
            "prod_dimensions": {
                "Height": "13 cm",
                "Diameter": "19 cm",
                "Volume": "3 l",
                "Length including handles": "31 cm",
                "Height including lid": "16 cm"
            },
            "packaging": [
                "HEMLAGAD",
                "Pot with lid",
                "Article no.:",
                "104.622.03",
                "Width: 20 cm",
                "Height: 14 cm",
                "Length: 32 cm",
                "Weight: 1.00 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comfortable handles make the cookware easy to lift. Made from aluminium, which spreads heat evenly and energy efficiently, and makes it easier to regulate heat so the food does not burn and stick. With Teflon\u00ae Select, a hardwearing non-stick coating that allows cooking with little fat and makes cleaning easy. Steam vents reduce pressure so that food does not easily boil over. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Remember to hold the lid when pouring since it does not have a catch that keeps it in place.",
            "sustainability": "",
            "images": [
                "data/cookware/hemlagad-pot-with-lid-black-10462203/hemlagad-pot-with-lid-black-10462203-0.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-10462203/hemlagad-pot-with-lid-black-10462203-1.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-10462203/hemlagad-pot-with-lid-black-10462203-2.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-10462203/hemlagad-pot-with-lid-black-10462203-3.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-10462203/hemlagad-pot-with-lid-black-10462203-4.JPG"
            ],
            "materials": "Basematerial:,Aluminium, Coated with Teflon(R) Select, Non-stick coating,Handle:,Phenolic plastic, Polyurethane plastic,Fire protector:,Aluminium, Powder coating,Disc/ Lid/ Screw:,Stainless steel,Knob:,Reinforced polyamide plastic, Polyurethane plastic,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "22": {
            "id": 22,
            "prod_name": "GRUNDVATTNET",
            "prod_price": "1",
            "prod_desc": "Box",
            "prod_dimensions": {
                "Length": "16.8 cm",
                "Width": "13.7 cm",
                "Height": "7.8 cm"
            },
            "packaging": [
                "GRUNDVATTNET",
                "Box",
                "Article no.:",
                "103.142.98",
                "Width: 13 cm",
                "Height: 8 cm",
                "Length: 17 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of durable, food-approved plastic for safe and long-term use. Practical to store food in. Can be placed in GRUNDVATTNET colander and used to separate different ingredients when preparing food.  Combine with other sink accessories in the GRUNDVATTNET series to create a flexible worktop space which is more organised. Fits in GRUNDVATTNET colander. May be combined with other sink accessories in the GRUNDVATTNET series. Tested and approved for food contact. This product bears the CE mark.",
            "sustainability": "",
            "images": [
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-0.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-1.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-2.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-3.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-4.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-5.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-6.JPG",
                "data/cookware/grundvattnet-box-10314298/grundvattnet-box-10314298-7.JPG"
            ],
            "materials": "Bowl:,Polypropylene plastic,Feet:,Synthetic rubber,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth.,Dishwasher-safe."
        },
        "23": {
            "id": 23,
            "prod_name": "PRUTA",
            "prod_price": "3",
            "prod_desc": "Food container, set of 17, transparent/green",
            "prod_dimensions": {},
            "packaging": [
                "PRUTA",
                "Food container, set of 17",
                "Article no.:",
                "601.496.73",
                "Width: 24 cm",
                "Height: 16 cm",
                "Length: 28 cm",
                "Weight: 0.90 kg",
                "Package(s): 1"
            ],
            "prod_details": "A good set of basic food containers for everything from cold cuts, cheese etc. to leftovers and individual food portions. Several empty food containers can be stacked inside one another to save space in your cabinets. Reduce food waste by storing your leftovers in a food container and reheating for another meal. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Several food containers can be stacked on top of one another to save space in fridge and freezer. Comprises: 4 containers (9x9x4cm, 150ml), 3 containers (12x8x4cm, 150ml), 2 containers (12x12x4cm, 300ml), 2 containers (12x12x14cm, 1l), 2 containers (14x14x6cm, 600ml), 2 containers (14x14x16cm, 1,6l) and 2 containers (23x16x8cm, 1,8l). Wash this product before using it for the first time. This container is not spill-proof and may leak if you store liquid contents like soup in it. If you think there is a risk of leakage, do not place the container in for example a bag.",
            "sustainability": "No BPA (Bisphenol A) added.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/pruta-food-container-set-of-17-transparent-green-60149673/pruta-food-container-set-of-17-transparent-green-60149673-0.JPG",
                "data/cookware/pruta-food-container-set-of-17-transparent-green-60149673/pruta-food-container-set-of-17-transparent-green-60149673-1.JPG",
                "data/cookware/pruta-food-container-set-of-17-transparent-green-60149673/pruta-food-container-set-of-17-transparent-green-60149673-2.JPG",
                "data/cookware/pruta-food-container-set-of-17-transparent-green-60149673/pruta-food-container-set-of-17-transparent-green-60149673-3.JPG",
                "data/cookware/pruta-food-container-set-of-17-transparent-green-60149673/pruta-food-container-set-of-17-transparent-green-60149673-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "24": {
            "id": 24,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, square glass/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "003.592.06",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 15 cm",
                "Weight: 0.50 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.617.89",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s39269120/ikea-365-food-container-with-lid-square-glass-plastic-s39269120-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s39269120/ikea-365-food-container-with-lid-square-glass-plastic-s39269120-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s39269120/ikea-365-food-container-with-lid-square-glass-plastic-s39269120-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Freezer-safe.,Dishwasher-safe."
        },
        "25": {
            "id": 25,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "51",
            "prod_desc": "Cooking kit 2",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 3 packages.",
                "OUMB\u00c4RLIG",
                "7-piece cookware set",
                "Article no.:",
                "302.864.16",
                "Width: 31 cm",
                "Height: 19 cm",
                "Length: 53 cm",
                "Weight: 5.01 kg",
                "Package(s): 1",
                "IKEA 365+ HJ\u00c4LTE",
                "Turner",
                "Article no.:",
                "001.494.59",
                "Width: 6 cm",
                "Height: 3 cm",
                "Length: 33 cm",
                "Weight: 0.08 kg",
                "Package(s): 1",
                "RINNIG",
                "Tea towel",
                "Article no.:",
                "204.763.46",
                "Length: 15 cm",
                "Weight: 0.24 kg",
                "Diameter: 9 cm",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: OUMB\u00c4RLIG 7-piece cookware set.",
            "sustainability": "Tea towel,Renewable material (cotton).,All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.,7-piece cookware set,No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.,Turner,No BPA (Bisphenol A) added.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-cooking-kit-2-s69401284/oumbaerlig-cooking-kit-2-s69401284-0.jpg"
            ],
            "materials": "7-piece cookware set,Lid/ Basematerial/ Handle/ Bottom/ Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,Turner,Handle:,Reinforced polyamide plastic, Silicone rubber,Bar:,Stainless steel,Lower part:,Polyamide plastic,Tea towel,100% cotton"
        },
        "26": {
            "id": 26,
            "prod_name": "FRUKOSTM\u00c5L",
            "prod_price": "2",
            "prod_desc": "Mug, collapsible, grey/white",
            "prod_dimensions": {
                "Min. height": "9 cm",
                "Max. height": "16 cm",
                "Volume": "350 ml"
            },
            "packaging": [
                "FRUKOSTM\u00c5L",
                "Mug, collapsible",
                "Article no.:",
                "304.797.97",
                "Width: 9 cm",
                "Height: 8 cm",
                "Length: 9 cm",
                "Weight: 0.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "When the mug is empty, it saves room in your bag since it is collapsible. Can be refilled and used time after time, making it kind to the environment. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/frukostmal-mug-collapsible-grey-white-30479797/frukostmal-mug-collapsible-grey-white-30479797-0.JPG",
                "data/cookware/frukostmal-mug-collapsible-grey-white-30479797/frukostmal-mug-collapsible-grey-white-30479797-1.JPG",
                "data/cookware/frukostmal-mug-collapsible-grey-white-30479797/frukostmal-mug-collapsible-grey-white-30479797-2.JPG"
            ],
            "materials": "Polypropylene plastic, Silicone rubber,Dishwasher-safe up to 60\u00b0C."
        },
        "27": {
            "id": 27,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "22",
            "prod_desc": "Wok",
            "prod_dimensions": {
                "Height": "10 cm",
                "Diameter": "32 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Wok",
                "Article no.:",
                "203.436.48",
                "Width: 33 cm",
                "Height: 13 cm",
                "Length: 58 cm",
                "Weight: 1.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. With Teflon\u00ae Platinum plus, a very hardwearing non-stick coating that makes the pan suitable for everyday use. The heat is highest at the bottom, and the sloping sides make the food drop down. Constantly stir the food for a crisp result. Two handles make it easy to lift the pan. Made of stainless steel, which makes the pan durable and easy to clean. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/oumbaerlig-wok-20343648/oumbaerlig-wok-20343648-0.JPG",
                "data/cookware/oumbaerlig-wok-20343648/oumbaerlig-wok-20343648-1.JPG",
                "data/cookware/oumbaerlig-wok-20343648/oumbaerlig-wok-20343648-2.JPG",
                "data/cookware/oumbaerlig-wok-20343648/oumbaerlig-wok-20343648-3.JPG",
                "data/cookware/oumbaerlig-wok-20343648/oumbaerlig-wok-20343648-4.JPG"
            ],
            "materials": "Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Disc:,Aluminium,Protector/ Handle:,Stainless steel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "28": {
            "id": 28,
            "prod_name": "L\u00c4MPLIG",
            "prod_price": "1",
            "prod_desc": "Pot stand, stainless steel",
            "prod_dimensions": {
                "Length": "18 cm",
                "Width": "18 cm"
            },
            "packaging": [
                "L\u00c4MPLIG",
                "Pot stand",
                "Article no.:",
                "001.860.41",
                "Width: 21 cm",
                "Height: 2 cm",
                "Length: 22 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Plastic feet prevent scratching on the surface.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/laemplig-pot-stand-stainless-steel-00186041/laemplig-pot-stand-stainless-steel-00186041-0.JPG",
                "data/cookware/laemplig-pot-stand-stainless-steel-00186041/laemplig-pot-stand-stainless-steel-00186041-1.JPG",
                "data/cookware/laemplig-pot-stand-stainless-steel-00186041/laemplig-pot-stand-stainless-steel-00186041-2.JPG"
            ],
            "materials": "Bar:,Stainless steel,Feet:,Synthetic rubber, Polypropylene plastic,Wipe clean with a cloth dampened in a mild cleaner."
        },
        "29": {
            "id": 29,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "10",
            "prod_desc": "Pot with lid",
            "prod_dimensions": {
                "Height": "13 cm",
                "Diameter": "20 cm",
                "Volume": "3 l"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Pot with lid",
                "Article no.:",
                "502.864.20",
                "Width: 24 cm",
                "Height: 17 cm",
                "Length: 28 cm",
                "Weight: 0.94 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-0.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-1.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-2.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-3.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-4.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-5.JPG",
                "data/cookware/oumbaerlig-pot-with-lid-50286420/oumbaerlig-pot-with-lid-50286420-6.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "30": {
            "id": 30,
            "prod_name": "HEMLAGAD",
            "prod_price": "17",
            "prod_desc": "Pot with lid, black",
            "prod_dimensions": {
                "Height": "15 cm",
                "Diameter": "25 cm",
                "Volume": "5 l",
                "Length including handles": "35 cm",
                "Height including lid": "18 cm"
            },
            "packaging": [
                "HEMLAGAD",
                "Pot with lid",
                "Article no.:",
                "004.622.13",
                "Width: 25 cm",
                "Height: 15 cm",
                "Length: 35 cm",
                "Weight: 1.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "The lid has a catch which means the water can be poured out through the holes in the lid. Comfortable handles make the cookware easy to lift. Made from aluminium, which spreads heat evenly and energy efficiently, and makes it easier to regulate heat so the food does not burn and stick. With Teflon\u00ae Select, a hardwearing non-stick coating that allows cooking with little fat and makes cleaning easy. Steam vent reduces pressure so that food does not easily boil over. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact.",
            "sustainability": "",
            "images": [
                "data/cookware/hemlagad-pot-with-lid-black-00462213/hemlagad-pot-with-lid-black-00462213-0.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-00462213/hemlagad-pot-with-lid-black-00462213-1.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-00462213/hemlagad-pot-with-lid-black-00462213-2.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-00462213/hemlagad-pot-with-lid-black-00462213-3.JPG",
                "data/cookware/hemlagad-pot-with-lid-black-00462213/hemlagad-pot-with-lid-black-00462213-4.JPG"
            ],
            "materials": "Basematerial:,Aluminium, Coated with Teflon(R) Select, Non-stick coating,Handle:,Phenolic plastic, Polyurethane plastic,Fire protector:,Aluminium, Powder coating,Disc/ Lid/ Screw:,Stainless steel,Knob:,Reinforced polyamide plastic, Polyurethane plastic,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "31": {
            "id": 31,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "8",
            "prod_desc": "Saucepan with lid",
            "prod_dimensions": {
                "Height": "10 cm",
                "Volume": "2 l"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Saucepan with lid",
                "Article no.:",
                "902.864.18",
                "Width: 19 cm",
                "Height: 15 cm",
                "Length: 37 cm",
                "Weight: 0.85 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-0.JPG",
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-1.JPG",
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-2.JPG",
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-3.JPG",
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-4.JPG",
                "data/cookware/oumbaerlig-saucepan-with-lid-90286418/oumbaerlig-saucepan-with-lid-90286418-5.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "32": {
            "id": 32,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, rectangular glass/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.99",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.68 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s89269071/ikea-365-food-container-with-lid-rectangular-glass-plastic-s89269071-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s89269071/ikea-365-food-container-with-lid-rectangular-glass-plastic-s89269071-1.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Freezer-safe.,Dishwasher-safe."
        },
        "33": {
            "id": 33,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container, rectangular/glass",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.99",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.68 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ rectangular-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-0.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-1.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-2.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-3.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-4.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-5.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-6.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359199/ikea-365-food-container-rectangular-glass-70359199-7.jpg"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "34": {
            "id": 34,
            "prod_name": "IKEA 365+",
            "prod_price": "15",
            "prod_desc": "Frying pan",
            "prod_dimensions": {
                "Height": "4 cm",
                "Diameter": "24 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Frying pan",
                "Article no.:",
                "303.298.97",
                "Width: 24 cm",
                "Height: 10 cm",
                "Length: 43 cm",
                "Weight: 0.92 kg",
                "Package(s): 1"
            ],
            "prod_details": "5 year guarantee. Read about the terms in the guarantee brochure. Works well on all types of hobs, including induction hob. With Teflon\u00ae Professional, our best non-stick coating; for you who place high demands on your pans. Heat spreads evenly over the bottom and sides, since the frying pan has a layer of aluminium between two layers of stainless steel which are equally thick across the entire pan. Made of stainless steel, which makes the pan durable and easy to clean. Can also be used in the oven since it is made entirely of metal. When using the cookware on an induction hob, for best performance use it on an induction zone that has the same diameter as the cookware. Wash this product before using it for the first time. Keep in mind that the handle become hot when using the pot. Always use pot holders when moving the cookware.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/ikea-365-frying-pan-30329897/ikea-365-frying-pan-30329897-0.JPG",
                "data/cookware/ikea-365-frying-pan-30329897/ikea-365-frying-pan-30329897-1.JPG",
                "data/cookware/ikea-365-frying-pan-30329897/ikea-365-frying-pan-30329897-2.JPG",
                "data/cookware/ikea-365-frying-pan-30329897/ikea-365-frying-pan-30329897-3.JPG",
                "data/cookware/ikea-365-frying-pan-30329897/ikea-365-frying-pan-30329897-4.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Aluminium, Coated with Teflon(R) Professional,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "35": {
            "id": 35,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "22",
            "prod_desc": "Stockpot with lid",
            "prod_dimensions": {
                "Height": "19 cm",
                "Diameter": "30 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Stockpot with lid",
                "Article no.:",
                "002.864.13",
                "Width: 30 cm",
                "Height: 20 cm",
                "Length: 40 cm",
                "Weight: 1.85 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Can also be used in the oven since it is made entirely of metal. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-stockpot-with-lid-00286413/oumbaerlig-stockpot-with-lid-00286413-0.JPG",
                "data/cookware/oumbaerlig-stockpot-with-lid-00286413/oumbaerlig-stockpot-with-lid-00286413-1.JPG",
                "data/cookware/oumbaerlig-stockpot-with-lid-00286413/oumbaerlig-stockpot-with-lid-00286413-2.JPG",
                "data/cookware/oumbaerlig-stockpot-with-lid-00286413/oumbaerlig-stockpot-with-lid-00286413-3.JPG",
                "data/cookware/oumbaerlig-stockpot-with-lid-00286413/oumbaerlig-stockpot-with-lid-00286413-4.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "36": {
            "id": 36,
            "prod_name": "KONCIS",
            "prod_price": "6",
            "prod_desc": "Roasting tin, stainless steel",
            "prod_dimensions": {
                "Length": "34 cm",
                "Width": "24 cm",
                "Height": "5.5 cm"
            },
            "packaging": [
                "KONCIS",
                "Roasting tin",
                "Article no.:",
                "900.990.54",
                "Width: 24 cm",
                "Height: 6 cm",
                "Length: 34 cm",
                "Weight: 0.86 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/koncis-roasting-tin-stainless-steel-90099054/koncis-roasting-tin-stainless-steel-90099054-0.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-90099054/koncis-roasting-tin-stainless-steel-90099054-1.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-90099054/koncis-roasting-tin-stainless-steel-90099054-2.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-90099054/koncis-roasting-tin-stainless-steel-90099054-3.JPG",
                "data/cookware/koncis-roasting-tin-stainless-steel-90099054/koncis-roasting-tin-stainless-steel-90099054-4.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,Oven-safe."
        },
        "37": {
            "id": 37,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Food container, square/plastic",
            "prod_dimensions": {
                "Package quantity": "3 pack",
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "604.521.74",
                "Width: 21 cm",
                "Height: 14 cm",
                "Length: 21 cm",
                "Weight: 0.55 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-0.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-1.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-2.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-3.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-4.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-5.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-60452174/ikea-365-food-container-square-plastic-60452174-6.JPG"
            ],
            "materials": "Jar/ Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "38": {
            "id": 38,
            "prod_name": "IKEA 365+ GUNSTIG",
            "prod_price": "5",
            "prod_desc": "Pot stand, magnetic, red/dark grey",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "18 cm"
            },
            "packaging": [
                "IKEA 365+ GUNSTIG",
                "Pot stand, magnetic",
                "Article no.:",
                "501.752.76",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 18 cm",
                "Weight: 0.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "The pot stand adheres to cookware suitable for use on induction hob as it is magnetic.  Slip the pot stand underneath a pot with magnetic bottom and it hangs on when you lift and carry the pot.  Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276-0.JPG",
                "data/cookware/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276-1.JPG",
                "data/cookware/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276-2.JPG",
                "data/cookware/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276/ikea-365-gunstig-pot-stand-magnetic-red-dark-grey-50175276-3.JPG"
            ],
            "materials": "Main parts:,Silicone rubber,Magnet:,Neodymium,Dishwasher-safe.,Withstands temperatures up to 160\u00b0C."
        },
        "39": {
            "id": 39,
            "prod_name": "SENSUELL",
            "prod_price": "35",
            "prod_desc": "Pot with lid, stainless steel/grey",
            "prod_dimensions": {
                "Height": "12 cm",
                "Diameter": "24 cm",
                "Volume": "4 l",
                "Length including handles": "29 cm",
                "Height including lid": "15 cm"
            },
            "packaging": [
                "SENSUELL",
                "Pot with lid",
                "Article no.:",
                "103.245.46",
                "Width: 25 cm",
                "Height: 14 cm",
                "Length: 26 cm",
                "Weight: 2.02 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. Tilted, easy to grip handles make it comfortable and safe to pour out the contents of the pot. The lid has a glass window that allows you to monitor the contents of the pot during the cooking process. The entire pot, both the bottom and the sides, has one layer of heat-conducting aluminium between two layers of stainless steel. This evenly distributes heat so that the food is heated up from several directions and makes it easy to regulate. The pan has extra thick walls and base, which distribute the heat evenly and give good cooking results. The graduated interior makes it easy to measure up liquid directly in the pan. You can cook food on a low heat and save energy because the stainless steel in the pan absorbs heat well and retains it for a long time. Works well on all types of hobs, including induction hob. The lid is slanted on the inside so that condensation drips down into the pot during cooking \u2013 instead of landing on the worktop when you remove the lid. Made of high-quality stainless steel, which makes the pan very durable and easy to clean. Steam vent reduces pressure so that food does not easily boil over. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. The lid for SENSUELL pot also fit the sauteuse in the same series. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-0.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-1.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-2.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-3.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-4.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-10324546/sensuell-pot-with-lid-stainless-steel-grey-10324546-5.JPG"
            ],
            "materials": "Body:,Stainless steel, Aluminium,Lid:,Stainless steel, Tempered glass, Silicone rubber,Handle:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "40": {
            "id": 40,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, square/glass",
            "prod_dimensions": {
                "Length": "8.5 cm",
                "Width": "8.5 cm",
                "Height": "6 cm",
                "Volume": "180 ml",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Food container with lid",
                "Article no.:",
                "804.449.46",
                "Width: 10 cm",
                "Height: 7 cm",
                "Length: 27 cm",
                "Weight: 0.67 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-glass-80444946/ikea-365-food-container-with-lid-square-glass-80444946-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-80444946/ikea-365-food-container-with-lid-square-glass-80444946-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-80444946/ikea-365-food-container-with-lid-square-glass-80444946-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-80444946/ikea-365-food-container-with-lid-square-glass-80444946-3.JPG"
            ],
            "materials": "Jar:,Heat resistant glass,Lid:,Polypropylene plastic,Seal:,Silicone rubber,The container is oven-safe, but the lid is not.,Microwave-safe.,Freezer-safe.,Dishwasher-safe."
        },
        "41": {
            "id": 41,
            "prod_name": "RINNIG",
            "prod_price": "1",
            "prod_desc": "Pot holder, grey",
            "prod_dimensions": {
                "Length": "21 cm",
                "Package quantity": "2 pack",
                "Width": "21 cm"
            },
            "packaging": [
                "RINNIG",
                "Pot holder",
                "Article no.:",
                "004.763.66",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 21 cm",
                "Weight: 0.09 kg",
                "Package(s): 1"
            ],
            "prod_details": "Felted polyester layer in between gives very good heat insulation.",
            "sustainability": "By using filling made of recycled polyester in this product, we consume less new raw materials and lower our environmental footprint.,All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.",
            "images": [
                "data/cookware/rinnig-pot-holder-grey-00476366/rinnig-pot-holder-grey-00476366-0.JPG",
                "data/cookware/rinnig-pot-holder-grey-00476366/rinnig-pot-holder-grey-00476366-1.JPG",
                "data/cookware/rinnig-pot-holder-grey-00476366/rinnig-pot-holder-grey-00476366-2.JPG",
                "data/cookware/rinnig-pot-holder-grey-00476366/rinnig-pot-holder-grey-00476366-3.JPG",
                "data/cookware/rinnig-pot-holder-grey-00476366/rinnig-pot-holder-grey-00476366-4.JPG"
            ],
            "materials": "Fabric:,100% cotton,Filling:,100% polyester (min. 70% recycled),Shrinkage maximum 4%.,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 200\u00b0C.,Do not dryclean.,Stretch into shape when wet."
        },
        "42": {
            "id": 42,
            "prod_name": "IKEA 365+",
            "prod_price": "27",
            "prod_desc": "Pot with lid, stainless steel/glass",
            "prod_dimensions": {
                "Height": "16 cm",
                "Diameter": "24 cm",
                "Volume": "5 l"
            },
            "packaging": [
                "IKEA 365+",
                "Pot with lid",
                "Article no.:",
                "102.567.50",
                "Width: 24 cm",
                "Height: 16 cm",
                "Length: 33 cm",
                "Weight: 2.20 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The glass lid allows you to monitor the contents of the pot during the cooking process.  The graduated interior makes it easy to measure up liquid directly in the pan. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Thanks to the smart design of the handles, you can stack the smaller pots in the larger ones from the same series. They take very little space, so you have room for other things in your cabinet. Works well on all types of hobs, including induction hob. The exterior is made of brushed steel which means that stains do not show as much as on a high-gloss surface. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. You can use the cookware in the oven, as it is made of metal and has a lid made of oven-safe glass. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. STABIL steamer insert, boiling insert and pasta insert 5 l fits. Keep in mind that the handles become hot when using the pot. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-0.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-1.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-2.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-3.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-4.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-5.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-6.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-7.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-8.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-10256750/ikea-365-pot-with-lid-stainless-steel-glass-10256750-9.JPG"
            ],
            "materials": "Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "43": {
            "id": 43,
            "prod_name": "VARDAGEN",
            "prod_price": "8",
            "prod_desc": "Oven dish, rectangular/dark grey",
            "prod_dimensions": {
                "Length": "29 cm",
                "Width": "23 cm",
                "Height": "6 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Oven dish",
                "Article no.:",
                "502.893.05",
                "Width: 23 cm",
                "Height: 6 cm",
                "Length: 29 cm",
                "Weight: 1.59 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-50289305/vardagen-oven-dish-rectangular-dark-grey-50289305-0.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-50289305/vardagen-oven-dish-rectangular-dark-grey-50289305-1.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-50289305/vardagen-oven-dish-rectangular-dark-grey-50289305-2.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-50289305/vardagen-oven-dish-rectangular-dark-grey-50289305-3.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-50289305/vardagen-oven-dish-rectangular-dark-grey-50289305-4.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "44": {
            "id": 44,
            "prod_name": "IKEA 365+",
            "prod_price": "40",
            "prod_desc": "Cooking kit 1",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 5 packages.",
                "IKEA 365+",
                "Pot with lid",
                "Article no.:",
                "102.567.50",
                "Width: 24 cm",
                "Height: 16 cm",
                "Length: 33 cm",
                "Weight: 2.20 kg",
                "Package(s): 1",
                "SANDVIVA",
                "Waist apron",
                "Article no.:",
                "904.679.42",
                "Width: 22 cm",
                "Height: 2 cm",
                "Length: 23 cm",
                "Weight: 0.16 kg",
                "Package(s): 1",
                "SANDVIVA",
                "Oven glove",
                "Article no.:",
                "104.643.82",
                "Width: 11 cm",
                "Height: 8 cm",
                "Length: 19 cm",
                "Weight: 0.11 kg",
                "Package(s): 1",
                "SANDVIVA",
                "Tea towel",
                "Article no.:",
                "204.644.14",
                "Width: 21 cm",
                "Height: 2 cm",
                "Length: 21 cm",
                "Weight: 0.15 kg",
                "Package(s): 1",
                "FULL\u00c4NDAD",
                "5-piece kitchen utensil set",
                "Article no.:",
                "804.359.42",
                "Width: 12 cm",
                "Height: 10 cm",
                "Length: 35 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ pot (5 l), 1 SANDVIVA waist apron, 1 SANDVIVA oven glove, 2 x SANDVIVA tea towels (40x60 cm) and FULL\u00c4NDAD 5-piece kitchen utensil set.",
            "sustainability": "Waist apron,Renewable material (cotton).,All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.,Tea towel,Renewable cellulose-based material from raw material of wood (lyocell).,Lyocell, a cellulose fibre made from wood, is produced in a closed process. Most of the added substances are recycled or reused, which is part of our ambition to reduce our environmental impact.",
            "images": [
                "data/cookware/ikea-365-cooking-kit-1-s19401366/ikea-365-cooking-kit-1-s19401366-0.JPG"
            ],
            "materials": "Pot with lid,Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Waist apron,Fabric:,80 % polyester, 20% cotton,Ties:,100% cotton,Oven glove,Silicone rubber,Tea towel,50% cotton, 50% lyocell,5-piece kitchen utensil set,Reinforced polyamide plastic"
        },
        "45": {
            "id": 45,
            "prod_name": "SNITSIG",
            "prod_price": "7",
            "prod_desc": "Pot with lid, stainless steel",
            "prod_dimensions": {
                "Height": "13 cm",
                "Diameter": "19 cm",
                "Volume": "3 l",
                "Length including handles": "27 cm",
                "Height including lid": "17 cm"
            },
            "packaging": [
                "SNITSIG",
                "Pot with lid",
                "Article no.:",
                "101.297.24",
                "Width: 20 cm",
                "Height: 15 cm",
                "Length: 27 cm",
                "Weight: 0.95 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. STABIL pasta insert 3 l, double-boiler insert, steamer insert and pot strainer fit. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/snitsig-pot-with-lid-stainless-steel-10129724/snitsig-pot-with-lid-stainless-steel-10129724-0.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-10129724/snitsig-pot-with-lid-stainless-steel-10129724-1.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-10129724/snitsig-pot-with-lid-stainless-steel-10129724-2.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-10129724/snitsig-pot-with-lid-stainless-steel-10129724-3.JPG"
            ],
            "materials": "Handle:,Phenolic plastic,Basematerial:,Stainless steel,Bottom:,Stainless steel, Aluminium,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "46": {
            "id": 46,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Dry food jar with lid, transparent/white",
            "prod_dimensions": {
                "Length": "17 cm",
                "Width": "8 cm",
                "Height": "18 cm",
                "Volume": "1.3 l"
            },
            "packaging": [
                "IKEA 365+",
                "Dry food jar with lid",
                "Article no.:",
                "800.667.23",
                "Width: 17 cm",
                "Height: 8 cm",
                "Length: 18 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Remove the lid completely to fill the jar and open half the lid to make it easier to pour from. Designed to give a good grip when you want to stir and pour at the same time. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. You can reduce your food waste by storing your dry foods in a jar with a tight-fitting lid, because it keeps the food fresh longer.  Suitable for storing dry foodstuffs. Wash this product before using it for the first time.",
            "sustainability": "Possible to separate for recycling or energy recovery if available in your community.,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-0.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-1.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-2.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-3.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-4.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-80066723/ikea-365-dry-food-jar-with-lid-transparent-white-80066723-5.JPG"
            ],
            "materials": "Polystyrene-acrylic plastic, Polypropylene plastic, Synthetic rubber,Dishwasher-safe in upper basket.,Withstands temperatures up to 70\u00b0C."
        },
        "47": {
            "id": 47,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "15",
            "prod_desc": "Frying pan",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "28 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Frying pan",
                "Article no.:",
                "502.920.96",
                "Width: 30 cm",
                "Height: 9 cm",
                "Length: 50 cm",
                "Weight: 1.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. With Teflon\u00ae Platinum plus, a very hardwearing non-stick coating that makes the pan suitable for everyday use. Made of stainless steel, which makes the pan durable and easy to clean. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.,No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-0.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-1.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-2.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-3.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-4.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-5.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-6.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-7.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-8.JPG",
                "data/cookware/oumbaerlig-frying-pan-50292096/oumbaerlig-frying-pan-50292096-9.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "48": {
            "id": 48,
            "prod_name": "IKEA 365+",
            "prod_price": "15",
            "prod_desc": "Saucepan with lid, stainless steel/glass",
            "prod_dimensions": {
                "Height": "8 cm",
                "Volume": "1 l"
            },
            "packaging": [
                "IKEA 365+",
                "Saucepan with lid",
                "Article no.:",
                "402.567.44",
                "Width: 17 cm",
                "Height: 12 cm",
                "Length: 31 cm",
                "Weight: 1.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The glass lid allows you to monitor the contents of the pot during the cooking process.  The graduated interior makes it easy to measure up liquid directly in the pan. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Thanks to the smart design of the handles, you can stack the smaller pots in the larger ones from the same series. They take very little space, so you have room for other things in your cabinet. Works well on all types of hobs, including induction hob. The exterior is made of brushed steel which means that stains do not show as much as on a high-gloss surface. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. You can use the cookware in the oven, as it is made of metal and has a lid made of oven-safe glass. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744-0.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744-1.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744-2.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744-3.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744/ikea-365-saucepan-with-lid-stainless-steel-glass-40256744-4.JPG"
            ],
            "materials": "Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "49": {
            "id": 49,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "15",
            "prod_desc": "Frying pan, copper-colour",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "28 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Frying pan",
                "Article no.:",
                "504.510.52",
                "Width: 30 cm",
                "Height: 8 cm",
                "Length: 50 cm",
                "Weight: 1.05 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. With Teflon\u00ae Platinum plus, a very hardwearing non-stick coating that makes the pan suitable for everyday use. Made of stainless steel, which makes the pan durable and easy to clean. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/oumbaerlig-frying-pan-copper-colour-50451052/oumbaerlig-frying-pan-copper-colour-50451052-0.JPG",
                "data/cookware/oumbaerlig-frying-pan-copper-colour-50451052/oumbaerlig-frying-pan-copper-colour-50451052-1.JPG",
                "data/cookware/oumbaerlig-frying-pan-copper-colour-50451052/oumbaerlig-frying-pan-copper-colour-50451052-2.JPG",
                "data/cookware/oumbaerlig-frying-pan-copper-colour-50451052/oumbaerlig-frying-pan-copper-colour-50451052-3.JPG",
                "data/cookware/oumbaerlig-frying-pan-copper-colour-50451052/oumbaerlig-frying-pan-copper-colour-50451052-4.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "50": {
            "id": 50,
            "prod_name": "\u00d6VERM\u00c4TT",
            "prod_price": "2",
            "prod_desc": "Food cover, set of 3, silicone multicolour",
            "prod_dimensions": {},
            "packaging": [
                "\u00d6VERM\u00c4TT",
                "Food cover, set of 3",
                "Article no.:",
                "804.173.11",
                "Width: 12 cm",
                "Height: 2 cm",
                "Length: 13 cm",
                "Weight: 0.06 kg",
                "Package(s): 1"
            ],
            "prod_details": "Can be washed and reused. The food covers function as lids and keep both food and drinks fresh longer. Perfect for everything from jars and glass containers to fruit and vegetables. Easy to clean, since they are dishwasher-safe. Comprises: 1 transparent food cover (dia. 6.2 cm), 1 pink food cover (dia. 9.5 cm) and 1 turquoise food cover (dia. 12.4 cm). The 3 food covers fit objects with diameter: 2.5-7 cm, 6-11 cm and 7-13 cm.",
            "sustainability": "",
            "images": [
                "data/cookware/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311-0.JPG",
                "data/cookware/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311-1.JPG",
                "data/cookware/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311-2.JPG",
                "data/cookware/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311/oevermaett-food-cover-set-of-3-silicone-multicolour-80417311-3.JPG"
            ],
            "materials": "Silicone rubber,Dishwasher-safe.,Not microwave-safe.,Not oven-safe.,To keep the food covers clean - make sure they are completely dry before putting them away. The easiest way is to let them air dry."
        },
        "51": {
            "id": 51,
            "prod_name": "KRISPIG",
            "prod_price": "5",
            "prod_desc": "Cake carrier",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "36 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KRISPIG",
                "Cake carrier",
                "Article no.:",
                "203.364.07",
                "This product has multiple packages.",
                "Length: 16 cm",
                "Weight: 0.44 kg",
                "Diameter: 40 cm",
                "Package(s): 1",
                "Length: 3 cm",
                "Weight: 0.29 kg",
                "Diameter: 35 cm",
                "Package(s): 1"
            ],
            "prod_details": "The tray has a dual function. One side that is smooth, for larger baked goods like cakes, and the other one with ridges for smaller baked goods like muffins. Four latches hold the lid in place so that you can safely take the cake carrier with you. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/krispig-cake-carrier-20336407/krispig-cake-carrier-20336407-0.JPG",
                "data/cookware/krispig-cake-carrier-20336407/krispig-cake-carrier-20336407-1.JPG",
                "data/cookware/krispig-cake-carrier-20336407/krispig-cake-carrier-20336407-2.JPG",
                "data/cookware/krispig-cake-carrier-20336407/krispig-cake-carrier-20336407-3.JPG",
                "data/cookware/krispig-cake-carrier-20336407/krispig-cake-carrier-20336407-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "52": {
            "id": 52,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Food container with lid, rectangular glass/bamboo",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.99",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.68 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.819.07",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 21 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s09269065-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "53": {
            "id": 53,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Lunch bag, white/beige",
            "prod_dimensions": {
                "Length": "22 cm",
                "Width": "17 cm",
                "Height": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lunch bag",
                "Article no.:",
                "104.800.23",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 22 cm",
                "Weight: 0.07 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to pack and reach the contents since the bag has a long zipper that makes the opening large. Stands steady thanks to the flat base. The bag has space for 2 rectangular IKEA 365+ food containers with lids, 1 l.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lunch-bag-white-beige-10480023/ikea-365-lunch-bag-white-beige-10480023-0.JPG",
                "data/cookware/ikea-365-lunch-bag-white-beige-10480023/ikea-365-lunch-bag-white-beige-10480023-1.JPG",
                "data/cookware/ikea-365-lunch-bag-white-beige-10480023/ikea-365-lunch-bag-white-beige-10480023-2.JPG",
                "data/cookware/ikea-365-lunch-bag-white-beige-10480023/ikea-365-lunch-bag-white-beige-10480023-3.JPG",
                "data/cookware/ikea-365-lunch-bag-white-beige-10480023/ikea-365-lunch-bag-white-beige-10480023-4.JPG"
            ],
            "materials": "Fabric:,100% polyethylene,Handle:,100% polyester,Do not wash.,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean.,Wipe clean with a damp cloth."
        },
        "54": {
            "id": 54,
            "prod_name": "VARDAGEN",
            "prod_price": "10",
            "prod_desc": "Oven dish, rectangular/dark grey",
            "prod_dimensions": {
                "Length": "33 cm",
                "Width": "26 cm",
                "Height": "7 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Oven dish",
                "Article no.:",
                "702.972.72",
                "Width: 26 cm",
                "Height: 7 cm",
                "Length: 34 cm",
                "Weight: 2.03 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-70297272/vardagen-oven-dish-rectangular-dark-grey-70297272-0.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-70297272/vardagen-oven-dish-rectangular-dark-grey-70297272-1.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-70297272/vardagen-oven-dish-rectangular-dark-grey-70297272-2.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-70297272/vardagen-oven-dish-rectangular-dark-grey-70297272-3.JPG",
                "data/cookware/vardagen-oven-dish-rectangular-dark-grey-70297272/vardagen-oven-dish-rectangular-dark-grey-70297272-4.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "55": {
            "id": 55,
            "prod_name": "SENSUELL",
            "prod_price": "29",
            "prod_desc": "Sauteuse, stainless steel/grey",
            "prod_dimensions": {
                "Height": "9 cm",
                "Diameter": "24 cm",
                "Volume": "3 l",
                "Length including handles": "43 cm"
            },
            "packaging": [
                "SENSUELL",
                "Sauteuse",
                "Article no.:",
                "503.245.49",
                "Width: 24 cm",
                "Height: 10 cm",
                "Length: 43 cm",
                "Weight: 1.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. The handle provides a comfortable and secure grip because it follows the contours of your hand and has silicon on the underside. Thick base and high sides lead the heat away from the base. This makes it possible to fry food, then add a sauce and let it boil together \u2013 ideal for stews or meaty pasta sauces. Works well on all types of hobs, including induction hob. You can cook food on a low heat and save energy because the stainless steel in the pan absorbs heat well and retains it for a long time. The entire pan, including the base and sides, has one layer of aluminium between two layers of stainless steel. This distributes heat evenly and energy efficiently from several directions and makes it easy to regulate. The pan has extra thick walls and base, which distribute the heat evenly and give good cooking results. Made of high-quality stainless steel, which makes the pan very durable and easy to clean. The graduated interior makes it easy to measure up liquid directly in the pan. The lid for SENSUELL pot also fit the sauteuse in the same series. To brown foods and prevent them from sticking, first heat up the pan then lower the temperature when you start to cook. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/sensuell-sauteuse-stainless-steel-grey-50324549/sensuell-sauteuse-stainless-steel-grey-50324549-0.JPG",
                "data/cookware/sensuell-sauteuse-stainless-steel-grey-50324549/sensuell-sauteuse-stainless-steel-grey-50324549-1.JPG",
                "data/cookware/sensuell-sauteuse-stainless-steel-grey-50324549/sensuell-sauteuse-stainless-steel-grey-50324549-2.JPG",
                "data/cookware/sensuell-sauteuse-stainless-steel-grey-50324549/sensuell-sauteuse-stainless-steel-grey-50324549-3.JPG",
                "data/cookware/sensuell-sauteuse-stainless-steel-grey-50324549/sensuell-sauteuse-stainless-steel-grey-50324549-4.JPG"
            ],
            "materials": "Body:,Stainless steel, Aluminium,Handle:,Stainless steel, Silicone rubber,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "56": {
            "id": 56,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Water bottle, dark grey",
            "prod_dimensions": {
                "Height": "24 cm",
                "Volume": "0.5 l"
            },
            "packaging": [
                "IKEA 365+",
                "Water bottle",
                "Article no.:",
                "204.800.13",
                "Length: 24 cm",
                "Weight: 0.09 kg",
                "Diameter: 7 cm",
                "Package(s): 1"
            ],
            "prod_details": "The bottle looks like it\u2019s made out of glass, but it\u2019s made of durable plastic that can withstand everyday wear and tear. The lid strap makes the bottle easy to carry. Spare parts are available to prolong the life of your product. Lid gasket spare part number 10050684. For more information, contact IKEA Customer Services at your IKEA store or IKEA.com. Wash this product before using it for the first time.",
            "sustainability": "Plastic can be recycled multiple times, reducing our environmental footprint. All products containing recycled materials meet the same quality and safety demands as we have on all our products.,BPA (Bisphenol A) free,By offering replacement parts, we make it easier to maintain and repair products. That way, products live longer, waste is reduced and the environmental impact is lowered.",
            "images": [
                "data/cookware/ikea-365-water-bottle-dark-grey-20480013/ikea-365-water-bottle-dark-grey-20480013-0.JPG",
                "data/cookware/ikea-365-water-bottle-dark-grey-20480013/ikea-365-water-bottle-dark-grey-20480013-1.JPG",
                "data/cookware/ikea-365-water-bottle-dark-grey-20480013/ikea-365-water-bottle-dark-grey-20480013-2.JPG"
            ],
            "materials": "Body:,PCTG plastic,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Freezer-safe.,Dishwasher-safe.,Withstands temperatures up to 70\u00b0C."
        },
        "57": {
            "id": 57,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Lid, round/glass",
            "prod_dimensions": {
                "Diameter": "14 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The transparent lid makes it easy to find what you are looking for, even if the jar is stored in the fridge or cabinet.   Fits with IKEA 365+ round-shaped food containers and jars. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-lid-round-glass-30393497/ikea-365-lid-round-glass-30393497-0.JPG",
                "data/cookware/ikea-365-lid-round-glass-30393497/ikea-365-lid-round-glass-30393497-1.JPG",
                "data/cookware/ikea-365-lid-round-glass-30393497/ikea-365-lid-round-glass-30393497-2.JPG",
                "data/cookware/ikea-365-lid-round-glass-30393497/ikea-365-lid-round-glass-30393497-3.JPG",
                "data/cookware/ikea-365-lid-round-glass-30393497/ikea-365-lid-round-glass-30393497-4.JPG"
            ],
            "materials": "Lid:,Glass,Seal:,Silicone rubber,Dishwasher-safe."
        },
        "58": {
            "id": 58,
            "prod_name": "ANNONS",
            "prod_price": "15",
            "prod_desc": "Pot with lid, glass/stainless steel",
            "prod_dimensions": {
                "Height": "20 cm",
                "Diameter": "26 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "ANNONS",
                "Pot with lid",
                "Article no.:",
                "303.264.22",
                "Width: 27 cm",
                "Height: 21 cm",
                "Length: 38 cm",
                "Weight: 2.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "The glass lid allows you to monitor the contents of the pot during the cooking process.  Works well on all types of hobs, including induction hob. Made of stainless steel, which makes the pan durable and easy to clean. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Steam vent reduces pressure so that food does not easily boil over.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-30326422/annons-pot-with-lid-glass-stainless-steel-30326422-0.JPG",
                "data/cookware/annons-pot-with-lid-glass-stainless-steel-30326422/annons-pot-with-lid-glass-stainless-steel-30326422-1.JPG"
            ],
            "materials": "Basematerial:,Stainless steel, Tempered glass,Knob:,Phenolic plastic,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "59": {
            "id": 59,
            "prod_name": "IKEA 365+",
            "prod_price": "9",
            "prod_desc": "On the go kit 2",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 4 packages.",
                "IKEA 365+",
                "Lunch box with inserts",
                "Article no.:",
                "404.800.07",
                "Width: 16 cm",
                "Height: 7 cm",
                "Length: 22 cm",
                "Weight: 0.38 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lunch bag",
                "Article no.:",
                "104.800.23",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 22 cm",
                "Weight: 0.07 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Ice pack",
                "Article no.:",
                "104.377.89",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 21 cm",
                "Weight: 0.63 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Water bottle",
                "Article no.:",
                "204.800.13",
                "Length: 24 cm",
                "Weight: 0.09 kg",
                "Diameter: 7 cm",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ lunchbox with inserts (1.0 l), 1 IKEA 365+ water bottle (0.5 l), 1 IKEA 365+ lunch bag (22x17x16 cm) and 1 IKEA 365+ ice pack.",
            "sustainability": "Water bottle,Plastic can be recycled multiple times, reducing our environmental footprint. All products containing recycled materials meet the same quality and safety demands as we have on all our products.,BPA (Bisphenol A) free,By offering replacement parts, we make it easier to maintain and repair products. That way, products live longer, waste is reduced and the environmental impact is lowered.",
            "images": [
                "data/cookware/ikea-365-on-the-go-kit-2-s69401175/ikea-365-on-the-go-kit-2-s69401175-0.JPG"
            ],
            "materials": "Lunch box with inserts,Jar/ Insert/ Lid:,Polypropylene plastic,Seal:,Silicone rubber,Lunch bag,Fabric:,100% polyethylene,Handle:,100% polyester,Ice pack,Body:,Polyethylene plastic,Filling:,Aqua,Belt:,Synthetic rubber,Water bottle,Body:,PCTG plastic,Lid:,Polypropylene plastic,Seal:,Silicone rubber"
        },
        "60": {
            "id": 60,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Label",
            "prod_dimensions": {
                "Package quantity": "50 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Label",
                "Article no.:",
                "204.385.47",
                "Width: 8 cm",
                "Height: 5 cm",
                "Length: 8 cm",
                "Weight: 0.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "Perfect for labelling your jars of dry goods or containers with leftovers.  The labels come in two sizes and are easy to put on and take off without leaving marks.  If you use a non-permanent marker, you can rub off the text and use the label over and over again. The labels are dishwasher safe, but still peel off easily when you want to remove them.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-0.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-1.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-2.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-3.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-4.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-5.JPG",
                "data/cookware/ikea-365-label-20438547/ikea-365-label-20438547-6.JPG"
            ],
            "materials": "Polypropylene plastic"
        },
        "61": {
            "id": 61,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Food container with lid, rectangular/glass plastic",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "9 cm",
                "Volume": "3.1 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "803.931.31",
                "Width: 21 cm",
                "Height: 8 cm",
                "Length: 32 cm",
                "Weight: 1.58 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.930.63",
                "Width: 27 cm",
                "Height: 1 cm",
                "Length: 37 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777/ikea-365-food-container-with-lid-rectangular-glass-plastic-s19276777-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The container is oven-safe, but the lid is not.,Food container,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "62": {
            "id": 62,
            "prod_name": "IKEA 365+",
            "prod_price": "19",
            "prod_desc": "Frying pan",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "28 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Frying pan",
                "Article no.:",
                "103.298.98",
                "Width: 28 cm",
                "Height: 11 cm",
                "Length: 49 cm",
                "Weight: 1.22 kg",
                "Package(s): 1"
            ],
            "prod_details": "5 year guarantee. Read about the terms in the guarantee brochure. Works well on all types of hobs, including induction hob. With Teflon\u00ae Professional, our best non-stick coating; for you who place high demands on your pans. Heat spreads evenly over the bottom and sides, since the frying pan has a layer of aluminium between two layers of stainless steel which are equally thick across the entire pan. Made of stainless steel, which makes the pan durable and easy to clean. Can also be used in the oven since it is made entirely of metal. When using the cookware on an induction hob, for best performance use it on an induction zone that has the same diameter as the cookware. Wash this product before using it for the first time. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/ikea-365-frying-pan-10329898/ikea-365-frying-pan-10329898-0.JPG",
                "data/cookware/ikea-365-frying-pan-10329898/ikea-365-frying-pan-10329898-1.JPG",
                "data/cookware/ikea-365-frying-pan-10329898/ikea-365-frying-pan-10329898-2.JPG",
                "data/cookware/ikea-365-frying-pan-10329898/ikea-365-frying-pan-10329898-3.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Aluminium, Coated with Teflon(R) Professional,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "63": {
            "id": 63,
            "prod_name": "IKEA 365+",
            "prod_price": "10",
            "prod_desc": "Oven dish, white",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "20 cm",
                "Height": "7 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Oven dish",
                "Article no.:",
                "902.867.34",
                "Width: 20 cm",
                "Height: 7 cm",
                "Length: 32 cm",
                "Weight: 1.45 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of feldspar porcelain, which makes the oven dish impact resistant and durable. The generous handles make it easy and safe for you to hold and lift the oven dish. The smart design allows you to stack the smaller sizes in the larger ones without taking more vertical space, so you get room for other things. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-oven-dish-white-90286734/ikea-365-oven-dish-white-90286734-0.JPG",
                "data/cookware/ikea-365-oven-dish-white-90286734/ikea-365-oven-dish-white-90286734-1.JPG",
                "data/cookware/ikea-365-oven-dish-white-90286734/ikea-365-oven-dish-white-90286734-2.JPG"
            ],
            "materials": "Feldspar porcelain,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "64": {
            "id": 64,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, round/silicone",
            "prod_dimensions": {
                "Diameter": "15 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.820.87",
                "Length: 2 cm",
                "Weight: 0.07 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "The lid creates a vacuum when placed on a container \u2012 keeping the food fresh longer and helping the food retain both heat and coolness. Can be used to protect from splatter in the oven and the microwave. Wash the lid in the dishwasher and use it again and again, as this helps you reduce the amount of plastic and aluminium foil you use. Fits with IKEA 365+ round-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-round-silicone-50382087/ikea-365-lid-round-silicone-50382087-0.JPG",
                "data/cookware/ikea-365-lid-round-silicone-50382087/ikea-365-lid-round-silicone-50382087-1.JPG",
                "data/cookware/ikea-365-lid-round-silicone-50382087/ikea-365-lid-round-silicone-50382087-2.JPG",
                "data/cookware/ikea-365-lid-round-silicone-50382087/ikea-365-lid-round-silicone-50382087-3.JPG"
            ],
            "materials": "Silicone rubber,Withstands temperatures up to 225\u00b0C.,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "65": {
            "id": 65,
            "prod_name": "IKEA 365+",
            "prod_price": "35",
            "prod_desc": "Stockpot with lid, stainless steel/glass",
            "prod_dimensions": {
                "Height": "19 cm",
                "Diameter": "28 cm",
                "Volume": "10 l"
            },
            "packaging": [
                "IKEA 365+",
                "Stockpot with lid",
                "Article no.:",
                "502.567.48",
                "Width: 29 cm",
                "Height: 21 cm",
                "Length: 38 cm",
                "Weight: 3.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The glass lid allows you to monitor the contents of the pot during the cooking process.  The graduated interior makes it easy to measure up liquid directly in the pan. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Thanks to the smart design of the handles, you can stack the smaller pots in the larger ones from the same series. They take very little space, so you have room for other things in your cabinet. Works well on all types of hobs, including induction hob. The exterior is made of brushed steel which means that stains do not show as much as on a high-gloss surface. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. You can use the cookware in the oven, as it is made of metal and has a lid made of oven-safe glass. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. STABIL splatter screen and lid dia. 28 cm fit. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-0.JPG",
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-1.JPG",
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-2.JPG",
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-3.JPG",
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-4.JPG",
                "data/cookware/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748/ikea-365-stockpot-with-lid-stainless-steel-glass-50256748-5.JPG"
            ],
            "materials": "Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "66": {
            "id": 66,
            "prod_name": "IKEA 365+",
            "prod_price": "45",
            "prod_desc": "56-piece cutlery set, stainless steel",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "56-piece cutlery set",
                "Article no.:",
                "903.997.50",
                "Width: 26 cm",
                "Height: 6 cm",
                "Length: 29 cm",
                "Weight: 2.91 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: Fork, knife, spoon, teaspoon, dessert-/salad fork, dessert-/salad knife and dessert-/salad spoon, 8 of each. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-56-piece-cutlery-set-stainless-steel-90399750/ikea-365-56-piece-cutlery-set-stainless-steel-90399750-0.JPG",
                "data/cookware/ikea-365-56-piece-cutlery-set-stainless-steel-90399750/ikea-365-56-piece-cutlery-set-stainless-steel-90399750-1.JPG",
                "data/cookware/ikea-365-56-piece-cutlery-set-stainless-steel-90399750/ikea-365-56-piece-cutlery-set-stainless-steel-90399750-2.JPG",
                "data/cookware/ikea-365-56-piece-cutlery-set-stainless-steel-90399750/ikea-365-56-piece-cutlery-set-stainless-steel-90399750-3.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,For the cutlery to be easy to clean and to reduce the risk of corrosion, always rinse off the remains of any food immediately."
        },
        "67": {
            "id": 67,
            "prod_name": "PRUTA",
            "prod_price": "0",
            "prod_desc": "Food container, transparent/blue",
            "prod_dimensions": {
                "Height": "4 cm",
                "Diameter": "7 cm",
                "Volume": "70 ml",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "PRUTA",
                "Food container",
                "Article no.:",
                "704.449.42",
                "Width: 8 cm",
                "Height: 5 cm",
                "Length: 8 cm",
                "Weight: 0.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/pruta-food-container-transparent-blue-70444942/pruta-food-container-transparent-blue-70444942-0.JPG",
                "data/cookware/pruta-food-container-transparent-blue-70444942/pruta-food-container-transparent-blue-70444942-1.JPG",
                "data/cookware/pruta-food-container-transparent-blue-70444942/pruta-food-container-transparent-blue-70444942-2.JPG",
                "data/cookware/pruta-food-container-transparent-blue-70444942/pruta-food-container-transparent-blue-70444942-3.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "68": {
            "id": 68,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Jar, round/glass",
            "prod_dimensions": {
                "Height": "19 cm",
                "Diameter": "17 cm",
                "Volume": "3.3 l"
            },
            "packaging": [
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "203.932.47",
                "Length: 19 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1"
            ],
            "prod_details": "Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-round-glass-20393247/ikea-365-jar-round-glass-20393247-0.JPG",
                "data/cookware/ikea-365-jar-round-glass-20393247/ikea-365-jar-round-glass-20393247-1.JPG",
                "data/cookware/ikea-365-jar-round-glass-20393247/ikea-365-jar-round-glass-20393247-2.JPG",
                "data/cookware/ikea-365-jar-round-glass-20393247/ikea-365-jar-round-glass-20393247-3.JPG",
                "data/cookware/ikea-365-jar-round-glass-20393247/ikea-365-jar-round-glass-20393247-4.JPG"
            ],
            "materials": "Glass,Dishwasher-safe."
        },
        "69": {
            "id": 69,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, round/glass",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "14 cm",
                "Volume": "400 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.95",
                "Length: 5 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-round-glass-50359195/ikea-365-food-container-round-glass-50359195-0.JPG",
                "data/cookware/ikea-365-food-container-round-glass-50359195/ikea-365-food-container-round-glass-50359195-1.JPG",
                "data/cookware/ikea-365-food-container-round-glass-50359195/ikea-365-food-container-round-glass-50359195-2.JPG",
                "data/cookware/ikea-365-food-container-round-glass-50359195/ikea-365-food-container-round-glass-50359195-3.JPG",
                "data/cookware/ikea-365-food-container-round-glass-50359195/ikea-365-food-container-round-glass-50359195-4.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "70": {
            "id": 70,
            "prod_name": "VARDAGEN",
            "prod_price": "8",
            "prod_desc": "Baking tin, silver-colour",
            "prod_dimensions": {
                "Length": "38 cm",
                "Width": "26 cm",
                "Volume": "2.0 l"
            },
            "packaging": [
                "VARDAGEN",
                "Baking tin",
                "Article no.:",
                "402.569.75",
                "Width: 26 cm",
                "Height: 3 cm",
                "Length: 38 cm",
                "Weight: 0.35 kg",
                "Package(s): 1"
            ],
            "prod_details": "Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. Always grease the tin with oil or butter for best results. Not suitable for acidic foods. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-0.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-1.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-2.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-3.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-4.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-40256975/vardagen-baking-tin-silver-colour-40256975-5.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe."
        },
        "71": {
            "id": 71,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, square/glass",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "003.592.06",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 15 cm",
                "Weight: 0.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ square-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-0.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-1.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-2.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-3.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-4.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-5.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-6.JPG",
                "data/cookware/ikea-365-food-container-square-glass-00359206/ikea-365-food-container-square-glass-00359206-7.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "72": {
            "id": 72,
            "prod_name": "IKEA 365+",
            "prod_price": "25",
            "prod_desc": "24-piece cutlery set, stainless steel",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "24-piece cutlery set",
                "Article no.:",
                "103.997.54",
                "Width: 16 cm",
                "Height: 5 cm",
                "Length: 23 cm",
                "Weight: 1.49 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: Fork, knife, spoon and teaspoon, 6 of each. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-0.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-1.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-2.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-3.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-4.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-5.JPG",
                "data/cookware/ikea-365-24-piece-cutlery-set-stainless-steel-10399754/ikea-365-24-piece-cutlery-set-stainless-steel-10399754-6.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,For the cutlery to be easy to clean and to reduce the risk of corrosion, always rinse off the remains of any food immediately."
        },
        "73": {
            "id": 73,
            "prod_name": "IKEA 365+",
            "prod_price": "22",
            "prod_desc": "Grill pan",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "28 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Grill pan",
                "Article no.:",
                "403.436.52",
                "Width: 28 cm",
                "Height: 11 cm",
                "Length: 49 cm",
                "Weight: 1.32 kg",
                "Package(s): 1"
            ],
            "prod_details": "5 year guarantee. Read about the terms in the guarantee brochure. Works well on all types of hobs, including induction hob. Gives appetising grill stripes on the food. Made from aluminium, which spreads heat evenly and energy efficiently, and makes it easier to regulate heat so the food does not burn and stick. With Teflon\u00ae Professional, our best non-stick coating; for you who place high demands on your pans. Can also be used in the oven since it is made entirely of metal. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/ikea-365-grill-pan-40343652/ikea-365-grill-pan-40343652-0.JPG",
                "data/cookware/ikea-365-grill-pan-40343652/ikea-365-grill-pan-40343652-1.JPG",
                "data/cookware/ikea-365-grill-pan-40343652/ikea-365-grill-pan-40343652-2.JPG",
                "data/cookware/ikea-365-grill-pan-40343652/ikea-365-grill-pan-40343652-3.JPG",
                "data/cookware/ikea-365-grill-pan-40343652/ikea-365-grill-pan-40343652-4.JPG"
            ],
            "materials": "Body:,Aluminium, Coated with Teflon(R) Professional, Fluorine plastic,Disc/ Handle:,Stainless steel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "74": {
            "id": 74,
            "prod_name": "SNITSIG",
            "prod_price": "10",
            "prod_desc": "Pot with lid, stainless steel",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "22 cm",
                "Volume": "5 l",
                "Length including handles": "31 cm",
                "Height including lid": "21 cm"
            },
            "packaging": [
                "SNITSIG",
                "Pot with lid",
                "Article no.:",
                "801.297.25",
                "Width: 23 cm",
                "Height: 17 cm",
                "Length: 31 cm",
                "Weight: 1.29 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/snitsig-pot-with-lid-stainless-steel-80129725/snitsig-pot-with-lid-stainless-steel-80129725-0.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-80129725/snitsig-pot-with-lid-stainless-steel-80129725-1.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-80129725/snitsig-pot-with-lid-stainless-steel-80129725-2.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-80129725/snitsig-pot-with-lid-stainless-steel-80129725-3.JPG"
            ],
            "materials": "Handle:,Phenolic plastic,Basematerial:,Stainless steel,Bottom:,Stainless steel, Aluminium,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "75": {
            "id": 75,
            "prod_name": "IKEA 365+",
            "prod_price": "15",
            "prod_desc": "4-piece serving set, stainless steel",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "4-piece serving set",
                "Article no.:",
                "803.997.60",
                "Width: 25 cm",
                "Height: 6 cm",
                "Length: 29 cm",
                "Weight: 0.55 kg",
                "Package(s): 1"
            ],
            "prod_details": "The timeless and smart design makes the dinnerware meet all your needs at home, regardless of what you eat and drink, and withstand being used 365 days a year. Comprises: 1 serving spoon, 1 serving ladle, 1 serving fork, and 1  cake-slicer. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-0.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-1.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-2.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-3.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-4.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-5.JPG",
                "data/cookware/ikea-365-4-piece-serving-set-stainless-steel-80399760/ikea-365-4-piece-serving-set-stainless-steel-80399760-6.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe.,For the cutlery to be easy to clean and to reduce the risk of corrosion, always rinse off the remains of any food immediately."
        },
        "76": {
            "id": 76,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, rectangular glass/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "1.8 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.592.03",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 21 cm",
                "Weight: 0.95 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074/ikea-365-food-container-with-lid-rectangular-glass-plastic-s29269074-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Food container,Freezer-safe.,Dishwasher-safe.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "77": {
            "id": 77,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "19",
            "prod_desc": "Frying pan",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "32 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Frying pan",
                "Article no.:",
                "702.920.95",
                "Width: 33 cm",
                "Height: 10 cm",
                "Length: 58 cm",
                "Weight: 1.29 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. With Teflon\u00ae Platinum plus, a very hardwearing non-stick coating that makes the pan suitable for everyday use. Made of stainless steel, which makes the pan durable and easy to clean. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.,No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.",
            "images": [
                "data/cookware/oumbaerlig-frying-pan-70292095/oumbaerlig-frying-pan-70292095-0.JPG",
                "data/cookware/oumbaerlig-frying-pan-70292095/oumbaerlig-frying-pan-70292095-1.JPG",
                "data/cookware/oumbaerlig-frying-pan-70292095/oumbaerlig-frying-pan-70292095-2.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "78": {
            "id": 78,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Lunch box with inserts, rectangular/beige",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "IKEA 365+",
                "Lunch box with inserts",
                "Article no.:",
                "404.800.07",
                "Width: 16 cm",
                "Height: 7 cm",
                "Length: 22 cm",
                "Weight: 0.38 kg",
                "Package(s): 1"
            ],
            "prod_details": "This lunch box has 3 removable inserts so that you can separate your main course from your salad and sauce. One of the inserts has a lid, perfect for things like sauces or dressings. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. Snap-and-lock lid creates an aroma-tight seal, so the food you store in the lunch box stays fresh for longer. The inserts fit with the square and rectangular food containers in the IKEA 365+ series. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-0.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-1.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-2.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-3.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-4.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-5.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-6.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007/ikea-365-lunch-box-with-inserts-rectangular-beige-40480007-7.JPG"
            ],
            "materials": "Jar/ Insert/ Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "79": {
            "id": 79,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, round/glass",
            "prod_dimensions": {
                "Height": "8 cm",
                "Diameter": "14 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "303.591.96",
                "Length: 8 cm",
                "Weight: 0.46 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-0.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-1.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-2.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-3.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-4.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-5.JPG",
                "data/cookware/ikea-365-food-container-round-glass-30359196/ikea-365-food-container-round-glass-30359196-6.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "80": {
            "id": 80,
            "prod_name": "UTRUSTNING",
            "prod_price": "9",
            "prod_desc": "Steel vacuum flask",
            "prod_dimensions": {
                "Height": "29 cm",
                "Volume": "1 l"
            },
            "packaging": [
                "UTRUSTNING",
                "Steel vacuum flask",
                "Article no.:",
                "604.153.51",
                "Length: 29 cm",
                "Weight: 0.66 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "This travel mug has a dry food compartment where you can keep things like tea bags, sugar and croutons for your soup. Two mugs are included, so you can always offer a friend a hot drink. Arrows show you how to pour \u2013 simple and without spills. Ideal for hot drinks or soups. Keeps the contents warm/cold for up to 6 hours. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-0.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-1.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-2.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-3.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-4.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-5.JPG",
                "data/cookware/utrustning-steel-vacuum-flask-60415351/utrustning-steel-vacuum-flask-60415351-6.JPG"
            ],
            "materials": "Cup/ Lid/ Insert/ Divider:,Polypropylene plastic,Insulation:,Expanded polyethylene plastic,Seal:,Silicone rubber,Body/ Bottom/ Washer:,Stainless steel,Handwash only."
        },
        "81": {
            "id": 81,
            "prod_name": "SENSUELL",
            "prod_price": "40",
            "prod_desc": "Pot with lid, stainless steel/grey",
            "prod_dimensions": {
                "Height": "15 cm",
                "Diameter": "24 cm",
                "Volume": "5.5 l",
                "Length including handles": "29 cm",
                "Height including lid": "18 cm"
            },
            "packaging": [
                "SENSUELL",
                "Pot with lid",
                "Article no.:",
                "903.245.47",
                "Width: 25 cm",
                "Height: 18 cm",
                "Length: 26 cm",
                "Weight: 2.36 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. Tilted, easy to grip handles make it comfortable and safe to pour out the contents of the pot. The lid has a glass window that allows you to monitor the contents of the pot during the cooking process. The entire pan, including the base and sides, has one layer of aluminium between two layers of stainless steel. This distributes heat evenly and energy efficiently from several directions and makes it easy to regulate. The pan has extra thick walls and base, which distribute the heat evenly and give good cooking results. The graduated interior makes it easy to measure up liquid directly in the pan. You can cook food on a low heat and save energy because the stainless steel in the pan absorbs heat well and retains it for a long time. Works well on all types of hobs, including induction hob. The lid is slanted on the inside so that condensation drips down into the pot during cooking \u2013 instead of landing on the worktop when you remove the lid. Made of high-quality stainless steel, which makes the pan very durable and easy to clean. Steam vent reduces pressure so that food does not easily boil over. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. The lid for SENSUELL pot also fit the sauteuse in the same series. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-90324547/sensuell-pot-with-lid-stainless-steel-grey-90324547-0.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-90324547/sensuell-pot-with-lid-stainless-steel-grey-90324547-1.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-90324547/sensuell-pot-with-lid-stainless-steel-grey-90324547-2.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-90324547/sensuell-pot-with-lid-stainless-steel-grey-90324547-3.JPG",
                "data/cookware/sensuell-pot-with-lid-stainless-steel-grey-90324547/sensuell-pot-with-lid-stainless-steel-grey-90324547-4.JPG"
            ],
            "materials": "Body:,Stainless steel, Aluminium,Lid:,Stainless steel, Tempered glass, Silicone rubber,Handle:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "82": {
            "id": 82,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container, large rectangular/glass",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "8 cm",
                "Volume": "3.1 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "803.931.31",
                "Width: 21 cm",
                "Height: 8 cm",
                "Length: 32 cm",
                "Weight: 1.58 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent container makes it easy to find what you are looking for, regardless of where it is placed. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-large-rectangular-glass-80393131/ikea-365-food-container-large-rectangular-glass-80393131-0.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-glass-80393131/ikea-365-food-container-large-rectangular-glass-80393131-1.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-glass-80393131/ikea-365-food-container-large-rectangular-glass-80393131-2.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-glass-80393131/ikea-365-food-container-large-rectangular-glass-80393131-3.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "83": {
            "id": 83,
            "prod_name": "SNITSIG",
            "prod_price": "15",
            "prod_desc": "Pot with lid, stainless steel",
            "prod_dimensions": {
                "Height": "19 cm",
                "Diameter": "27 cm",
                "Volume": "8.5 l",
                "Length including handles": "35 cm",
                "Height including lid": "24 cm"
            },
            "packaging": [
                "SNITSIG",
                "Pot with lid",
                "Article no.:",
                "401.297.27",
                "Width: 27 cm",
                "Height: 21 cm",
                "Length: 35 cm",
                "Weight: 1.77 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. The base has one layer of aluminium between two layers of stainless steel, which gives an even heat and reduces the risk of food burning and sticking. Made of stainless steel, which makes the pan durable and easy to clean. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/snitsig-pot-with-lid-stainless-steel-40129727/snitsig-pot-with-lid-stainless-steel-40129727-0.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-40129727/snitsig-pot-with-lid-stainless-steel-40129727-1.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-40129727/snitsig-pot-with-lid-stainless-steel-40129727-2.JPG",
                "data/cookware/snitsig-pot-with-lid-stainless-steel-40129727/snitsig-pot-with-lid-stainless-steel-40129727-3.JPG"
            ],
            "materials": "Handle:,Phenolic plastic,Basematerial:,Stainless steel,Bottom:,Stainless steel, Aluminium,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "84": {
            "id": 84,
            "prod_name": "VARDAGEN",
            "prod_price": "4",
            "prod_desc": "Measuring cup, set of 5",
            "prod_dimensions": {},
            "packaging": [
                "VARDAGEN",
                "Measuring cup, set of 5",
                "Article no.:",
                "603.247.23",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 12 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 millilitre, 1 teaspoon, 1 tablespoon, 1/2 decilitre and 1 decilitre. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-measuring-cup-set-of-5-60324723/vardagen-measuring-cup-set-of-5-60324723-0.JPG",
                "data/cookware/vardagen-measuring-cup-set-of-5-60324723/vardagen-measuring-cup-set-of-5-60324723-1.JPG",
                "data/cookware/vardagen-measuring-cup-set-of-5-60324723/vardagen-measuring-cup-set-of-5-60324723-2.JPG",
                "data/cookware/vardagen-measuring-cup-set-of-5-60324723/vardagen-measuring-cup-set-of-5-60324723-3.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe."
        },
        "85": {
            "id": 85,
            "prod_name": "IKEA 365+",
            "prod_price": "6",
            "prod_desc": "Jar with lid, glass/bamboo",
            "prod_dimensions": {
                "Height": "20 cm",
                "Diameter": "17 cm",
                "Volume": "3.3 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "203.932.47",
                "Length: 19 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276759/ikea-365-jar-with-lid-glass-bamboo-s99276759-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276759/ikea-365-jar-with-lid-glass-bamboo-s99276759-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276759/ikea-365-jar-with-lid-glass-bamboo-s99276759-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber"
        },
        "86": {
            "id": 86,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Grater with handle",
            "prod_dimensions": {
                "Length": "33 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Grater with handle",
                "Article no.:",
                "103.098.19",
                "Width: 7 cm",
                "Height: 3 cm",
                "Length: 33 cm",
                "Weight: 0.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-grater-with-handle-10309819/vardagen-grater-with-handle-10309819-0.JPG",
                "data/cookware/vardagen-grater-with-handle-10309819/vardagen-grater-with-handle-10309819-1.JPG",
                "data/cookware/vardagen-grater-with-handle-10309819/vardagen-grater-with-handle-10309819-2.JPG",
                "data/cookware/vardagen-grater-with-handle-10309819/vardagen-grater-with-handle-10309819-3.JPG"
            ],
            "materials": "Handle:,Polypropylene plastic, Acetal plastic,Rivet/ Bolster/ Bar/ Grater:,Stainless steel,Dishwasher-safe."
        },
        "87": {
            "id": 87,
            "prod_name": "VARDAGEN",
            "prod_price": "6",
            "prod_desc": "Pie dish, silver-colour",
            "prod_dimensions": {
                "Diameter": "31 cm",
                "Volume": "1.8 l"
            },
            "packaging": [
                "VARDAGEN",
                "Pie dish",
                "Article no.:",
                "202.569.95",
                "Length: 4 cm",
                "Weight: 0.31 kg",
                "Diameter: 31 cm",
                "Package(s): 1"
            ],
            "prod_details": "Loose bottom makes turning out the piecrust easy. Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. Always grease the tin with oil or butter for best results. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-0.JPG",
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-1.JPG",
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-2.JPG",
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-3.JPG",
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-4.JPG",
                "data/cookware/vardagen-pie-dish-silver-colour-20256995/vardagen-pie-dish-silver-colour-20256995-5.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe."
        },
        "88": {
            "id": 88,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lunch bag, white/turquoise",
            "prod_dimensions": {
                "Length": "22 cm",
                "Width": "17 cm",
                "Height": "30 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lunch bag",
                "Article no.:",
                "404.800.26",
                "Width: 18 cm",
                "Height: 2 cm",
                "Length: 22 cm",
                "Weight: 0.11 kg",
                "Package(s): 1"
            ],
            "prod_details": "Easy to pack and reach the contents since the bag has a long zipper that makes the opening large. Inside the bag there is a pocket for cutlery or other utensils. Easy to hang over your shoulder since the straps are long. Stands steady thanks to the flat base. The bag has space for 5 rectangular IKEA 365+ food containers with lids, 1 l.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lunch-bag-white-turquoise-40480026/ikea-365-lunch-bag-white-turquoise-40480026-0.JPG",
                "data/cookware/ikea-365-lunch-bag-white-turquoise-40480026/ikea-365-lunch-bag-white-turquoise-40480026-1.JPG",
                "data/cookware/ikea-365-lunch-bag-white-turquoise-40480026/ikea-365-lunch-bag-white-turquoise-40480026-2.JPG",
                "data/cookware/ikea-365-lunch-bag-white-turquoise-40480026/ikea-365-lunch-bag-white-turquoise-40480026-3.JPG",
                "data/cookware/ikea-365-lunch-bag-white-turquoise-40480026/ikea-365-lunch-bag-white-turquoise-40480026-4.JPG"
            ],
            "materials": "Fabric:,100% polyethylene,Handle:,100% polyester,Do not wash.,Do not bleach.,Do not tumble dry.,Do not iron.,Do not dryclean.,Wipe clean with a damp cloth."
        },
        "89": {
            "id": 89,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container, large rectangular/plastic",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "11 cm",
                "Volume": "5.2 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "803.930.65",
                "Width: 22 cm",
                "Height: 11 cm",
                "Length: 32 cm",
                "Weight: 0.30 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The transparent container makes it easy to find what you are looking for, regardless of where it is placed. Wash this product before using it for the first time.",
            "sustainability": "BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-80393065/ikea-365-food-container-large-rectangular-plastic-80393065-0.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-80393065/ikea-365-food-container-large-rectangular-plastic-80393065-1.JPG"
            ],
            "materials": "Polypropylene plastic,Freezer-safe.,Dishwasher-safe."
        },
        "90": {
            "id": 90,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Jar with lid, glass/plastic",
            "prod_dimensions": {
                "Height": "14 cm",
                "Diameter": "14 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "003.932.48",
                "Length: 13 cm",
                "Weight: 0.66 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The jar is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the jar is easy to clean. The jar and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s39277771/ikea-365-jar-with-lid-glass-plastic-s39277771-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s39277771/ikea-365-jar-with-lid-glass-plastic-s39277771-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s39277771/ikea-365-jar-with-lid-glass-plastic-s39277771-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Jar/lid,Dishwasher-safe."
        },
        "91": {
            "id": 91,
            "prod_name": "FJ\u00c4RMA",
            "prod_price": "5",
            "prod_desc": "Food container, collapsible, light grey",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "1 l"
            },
            "packaging": [
                "FJ\u00c4RMA",
                "Food container, collapsible",
                "Article no.:",
                "404.675.10",
                "Width: 16 cm",
                "Height: 4 cm",
                "Length: 22 cm",
                "Weight: 0.28 kg",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for storing food in portions so you can bring it with you to school or work. Reduce food waste by storing your leftovers in a food container and reheating for another meal. You don\u2019t need to remove the lid when heating the food in the microwave \u2013 instead, just pull up the round button in the centre of the lid. When the food container is empty, it takes up less space in a bag or in a cabinet since it\u2019s collapsible. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/fjaerma-food-container-collapsible-light-grey-40467510/fjaerma-food-container-collapsible-light-grey-40467510-0.JPG",
                "data/cookware/fjaerma-food-container-collapsible-light-grey-40467510/fjaerma-food-container-collapsible-light-grey-40467510-1.JPG",
                "data/cookware/fjaerma-food-container-collapsible-light-grey-40467510/fjaerma-food-container-collapsible-light-grey-40467510-2.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Body:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "92": {
            "id": 92,
            "prod_name": "EFTERFR\u00c5GAD",
            "prod_price": "10",
            "prod_desc": "Food vacuum flask, stainless steel",
            "prod_dimensions": {
                "Height": "14 cm",
                "Volume": "0.5 l"
            },
            "packaging": [
                "EFTERFR\u00c5GAD",
                "Food vacuum flask",
                "Article no.:",
                "402.883.54",
                "Length: 15 cm",
                "Weight: 0.32 kg",
                "Diameter: 10 cm",
                "Package(s): 1"
            ],
            "prod_details": "Easy to fill up with food and eat directly from, thanks to the wide mouth. Can be used both for beverages and for food like soup. The insert is made of metal and is therefore resistant to impact. You can lower your food waste by saving your leftovers in this food vacuum flask. It keeps the food warm, is easy to eat from and take with you. Keeps food or soup warm for up to 6 hours. For best results, pre-heat the food flask with boiling water a couple of minutes before you put the food in. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/efterfragad-food-vacuum-flask-stainless-steel-40288354/efterfragad-food-vacuum-flask-stainless-steel-40288354-0.JPG",
                "data/cookware/efterfragad-food-vacuum-flask-stainless-steel-40288354/efterfragad-food-vacuum-flask-stainless-steel-40288354-1.JPG",
                "data/cookware/efterfragad-food-vacuum-flask-stainless-steel-40288354/efterfragad-food-vacuum-flask-stainless-steel-40288354-2.JPG",
                "data/cookware/efterfragad-food-vacuum-flask-stainless-steel-40288354/efterfragad-food-vacuum-flask-stainless-steel-40288354-3.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic, Expanded polyethylene plastic,Body/ Bottom:,Stainless steel,Seal:,Silicone rubber"
        },
        "93": {
            "id": 93,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, round glass/plastic",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "14 cm",
                "Volume": "400 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.95",
                "Length: 5 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-glass-plastic-s09269094/ikea-365-food-container-with-lid-round-glass-plastic-s09269094-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-plastic-s09269094/ikea-365-food-container-with-lid-round-glass-plastic-s09269094-1.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Food container,Freezer-safe.,Dishwasher-safe.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "94": {
            "id": 94,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Oven dish, white",
            "prod_dimensions": {
                "Length": "18 cm",
                "Width": "13 cm",
                "Height": "6 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Oven dish",
                "Article no.:",
                "102.867.33",
                "Width: 13 cm",
                "Height: 6 cm",
                "Length: 19 cm",
                "Weight: 0.64 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of feldspar porcelain, which makes the oven dish impact resistant and durable. The generous handles make it easy and safe for you to hold and lift the oven dish. The smart design allows you to stack the smaller sizes in the larger ones without taking more vertical space, so you get room for other things. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-oven-dish-white-10286733/ikea-365-oven-dish-white-10286733-0.JPG",
                "data/cookware/ikea-365-oven-dish-white-10286733/ikea-365-oven-dish-white-10286733-1.JPG",
                "data/cookware/ikea-365-oven-dish-white-10286733/ikea-365-oven-dish-white-10286733-2.JPG",
                "data/cookware/ikea-365-oven-dish-white-10286733/ikea-365-oven-dish-white-10286733-3.JPG"
            ],
            "materials": "Feldspar porcelain,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "95": {
            "id": 95,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "23 cm",
                "Volume": "4.2 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "603.930.66",
                "Width: 21 cm",
                "Height: 15 cm",
                "Length: 23 cm",
                "Weight: 0.27 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,BPA (Bisphenol A) free,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s59276822/ikea-365-food-container-with-lid-rectangular-plastic-s59276822-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s59276822/ikea-365-food-container-with-lid-rectangular-plastic-s59276822-1.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container/lid,Freezer-safe.,Dishwasher-safe."
        },
        "96": {
            "id": 96,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "2.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "603.591.52",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 21 cm",
                "Weight: 0.16 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s99269080/ikea-365-food-container-with-lid-rectangular-plastic-s99269080-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s99269080/ikea-365-food-container-with-lid-rectangular-plastic-s99269080-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s99269080/ikea-365-food-container-with-lid-rectangular-plastic-s99269080-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s99269080/ikea-365-food-container-with-lid-rectangular-plastic-s99269080-3.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "97": {
            "id": 97,
            "prod_name": "SANDVIVA",
            "prod_price": "1",
            "prod_desc": "Pot holder, silicone",
            "prod_dimensions": {
                "Length": "18 cm",
                "Width": "18 cm"
            },
            "packaging": [
                "SANDVIVA",
                "Pot holder",
                "Article no.:",
                "404.718.14",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 18 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/sandviva-pot-holder-silicone-40471814/sandviva-pot-holder-silicone-40471814-0.JPG",
                "data/cookware/sandviva-pot-holder-silicone-40471814/sandviva-pot-holder-silicone-40471814-1.JPG",
                "data/cookware/sandviva-pot-holder-silicone-40471814/sandviva-pot-holder-silicone-40471814-2.JPG",
                "data/cookware/sandviva-pot-holder-silicone-40471814/sandviva-pot-holder-silicone-40471814-3.JPG",
                "data/cookware/sandviva-pot-holder-silicone-40471814/sandviva-pot-holder-silicone-40471814-4.JPG"
            ],
            "materials": "Silicone rubber,Dishwasher-safe.,Withstands temperatures up to 160\u00b0C."
        },
        "98": {
            "id": 98,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container with lid, square/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.76",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 15 cm",
                "Weight: 0.09 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.617.89",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-3.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-4.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-5.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s49269105/ikea-365-food-container-with-lid-square-plastic-s49269105-6.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "99": {
            "id": 99,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, square/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "1.4 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "903.591.79",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 15 cm",
                "Weight: 0.13 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.617.89",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s89269108/ikea-365-food-container-with-lid-square-plastic-s89269108-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s89269108/ikea-365-food-container-with-lid-square-plastic-s89269108-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s89269108/ikea-365-food-container-with-lid-square-plastic-s89269108-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-plastic-s89269108/ikea-365-food-container-with-lid-square-plastic-s89269108-3.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "100": {
            "id": 100,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container with lid, round/plastic",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "14 cm",
                "Volume": "450 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.42",
                "Length: 5 cm",
                "Weight: 0.07 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s39269101/ikea-365-food-container-with-lid-round-plastic-s39269101-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s39269101/ikea-365-food-container-with-lid-round-plastic-s39269101-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s39269101/ikea-365-food-container-with-lid-round-plastic-s39269101-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s39269101/ikea-365-food-container-with-lid-round-plastic-s39269101-3.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "101": {
            "id": 101,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Turner",
            "prod_dimensions": {
                "Length": "30 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Turner",
                "Article no.:",
                "403.098.13",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 30 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-turner-40309813/vardagen-turner-40309813-0.JPG",
                "data/cookware/vardagen-turner-40309813/vardagen-turner-40309813-1.JPG",
                "data/cookware/vardagen-turner-40309813/vardagen-turner-40309813-2.JPG"
            ],
            "materials": "Handle:,Acetal plastic,Rivet/ Lower part:,Stainless steel,Dishwasher-safe."
        },
        "102": {
            "id": 102,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, square/silicone",
            "prod_dimensions": {
                "Length": "16 cm",
                "Width": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.820.86",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.09 kg",
                "Package(s): 1"
            ],
            "prod_details": "The lid creates a vacuum when placed on a container \u2012 keeping the food fresh longer and helping the food retain both heat and coolness. Can be used to protect from splatter in the oven and the microwave. Wash the lid in the dishwasher and use it again and again, as this helps you reduce the amount of plastic and aluminium foil you use. Fits with IKEA 365+ square-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-square-silicone-70382086/ikea-365-lid-square-silicone-70382086-0.JPG",
                "data/cookware/ikea-365-lid-square-silicone-70382086/ikea-365-lid-square-silicone-70382086-1.JPG",
                "data/cookware/ikea-365-lid-square-silicone-70382086/ikea-365-lid-square-silicone-70382086-2.JPG",
                "data/cookware/ikea-365-lid-square-silicone-70382086/ikea-365-lid-square-silicone-70382086-3.JPG"
            ],
            "materials": "Silicone rubber,Withstands temperatures up to 225\u00b0C.,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "103": {
            "id": 103,
            "prod_name": "VARDAGEN",
            "prod_price": "3",
            "prod_desc": "Pie dish, off-white",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "11 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pie dish",
                "Article no.:",
                "802.893.04",
                "Length: 6 cm",
                "Weight: 0.32 kg",
                "Diameter: 12 cm",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-pie-dish-off-white-80289304/vardagen-pie-dish-off-white-80289304-0.JPG",
                "data/cookware/vardagen-pie-dish-off-white-80289304/vardagen-pie-dish-off-white-80289304-1.JPG",
                "data/cookware/vardagen-pie-dish-off-white-80289304/vardagen-pie-dish-off-white-80289304-2.JPG",
                "data/cookware/vardagen-pie-dish-off-white-80289304/vardagen-pie-dish-off-white-80289304-3.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "104": {
            "id": 104,
            "prod_name": "IKEA 365+",
            "prod_price": "20",
            "prod_desc": "Food storage kit 2",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 13 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.99",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.68 kg",
                "Package(s): 5",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 5",
                "IKEA 365+",
                "Ice pack",
                "Article no.:",
                "104.377.89",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 21 cm",
                "Weight: 0.63 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lunch bag",
                "Article no.:",
                "404.800.26",
                "Width: 18 cm",
                "Height: 2 cm",
                "Length: 22 cm",
                "Weight: 0.11 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Water bottle",
                "Article no.:",
                "204.800.13",
                "Length: 24 cm",
                "Weight: 0.09 kg",
                "Diameter: 7 cm",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ food container (1 l), 1 IKEA 365+ water bottle (0.5 l) and 1 IKEA 365+ lunch bag (22x17x40 cm).",
            "sustainability": "Water bottle,Plastic can be recycled multiple times, reducing our environmental footprint. All products containing recycled materials meet the same quality and safety demands as we have on all our products.,BPA (Bisphenol A) free,By offering replacement parts, we make it easier to maintain and repair products. That way, products live longer, waste is reduced and the environmental impact is lowered.,Food container,No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-storage-kit-2-s69401279/ikea-365-food-storage-kit-2-s69401279-0.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Ice pack,Body:,Polyethylene plastic,Filling:,Aqua,Belt:,Synthetic rubber,Lunch bag,Fabric:,100% polyethylene,Handle:,100% polyester,Water bottle,Body:,PCTG plastic,Lid:,Polypropylene plastic,Seal:,Silicone rubber"
        },
        "105": {
            "id": 105,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Food container with lid, rectangular glass/bamboo",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "1.8 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.592.03",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 21 cm",
                "Weight: 0.95 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.819.07",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 21 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068/ikea-365-food-container-with-lid-rectangular-glass-bamboo-s49269068-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "106": {
            "id": 106,
            "prod_name": "IKEA 365+",
            "prod_price": "6",
            "prod_desc": "Food container with lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "23 cm",
                "Volume": "10.6 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "103.930.64",
                "Width: 23 cm",
                "Height: 22 cm",
                "Length: 32 cm",
                "Weight: 0.49 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.930.63",
                "Width: 27 cm",
                "Height: 1 cm",
                "Length: 37 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s79276760/ikea-365-food-container-with-lid-rectangular-plastic-s79276760-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s79276760/ikea-365-food-container-with-lid-rectangular-plastic-s79276760-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s79276760/ikea-365-food-container-with-lid-rectangular-plastic-s79276760-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s79276760/ikea-365-food-container-with-lid-rectangular-plastic-s79276760-3.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s79276760/ikea-365-food-container-with-lid-rectangular-plastic-s79276760-4.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container/lid,Freezer-safe.,Dishwasher-safe."
        },
        "107": {
            "id": 107,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Holder for container, white",
            "prod_dimensions": {
                "Width": "15 cm",
                "Depth": "23 cm",
                "Height": "3 cm",
                "Package quantity": "2 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Holder for container",
                "Article no.:",
                "103.783.46",
                "Width: 17 cm",
                "Height: 4 cm",
                "Length: 29 cm",
                "Weight: 0.30 kg",
                "Package(s): 1"
            ],
            "prod_details": "With this holder for container, you can use the space under your shelves in a smart and efficient way. The holders are flexible and can be used for both square and rectangular containers in the IKEA 365+ series. Fits with IKEA 365+ square and rectangular food containers. Fits METOD kitchen system and 16-18 mm thick shelves.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-holder-for-container-white-10378346/ikea-365-holder-for-container-white-10378346-0.JPG",
                "data/cookware/ikea-365-holder-for-container-white-10378346/ikea-365-holder-for-container-white-10378346-1.JPG",
                "data/cookware/ikea-365-holder-for-container-white-10378346/ikea-365-holder-for-container-white-10378346-2.JPG",
                "data/cookware/ikea-365-holder-for-container-white-10378346/ikea-365-holder-for-container-white-10378346-3.JPG",
                "data/cookware/ikea-365-holder-for-container-white-10378346/ikea-365-holder-for-container-white-10378346-4.JPG"
            ],
            "materials": "Steel, Powder coating"
        },
        "108": {
            "id": 108,
            "prod_name": "\u00d6VERM\u00c4TT",
            "prod_price": "6",
            "prod_desc": "Food cover, set of 2, silicone light blue",
            "prod_dimensions": {},
            "packaging": [
                "\u00d6VERM\u00c4TT",
                "Food cover, set of 2",
                "Article no.:",
                "704.619.36",
                "Width: 18 cm",
                "Height: 2 cm",
                "Length: 28 cm",
                "Weight: 0.24 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food covers function as lids and keep the contents fresh for longer. Can be washed and reused. Easy to clean, since they are dishwasher-safe. Comprises: 1 round food cover (dia. 28 cm) and 1 rectangular food cover (length 33 cm, width 24.5 cm). The round food cover fits containers with a diameter of 25-28 cm and the rectangular food cover fits containers with dimensions 31-35cm x 22-25 cm.",
            "sustainability": "",
            "images": [
                "data/cookware/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936-0.JPG",
                "data/cookware/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936-1.JPG",
                "data/cookware/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936/oevermaett-food-cover-set-of-2-silicone-light-blue-70461936-2.JPG"
            ],
            "materials": "Silicone rubber,Dishwasher-safe.,Not microwave-safe.,Not oven-safe.,To keep the food covers clean - make sure they are completely dry before putting them away. The easiest way is to let them air dry."
        },
        "109": {
            "id": 109,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "403.591.48",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ rectangular-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.",
            "images": [
                "data/cookware/ikea-365-food-container-rectangular-plastic-40359148/ikea-365-food-container-rectangular-plastic-40359148-0.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-40359148/ikea-365-food-container-rectangular-plastic-40359148-1.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-40359148/ikea-365-food-container-rectangular-plastic-40359148-2.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-40359148/ikea-365-food-container-rectangular-plastic-40359148-3.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-40359148/ikea-365-food-container-rectangular-plastic-40359148-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "110": {
            "id": 110,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Jar with lid, glass/plastic",
            "prod_dimensions": {
                "Height": "20 cm",
                "Diameter": "17 cm",
                "Volume": "3.3 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "203.932.47",
                "Length: 19 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The jar is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the jar is easy to clean. The jar and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s19277767/ikea-365-jar-with-lid-glass-plastic-s19277767-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s19277767/ikea-365-jar-with-lid-glass-plastic-s19277767-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s19277767/ikea-365-jar-with-lid-glass-plastic-s19277767-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber"
        },
        "111": {
            "id": 111,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Potato masher",
            "prod_dimensions": {
                "Length": "30 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Potato masher",
                "Article no.:",
                "803.098.11",
                "Width: 12 cm",
                "Height: 9 cm",
                "Length: 30 cm",
                "Weight: 0.19 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-potato-masher-80309811/vardagen-potato-masher-80309811-0.JPG",
                "data/cookware/vardagen-potato-masher-80309811/vardagen-potato-masher-80309811-1.JPG",
                "data/cookware/vardagen-potato-masher-80309811/vardagen-potato-masher-80309811-2.JPG",
                "data/cookware/vardagen-potato-masher-80309811/vardagen-potato-masher-80309811-3.JPG"
            ],
            "materials": "Handle:,Acetal plastic,Rivet/ Bolster/ Thread:,Stainless steel,Dishwasher-safe."
        },
        "112": {
            "id": 112,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "22 cm",
                "Volume": "4.2 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "603.930.66",
                "Width: 21 cm",
                "Height: 15 cm",
                "Length: 23 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The transparent container makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ rectangular-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-rectangular-plastic-60393066/ikea-365-food-container-rectangular-plastic-60393066-0.JPG"
            ],
            "materials": "Polypropylene plastic,Freezer-safe.,Dishwasher-safe."
        },
        "113": {
            "id": 113,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, glass",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "14 cm",
                "Volume": "400 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.95",
                "Length: 5 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-glass-s19279653/ikea-365-food-container-with-lid-glass-s19279653-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-glass-s19279653/ikea-365-food-container-with-lid-glass-s19279653-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-glass-s19279653/ikea-365-food-container-with-lid-glass-s19279653-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Glass,Seal:,Silicone rubber,Food container,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe.,Lid,Dishwasher-safe."
        },
        "114": {
            "id": 114,
            "prod_name": "IKEA 365+",
            "prod_price": "0",
            "prod_desc": "Food container, round/plastic",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "14 cm",
                "Volume": "450 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.42",
                "Length: 5 cm",
                "Weight: 0.07 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-round-plastic-70359142/ikea-365-food-container-round-plastic-70359142-0.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-70359142/ikea-365-food-container-round-plastic-70359142-1.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-70359142/ikea-365-food-container-round-plastic-70359142-2.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-70359142/ikea-365-food-container-round-plastic-70359142-3.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-70359142/ikea-365-food-container-round-plastic-70359142-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "115": {
            "id": 115,
            "prod_name": "HEMLAGAD",
            "prod_price": "45",
            "prod_desc": "6-piece cookware set, black",
            "prod_dimensions": {},
            "packaging": [
                "HEMLAGAD",
                "6-piece cookware set",
                "Article no.:",
                "004.628.64",
                "Width: 30 cm",
                "Height: 18 cm",
                "Length: 32 cm",
                "Weight: 4.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "Works well on all types of hobs, including induction hob. Made from aluminium, which spreads heat evenly and energy efficiently, and makes it easier to regulate heat so the food does not burn and stick. Comfortable handles make the cookware easy to lift. The pan has extra thick walls and base, which distribute the heat evenly and give good cooking results. The 5-litre pot has a lid with a catch which makes it possible to pour out water through the holes in the lid. The pan has two spouts and is therefore easy to use for both right- and left-handed cooks. The lid to the 3-litre pot has a steam vent which reduces pressure so that food does not easily boil over. With Teflon\u00ae Select, a hardwearing non-stick coating that allows cooking with little fat and makes cleaning easy. The pan's low weight makes it easy to handle when filled with food. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. Comprises: Pot with lid 3 l and 5 l, saucepan 1 l and frying pan dia. 28 cm.",
            "sustainability": "",
            "images": [
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-0.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-1.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-2.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-3.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-4.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-5.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-6.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-7.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-8.JPG",
                "data/cookware/hemlagad-6-piece-cookware-set-black-00462864/hemlagad-6-piece-cookware-set-black-00462864-9.JPG"
            ],
            "materials": "Basematerial:,Aluminium, Coated with Teflon(R) Select, Non-stick coating,Handle:,Phenolic plastic, Polyurethane plastic,Fire protector:,Aluminium, Powder coating,Disc/ Lid/ Screw:,Stainless steel,Knob:,Reinforced polyamide plastic, Polyurethane plastic,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob."
        },
        "116": {
            "id": 116,
            "prod_name": "IKEA 365+",
            "prod_price": "17",
            "prod_desc": "Pot with lid, stainless steel/glass",
            "prod_dimensions": {
                "Height": "11 cm",
                "Diameter": "21 cm",
                "Volume": "3 l"
            },
            "packaging": [
                "IKEA 365+",
                "Pot with lid",
                "Article no.:",
                "702.567.52",
                "Width: 22 cm",
                "Height: 13 cm",
                "Length: 31 cm",
                "Weight: 1.72 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The glass lid allows you to monitor the contents of the pot during the cooking process.  The graduated interior makes it easy to measure up liquid directly in the pan. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Thanks to the smart design of the handles, you can stack the smaller pots in the larger ones from the same series. They take very little space, so you have room for other things in your cabinet. Works well on all types of hobs, including induction hob. The exterior is made of brushed steel which means that stains do not show as much as on a high-gloss surface. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. You can use the cookware in the oven, as it is made of metal and has a lid made of oven-safe glass. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. STABIL steamer insert fit. Keep in mind that the handles become hot when using the pot. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-0.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-1.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-2.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-3.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-4.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-5.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-6.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-7.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-8.JPG",
                "data/cookware/ikea-365-pot-with-lid-stainless-steel-glass-70256752/ikea-365-pot-with-lid-stainless-steel-glass-70256752-9.JPG"
            ],
            "materials": "Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "117": {
            "id": 117,
            "prod_name": "VARDAGEN",
            "prod_price": "25",
            "prod_desc": "Pot with lid, cast iron",
            "prod_dimensions": {
                "Height": "13 cm",
                "Diameter": "20 cm",
                "Volume": "3 l",
                "Length including handles": "27 cm",
                "Height including lid": "17 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pot with lid",
                "Article no.:",
                "804.370.50",
                "Width: 24 cm",
                "Height: 15 cm",
                "Length: 26 cm",
                "Weight: 3.89 kg",
                "Package(s): 1"
            ],
            "prod_details": "25 year guarantee. Read about the terms in the guarantee brochure. Made from cast iron, which spreads heat evenly through the pan and retains the heat for a long time. This makes it ideal, for example, for slower cooking such as roasts and casseroles. Works well on all types of hobs, including induction hob. Steam collects on the inside of the lid and drips down from the knobs. In this way the food bastes itself, which gives a succulent and tasty result. Can also be used in the oven since it is made entirely of metal. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. To season a cast iron pot/pan, rub all surfaces with oil. Then heat the pot/pan in the oven or on the hob to max. 150 \u00b0C for a minimum of one hour. Leave it to cool and wipe off excess oil. If corrosion or food stains arise, or if food burns and sticks, the pot/pan can be cleaned with steel wool or an abrasive sponge and then re-seasoned. Use a hob with the same or a smaller diameter to save energy. The pot/pan gets hot during use. Therefore, always use pot holders when moving it. Do not expose the pot/pan to great variations in temperature, e.g. by placing it directly on a hot hob. This product is pre-treated with vegetable soybean oil.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-0.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-1.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-2.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-3.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-4.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-5.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-6.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-7.JPG",
                "data/cookware/vardagen-pot-with-lid-cast-iron-80437050/vardagen-pot-with-lid-cast-iron-80437050-8.JPG"
            ],
            "materials": "Body/ Lid:,Cast iron, Oil,Screw:,Stainless steel,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe.,Wash this product before using it for the first time."
        },
        "118": {
            "id": 118,
            "prod_name": "OUMB\u00c4RLIG",
            "prod_price": "10",
            "prod_desc": "Frying pan",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "24 cm"
            },
            "packaging": [
                "OUMB\u00c4RLIG",
                "Frying pan",
                "Article no.:",
                "102.920.98",
                "Width: 26 cm",
                "Height: 8 cm",
                "Length: 45 cm",
                "Weight: 0.84 kg",
                "Package(s): 1"
            ],
            "prod_details": "Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Works well on all types of hobs, including induction hob. With Teflon\u00ae Platinum plus, a very hardwearing non-stick coating that makes the pan suitable for everyday use. Made of stainless steel, which makes the pan durable and easy to clean. Keep in mind that the handle becomes hot when using the frying pan. Always use pot holders when moving it or removing the lid. Wash this product before using it for the first time.",
            "sustainability": "No PFOA (perfluorooctanoic acid) is used to create the non-stick surface of this product.,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/oumbaerlig-frying-pan-10292098/oumbaerlig-frying-pan-10292098-0.JPG",
                "data/cookware/oumbaerlig-frying-pan-10292098/oumbaerlig-frying-pan-10292098-1.JPG",
                "data/cookware/oumbaerlig-frying-pan-10292098/oumbaerlig-frying-pan-10292098-2.JPG",
                "data/cookware/oumbaerlig-frying-pan-10292098/oumbaerlig-frying-pan-10292098-3.JPG",
                "data/cookware/oumbaerlig-frying-pan-10292098/oumbaerlig-frying-pan-10292098-4.JPG"
            ],
            "materials": "Handle:,Stainless steel,Basematerial:,Stainless steel, Coated with Teflon(R) Platinum Plus,Bottom:,Stainless steel, Aluminium,Handwash only.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "119": {
            "id": 119,
            "prod_name": "IKEA 365+",
            "prod_price": "11",
            "prod_desc": "Food storage kit 3",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 4 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "203.932.47",
                "Length: 19 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "803.932.49",
                "Length: 16 cm",
                "Weight: 0.94 kg",
                "Diameter: 15 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 2"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ jar (3.3 l), 1 IKEA 365+ jar (1.7 l) and 2 x IKEA 365+ lid.",
            "sustainability": "Jar,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-storage-kit-3-s29401281/ikea-365-food-storage-kit-3-s29401281-0.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber"
        },
        "120": {
            "id": 120,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Scoop set of 2, metal",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "Scoop set of 2",
                "Article no.:",
                "704.442.92",
                "Width: 9 cm",
                "Height: 5 cm",
                "Length: 16 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-0.JPG",
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-1.JPG",
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-2.JPG",
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-3.JPG",
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-4.JPG",
                "data/cookware/ikea-365-scoop-set-of-2-metal-70444292/ikea-365-scoop-set-of-2-metal-70444292-5.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe."
        },
        "121": {
            "id": 121,
            "prod_name": "PRUTA",
            "prod_price": "1",
            "prod_desc": "Food container, transparent/yellow",
            "prod_dimensions": {
                "Length": "14 cm",
                "Width": "14 cm",
                "Height": "6 cm",
                "Volume": "0.6 l",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "PRUTA",
                "Food container",
                "Article no.:",
                "903.358.43",
                "Width: 14 cm",
                "Height: 10 cm",
                "Length: 14 cm",
                "Weight: 0.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for storing everything from cold cuts, cheese etc. to individual portions of food. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Several empty food containers can be stacked inside one another to save space in your cabinets. Several food containers can be stacked on top of each other to save space in the fridge and cabinets. Wash this product before using it for the first time. This container is not spill-proof and may leak if you store liquid contents like soup in it. If you think there is a risk of leakage, do not place the container in for example a bag.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/pruta-food-container-transparent-yellow-90335843/pruta-food-container-transparent-yellow-90335843-0.JPG",
                "data/cookware/pruta-food-container-transparent-yellow-90335843/pruta-food-container-transparent-yellow-90335843-1.JPG",
                "data/cookware/pruta-food-container-transparent-yellow-90335843/pruta-food-container-transparent-yellow-90335843-2.JPG",
                "data/cookware/pruta-food-container-transparent-yellow-90335843/pruta-food-container-transparent-yellow-90335843-3.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "122": {
            "id": 122,
            "prod_name": "IKEA 365+",
            "prod_price": "40",
            "prod_desc": "3-piece knife set",
            "prod_dimensions": {},
            "packaging": [
                "IKEA 365+",
                "3-piece knife set",
                "Article no.:",
                "903.411.70",
                "Width: 19 cm",
                "Height: 2 cm",
                "Length: 41 cm",
                "Weight: 0.61 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Comprises: 1 utility knife 14 cm (tot. length 25 cm), 1 cook\u2019s knife 16 cm (tot. length 29 cm) and 1 cook\u2019s knife 20 cm (tot. length 33 cm).",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-3-piece-knife-set-90341170/ikea-365-3-piece-knife-set-90341170-0.JPG",
                "data/cookware/ikea-365-3-piece-knife-set-90341170/ikea-365-3-piece-knife-set-90341170-1.JPG",
                "data/cookware/ikea-365-3-piece-knife-set-90341170/ikea-365-3-piece-knife-set-90341170-2.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "123": {
            "id": 123,
            "prod_name": "VARDAGEN",
            "prod_price": "57",
            "prod_desc": "Cooking kit 9",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 5 packages.",
                "VARDAGEN",
                "Pot with lid",
                "Article no.:",
                "004.370.54",
                "Width: 27 cm",
                "Height: 18 cm",
                "Length: 28 cm",
                "Weight: 5.44 kg",
                "Package(s): 1",
                "VARDAGEN",
                "Frying pan",
                "Article no.:",
                "104.373.03",
                "Width: 30 cm",
                "Height: 8 cm",
                "Length: 54 cm",
                "Weight: 3.55 kg",
                "Package(s): 1",
                "R\u00d6RT",
                "Fork",
                "Article no.:",
                "002.784.65",
                "Width: 5 cm",
                "Height: 2 cm",
                "Length: 31 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "R\u00d6RT",
                "Spoon",
                "Article no.:",
                "102.784.60",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 31 cm",
                "Weight: 0.08 kg",
                "Package(s): 1",
                "VARDAGEN",
                "Oven glove",
                "Article no.:",
                "702.926.32",
                "Width: 16 cm",
                "Height: 3 cm",
                "Length: 26 cm",
                "Weight: 0.11 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 VARDAGEN pot with lid, cast iron (5 l), 1 VARDAGEN frying pan, cast iron (dia. 28 cm), 1 VARDAGEN oven glove, 1 R\u00d6RT fork and 1 R\u00d6RT spoon.",
            "sustainability": "Fork/spoon,Renewable material (wood).,We have clear requirements for all the wood we use, including a ban on illegally harvested wood. By 2020, we want all our wood to come from more sustainable sources, defined as certified or recycled.,Oven glove,All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.,No optical brightener has been used.,By using renewable materials like cotton and flax in this product, we avoid using fossil or finite materials.,Pot with lid/frying pan,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-cooking-kit-9-s09414388/vardagen-cooking-kit-9-s09414388-0.JPG"
            ],
            "materials": "Pot with lid,Body/ Lid:,Cast iron, Oil,Screw:,Stainless steel,Frying pan,Cast iron, Oil,Fork/ spoon,Solid beech, Oil,Oven glove,Fabric:,80% cotton, 20% linen,Filling:,Polyester wadding,Lining:,100% cotton"
        },
        "124": {
            "id": 124,
            "prod_name": "IKEA 365+",
            "prod_price": "19",
            "prod_desc": "Saucepan with lid, stainless steel/glass",
            "prod_dimensions": {
                "Height": "10 cm",
                "Volume": "2 l"
            },
            "packaging": [
                "IKEA 365+",
                "Saucepan with lid",
                "Article no.:",
                "902.567.46",
                "Width: 19 cm",
                "Height: 14 cm",
                "Length: 35 cm",
                "Weight: 1.35 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The glass lid allows you to monitor the contents of the pot during the cooking process.  The graduated interior makes it easy to measure up liquid directly in the pan. Thick base with one layer of aluminium between two layers of stainless steel. Gives an even and energy-efficient heat, which reduces the risk of food burning and sticking. Thanks to the smart design of the handles, you can stack the smaller pots in the larger ones from the same series. They take very little space, so you have room for other things in your cabinet. Works well on all types of hobs, including induction hob. The exterior is made of brushed steel which means that stains do not show as much as on a high-gloss surface. Steam vent reduces pressure so that food does not easily boil over. Made of stainless steel, which makes the pan durable and easy to clean. You can use the cookware in the oven, as it is made of metal and has a lid made of oven-safe glass. Using the lid brings the contents of the pot to a boil faster, so that you can save time, energy and money while lowering your environmental impact. STABIL steamer insert fit. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-0.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-1.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-2.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-3.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-4.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-5.JPG",
                "data/cookware/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746/ikea-365-saucepan-with-lid-stainless-steel-glass-90256746-6.JPG"
            ],
            "materials": "Lid:,Heat resistant glass,Handle/ Cover/ Body:,Stainless steel,Dishwasher-safe.,Suitable for use on gas hob.,Suitable for use on induction hob.,Suitable for use on glass ceramic hob.,Suitable for use on cast iron hob.,Oven-safe."
        },
        "125": {
            "id": 125,
            "prod_name": "EFTERSTR\u00c4VA",
            "prod_price": "7",
            "prod_desc": "Travel mug, clear glass/silicone",
            "prod_dimensions": {
                "Volume": "0.5 l"
            },
            "packaging": [
                "EFTERSTR\u00c4VA",
                "Travel mug",
                "Article no.:",
                "404.153.09",
                "Length: 23 cm",
                "Weight: 0.40 kg",
                "Diameter: 7 cm",
                "Package(s): 1"
            ],
            "prod_details": "Leakproof travel mug with a stainless steel infusion filter which you can easily mount or remove. A silicone cover protects your hands from heat.  Just click on the lid to open the travel mug with one hand.  Fits most cup holders in cars. Tempered glass should be handled with care! A damaged edge or a scratched surface can cause the glass to break suddenly. Be careful when drinking hot beverages directly from the mug. Do not keep carbonated drinks in the mug. Pressure can build up that makes the lid explode off with great force. This can also occur if sugary drinks in the mug are exposed to heat, since a fermentation process starts. Wash this product before using it for the first time. Heat-resistant glass for hot and cold drinks. Wash by hand in dishwater with bicarbonate or detergent added.",
            "sustainability": "",
            "images": [
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-0.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-1.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-2.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-3.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-4.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-5.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-6.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-7.JPG",
                "data/cookware/efterstraeva-travel-mug-clear-glass-silicone-40415309/efterstraeva-travel-mug-clear-glass-silicone-40415309-8.JPG"
            ],
            "materials": "Body:,Heat resistant glass,Seal/ Insulation:,Silicone rubber,Strainer:,Stainless steel,Lid:,Polypropylene plastic,The glass part is dishwasher-safe. The lid should be washed by hand."
        },
        "126": {
            "id": 126,
            "prod_name": "IKEA 365+",
            "prod_price": "36",
            "prod_desc": "Food storage kit 1",
            "prod_dimensions": {},
            "packaging": [
                "This product comes as 13 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.591.99",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 21 cm",
                "Weight: 0.68 kg",
                "Package(s): 5",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 5",
                "IKEA 365+",
                "Mandoline",
                "Article no.:",
                "004.223.21",
                "Width: 12 cm",
                "Height: 5 cm",
                "Length: 29 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Vegetable knife",
                "Article no.:",
                "702.879.37",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 36 cm",
                "Weight: 0.25 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Label",
                "Article no.:",
                "204.385.47",
                "Width: 8 cm",
                "Height: 5 cm",
                "Length: 8 cm",
                "Weight: 0.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "Comprises: 1 IKEA 365+ food container with lid (1 l), 1 IKEA 365+ vegetable knife (16 cm), 1 IKEA 365+ mandolin and 50 x IKEA 365+ labels.",
            "sustainability": "Food container,No cadmium or lead added.,By creating products that help people minimize waste, we contribute to enabling a more sustainable life at home.,Lid,No BPA (Bisphenol A) added.,Vegetable knife,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-food-storage-kit-1-s29401276/ikea-365-food-storage-kit-1-s29401276-0.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Mandoline,Body:,Polyamide plastic,Side:,Synthetic rubber,Holder:,Reinforced polypropylene plastic,Blade:,Stainless steel,Vegetable knife,Stainless steel,Label,Polypropylene plastic"
        },
        "127": {
            "id": 127,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Pot holder, grey",
            "prod_dimensions": {
                "Length": "26 cm",
                "Width": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Pot holder",
                "Article no.:",
                "702.578.03",
                "Width: 16 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.05 kg",
                "Package(s): 1"
            ],
            "prod_details": "The pot holder has a pocket for your hand, so you get a good grip and don\u2019t burn yourself on hot pans or baking trays. The loop means you can hang it up when it is not being used. Felted polyester layer in between gives very good heat insulation.",
            "sustainability": "All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.,Renewable material (cotton).",
            "images": [
                "data/cookware/ikea-365-pot-holder-grey-70257803/ikea-365-pot-holder-grey-70257803-0.JPG",
                "data/cookware/ikea-365-pot-holder-grey-70257803/ikea-365-pot-holder-grey-70257803-1.JPG",
                "data/cookware/ikea-365-pot-holder-grey-70257803/ikea-365-pot-holder-grey-70257803-2.JPG",
                "data/cookware/ikea-365-pot-holder-grey-70257803/ikea-365-pot-holder-grey-70257803-3.JPG",
                "data/cookware/ikea-365-pot-holder-grey-70257803/ikea-365-pot-holder-grey-70257803-4.JPG"
            ],
            "materials": "Fabric:,100% cotton,Filling:,Polyester fibres,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 150\u00b0C.,Do not dryclean.,Stretch into shape when wet.,Shrinkage 4%."
        },
        "128": {
            "id": 128,
            "prod_name": "IKEA 365+",
            "prod_price": "12",
            "prod_desc": "Utility knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "14 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Utility knife",
                "Article no.:",
                "102.835.17",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 32 cm",
                "Weight: 0.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. For easy slicing and trimming. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-utility-knife-stainless-steel-10283517/ikea-365-utility-knife-stainless-steel-10283517-0.JPG",
                "data/cookware/ikea-365-utility-knife-stainless-steel-10283517/ikea-365-utility-knife-stainless-steel-10283517-1.JPG",
                "data/cookware/ikea-365-utility-knife-stainless-steel-10283517/ikea-365-utility-knife-stainless-steel-10283517-2.JPG",
                "data/cookware/ikea-365-utility-knife-stainless-steel-10283517/ikea-365-utility-knife-stainless-steel-10283517-3.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "129": {
            "id": 129,
            "prod_name": "IKEA 365+",
            "prod_price": "15",
            "prod_desc": "Vegetable knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Vegetable knife",
                "Article no.:",
                "702.879.37",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 36 cm",
                "Weight: 0.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The knife has indentations on the blade which let air into the cutting surface so the food you slice doesn't stick to the blade. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-vegetable-knife-stainless-steel-70287937/ikea-365-vegetable-knife-stainless-steel-70287937-0.JPG",
                "data/cookware/ikea-365-vegetable-knife-stainless-steel-70287937/ikea-365-vegetable-knife-stainless-steel-70287937-1.JPG",
                "data/cookware/ikea-365-vegetable-knife-stainless-steel-70287937/ikea-365-vegetable-knife-stainless-steel-70287937-2.JPG",
                "data/cookware/ikea-365-vegetable-knife-stainless-steel-70287937/ikea-365-vegetable-knife-stainless-steel-70287937-3.JPG",
                "data/cookware/ikea-365-vegetable-knife-stainless-steel-70287937/ikea-365-vegetable-knife-stainless-steel-70287937-4.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "130": {
            "id": 130,
            "prod_name": "IKEA 365+",
            "prod_price": "19",
            "prod_desc": "Cook's knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "20 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Cook's knife",
                "Article no.:",
                "102.835.22",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 40 cm",
                "Weight: 0.26 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The sturdy blade makes it easier to divide and chop, for example, meat and root vegetables. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-0.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-1.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-2.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-3.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-4.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-10283522/ikea-365-cooks-knife-stainless-steel-10283522-5.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "131": {
            "id": 131,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Jar with lid, glass/bamboo",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "14 cm",
                "Volume": "1.7 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "803.932.49",
                "Length: 16 cm",
                "Weight: 0.94 kg",
                "Diameter: 15 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276778/ikea-365-jar-with-lid-glass-bamboo-s99276778-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276778/ikea-365-jar-with-lid-glass-bamboo-s99276778-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276778/ikea-365-jar-with-lid-glass-bamboo-s99276778-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber"
        },
        "132": {
            "id": 132,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Jar, round/glass",
            "prod_dimensions": {
                "Height": "16 cm",
                "Diameter": "14 cm",
                "Volume": "1.7 l"
            },
            "packaging": [
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "803.932.49",
                "Length: 16 cm",
                "Weight: 0.94 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-round-glass-80393249/ikea-365-jar-round-glass-80393249-0.JPG",
                "data/cookware/ikea-365-jar-round-glass-80393249/ikea-365-jar-round-glass-80393249-1.JPG",
                "data/cookware/ikea-365-jar-round-glass-80393249/ikea-365-jar-round-glass-80393249-2.JPG",
                "data/cookware/ikea-365-jar-round-glass-80393249/ikea-365-jar-round-glass-80393249-3.JPG",
                "data/cookware/ikea-365-jar-round-glass-80393249/ikea-365-jar-round-glass-80393249-4.JPG"
            ],
            "materials": "Glass,Dishwasher-safe."
        },
        "133": {
            "id": 133,
            "prod_name": "IKEA 365+",
            "prod_price": "9",
            "prod_desc": "Paring knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "9 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Paring knife",
                "Article no.:",
                "302.835.21",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. Small and handy. Suitable for peeling and trimming fruit and vegetables. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-paring-knife-stainless-steel-30283521/ikea-365-paring-knife-stainless-steel-30283521-0.JPG",
                "data/cookware/ikea-365-paring-knife-stainless-steel-30283521/ikea-365-paring-knife-stainless-steel-30283521-1.JPG",
                "data/cookware/ikea-365-paring-knife-stainless-steel-30283521/ikea-365-paring-knife-stainless-steel-30283521-2.JPG",
                "data/cookware/ikea-365-paring-knife-stainless-steel-30283521/ikea-365-paring-knife-stainless-steel-30283521-3.JPG",
                "data/cookware/ikea-365-paring-knife-stainless-steel-30283521/ikea-365-paring-knife-stainless-steel-30283521-4.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "134": {
            "id": 134,
            "prod_name": "LACKTICKA",
            "prod_price": "1",
            "prod_desc": "Pot holder, black",
            "prod_dimensions": {
                "Length": "22 cm",
                "Width": "22 cm",
                "Package quantity": "2 pack"
            },
            "packaging": [
                "LACKTICKA",
                "Pot holder",
                "Article no.:",
                "503.711.83",
                "Width: 22 cm",
                "Height: 2 cm",
                "Length: 22 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Felted polyester layer in between gives very good heat insulation.",
            "sustainability": "Renewable material (cotton).,All the cotton in our products comes from more sustainable sources. This means that the cotton is either recycled, or grown with less water, less fertilisers and less pesticides, while increasing profit margins for the farmers.",
            "images": [
                "data/cookware/lackticka-pot-holder-black-50371183/lackticka-pot-holder-black-50371183-0.JPG",
                "data/cookware/lackticka-pot-holder-black-50371183/lackticka-pot-holder-black-50371183-1.JPG",
                "data/cookware/lackticka-pot-holder-black-50371183/lackticka-pot-holder-black-50371183-2.JPG"
            ],
            "materials": "Fabric:,100% cotton,Filling:,Polyester wadding,Shrinkage maximum 4%.,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 150\u00b0C.,Do not dryclean.,Stretch into shape when wet."
        },
        "135": {
            "id": 135,
            "prod_name": "IKEA 365+",
            "prod_price": "15",
            "prod_desc": "Cook's knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Cook's knife",
                "Article no.:",
                "702.835.24",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 36 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The sturdy blade makes it easier to divide and chop, for example, meat and root vegetables. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-0.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-1.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-2.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-3.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-4.JPG",
                "data/cookware/ikea-365-cooks-knife-stainless-steel-70283524/ikea-365-cooks-knife-stainless-steel-70283524-5.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "136": {
            "id": 136,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Gasket, round/mixed colours",
            "prod_dimensions": {
                "Diameter": "14.0 cm",
                "Package quantity": "4 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Gasket",
                "Article no.:",
                "003.686.68",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 21 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can personalise and organise your food containers using the 4 replaceable gaskets. Use a specific colour for for each family member, type of food or day of the week. Fits with IKEA 365+ plastic lids. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-gasket-round-mixed-colours-00368668/ikea-365-gasket-round-mixed-colours-00368668-0.JPG",
                "data/cookware/ikea-365-gasket-round-mixed-colours-00368668/ikea-365-gasket-round-mixed-colours-00368668-1.JPG",
                "data/cookware/ikea-365-gasket-round-mixed-colours-00368668/ikea-365-gasket-round-mixed-colours-00368668-2.JPG",
                "data/cookware/ikea-365-gasket-round-mixed-colours-00368668/ikea-365-gasket-round-mixed-colours-00368668-3.JPG"
            ],
            "materials": "Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "137": {
            "id": 137,
            "prod_name": "VARDAGEN",
            "prod_price": "12",
            "prod_desc": "Vegetable knife, dark grey",
            "prod_dimensions": {
                "Length of knife blade": "16 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Vegetable knife",
                "Article no.:",
                "602.947.16",
                "Width: 7 cm",
                "Height: 3 cm",
                "Length: 36 cm",
                "Weight: 0.26 kg",
                "Package(s): 1"
            ],
            "prod_details": "The knife has indentations on the blade which let air into the cutting surface so the food you slice doesn't stick to the blade. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. The knife's tang runs through the length of the handle, making it very wear-resistant and balanced. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-0.JPG",
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-1.JPG",
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-2.JPG",
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-3.JPG",
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-4.JPG",
                "data/cookware/vardagen-vegetable-knife-dark-grey-60294716/vardagen-vegetable-knife-dark-grey-60294716-5.JPG"
            ],
            "materials": "Blade/ Rivet:,Stainless steel,Handle:,Acetal plastic,Handwash only."
        },
        "138": {
            "id": 138,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Gasket, square/mixed colours",
            "prod_dimensions": {
                "Length": "14.0 cm",
                "Width": "14.0 cm",
                "Package quantity": "4 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Gasket",
                "Article no.:",
                "703.686.41",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 22 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can personalise and organise your food containers using the 4 replaceable gaskets. Use a specific colour for for each family member, type of food or day of the week. Fits with IKEA 365+ plastic lids. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-gasket-square-mixed-colours-70368641/ikea-365-gasket-square-mixed-colours-70368641-0.JPG",
                "data/cookware/ikea-365-gasket-square-mixed-colours-70368641/ikea-365-gasket-square-mixed-colours-70368641-1.JPG",
                "data/cookware/ikea-365-gasket-square-mixed-colours-70368641/ikea-365-gasket-square-mixed-colours-70368641-2.JPG",
                "data/cookware/ikea-365-gasket-square-mixed-colours-70368641/ikea-365-gasket-square-mixed-colours-70368641-3.JPG"
            ],
            "materials": "Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "139": {
            "id": 139,
            "prod_name": "HEAT",
            "prod_price": "2",
            "prod_desc": "Pot stand, cork",
            "prod_dimensions": {
                "Diameter": "19 cm",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "HEAT",
                "Pot stand",
                "Article no.:",
                "870.777.00",
                "Height: 3 cm",
                "Weight: 0.24 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "You can combine several pot stands to fit larger pots and dishes.",
            "sustainability": "By using a renewable material like cork in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-0.JPG",
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-1.JPG",
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-2.JPG",
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-3.JPG",
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-4.JPG",
                "data/cookware/heat-pot-stand-cork-87077700/heat-pot-stand-cork-87077700-5.JPG"
            ],
            "materials": "Cork,Wipe clean with a damp cloth."
        },
        "140": {
            "id": 140,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Dry food jar with lid, transparent/white",
            "prod_dimensions": {
                "Length": "17 cm",
                "Width": "8 cm",
                "Height": "30 cm",
                "Volume": "2.3 l"
            },
            "packaging": [
                "IKEA 365+",
                "Dry food jar with lid",
                "Article no.:",
                "900.667.08",
                "Width: 17 cm",
                "Height: 8 cm",
                "Length: 30 cm",
                "Weight: 0.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "Remove the lid completely to fill the jar and open half the lid to make it easier to pour from. Designed to give a good grip when you want to stir and pour at the same time. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. You can reduce your food waste by storing your dry foods in a jar with a tight-fitting lid, because it keeps the food fresh longer.  Suitable for storing dry foodstuffs. Wash this product before using it for the first time.",
            "sustainability": "Possible to separate for recycling or energy recovery if available in your community.,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-90066708/ikea-365-dry-food-jar-with-lid-transparent-white-90066708-0.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-90066708/ikea-365-dry-food-jar-with-lid-transparent-white-90066708-1.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-90066708/ikea-365-dry-food-jar-with-lid-transparent-white-90066708-2.JPG",
                "data/cookware/ikea-365-dry-food-jar-with-lid-transparent-white-90066708/ikea-365-dry-food-jar-with-lid-transparent-white-90066708-3.JPG"
            ],
            "materials": "Polystyrene-acrylic plastic, Polypropylene plastic, Synthetic rubber,Dishwasher-safe in upper basket.,Withstands temperatures up to 70\u00b0C."
        },
        "141": {
            "id": 141,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, square glass/bamboo",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "7 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "003.592.06",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 15 cm",
                "Weight: 0.50 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.819.09",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 15 cm",
                "Weight: 0.19 kg",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116/ikea-365-food-container-with-lid-square-glass-bamboo-s19269116-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "142": {
            "id": 142,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, round glass/bamboo",
            "prod_dimensions": {
                "Height": "9 cm",
                "Diameter": "14 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "303.591.96",
                "Length: 8 cm",
                "Weight: 0.46 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091/ikea-365-food-container-with-lid-round-glass-bamboo-s69269091-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "143": {
            "id": 143,
            "prod_name": "VARDAGEN",
            "prod_price": "2",
            "prod_desc": "Peeler",
            "prod_dimensions": {
                "Length": "13 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Peeler",
                "Article no.:",
                "403.243.66",
                "Width: 8 cm",
                "Height: 2 cm",
                "Length: 19 cm",
                "Weight: 0.05 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-peeler-40324366/vardagen-peeler-40324366-0.JPG",
                "data/cookware/vardagen-peeler-40324366/vardagen-peeler-40324366-1.JPG",
                "data/cookware/vardagen-peeler-40324366/vardagen-peeler-40324366-2.JPG",
                "data/cookware/vardagen-peeler-40324366/vardagen-peeler-40324366-3.JPG"
            ],
            "materials": "Stainless steel,Dishwasher-safe."
        },
        "144": {
            "id": 144,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container with lid, round glass/plastic",
            "prod_dimensions": {
                "Height": "9 cm",
                "Diameter": "14 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "303.591.96",
                "Length: 8 cm",
                "Weight: 0.46 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-glass-plastic-s39269097/ikea-365-food-container-with-lid-round-glass-plastic-s39269097-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-plastic-s39269097/ikea-365-food-container-with-lid-round-glass-plastic-s39269097-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-plastic-s39269097/ikea-365-food-container-with-lid-round-glass-plastic-s39269097-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Freezer-safe.,Dishwasher-safe."
        },
        "145": {
            "id": 145,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Food container with lid, square glass/bamboo",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "1.2 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "403.592.09",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 15 cm",
                "Weight: 0.71 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.819.09",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 15 cm",
                "Weight: 0.19 kg",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111/ikea-365-food-container-with-lid-square-glass-bamboo-s29269111-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "146": {
            "id": 146,
            "prod_name": "IKEA 365+",
            "prod_price": "5",
            "prod_desc": "Jar with lid, glass",
            "prod_dimensions": {
                "Height": "20 cm",
                "Diameter": "17 cm",
                "Volume": "3.3 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "203.932.47",
                "Length: 19 cm",
                "Weight: 1.04 kg",
                "Diameter: 17 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar/lid,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-s79276821/ikea-365-jar-with-lid-glass-s79276821-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s79276821/ikea-365-jar-with-lid-glass-s79276821-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s79276821/ikea-365-jar-with-lid-glass-s79276821-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Glass,Seal:,Silicone rubber"
        },
        "147": {
            "id": 147,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, round glass/bamboo",
            "prod_dimensions": {
                "Height": "6 cm",
                "Diameter": "14 cm",
                "Volume": "400 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.95",
                "Length: 5 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The natural bamboo creates a warm and vibrant look.  The food container is made of oven-safe glass and can be used as an oven/serving dish. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083/ikea-365-food-container-with-lid-round-glass-bamboo-s39269083-3.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,The bamboo lid withstands temperatures up to 100\u00b0C.,The container is dishwasher-safe. The lid should be washed by hand.,The container is oven-safe and microwave-safe, but the lid is not."
        },
        "148": {
            "id": 148,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Food container with lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "12 cm",
                "Volume": "5.2 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "803.930.65",
                "Width: 22 cm",
                "Height: 11 cm",
                "Length: 32 cm",
                "Weight: 0.30 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.930.63",
                "Width: 27 cm",
                "Height: 1 cm",
                "Length: 37 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s69276807/ikea-365-food-container-with-lid-rectangular-plastic-s69276807-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-rectangular-plastic-s69276807/ikea-365-food-container-with-lid-rectangular-plastic-s69276807-1.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container/lid,Freezer-safe.,Dishwasher-safe."
        },
        "149": {
            "id": 149,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Jar with lid, glass",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "14 cm",
                "Volume": "1.7 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "803.932.49",
                "Length: 16 cm",
                "Weight: 0.94 kg",
                "Diameter: 15 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar/lid,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-s89276788/ikea-365-jar-with-lid-glass-s89276788-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s89276788/ikea-365-jar-with-lid-glass-s89276788-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s89276788/ikea-365-jar-with-lid-glass-s89276788-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Glass,Seal:,Silicone rubber"
        },
        "150": {
            "id": 150,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Lid, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.617.92",
                "Width: 21 cm",
                "Height: 1 cm",
                "Length: 26 cm",
                "Weight: 0.14 kg",
                "Package(s): 1"
            ],
            "prod_details": "Snap-and-lock lid creates an aroma-tight seal, so the food you store in the food container stays fresh for longer. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The transparent lid lets you see what's stored inside. Fits with IKEA 365+ rectangular-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-lid-rectangular-plastic-50361792/ikea-365-lid-rectangular-plastic-50361792-0.JPG",
                "data/cookware/ikea-365-lid-rectangular-plastic-50361792/ikea-365-lid-rectangular-plastic-50361792-1.JPG",
                "data/cookware/ikea-365-lid-rectangular-plastic-50361792/ikea-365-lid-rectangular-plastic-50361792-2.JPG",
                "data/cookware/ikea-365-lid-rectangular-plastic-50361792/ikea-365-lid-rectangular-plastic-50361792-3.JPG",
                "data/cookware/ikea-365-lid-rectangular-plastic-50361792/ikea-365-lid-rectangular-plastic-50361792-4.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "151": {
            "id": 151,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Water bottle, light red",
            "prod_dimensions": {
                "Height": "24 cm",
                "Volume": "0.5 l"
            },
            "packaging": [
                "IKEA 365+",
                "Water bottle",
                "Article no.:",
                "804.800.10",
                "Length: 24 cm",
                "Weight: 0.09 kg",
                "Diameter: 7 cm",
                "Package(s): 1"
            ],
            "prod_details": "The bottle looks like it\u2019s made out of glass, but it\u2019s made of durable plastic that can withstand everyday wear and tear. The lid strap makes the bottle easy to carry. Spare parts are available to prolong the life of your product. Lid gasket spare part number 10050684. For more information, contact IKEA Customer Services at your IKEA store or IKEA.com. Wash this product before using it for the first time.",
            "sustainability": "Plastic can be recycled multiple times, reducing our environmental footprint. All products containing recycled materials meet the same quality and safety demands as we have on all our products.,BPA (Bisphenol A) free,By offering replacement parts, we make it easier to maintain and repair products. That way, products live longer, waste is reduced and the environmental impact is lowered.",
            "images": [
                "data/cookware/ikea-365-water-bottle-light-red-80480010/ikea-365-water-bottle-light-red-80480010-0.JPG",
                "data/cookware/ikea-365-water-bottle-light-red-80480010/ikea-365-water-bottle-light-red-80480010-1.JPG",
                "data/cookware/ikea-365-water-bottle-light-red-80480010/ikea-365-water-bottle-light-red-80480010-2.JPG"
            ],
            "materials": "Body:,PCTG plastic,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Freezer-safe.,Dishwasher-safe.,Withstands temperatures up to 70\u00b0C."
        },
        "152": {
            "id": 152,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Balloon whisk",
            "prod_dimensions": {
                "Length": "30 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Balloon whisk",
                "Article no.:",
                "603.098.26",
                "Width: 8 cm",
                "Height: 8 cm",
                "Length: 30 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/vardagen-balloon-whisk-60309826/vardagen-balloon-whisk-60309826-0.JPG",
                "data/cookware/vardagen-balloon-whisk-60309826/vardagen-balloon-whisk-60309826-1.JPG",
                "data/cookware/vardagen-balloon-whisk-60309826/vardagen-balloon-whisk-60309826-2.JPG",
                "data/cookware/vardagen-balloon-whisk-60309826/vardagen-balloon-whisk-60309826-3.JPG"
            ],
            "materials": "Handle:,Acetal plastic,Rivet/ Bolster/ Whisk:,Stainless steel,Dishwasher-safe."
        },
        "153": {
            "id": 153,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, rectangular/bamboo",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "503.819.07",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 21 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "The natural bamboo creates a warm and vibrant look.  Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Fits with IKEA 365+ rectangular-shaped food containers. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-rectangular-bamboo-50381907/ikea-365-lid-rectangular-bamboo-50381907-0.JPG",
                "data/cookware/ikea-365-lid-rectangular-bamboo-50381907/ikea-365-lid-rectangular-bamboo-50381907-1.JPG",
                "data/cookware/ikea-365-lid-rectangular-bamboo-50381907/ikea-365-lid-rectangular-bamboo-50381907-2.JPG",
                "data/cookware/ikea-365-lid-rectangular-bamboo-50381907/ikea-365-lid-rectangular-bamboo-50381907-3.JPG"
            ],
            "materials": "Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,Handwash only.,Not microwave-safe."
        },
        "154": {
            "id": 154,
            "prod_name": "LAGG",
            "prod_price": "1",
            "prod_desc": "Pot stand, green",
            "prod_dimensions": {
                "Length": "18 cm",
                "Width": "18 cm"
            },
            "packaging": [
                "LAGG",
                "Pot stand",
                "Article no.:",
                "001.752.69",
                "Width: 18 cm",
                "Height: 1 cm",
                "Length: 18 cm",
                "Weight: 0.09 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/lagg-pot-stand-green-00175269/lagg-pot-stand-green-00175269-0.JPG",
                "data/cookware/lagg-pot-stand-green-00175269/lagg-pot-stand-green-00175269-1.JPG",
                "data/cookware/lagg-pot-stand-green-00175269/lagg-pot-stand-green-00175269-2.JPG",
                "data/cookware/lagg-pot-stand-green-00175269/lagg-pot-stand-green-00175269-3.JPG",
                "data/cookware/lagg-pot-stand-green-00175269/lagg-pot-stand-green-00175269-4.JPG"
            ],
            "materials": "Silicone rubber,Dishwasher-safe.,Withstands temperatures up to 160\u00b0C."
        },
        "155": {
            "id": 155,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, square glass/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "12 cm",
                "Volume": "1.2 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "403.592.09",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 15 cm",
                "Weight: 0.71 kg",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.617.89",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s59269119/ikea-365-food-container-with-lid-square-glass-plastic-s59269119-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s59269119/ikea-365-food-container-with-lid-square-glass-plastic-s59269119-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s59269119/ikea-365-food-container-with-lid-square-glass-plastic-s59269119-2.JPG",
                "data/cookware/ikea-365-food-container-with-lid-square-glass-plastic-s59269119/ikea-365-food-container-with-lid-square-glass-plastic-s59269119-3.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Food container with lid,The lid is microwave-safe; heat food up to 100\u00b0C.,The container is microwave-safe.,The container is oven-safe, but the lid is not.,Food container,Freezer-safe.,Dishwasher-safe.,Lid,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "156": {
            "id": 156,
            "prod_name": "VARDAGEN",
            "prod_price": "6",
            "prod_desc": "Pie dish, off-white",
            "prod_dimensions": {
                "Height": "4 cm",
                "Diameter": "32 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Pie dish",
                "Article no.:",
                "102.893.07",
                "Length: 4 cm",
                "Weight: 1.70 kg",
                "Diameter: 32 cm",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-pie-dish-off-white-10289307/vardagen-pie-dish-off-white-10289307-0.JPG",
                "data/cookware/vardagen-pie-dish-off-white-10289307/vardagen-pie-dish-off-white-10289307-1.JPG",
                "data/cookware/vardagen-pie-dish-off-white-10289307/vardagen-pie-dish-off-white-10289307-2.JPG",
                "data/cookware/vardagen-pie-dish-off-white-10289307/vardagen-pie-dish-off-white-10289307-3.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "157": {
            "id": 157,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Cooking tweezers",
            "prod_dimensions": {
                "Length": "30 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Cooking tweezers",
                "Article no.:",
                "903.098.15",
                "Width: 9 cm",
                "Height: 3 cm",
                "Length: 30 cm",
                "Weight: 0.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-cooking-tweezers-90309815/vardagen-cooking-tweezers-90309815-0.JPG",
                "data/cookware/vardagen-cooking-tweezers-90309815/vardagen-cooking-tweezers-90309815-1.JPG",
                "data/cookware/vardagen-cooking-tweezers-90309815/vardagen-cooking-tweezers-90309815-2.JPG",
                "data/cookware/vardagen-cooking-tweezers-90309815/vardagen-cooking-tweezers-90309815-3.JPG"
            ],
            "materials": "Main parts/ Rivet:,Stainless steel,Handle:,Acetal plastic,Dishwasher-safe."
        },
        "158": {
            "id": 158,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container, rectangular/glass",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "11 cm",
                "Volume": "1.8 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "703.592.03",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 21 cm",
                "Weight: 0.95 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ rectangular-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-0.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-1.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-2.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-3.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-4.JPG",
                "data/cookware/ikea-365-food-container-rectangular-glass-70359203/ikea-365-food-container-rectangular-glass-70359203-5.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "159": {
            "id": 159,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, rectangular/plastic",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "11 cm",
                "Volume": "2.0 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "603.591.52",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 21 cm",
                "Weight: 0.16 kg",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ rectangular-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-rectangular-plastic-60359152/ikea-365-food-container-rectangular-plastic-60359152-0.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-60359152/ikea-365-food-container-rectangular-plastic-60359152-1.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-60359152/ikea-365-food-container-rectangular-plastic-60359152-2.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-60359152/ikea-365-food-container-rectangular-plastic-60359152-3.JPG",
                "data/cookware/ikea-365-food-container-rectangular-plastic-60359152/ikea-365-food-container-rectangular-plastic-60359152-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "160": {
            "id": 160,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Jar with lid, glass/bamboo",
            "prod_dimensions": {
                "Height": "14 cm",
                "Diameter": "14 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "003.932.48",
                "Length: 13 cm",
                "Weight: 0.66 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "The natural bamboo creates a warm and vibrant look.  Tight-fitting lid which keeps food fresh and preserves aromas and flavours. The jar is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the jar is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276797/ikea-365-jar-with-lid-glass-bamboo-s99276797-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-bamboo-s99276797/ikea-365-jar-with-lid-glass-bamboo-s99276797-1.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,Lid,Handwash only.,Not microwave-safe.,Jar,Dishwasher-safe."
        },
        "161": {
            "id": 161,
            "prod_name": "IKEA 365+",
            "prod_price": "13",
            "prod_desc": "Oven dish, white",
            "prod_dimensions": {
                "Length": "38 cm",
                "Width": "26 cm",
                "Height": "7 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Oven dish",
                "Article no.:",
                "402.867.36",
                "Width: 26 cm",
                "Height: 7 cm",
                "Length: 38 cm",
                "Weight: 2.34 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of feldspar porcelain, which makes the oven dish impact resistant and durable. The generous handles make it easy and safe for you to hold and lift the oven dish. The smart design allows you to stack the smaller sizes in the larger ones without taking more vertical space, so you get room for other things. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-oven-dish-white-40286736/ikea-365-oven-dish-white-40286736-0.JPG",
                "data/cookware/ikea-365-oven-dish-white-40286736/ikea-365-oven-dish-white-40286736-1.JPG",
                "data/cookware/ikea-365-oven-dish-white-40286736/ikea-365-oven-dish-white-40286736-2.JPG",
                "data/cookware/ikea-365-oven-dish-white-40286736/ikea-365-oven-dish-white-40286736-3.JPG"
            ],
            "materials": "Feldspar porcelain,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "162": {
            "id": 162,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Lid, round/plastic",
            "prod_dimensions": {
                "Diameter": "14 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Snap-and-lock lid creates an aroma-tight seal, so the food you store in the food container stays fresh for longer. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The transparent lid lets you see what's stored inside. Fits with IKEA 365+ round-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-lid-round-plastic-70361786/ikea-365-lid-round-plastic-70361786-0.JPG",
                "data/cookware/ikea-365-lid-round-plastic-70361786/ikea-365-lid-round-plastic-70361786-1.JPG",
                "data/cookware/ikea-365-lid-round-plastic-70361786/ikea-365-lid-round-plastic-70361786-2.JPG",
                "data/cookware/ikea-365-lid-round-plastic-70361786/ikea-365-lid-round-plastic-70361786-3.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "163": {
            "id": 163,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Lid, square/plastic",
            "prod_dimensions": {
                "Length": "20 cm",
                "Width": "20 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.617.89",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "Snap-and-lock lid creates an aroma-tight seal, so the food you store in the food container stays fresh for longer. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The transparent lid lets you see what's stored inside. Fits with IKEA 365+ square-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-0.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-1.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-2.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-3.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-4.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-5.JPG",
                "data/cookware/ikea-365-lid-square-plastic-10361789/ikea-365-lid-square-plastic-10361789-6.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "164": {
            "id": 164,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, round/bamboo",
            "prod_dimensions": {
                "Diameter": "14 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "603.818.98",
                "Length: 2 cm",
                "Weight: 0.15 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "The natural bamboo creates a warm and vibrant look.  Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Fits with IKEA 365+ round-shaped food containers. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-0.JPG",
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-1.JPG",
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-2.JPG",
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-3.JPG",
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-4.JPG",
                "data/cookware/ikea-365-lid-round-bamboo-60381898/ikea-365-lid-round-bamboo-60381898-5.JPG"
            ],
            "materials": "Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,Handwash only.,Not microwave-safe."
        },
        "165": {
            "id": 165,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Food container with lid, glass",
            "prod_dimensions": {
                "Height": "9 cm",
                "Diameter": "14 cm",
                "Volume": "600 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "303.591.96",
                "Length: 8 cm",
                "Weight: 0.46 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. The container is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-glass-s59279651/ikea-365-food-container-with-lid-glass-s59279651-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-glass-s59279651/ikea-365-food-container-with-lid-glass-s59279651-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-glass-s59279651/ikea-365-food-container-with-lid-glass-s59279651-2.JPG"
            ],
            "materials": "Food container,Heat resistant glass,Lid,Lid:,Glass,Seal:,Silicone rubber,Food container,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe.,Lid,Dishwasher-safe."
        },
        "166": {
            "id": 166,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container with lid, round/plastic",
            "prod_dimensions": {
                "Height": "9 cm",
                "Diameter": "14 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "003.591.45",
                "Length: 8 cm",
                "Weight: 0.09 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. The container and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Wash this product before using it for the first time.",
            "sustainability": "Food container/lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s79269104/ikea-365-food-container-with-lid-round-plastic-s79269104-0.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s79269104/ikea-365-food-container-with-lid-round-plastic-s79269104-1.JPG",
                "data/cookware/ikea-365-food-container-with-lid-round-plastic-s79269104/ikea-365-food-container-with-lid-round-plastic-s79269104-2.JPG"
            ],
            "materials": "Food container,Polypropylene plastic,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber,Lid,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,Food container,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "167": {
            "id": 167,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Jar with lid, glass/plastic",
            "prod_dimensions": {
                "Height": "17 cm",
                "Diameter": "14 cm",
                "Volume": "1.7 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "803.932.49",
                "Length: 16 cm",
                "Weight: 0.94 kg",
                "Diameter: 15 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "703.617.86",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.10 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and creates an aroma tight seal, making it ideal for both transporting and storing food. The jar is made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the jar is easy to clean. The jar and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar,No cadmium or lead added.,Lid,No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s49277775/ikea-365-jar-with-lid-glass-plastic-s49277775-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s49277775/ikea-365-jar-with-lid-glass-plastic-s49277775-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-plastic-s49277775/ikea-365-jar-with-lid-glass-plastic-s49277775-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Polypropylene plastic,Seal:,Silicone rubber"
        },
        "168": {
            "id": 168,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Jar with lid, glass",
            "prod_dimensions": {
                "Height": "14 cm",
                "Diameter": "14 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "003.932.48",
                "Length: 13 cm",
                "Weight: 0.66 kg",
                "Diameter: 14 cm",
                "Package(s): 1",
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.934.97",
                "Length: 2 cm",
                "Weight: 0.35 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The jar and the lid are both transparent, so it\u2019s easy to find what you are looking for, regardless of where the jar is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "Jar/lid,No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-with-lid-glass-s79276784/ikea-365-jar-with-lid-glass-s79276784-0.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s79276784/ikea-365-jar-with-lid-glass-s79276784-1.JPG",
                "data/cookware/ikea-365-jar-with-lid-glass-s79276784/ikea-365-jar-with-lid-glass-s79276784-2.JPG"
            ],
            "materials": "Jar,Glass,Lid,Lid:,Glass,Seal:,Silicone rubber,Jar/lid,Dishwasher-safe."
        },
        "169": {
            "id": 169,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Lunch box with inserts, square/beige light red",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Lunch box with inserts",
                "Article no.:",
                "704.801.24",
                "Width: 16 cm",
                "Height: 7 cm",
                "Length: 16 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "This lunch box has 2 removable inserts so that you can separate your main course from your salad and sauce. One of the inserts has a lid, perfect for things like sauces or dressings. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. Snap-and-lock lid creates an aroma-tight seal, so the food you store in the lunch box stays fresh for longer. The inserts fit with the square and rectangular food containers in the IKEA 365+ series. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-0.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-1.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-2.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-3.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-4.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-5.JPG",
                "data/cookware/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124/ikea-365-lunch-box-with-inserts-square-beige-light-red-70480124-6.JPG"
            ],
            "materials": "Jar/ Insert/ Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "170": {
            "id": 170,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Oven dish, oval/off-white",
            "prod_dimensions": {
                "Length": "26 cm",
                "Width": "21 cm",
                "Height": "6 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Oven dish",
                "Article no.:",
                "702.893.09",
                "Width: 21 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 1.05 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-oven-dish-oval-off-white-70289309/vardagen-oven-dish-oval-off-white-70289309-0.JPG",
                "data/cookware/vardagen-oven-dish-oval-off-white-70289309/vardagen-oven-dish-oval-off-white-70289309-1.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "171": {
            "id": 171,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Lid, rectangular/silicone",
            "prod_dimensions": {
                "Length": "22 cm",
                "Width": "16 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.820.88",
                "Width: 16 cm",
                "Height: 2 cm",
                "Length: 22 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "The lid creates a vacuum when placed on a container \u2012 keeping the food fresh longer and helping the food retain both heat and coolness. Can be used to protect from splatter in the oven and the microwave. Wash the lid in the dishwasher and use it again and again, as this helps you reduce the amount of plastic and aluminium foil you use. Fits with IKEA 365+ rectangular-shaped food containers. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-rectangular-silicone-30382088/ikea-365-lid-rectangular-silicone-30382088-0.JPG",
                "data/cookware/ikea-365-lid-rectangular-silicone-30382088/ikea-365-lid-rectangular-silicone-30382088-1.JPG",
                "data/cookware/ikea-365-lid-rectangular-silicone-30382088/ikea-365-lid-rectangular-silicone-30382088-2.JPG",
                "data/cookware/ikea-365-lid-rectangular-silicone-30382088/ikea-365-lid-rectangular-silicone-30382088-3.JPG",
                "data/cookware/ikea-365-lid-rectangular-silicone-30382088/ikea-365-lid-rectangular-silicone-30382088-4.JPG"
            ],
            "materials": "Silicone rubber,Withstands temperatures up to 225\u00b0C.,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "172": {
            "id": 172,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, square/bamboo",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "103.819.09",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 15 cm",
                "Weight: 0.19 kg",
                "Package(s): 1"
            ],
            "prod_details": "The natural bamboo creates a warm and vibrant look.  Tight-fitting lid which keeps food fresh and preserves aromas and flavours. Fits with IKEA 365+ square-shaped food containers. The lid can also be used as a coaster and withstands temperatures up to 100\u00b0C. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-0.JPG",
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-1.JPG",
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-2.JPG",
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-3.JPG",
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-4.JPG",
                "data/cookware/ikea-365-lid-square-bamboo-10381909/ikea-365-lid-square-bamboo-10381909-5.JPG"
            ],
            "materials": "Lid:,Bamboo, Clear nitrocellulose lacquer,Seal:,Silicone rubber,Handwash only.,Not microwave-safe."
        },
        "173": {
            "id": 173,
            "prod_name": "VARDAGEN",
            "prod_price": "13",
            "prod_desc": "Loose-base cake tin, silver-colour",
            "prod_dimensions": {},
            "packaging": [
                "VARDAGEN",
                "Loose-base cake tin",
                "Article no.:",
                "802.569.83",
                "Length: 7 cm",
                "Weight: 0.51 kg",
                "Diameter: 29 cm",
                "Package(s): 1"
            ],
            "prod_details": "Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. The ridges in the base help to catch the batter and prevent the tin from leaking. Serving is easy, as the removable base makes it easy to get the cake out of the tin. Switch between the 2 removable bases to bake different types of cake using the same tin. Baking tin with two different bottoms. Capacity 2.5 l alt. 3 l. Always grease the tin with oil or butter for best results. Not suitable for acidic foods. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-0.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-1.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-2.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-3.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-4.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-5.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-6.JPG",
                "data/cookware/vardagen-loose-base-cake-tin-silver-colour-80256983/vardagen-loose-base-cake-tin-silver-colour-80256983-7.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe.,Not dishwasher-safe."
        },
        "174": {
            "id": 174,
            "prod_name": "IKEA 365+",
            "prod_price": "4",
            "prod_desc": "Food container, large rectangular/plastic",
            "prod_dimensions": {
                "Length": "32 cm",
                "Width": "21 cm",
                "Height": "22 cm",
                "Volume": "10.6 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "103.930.64",
                "Width: 23 cm",
                "Height: 22 cm",
                "Length: 32 cm",
                "Weight: 0.49 kg",
                "Package(s): 1"
            ],
            "prod_details": "Helps you organise dry foods in your cabinets and drawers. The food containers come in different sizes and are stackable, so you can use the space efficiently. The transparent container makes it easy to find what you are looking for, regardless of where it is placed. Wash this product before using it for the first time.",
            "sustainability": "BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-10393064/ikea-365-food-container-large-rectangular-plastic-10393064-0.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-10393064/ikea-365-food-container-large-rectangular-plastic-10393064-1.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-10393064/ikea-365-food-container-large-rectangular-plastic-10393064-2.JPG",
                "data/cookware/ikea-365-food-container-large-rectangular-plastic-10393064/ikea-365-food-container-large-rectangular-plastic-10393064-3.JPG"
            ],
            "materials": "Polypropylene plastic,Freezer-safe.,Dishwasher-safe."
        },
        "175": {
            "id": 175,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Loaf tin, silver-colour",
            "prod_dimensions": {
                "Volume": "1.8 l"
            },
            "packaging": [
                "VARDAGEN",
                "Loaf tin",
                "Article no.:",
                "302.569.90",
                "Width: 13 cm",
                "Height: 8 cm",
                "Length: 32 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. Always grease the tin with oil or butter for best results. Not suitable for acidic foods. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-0.JPG",
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-1.JPG",
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-2.JPG",
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-3.JPG",
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-4.JPG",
                "data/cookware/vardagen-loaf-tin-silver-colour-30256990/vardagen-loaf-tin-silver-colour-30256990-5.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe."
        },
        "176": {
            "id": 176,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Baking tin, silver-colour",
            "prod_dimensions": {
                "Volume": "0.5 l",
                "Package quantity": "2 pack"
            },
            "packaging": [
                "VARDAGEN",
                "Baking tin",
                "Article no.:",
                "702.569.74",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 17 cm",
                "Weight: 0.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. Always grease the tin with oil or butter for best results. Not suitable for acidic foods. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-0.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-1.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-2.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-3.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-4.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-5.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-6.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-7.JPG",
                "data/cookware/vardagen-baking-tin-silver-colour-70256974/vardagen-baking-tin-silver-colour-70256974-8.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe."
        },
        "177": {
            "id": 177,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lunch box with dry food compartment, round turquoise",
            "prod_dimensions": {
                "Height": "5 cm",
                "Diameter": "14 cm",
                "Volume": "450 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Lunch box with dry food compartment",
                "Article no.:",
                "804.800.29",
                "Length: 7 cm",
                "Weight: 0.18 kg",
                "Diameter: 15 cm",
                "Package(s): 1"
            ],
            "prod_details": "Perfect for storing dry goods such as grains, muesli and nuts. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Reduce food waste by storing your leftovers in a food container and reheating for another meal. Perfect for storing individual food portions. Snap-and-lock lid creates an aroma-tight seal, so the food you store in the food container stays fresh for longer. The lid creates a vacuum when placed on a container \u2012 keeping the food fresh longer and helping the food retain both heat and coolness. The lid fits with all IKEA 365+ round food containers and jars. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-0.JPG",
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-1.JPG",
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-2.JPG",
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-3.JPG",
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-4.JPG",
                "data/cookware/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029/ikea-365-lunch-box-with-dry-food-compartment-round-turquoise-80480029-5.JPG"
            ],
            "materials": "Lid/ Insert/ Jar:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam.,The top lid is not suitable for use in a microwave oven."
        },
        "178": {
            "id": 178,
            "prod_name": "VARDAGEN",
            "prod_price": "5",
            "prod_desc": "Bottle opener and can opener",
            "prod_dimensions": {
                "Length": "13 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Bottle opener and can opener",
                "Article no.:",
                "303.243.57",
                "Width: 10 cm",
                "Height: 4 cm",
                "Length: 17 cm",
                "Weight: 0.17 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-bottle-opener-and-can-opener-30324357/vardagen-bottle-opener-and-can-opener-30324357-0.JPG",
                "data/cookware/vardagen-bottle-opener-and-can-opener-30324357/vardagen-bottle-opener-and-can-opener-30324357-1.JPG",
                "data/cookware/vardagen-bottle-opener-and-can-opener-30324357/vardagen-bottle-opener-and-can-opener-30324357-2.JPG"
            ],
            "materials": "Handle:,Acetal plastic,Main parts:,Stainless steel, Stainless steel,Rivet:,Stainless steel,Dishwasher-safe."
        },
        "179": {
            "id": 179,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Food container, square/glass",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "11 cm",
                "Volume": "1.2 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "403.592.09",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 15 cm",
                "Weight: 0.71 kg",
                "Package(s): 1"
            ],
            "prod_details": "The food container is made of oven-safe glass and can be used as an oven/serving dish. Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ square-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-0.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-1.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-2.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-3.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-4.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-5.JPG",
                "data/cookware/ikea-365-food-container-square-glass-40359209/ikea-365-food-container-square-glass-40359209-6.JPG"
            ],
            "materials": "Heat resistant glass,Microwave-safe.,Freezer-safe.,Dishwasher-safe.,Oven-safe."
        },
        "180": {
            "id": 180,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Lid, large rectangular/plastic",
            "prod_dimensions": {
                "Length": "37 cm",
                "Width": "26 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Lid",
                "Article no.:",
                "303.930.63",
                "Width: 27 cm",
                "Height: 1 cm",
                "Length: 37 cm",
                "Weight: 0.23 kg",
                "Package(s): 1"
            ],
            "prod_details": "The snap-and-lock lid prevents leakage and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. Leak-proof lid prevents spills and protects the contents from frost damage, making it ideal for both transporting food and storing leftovers. The transparent lid lets you see what's stored inside. Wash this product before using it for the first time.",
            "sustainability": "BPA (Bisphenol A) free",
            "images": [
                "data/cookware/ikea-365-lid-large-rectangular-plastic-30393063/ikea-365-lid-large-rectangular-plastic-30393063-0.JPG",
                "data/cookware/ikea-365-lid-large-rectangular-plastic-30393063/ikea-365-lid-large-rectangular-plastic-30393063-1.JPG",
                "data/cookware/ikea-365-lid-large-rectangular-plastic-30393063/ikea-365-lid-large-rectangular-plastic-30393063-2.JPG",
                "data/cookware/ikea-365-lid-large-rectangular-plastic-30393063/ikea-365-lid-large-rectangular-plastic-30393063-3.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Seal:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe.,Leave lid ajar while heating to release steam."
        },
        "181": {
            "id": 181,
            "prod_name": "IKEA 365+",
            "prod_price": "2",
            "prod_desc": "Jar, round/glass",
            "prod_dimensions": {
                "Height": "13 cm",
                "Diameter": "14 cm",
                "Volume": "1.0 l"
            },
            "packaging": [
                "IKEA 365+",
                "Jar",
                "Article no.:",
                "003.932.48",
                "Length: 13 cm",
                "Weight: 0.66 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Made of glass, which does not absorb odours or discolour from tomato sauce, etc, so the food container is easy to clean. The transparent jar makes it easy to find what you are looking for, regardless of where it is placed. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/ikea-365-jar-round-glass-00393248/ikea-365-jar-round-glass-00393248-0.JPG",
                "data/cookware/ikea-365-jar-round-glass-00393248/ikea-365-jar-round-glass-00393248-1.JPG",
                "data/cookware/ikea-365-jar-round-glass-00393248/ikea-365-jar-round-glass-00393248-2.JPG",
                "data/cookware/ikea-365-jar-round-glass-00393248/ikea-365-jar-round-glass-00393248-3.JPG",
                "data/cookware/ikea-365-jar-round-glass-00393248/ikea-365-jar-round-glass-00393248-4.JPG"
            ],
            "materials": "Glass,Dishwasher-safe."
        },
        "182": {
            "id": 182,
            "prod_name": "VARDAGEN",
            "prod_price": "9",
            "prod_desc": "Oven dish, oval/off-white",
            "prod_dimensions": {
                "Length": "31 cm",
                "Width": "24 cm",
                "Height": "7 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Oven dish",
                "Article no.:",
                "202.893.16",
                "Width: 24 cm",
                "Height: 7 cm",
                "Length: 31 cm",
                "Weight: 1.42 kg",
                "Package(s): 1"
            ],
            "prod_details": "Wash this product before using it for the first time.",
            "sustainability": "No cadmium or lead added.",
            "images": [
                "data/cookware/vardagen-oven-dish-oval-off-white-20289316/vardagen-oven-dish-oval-off-white-20289316-0.JPG",
                "data/cookware/vardagen-oven-dish-oval-off-white-20289316/vardagen-oven-dish-oval-off-white-20289316-1.JPG",
                "data/cookware/vardagen-oven-dish-oval-off-white-20289316/vardagen-oven-dish-oval-off-white-20289316-2.JPG"
            ],
            "materials": "Stoneware,Microwave-safe.,Dishwasher-safe.,Oven-safe."
        },
        "183": {
            "id": 183,
            "prod_name": "FJ\u00c4RMA",
            "prod_price": "4",
            "prod_desc": "Food container, collapsible, pink-red",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Height": "5 cm",
                "Volume": "800 ml"
            },
            "packaging": [
                "FJ\u00c4RMA",
                "Food container, collapsible",
                "Article no.:",
                "004.701.33",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 22 cm",
                "Weight: 0.27 kg",
                "Package(s): 1"
            ],
            "prod_details": "Suitable for storing food in portions so you can bring it with you to school or work. Reduce food waste by storing your leftovers in a food container and reheating for another meal. When the food container is empty, it takes up less space in a bag or in a cabinet since it\u2019s collapsible. You don\u2019t need to remove the lid when heating the food in the microwave \u2013 instead, just pull up the round button in the centre of the lid. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/fjaerma-food-container-collapsible-pink-red-00470133/fjaerma-food-container-collapsible-pink-red-00470133-0.JPG",
                "data/cookware/fjaerma-food-container-collapsible-pink-red-00470133/fjaerma-food-container-collapsible-pink-red-00470133-1.JPG",
                "data/cookware/fjaerma-food-container-collapsible-pink-red-00470133/fjaerma-food-container-collapsible-pink-red-00470133-2.JPG",
                "data/cookware/fjaerma-food-container-collapsible-pink-red-00470133/fjaerma-food-container-collapsible-pink-red-00470133-3.JPG"
            ],
            "materials": "Lid:,Polypropylene plastic,Body:,Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "184": {
            "id": 184,
            "prod_name": "IKEA 365+",
            "prod_price": "0",
            "prod_desc": "Food container, square/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "6 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "503.591.76",
                "Width: 15 cm",
                "Height: 6 cm",
                "Length: 15 cm",
                "Weight: 0.09 kg",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ square-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-0.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-1.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-2.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-3.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-4.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-5.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-50359176/ikea-365-food-container-square-plastic-50359176-6.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "185": {
            "id": 185,
            "prod_name": "VARDAGEN",
            "prod_price": "13",
            "prod_desc": "Muffin tin, silver-colour",
            "prod_dimensions": {
                "Length": "38 cm",
                "Width": "29 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Muffin tin",
                "Article no.:",
                "702.569.93",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 39 cm",
                "Weight: 0.53 kg",
                "Package(s): 1"
            ],
            "prod_details": "Anodised aluminium gives the baking tin an extra durable and hard-wearing surface, so that you can keep baking for years. Always grease the tin with oil or butter for best results. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-muffin-tin-silver-colour-70256993/vardagen-muffin-tin-silver-colour-70256993-0.JPG",
                "data/cookware/vardagen-muffin-tin-silver-colour-70256993/vardagen-muffin-tin-silver-colour-70256993-1.JPG",
                "data/cookware/vardagen-muffin-tin-silver-colour-70256993/vardagen-muffin-tin-silver-colour-70256993-2.JPG",
                "data/cookware/vardagen-muffin-tin-silver-colour-70256993/vardagen-muffin-tin-silver-colour-70256993-3.JPG",
                "data/cookware/vardagen-muffin-tin-silver-colour-70256993/vardagen-muffin-tin-silver-colour-70256993-4.JPG"
            ],
            "materials": "Aluminium, Anodized,Handwash only.,Oven-safe."
        },
        "186": {
            "id": 186,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Ice pack, rectangular",
            "prod_dimensions": {
                "Length": "21 cm",
                "Width": "15 cm",
                "Thickness": "3 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Ice pack",
                "Article no.:",
                "104.377.89",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 21 cm",
                "Weight: 0.63 kg",
                "Package(s): 1"
            ],
            "prod_details": "The elastic strap allows you to attach the freezer pack on top or underneath a food container to ensure it stays cold. Can be used without the elastic strap in a cooler bag in order to keep the contents cold. Reusable freezer pack that fits perfectly in food containers and cooler bags of different sizes. Needs to be kept in the freezer before use. Dimensioned for IKEA 365+ food containers. Store the freezer pack in the freezer without the elastic band, as the band may lose shape due to the cold.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-0.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-1.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-2.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-3.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-4.jpg",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-5.jpg",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-6.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-7.JPG",
                "data/cookware/ikea-365-ice-pack-rectangular-10437789/ikea-365-ice-pack-rectangular-10437789-8.JPG"
            ],
            "materials": "Body:,Polyethylene plastic,Filling:,Aqua,Belt:,Synthetic rubber,Handwash only."
        },
        "187": {
            "id": 187,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Food container, square/plastic",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Height": "11 cm",
                "Volume": "1.4 l"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "903.591.79",
                "Width: 15 cm",
                "Height: 11 cm",
                "Length: 15 cm",
                "Weight: 0.13 kg",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ square-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-square-plastic-90359179/ikea-365-food-container-square-plastic-90359179-0.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-90359179/ikea-365-food-container-square-plastic-90359179-1.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-90359179/ikea-365-food-container-square-plastic-90359179-2.JPG",
                "data/cookware/ikea-365-food-container-square-plastic-90359179/ikea-365-food-container-square-plastic-90359179-3.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "188": {
            "id": 188,
            "prod_name": "IKEA 365+",
            "prod_price": "0",
            "prod_desc": "Food container, round/plastic",
            "prod_dimensions": {
                "Height": "8 cm",
                "Diameter": "14 cm",
                "Volume": "750 ml"
            },
            "packaging": [
                "IKEA 365+",
                "Food container",
                "Article no.:",
                "003.591.45",
                "Length: 8 cm",
                "Weight: 0.09 kg",
                "Diameter: 14 cm",
                "Package(s): 1"
            ],
            "prod_details": "Reduce food waste by storing your leftovers in a food container and reheating for another meal. Several empty food containers can be stacked inside one another to save space in your cabinets. The container is made of durable plastic that keeps its shape even if you cram it into your bag or backpack. Fits with IKEA 365+ round-shaped lids. Wash this product before using it for the first time.",
            "sustainability": "No BPA (Bisphenol A) added.",
            "images": [
                "data/cookware/ikea-365-food-container-round-plastic-00359145/ikea-365-food-container-round-plastic-00359145-0.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-00359145/ikea-365-food-container-round-plastic-00359145-1.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-00359145/ikea-365-food-container-round-plastic-00359145-2.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-00359145/ikea-365-food-container-round-plastic-00359145-3.JPG",
                "data/cookware/ikea-365-food-container-round-plastic-00359145/ikea-365-food-container-round-plastic-00359145-4.JPG"
            ],
            "materials": "Polypropylene plastic,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "189": {
            "id": 189,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Ice pack, round",
            "prod_dimensions": {
                "Diameter": "14 cm",
                "Thickness": "3 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Ice pack",
                "Article no.:",
                "004.378.17",
                "Width: 14 cm",
                "Height: 3 cm",
                "Length: 16 cm",
                "Weight: 0.32 kg",
                "Package(s): 1"
            ],
            "prod_details": "The elastic strap allows you to attach the freezer pack on top or underneath a food container to ensure it stays cold. Can be used without the elastic strap in a cooler bag in order to keep the contents cold. Reusable freezer pack that fits perfectly in food containers and cooler bags of different sizes. Needs to be kept in the freezer before use. Dimensioned for IKEA 365+ food containers. Store the freezer pack in the freezer without the elastic band, as the band may lose shape due to the cold.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-0.JPG",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-1.JPG",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-2.JPG",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-3.JPG",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-4.jpg",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-5.jpg",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-6.JPG",
                "data/cookware/ikea-365-ice-pack-round-00437817/ikea-365-ice-pack-round-00437817-7.JPG"
            ],
            "materials": "Body:,Polyethylene plastic,Filling:,Aqua,Belt:,Synthetic rubber,Handwash only."
        },
        "190": {
            "id": 190,
            "prod_name": "IKEA 365+",
            "prod_price": "1",
            "prod_desc": "Ice pack, square",
            "prod_dimensions": {
                "Length": "15 cm",
                "Width": "15 cm",
                "Thickness": "3 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Ice pack",
                "Article no.:",
                "204.377.55",
                "Width: 15 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.44 kg",
                "Package(s): 1"
            ],
            "prod_details": "The elastic strap allows you to attach the freezer pack on top or underneath a food container to ensure it stays cold. Can be used without the elastic strap in a cooler bag in order to keep the contents cold. Reusable freezer pack that fits perfectly in food containers and cooler bags of different sizes. Needs to be kept in the freezer before use. Dimensioned for IKEA 365+ food containers. Store the freezer pack in the freezer without the elastic band, as the band may lose shape due to the cold.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-0.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-1.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-2.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-3.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-4.jpg",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-5.jpg",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-6.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-7.JPG",
                "data/cookware/ikea-365-ice-pack-square-20437755/ikea-365-ice-pack-square-20437755-8.JPG"
            ],
            "materials": "Body:,Polyethylene plastic,Filling:,Aqua,Belt:,Synthetic rubber,Handwash only."
        },
        "191": {
            "id": 191,
            "prod_name": "HILDEGUN",
            "prod_price": "1",
            "prod_desc": "Pot holder, blue",
            "prod_dimensions": {
                "Length": "19 cm",
                "Width": "19 cm"
            },
            "packaging": [
                "HILDEGUN",
                "Pot holder",
                "Article no.:",
                "304.840.63",
                "Width: 19 cm",
                "Height: 1 cm",
                "Length: 19 cm",
                "Weight: 0.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/hildegun-pot-holder-blue-30484063/hildegun-pot-holder-blue-30484063-0.JPG",
                "data/cookware/hildegun-pot-holder-blue-30484063/hildegun-pot-holder-blue-30484063-1.JPG",
                "data/cookware/hildegun-pot-holder-blue-30484063/hildegun-pot-holder-blue-30484063-2.JPG",
                "data/cookware/hildegun-pot-holder-blue-30484063/hildegun-pot-holder-blue-30484063-3.JPG"
            ],
            "materials": "Fabric:,100% cotton,Filling:,100 % polyester,Shrinkage maximum 4%.,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 200\u00b0C.,Do not dryclean.,Stretch into shape when wet."
        },
        "192": {
            "id": 192,
            "prod_name": "MARIATHERES",
            "prod_price": "3",
            "prod_desc": "Pot holder, grey/beige",
            "prod_dimensions": {
                "Length": "19 cm",
                "Width": "19 cm",
                "Package quantity": "2 pack"
            },
            "packaging": [
                "MARIATHERES",
                "Pot holder",
                "Article no.:",
                "704.796.01",
                "Width: 20 cm",
                "Height: 1 cm",
                "Length: 20 cm",
                "Weight: 0.13 kg",
                "Package(s): 1"
            ],
            "prod_details": "Cotton/linen blend with high absorption capacity. Linen/cotton blend; combines the shine and firmness of linen with the softness of cotton.",
            "sustainability": "By using renewable materials like cotton and flax in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/cookware/mariatheres-pot-holder-grey-beige-70479601/mariatheres-pot-holder-grey-beige-70479601-0.jpg",
                "data/cookware/mariatheres-pot-holder-grey-beige-70479601/mariatheres-pot-holder-grey-beige-70479601-1.jpg",
                "data/cookware/mariatheres-pot-holder-grey-beige-70479601/mariatheres-pot-holder-grey-beige-70479601-2.jpg",
                "data/cookware/mariatheres-pot-holder-grey-beige-70479601/mariatheres-pot-holder-grey-beige-70479601-3.jpg"
            ],
            "materials": "Outer fabric/ Inner fabric:,60% cotton, 40% linen,Filling:,100 % polyester,Shrinkage maximum 4%.,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 200\u00b0C.,Do not dryclean.,Stretch into shape when wet."
        },
        "193": {
            "id": 193,
            "prod_name": "VARDAGEN",
            "prod_price": "15",
            "prod_desc": "Bread knife, dark grey",
            "prod_dimensions": {
                "Length of knife blade": "23 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Bread knife",
                "Article no.:",
                "002.947.24",
                "Width: 7 cm",
                "Height: 3 cm",
                "Length: 43 cm",
                "Weight: 0.29 kg",
                "Package(s): 1"
            ],
            "prod_details": "The knife has a serrated edge which makes it easy to slice bread and cut soft vegetables such as tomatoes. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. The knife's tang runs through the length of the handle, making it very wear-resistant and balanced. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-0.JPG",
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-1.JPG",
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-2.JPG",
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-3.JPG",
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-4.JPG",
                "data/cookware/vardagen-bread-knife-dark-grey-00294724/vardagen-bread-knife-dark-grey-00294724-5.JPG"
            ],
            "materials": "Blade/ Rivet:,Stainless steel,Handle:,Acetal plastic,Handwash only."
        },
        "194": {
            "id": 194,
            "prod_name": "VARDAGEN",
            "prod_price": "8",
            "prod_desc": "Paring knife, dark grey",
            "prod_dimensions": {
                "Length of knife blade": "9 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Paring knife",
                "Article no.:",
                "202.947.18",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 26 cm",
                "Weight: 0.12 kg",
                "Package(s): 1"
            ],
            "prod_details": "Small and handy. Suitable for peeling and trimming fruit and vegetables. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. The knife's tang runs through the length of the handle, making it very wear-resistant and balanced. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-0.JPG",
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-1.JPG",
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-2.JPG",
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-3.JPG",
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-4.JPG",
                "data/cookware/vardagen-paring-knife-dark-grey-20294718/vardagen-paring-knife-dark-grey-20294718-5.JPG"
            ],
            "materials": "Blade/ Rivet:,Stainless steel,Handle:,Acetal plastic,Handwash only."
        },
        "195": {
            "id": 195,
            "prod_name": "HILDEGUN",
            "prod_price": "1",
            "prod_desc": "Pot holder, red",
            "prod_dimensions": {
                "Length": "19 cm",
                "Width": "19 cm"
            },
            "packaging": [
                "HILDEGUN",
                "Pot holder",
                "Article no.:",
                "204.840.54",
                "Width: 19 cm",
                "Height: 1 cm",
                "Length: 19 cm",
                "Weight: 0.04 kg",
                "Package(s): 1"
            ],
            "prod_details": "",
            "sustainability": "",
            "images": [
                "data/cookware/hildegun-pot-holder-red-20484054/hildegun-pot-holder-red-20484054-0.JPG",
                "data/cookware/hildegun-pot-holder-red-20484054/hildegun-pot-holder-red-20484054-1.JPG",
                "data/cookware/hildegun-pot-holder-red-20484054/hildegun-pot-holder-red-20484054-2.JPG",
                "data/cookware/hildegun-pot-holder-red-20484054/hildegun-pot-holder-red-20484054-3.JPG"
            ],
            "materials": "Fabric:,100% cotton,Filling:,100 % polyester,Shrinkage maximum 4%.,Machine wash, max 60\u00b0C, normal process.,Do not bleach.,Do not tumble dry.,Iron, max 200\u00b0C.,Do not dryclean.,Stretch into shape when wet."
        },
        "196": {
            "id": 196,
            "prod_name": "VARDAGEN",
            "prod_price": "15",
            "prod_desc": "Cook's knife, dark grey",
            "prod_dimensions": {
                "Length of knife blade": "20 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Cook's knife",
                "Article no.:",
                "402.947.22",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 40 cm",
                "Weight: 0.29 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. The sturdy blade makes it easier to divide and chop, for example, meat and root vegetables. The knife's tang runs through the length of the handle, making it very wear-resistant and balanced. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-0.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-1.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-2.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-3.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-4.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-40294722/vardagen-cooks-knife-dark-grey-40294722-5.JPG"
            ],
            "materials": "Blade/ Rivet:,Stainless steel,Handle:,Acetal plastic,Handwash only."
        },
        "197": {
            "id": 197,
            "prod_name": "IKEA 365+",
            "prod_price": "3",
            "prod_desc": "Gasket, rectangular/mixed colours",
            "prod_dimensions": {
                "Length": "20.2 cm",
                "Width": "14.4 cm",
                "Package quantity": "4 pack"
            },
            "packaging": [
                "IKEA 365+",
                "Gasket",
                "Article no.:",
                "603.686.27",
                "Width: 21 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.15 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can personalise and organise your food containers using the 4 replaceable gaskets. Use a specific colour for for each family member, type of food or day of the week. Fits with IKEA 365+ plastic lids. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/ikea-365-gasket-rectangular-mixed-colours-60368627/ikea-365-gasket-rectangular-mixed-colours-60368627-0.JPG",
                "data/cookware/ikea-365-gasket-rectangular-mixed-colours-60368627/ikea-365-gasket-rectangular-mixed-colours-60368627-1.JPG",
                "data/cookware/ikea-365-gasket-rectangular-mixed-colours-60368627/ikea-365-gasket-rectangular-mixed-colours-60368627-2.JPG",
                "data/cookware/ikea-365-gasket-rectangular-mixed-colours-60368627/ikea-365-gasket-rectangular-mixed-colours-60368627-3.JPG",
                "data/cookware/ikea-365-gasket-rectangular-mixed-colours-60368627/ikea-365-gasket-rectangular-mixed-colours-60368627-4.JPG"
            ],
            "materials": "Silicone rubber,Microwave-safe; heat food up to 100\u00b0C.,Freezer-safe.,Dishwasher-safe."
        },
        "198": {
            "id": 198,
            "prod_name": "IKEA 365+",
            "prod_price": "19",
            "prod_desc": "Bread knife, stainless steel",
            "prod_dimensions": {
                "Length of knife blade": "23 cm"
            },
            "packaging": [
                "IKEA 365+",
                "Bread knife",
                "Article no.:",
                "702.835.19",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 43 cm",
                "Weight: 0.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "15 year guarantee. Read about the terms in the guarantee brochure. The knife has a serrated edge which makes it easy to slice bread and cut soft vegetables such as tomatoes. The knife is very hardwearing, balanced and easy to clean, as it is made of stainless steel. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. Groves on the handle give a firm, secure grip and keep the knife from sliding in your hand. Wash this product before using it for the first time.",
            "sustainability": "The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/cookware/ikea-365-bread-knife-stainless-steel-70283519/ikea-365-bread-knife-stainless-steel-70283519-0.JPG",
                "data/cookware/ikea-365-bread-knife-stainless-steel-70283519/ikea-365-bread-knife-stainless-steel-70283519-1.JPG",
                "data/cookware/ikea-365-bread-knife-stainless-steel-70283519/ikea-365-bread-knife-stainless-steel-70283519-2.JPG",
                "data/cookware/ikea-365-bread-knife-stainless-steel-70283519/ikea-365-bread-knife-stainless-steel-70283519-3.JPG",
                "data/cookware/ikea-365-bread-knife-stainless-steel-70283519/ikea-365-bread-knife-stainless-steel-70283519-4.JPG"
            ],
            "materials": "Stainless steel,Handwash only."
        },
        "199": {
            "id": 199,
            "prod_name": "V\u00c5RFINT",
            "prod_price": "2",
            "prod_desc": "Pot stand, cork patterned",
            "prod_dimensions": {
                "Diameter": "19 cm",
                "Package quantity": "3 pack"
            },
            "packaging": [
                "V\u00c5RFINT",
                "Pot stand",
                "Article no.:",
                "704.859.56",
                "Height: 3 cm",
                "Weight: 0.22 kg",
                "Diameter: 19 cm",
                "Package(s): 1"
            ],
            "prod_details": "You can combine several pot stands to fit larger pots and dishes.",
            "sustainability": "By using a renewable material like cork in this product, we avoid using fossil or finite materials.",
            "images": [
                "data/cookware/varfint-pot-stand-cork-patterned-70485956/varfint-pot-stand-cork-patterned-70485956-0.JPG",
                "data/cookware/varfint-pot-stand-cork-patterned-70485956/varfint-pot-stand-cork-patterned-70485956-1.JPG",
                "data/cookware/varfint-pot-stand-cork-patterned-70485956/varfint-pot-stand-cork-patterned-70485956-2.JPG",
                "data/cookware/varfint-pot-stand-cork-patterned-70485956/varfint-pot-stand-cork-patterned-70485956-3.JPG"
            ],
            "materials": "Cork,Wipe clean with a damp cloth."
        },
        "200": {
            "id": 200,
            "prod_name": "VARDAGEN",
            "prod_price": "12",
            "prod_desc": "Cook's knife, dark grey",
            "prod_dimensions": {
                "Length of knife blade": "16 cm"
            },
            "packaging": [
                "VARDAGEN",
                "Cook's knife",
                "Article no.:",
                "802.947.20",
                "Width: 7 cm",
                "Height: 2 cm",
                "Length: 36 cm",
                "Weight: 0.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "The sturdy blade makes it easier to divide and chop, for example, meat and root vegetables. Made of molybdenum/vanadium stainless steel, which is why the knife stays sharp for a very long time. The knife's tang runs through the length of the handle, making it very wear-resistant and balanced. Wash this product before using it for the first time.",
            "sustainability": "",
            "images": [
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-0.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-1.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-2.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-3.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-4.JPG",
                "data/cookware/vardagen-cooks-knife-dark-grey-80294720/vardagen-cooks-knife-dark-grey-80294720-5.JPG"
            ],
            "materials": "Blade/ Rivet:,Stainless steel,Handle:,Acetal plastic,Handwash only."
        }
    },
    "wardrobes": {
        "0": {
            "id": 0,
            "prod_name": "BRIMNES",
            "prod_price": "150",
            "prod_desc": "Wardrobe with 3 doors, white",
            "prod_dimensions": {
                "Width": "117 cm",
                "Depth": "50 cm",
                "Height": "190 cm"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "BRIMNES",
                "Wardrobe with 3 doors",
                "Article no.:",
                "404.079.22",
                "This product has multiple packages.",
                "Width: 51 cm",
                "Height: 6 cm",
                "Length: 194 cm",
                "Weight: 31.00 kg",
                "Package(s): 1",
                "Width: 51 cm",
                "Height: 6 cm",
                "Length: 189 cm",
                "Weight: 31.00 kg",
                "Package(s): 1",
                "Width: 51 cm",
                "Height: 6 cm",
                "Length: 160 cm",
                "Weight: 25.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "Of course your home should be a safe place for the entire family. That\u2019s why a safety fitting is included so that you can attach the wardrobe to the wall. The mirror door can be placed on the left side, right side or in the middle. You save space with a mirror door, because you don't need a separate mirror. Adjustable shelves make it easy to customise the space according to your needs. If you want to organise inside, you can complement with interior accessories from the SKUBB series. Adjustable hinges ensure that the doors hang straight. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail included. 3 adjustable shelves and 1 fixed shelf included. Handles included. Interior accessories  that help you organise inside your wardrobe are sold separately. Combines with other furniture in the BRIMNES series.",
            "sustainability": "",
            "images": [
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-0.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-1.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-2.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-3.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-4.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-5.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-6.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-7.JPG",
                "data/wardrobes/brimnes-wardrobe-with-3-doors-white-40407922/brimnes-wardrobe-with-3-doors-white-40407922-8.JPG"
            ],
            "materials": "Side panel/ Top panel/ Partition/ Bottom panel/ Shelf/ Plinth front/ Door frame:,Particleboard, Paper foil,Back panel/ Door panel:,Fibreboard, Paper foil,Plinth back:,Particleboard,Mirror:,Glass, Fibreboard, Paper foil,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "1": {
            "id": 1,
            "prod_name": "KLEPPSTAD",
            "prod_price": "99",
            "prod_desc": "Wardrobe with 3 doors, white",
            "prod_dimensions": {
                "Width": "117 cm",
                "Depth": "55 cm",
                "Height": "176 cm"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "KLEPPSTAD",
                "Wardrobe with 3 doors",
                "Article no.:",
                "004.417.58",
                "This product has multiple packages.",
                "Width: 56 cm",
                "Height: 7 cm",
                "Length: 173 cm",
                "Weight: 30.90 kg",
                "Package(s): 1",
                "Width: 56 cm",
                "Height: 5 cm",
                "Length: 173 cm",
                "Weight: 20.30 kg",
                "Package(s): 1",
                "Width: 56 cm",
                "Height: 5 cm",
                "Length: 181 cm",
                "Weight: 28.00 kg",
                "Package(s): 1"
            ],
            "prod_details": "Maximise your storage and create a coordinated look by building your own KLEPPSTAD wardrobe combination.  Additional KLEPPSTAD shelves can be purchased to customise your storage solution to your personal needs. The clothes rail holds about 20 shirts on hangers. One shelf holds about 10 pairs of folded trousers or 20 T-shirts. May be completed with up to 2 additional KLEPPSTAD shelves.",
            "sustainability": "",
            "images": [
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-0.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-1.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-2.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-3.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-4.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-3-doors-white-00441758/kleppstad-wardrobe-with-3-doors-white-00441758-5.JPG"
            ],
            "materials": "Top panel/ Bottom panel/ Side panel/ Shelf/ Plinth/ Door:,Particleboard, Paper foil,Back panel:,Fibreboard, Printed acrylic paint,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "2": {
            "id": 2,
            "prod_name": "PAX",
            "prod_price": "230",
            "prod_desc": "Wardrobe, white",
            "prod_dimensions": {
                "Width": "175 cm",
                "Depth": "58 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 13 packages.",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "902.568.93",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 49 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "402.568.95",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 74 cm",
                "Weight: 0.43 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 4",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 2",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.64",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 221 cm",
                "Weight: 41.68 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "102.463.32",
                "Width: 57 cm",
                "Height: 6 cm",
                "Length: 75 cm",
                "Weight: 7.63 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "902.779.61",
                "Width: 58 cm",
                "Height: 2 cm",
                "Length: 73 cm",
                "Weight: 5.02 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. If you want to complete your PAX frame with a sliding door, the minimum ceiling height required is 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-s69128567/pax-wardrobe-white-s69128567-0.JPG",
                "data/wardrobes/pax-wardrobe-white-s69128567/pax-wardrobe-white-s69128567-1.JPG",
                "data/wardrobes/pax-wardrobe-white-s69128567/pax-wardrobe-white-s69128567-2.JPG"
            ],
            "materials": "Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Wardrobe,Wipe clean with a mild soapy solution.,Clothes rail/shelf/wardrobe frame/drawer,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "4": {
            "id": 4,
            "prod_name": "KLEPPSTAD",
            "prod_price": "115",
            "prod_desc": "Wardrobe with sliding doors, white",
            "prod_dimensions": {
                "Width": "117 cm",
                "Depth": "55 cm",
                "Height": "176 cm"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "KLEPPSTAD",
                "Wardrobe with sliding doors",
                "Article no.:",
                "904.372.38",
                "This product has multiple packages.",
                "Width: 58 cm",
                "Height: 5 cm",
                "Length: 176 cm",
                "Weight: 25.25 kg",
                "Package(s): 1",
                "Width: 59 cm",
                "Height: 4 cm",
                "Length: 174 cm",
                "Weight: 24.75 kg",
                "Package(s): 1",
                "Width: 56 cm",
                "Height: 5 cm",
                "Length: 181 cm",
                "Weight: 26.70 kg",
                "Package(s): 1"
            ],
            "prod_details": "The clothes rail holds about 10-12 shirts on hangers. One shelf holds about 20 pairs of folded trousers or 40 T-shirts. May be completed with up to 1 additional KLEPPSTAD shelf.",
            "sustainability": "",
            "images": [
                "data/wardrobes/kleppstad-wardrobe-with-sliding-doors-white-90437238/kleppstad-wardrobe-with-sliding-doors-white-90437238-0.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-sliding-doors-white-90437238/kleppstad-wardrobe-with-sliding-doors-white-90437238-1.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-sliding-doors-white-90437238/kleppstad-wardrobe-with-sliding-doors-white-90437238-2.JPG"
            ],
            "materials": "Top panel/ Bottom panel/ Side panel/ Shelf/ Plinth/ Door:,Particleboard, Paper foil,Back panel:,Fibreboard, Printed acrylic paint,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "5": {
            "id": 5,
            "prod_name": "KLEPPSTAD",
            "prod_price": "75",
            "prod_desc": "Wardrobe with 2 doors, white",
            "prod_dimensions": {
                "Width": "79 cm",
                "Depth": "55 cm",
                "Height": "176 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "KLEPPSTAD",
                "Wardrobe with 2 doors",
                "Article no.:",
                "804.372.34",
                "This product has multiple packages.",
                "Width: 56 cm",
                "Height: 6 cm",
                "Length: 181 cm",
                "Weight: 24.30 kg",
                "Package(s): 1",
                "Width: 56 cm",
                "Height: 6 cm",
                "Length: 181 cm",
                "Weight: 29.25 kg",
                "Package(s): 1"
            ],
            "prod_details": "Maximise your storage and create a coordinated look by building your own KLEPPSTAD wardrobe combination.  Additional KLEPPSTAD shelves can be purchased to customise your storage solution to your personal needs. The clothes rail holds about 20 shirts on hangers. One shelf holds about 20 pairs of folded trousers or 40 T-shirts. May be completed with up to 1 additional KLEPPSTAD shelf.",
            "sustainability": "",
            "images": [
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-0.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-1.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-2.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-3.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-4.JPG",
                "data/wardrobes/kleppstad-wardrobe-with-2-doors-white-80437234/kleppstad-wardrobe-with-2-doors-white-80437234-5.JPG"
            ],
            "materials": "Top panel/ Bottom panel/ Side panel/ Shelf/ Plinth/ Door:,Particleboard, Paper foil,Back panel:,Fibreboard, Printed acrylic paint,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "6": {
            "id": 6,
            "prod_name": "SONGESAND",
            "prod_price": "179",
            "prod_desc": "Wardrobe, white",
            "prod_dimensions": {
                "Width": "120 cm",
                "Depth": "60 cm",
                "Height": "191 cm"
            },
            "packaging": [
                "This product comes as 4 packages.",
                "SONGESAND",
                "Wardrobe",
                "Article no.:",
                "903.473.51",
                "This product has multiple packages.",
                "Width: 62 cm",
                "Height: 5 cm",
                "Length: 196 cm",
                "Weight: 26.50 kg",
                "Package(s): 1",
                "Width: 62 cm",
                "Height: 4 cm",
                "Length: 198 cm",
                "Weight: 29.00 kg",
                "Package(s): 1",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 193 cm",
                "Weight: 21.00 kg",
                "Package(s): 1",
                "Width: 54 cm",
                "Height: 4 cm",
                "Length: 186 cm",
                "Weight: 21.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "You save space with a mirror door, because you don't need a separate mirror. Adjustable shelves and clothes rails make it easy for you to customise the space according to your needs. Complete with boxes and dividers to make it easier to keep track of smaller things. STUK, SKUBB and STORSTABBE storage series have items which are perfectly suited for this. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 3 adjustable shelves and 2 clothes rails included. Handles included. Interior accessories  that help you organise inside your wardrobe are sold separately. The small clothes rail holds about 10 shirts on hangers. The big clothes rail holds about 25 shirts on hangers.",
            "sustainability": "",
            "images": [
                "data/wardrobes/songesand-wardrobe-white-90347351/songesand-wardrobe-white-90347351-0.JPG",
                "data/wardrobes/songesand-wardrobe-white-90347351/songesand-wardrobe-white-90347351-1.JPG",
                "data/wardrobes/songesand-wardrobe-white-90347351/songesand-wardrobe-white-90347351-2.JPG",
                "data/wardrobes/songesand-wardrobe-white-90347351/songesand-wardrobe-white-90347351-3.JPG"
            ],
            "materials": "Top panel/ Side panel:,Particleboard, Paper foil, Plastic edging,Bottom panel/ Partition/ Plinth back/ Support rail, back/ Shelf:,Particleboard, Paper foil,Back panel:,Fibreboard,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel/ Plinth front/ Support rail, front:,Fibreboard, Paper foil,Mirror:,Glass,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "7": {
            "id": 7,
            "prod_name": "PAX",
            "prod_price": "300",
            "prod_desc": "Wardrobe, white/Hasvik white",
            "prod_dimensions": {
                "Width": "200 cm",
                "Depth": "66 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 10 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2",
                "HASVIK",
                "Pair of sliding doors",
                "Article no.:",
                "903.911.36",
                "This product has multiple packages.",
                "Width: 53 cm",
                "Height: 5 cm",
                "Length: 201 cm",
                "Weight: 17.65 kg",
                "Package(s): 1",
                "Width: 53 cm",
                "Height: 5 cm",
                "Length: 201 cm",
                "Weight: 17.65 kg",
                "Package(s): 1",
                "Width: 26 cm",
                "Height: 7 cm",
                "Length: 204 cm",
                "Weight: 5.70 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing device",
                "Article no.:",
                "503.274.54",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.47 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-closing device catches the running doors so that they close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s89180597/pax-wardrobe-white-hasvik-white-s89180597-0.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s89180597/pax-wardrobe-white-hasvik-white-s89180597-1.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s89180597/pax-wardrobe-white-hasvik-white-s89180597-2.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s89180597/pax-wardrobe-white-hasvik-white-s89180597-3.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s89180597/pax-wardrobe-white-hasvik-white-s89180597-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Pair of sliding doors,Board on frame:,Particleboard, Fibreboard, Plastic edging, Acrylic paint,Filling material:,Honeycomb structure paper filling (min. 70% recycled),Cover strip/ Rail:,Aluminium, Anodized,Soft closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Shelf,Particleboard, Paper foil,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/pair of sliding doors/soft closing device/shelf/clothes rail,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "9": {
            "id": 9,
            "prod_name": "BRIMNES",
            "prod_price": "115",
            "prod_desc": "Wardrobe with 2 doors, white",
            "prod_dimensions": {
                "Width": "78 cm",
                "Depth": "50 cm",
                "Height": "190 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "BRIMNES",
                "Wardrobe with 2 doors",
                "Article no.:",
                "404.004.78",
                "This product has multiple packages.",
                "Width: 51 cm",
                "Height: 7 cm",
                "Length: 194 cm",
                "Weight: 34.00 kg",
                "Package(s): 1",
                "Width: 49 cm",
                "Height: 6 cm",
                "Length: 194 cm",
                "Weight: 30.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "Of course your home should be a safe place for the entire family. That\u2019s why a safety fitting is included so that you can attach the wardrobe to the wall. Perfect for folded as well as long and short hanging garments. If you want to organise inside you can complement with SKUBB box 3-pack. Adjustable hinges ensure that the doors hang straight. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail, 1 fixed and 1 adjustable shelf included. Handles included. Interior accessories  that help you organise inside your wardrobe are sold separately. Combines with other furniture in the BRIMNES series. The clothes rail holds about 20 shirts on hangers. One shelf holds about 10 pairs of folded trousers or 20 T-shirts.",
            "sustainability": "",
            "images": [
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-0.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-1.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-2.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-3.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-4.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-5.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-6.JPG",
                "data/wardrobes/brimnes-wardrobe-with-2-doors-white-40400478/brimnes-wardrobe-with-2-doors-white-40400478-7.JPG"
            ],
            "materials": "Side panel/ Top panel/ Partition/ Back/ Bottom panel/ Shelf/ Plinth front/ Door frame:,Particleboard, Paper foil,Back panel/ Door panel:,Fibreboard, Paper foil,Plinth back:,Particleboard,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "10": {
            "id": 10,
            "prod_name": "GODISHUS",
            "prod_price": "55",
            "prod_desc": "Wardrobe, white",
            "prod_dimensions": {
                "Width": "60 cm",
                "Depth": "51 cm",
                "Height": "178 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "GODISHUS",
                "Wardrobe",
                "Article no.:",
                "504.224.94",
                "This product has multiple packages.",
                "Width: 41 cm",
                "Height: 5 cm",
                "Length: 178 cm",
                "Weight: 15.00 kg",
                "Package(s): 1",
                "Width: 54 cm",
                "Height: 5 cm",
                "Length: 180 cm",
                "Weight: 29.00 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can position the shelf and clothes rail in two different ways \u2013 clothes rail at the top and shelf down below, or both together at the top of the wardrobe. Deep enough to hold standard-sized adult hangers. With the included colourful stickers, you can quickly label the doors in your own personal way. You can also write with chalk on the sticker to keep track of where you have your things. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately.",
            "sustainability": "",
            "images": [
                "data/wardrobes/godishus-wardrobe-white-50422494/godishus-wardrobe-white-50422494-0.JPG",
                "data/wardrobes/godishus-wardrobe-white-50422494/godishus-wardrobe-white-50422494-1.JPG",
                "data/wardrobes/godishus-wardrobe-white-50422494/godishus-wardrobe-white-50422494-2.JPG",
                "data/wardrobes/godishus-wardrobe-white-50422494/godishus-wardrobe-white-50422494-3.JPG",
                "data/wardrobes/godishus-wardrobe-white-50422494/godishus-wardrobe-white-50422494-4.JPG"
            ],
            "materials": "Side panel/ Bottom panel/ Top panel/ Shelf:,Particleboard, Plastic edging, Melamine foil,Back panel:,Fibreboard, Acrylic paint,Door:,Particleboard, Melamine foil, Plastic edging,Wipe clean with a damp cloth.,Wipe clean with a dry cloth."
        },
        "11": {
            "id": 11,
            "prod_name": "PAX / VIKEDAL",
            "prod_price": "312",
            "prod_desc": "Wardrobe combination, white/mirror glass",
            "prod_dimensions": {
                "Width": "150.0 cm",
                "Depth": "60.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 18 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 1",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "700.233.19",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 207 cm",
                "Weight: 19.91 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "902.568.93",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 49 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Valet hanger",
                "Article no.:",
                "702.569.31",
                "Width: 9 cm",
                "Height: 5 cm",
                "Length: 16 cm",
                "Weight: 0.11 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. Open this solution in the PAX planner to change it to fit your needs. Another drawer? Less ones? Add a frame or change doors? No problems. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Hinges are needed for this product. They are included in the price but picked up separately. Interior accessories  that help you organise inside your wardrobe are sold separately. Handles included.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.",
            "images": [
                "data/wardrobes/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165-0.JPG",
                "data/wardrobes/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165-1.JPG",
                "data/wardrobes/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165/pax-vikedal-wardrobe-combination-white-mirror-glass-s49396165-2.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Valet hanger,Steel, Pigmented epoxy/polyester powder coating,Door,Wipe clean with a cloth dampened in water or window-cleaner.,Wipe dry with a clean cloth.,Wardrobe combination,Wipe clean with a mild soapy solution.,Wardrobe frame/pull-out rail for baskets/valet hanger/soft closing hinge/clothes rail/shelf/mesh basket,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "12": {
            "id": 12,
            "prod_name": "PAX",
            "prod_price": "335",
            "prod_desc": "Wardrobe, white/Bergsbo white",
            "prod_dimensions": {
                "Width": "150 cm",
                "Depth": "60 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 24 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 1",
                "BERGSBO",
                "Door",
                "Article no.:",
                "202.074.10",
                "Width: 51 cm",
                "Height: 3 cm",
                "Length: 203 cm",
                "Weight: 9.00 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Divider for frames",
                "Article no.:",
                "602.463.96",
                "Width: 58 cm",
                "Height: 7 cm",
                "Length: 83 cm",
                "Weight: 12.83 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 6",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "102.573.06",
                "Width: 44 cm",
                "Height: 16 cm",
                "Length: 54 cm",
                "Weight: 1.24 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-bergsbo-white-s39025599/pax-wardrobe-white-bergsbo-white-s39025599-0.JPG",
                "data/wardrobes/pax-wardrobe-white-bergsbo-white-s39025599/pax-wardrobe-white-bergsbo-white-s39025599-1.JPG",
                "data/wardrobes/pax-wardrobe-white-bergsbo-white-s39025599/pax-wardrobe-white-bergsbo-white-s39025599-2.JPG",
                "data/wardrobes/pax-wardrobe-white-bergsbo-white-s39025599/pax-wardrobe-white-bergsbo-white-s39025599-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Door frame:,Fibreboard, Plastic edging, Paper foil,Door panel:,Fibreboard, Paper foil,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Divider for frames,Particle- and fibreboard with honeycomb paper filling (100% recycled paper), Paper foil,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/door/soft closing hinge/clothes rail/divider for frames/pull-out rail for baskets/shelf/mesh basket,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "13": {
            "id": 13,
            "prod_name": "PAX",
            "prod_price": "455",
            "prod_desc": "Wardrobe, white/Flisberget light beige",
            "prod_dimensions": {
                "Width": "200 cm",
                "Depth": "60 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 22 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 2",
                "FLISBERGET",
                "Door",
                "Article no.:",
                "003.447.43",
                "Width: 50 cm",
                "Height: 3 cm",
                "Length: 203 cm",
                "Weight: 7.96 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "902.568.93",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 49 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "902.463.52",
                "Width: 58 cm",
                "Height: 6 cm",
                "Length: 100 cm",
                "Weight: 9.40 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out tray",
                "Article no.:",
                "702.463.86",
                "Width: 57 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 5.46 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 5"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Feeling even more organised? Complement the drawers with KOMPLEMENT boxes, they can be combined to fit perfectly so that you can utilize the drawer fully. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-flisberget-light-beige-s49304340/pax-wardrobe-white-flisberget-light-beige-s49304340-0.JPG",
                "data/wardrobes/pax-wardrobe-white-flisberget-light-beige-s49304340/pax-wardrobe-white-flisberget-light-beige-s49304340-1.JPG",
                "data/wardrobes/pax-wardrobe-white-flisberget-light-beige-s49304340/pax-wardrobe-white-flisberget-light-beige-s49304340-2.JPG",
                "data/wardrobes/pax-wardrobe-white-flisberget-light-beige-s49304340/pax-wardrobe-white-flisberget-light-beige-s49304340-3.JPG",
                "data/wardrobes/pax-wardrobe-white-flisberget-light-beige-s49304340/pax-wardrobe-white-flisberget-light-beige-s49304340-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Pull-out tray,Drawer front:,Solid hardwood, Foil, Melamine foil,Drawer side:,Fibreboard, Foil, Melamine foil,Drawer back/ Drawer bottom:,Fibreboard, Foil,Shelf,Particleboard, Paper foil,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/door/soft closing hinge/clothes rail/drawer/pull-out tray/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "14": {
            "id": 14,
            "prod_name": "SM\u00c5STAD / PLATSA",
            "prod_price": "150",
            "prod_desc": "Wardrobe, white white/with 3 drawers",
            "prod_dimensions": {
                "Depth": "55 cm",
                "Height": "180 cm",
                "Width": "60 cm"
            },
            "packaging": [
                "This product comes as 20 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "503.309.51",
                "Width: 56 cm",
                "Height: 7 cm",
                "Length: 187 cm",
                "Weight: 23.80 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Door",
                "Article no.:",
                "904.341.88",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 128 cm",
                "Weight: 7.92 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Drawer front",
                "Article no.:",
                "004.340.98",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 61 cm",
                "Weight: 1.02 kg",
                "Package(s): 2",
                "SM\u00c5STAD",
                "Drawer front",
                "Article no.:",
                "704.341.13",
                "Width: 30 cm",
                "Height: 2 cm",
                "Length: 61 cm",
                "Weight: 1.93 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Clothes rail",
                "Article no.:",
                "503.312.05",
                "Width: 4 cm",
                "Height: 3 cm",
                "Length: 65 cm",
                "Weight: 0.31 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Pull-out rail for baskets",
                "Article no.:",
                "103.311.94",
                "Width: 8 cm",
                "Height: 6 cm",
                "Length: 65 cm",
                "Weight: 0.44 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "903.311.66",
                "Width: 56 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 2.35 kg",
                "Package(s): 2",
                "HJ\u00c4LPA",
                "Soft closing hinge",
                "Article no.:",
                "903.828.82",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.11 kg",
                "Package(s): 4",
                "HJ\u00c4LPA",
                "Wire basket",
                "Article no.:",
                "403.311.83",
                "Width: 51 cm",
                "Height: 16 cm",
                "Length: 54 cm",
                "Weight: 1.43 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Hook for clothes rail",
                "Article no.:",
                "904.461.48",
                "Width: 9 cm",
                "Height: 4 cm",
                "Length: 16 cm",
                "Weight: 0.10 kg",
                "Package(s): 1",
                "KONSTRUERA",
                "Drawer without front",
                "Article no.:",
                "504.367.78",
                "Width: 53 cm",
                "Height: 3 cm",
                "Length: 55 cm",
                "Weight: 3.13 kg",
                "Package(s): 2",
                "KONSTRUERA",
                "Drawer without front",
                "Article no.:",
                "404.367.74",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 56 cm",
                "Weight: 4.58 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Hook and clip",
                "Article no.:",
                "104.369.78",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "Your child can use this wardrobe for many years since it is deep enough to hold adult-sized hangers and has an interior which you can move as your child grows. The doors have soft-closing hinges which make them close softly and quietly \u2013 even after a heated argument. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. 1 clothes rail, 2 shelves, 1 wire basket, 2 HJ\u00c4LPA hooks for clothes rail and 2 HJ\u00c4LPA hooks and clip are included. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. May be completed with UPPRYMD and RASSLA boxes - perfect for storing small things that have a tendency to disappear. Sold separately. May be completed with H\u00c4NGIG label holder to keep things organised and easier to find. Sold separately. Knobs and handles are sold separately.",
            "sustainability": "",
            "images": [
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-0.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-1.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-2.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-3.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-4.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-5.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190/smastad-platsa-wardrobe-white-white-with-3-drawers-s19389190-6.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door/ drawer front,Fibreboard, Acrylic paint,Clothes rail,Steel, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Epoxy/polyester powder coating,Wheel:,Acetal plastic,Soft closing hinge,Hinge:,Steel, Copper-plated,Soft closing device:,Acetal plastic,Wire basket,Steel, Epoxy/polyester powder coating,Hook for clothes rail/ hook and clip,Steel, Epoxy/polyester powder coating, Epoxy/polyester powder coating,Drawer without front,Drawer side/ Drawer back:,Particleboard, Plastic foil,Drawer bottom:,Fibreboard, Acrylic paint,Leg, adjustable,Steel, Polypropylene plastic, Galvanized"
        },
        "15": {
            "id": 15,
            "prod_name": "HAUGA",
            "prod_price": "179",
            "prod_desc": "Wardrobe with sliding doors, white",
            "prod_dimensions": {
                "Width": "118.0 cm",
                "Depth": "55.0 cm",
                "Height": "199.0 cm"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "HAUGA",
                "Wardrobe with sliding doors",
                "Article no.:",
                "604.569.16",
                "This product has multiple packages.",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 203 cm",
                "Weight: 22.00 kg",
                "Package(s): 1",
                "Width: 62 cm",
                "Height: 6 cm",
                "Length: 204 cm",
                "Weight: 34.00 kg",
                "Package(s): 1",
                "Width: 62 cm",
                "Height: 6 cm",
                "Length: 204 cm",
                "Weight: 34.20 kg",
                "Package(s): 1"
            ],
            "prod_details": "Of course your home should be a safe place for the entire family. That\u2019s why a safety fitting is included so that you can attach the storage unit to the wall. Designed to be used both on its own throughout the home and is also a perfect fit with other furniture in the HAUGA series, either to coordinate the style or create bigger storage solutions. Maximise your storage and create a coordinated look by building your own HAUGA storage combination. A versatile piece of furniture that you can use in many different rooms in the home. Thanks to the distinctive look and smart design, furniture in the HAUGA series work well on their own and even better together. The flat, smooth sides create seamless units when pieces are placed next to each other. Perfect for folded as well as long and short hanging garments. Sliding doors allow more room for furniture because they don\u2019t take any space to open. You get a handy place to hang your bags, bathrobe and accessories on on the side of the wardrobe by adding SKOGSVIKEN hooks for door. The characteristic top shelf is a common feature in the entire HAUGA series and adds to the traditional style. Regardless if you use it for hats, boxes or decorations, the edge keeps your things in place. The frame is easy to assemble thanks to the construction with a wedge dowel that easily clicks into the pre-drilled holes. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. The clothes rail holds about 30 shirts on hangers.",
            "sustainability": "By using sawmill leftovers and scrap wood in the particle board in this product, we make use of whole trees and not only the trunks. That way, we take better care of resources.",
            "images": [
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-0.JPG",
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-1.JPG",
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-2.JPG",
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-3.JPG",
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-4.JPG",
                "data/wardrobes/hauga-wardrobe-with-sliding-doors-white-60456916/hauga-wardrobe-with-sliding-doors-white-60456916-5.JPG"
            ],
            "materials": "Side panel:,Particleboard, Paper foil, Plastic edging,Top panel/ Back rail/ Partition/ Bottom panel/ Shelf:,Particleboard, Paper foil,Back panel:,Fibreboard, Acrylic paint,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Wipe clean with a damp cloth.,Wipe dry with a clean cloth."
        },
        "16": {
            "id": 16,
            "prod_name": "PAX / GRIMO",
            "prod_price": "435",
            "prod_desc": "Wardrobe combination, white/Grimo grey",
            "prod_dimensions": {
                "Width": "200.0 cm",
                "Depth": "60.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 22 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 2",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "GRIMO",
                "Door",
                "Article no.:",
                "204.351.86",
                "Width: 50 cm",
                "Height: 3 cm",
                "Length: 203 cm",
                "Weight: 10.16 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "902.568.93",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 49 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "902.463.52",
                "Width: 58 cm",
                "Height: 6 cm",
                "Length: 100 cm",
                "Weight: 9.40 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out tray",
                "Article no.:",
                "702.463.86",
                "Width: 57 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 5.46 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 5"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Feeling even more organised? Complement the drawers with KOMPLEMENT boxes, they can be combined to fit perfectly so that you can utilize the drawer fully. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. GRIMO door is covered in a grey foil which matches perfectly with HAUGA series. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619-0.jpg",
                "data/wardrobes/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619-1.JPG",
                "data/wardrobes/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619/pax-grimo-wardrobe-combination-white-grimo-grey-s29386619-2.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Pull-out tray,Drawer front:,Solid hardwood, Foil, Melamine foil,Drawer side:,Fibreboard, Foil, Melamine foil,Drawer back/ Drawer bottom:,Fibreboard, Foil,Shelf,Particleboard, Paper foil,Wardrobe frame/door/soft closing hinge/clothes rail/drawer/pull-out tray/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "17": {
            "id": 17,
            "prod_name": "PAX / MEHAMN/AULI",
            "prod_price": "420",
            "prod_desc": "Wardrobe combination, white/mirror glass",
            "prod_dimensions": {
                "Width": "200.0 cm",
                "Depth": "66.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 14 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2",
                "MEHAMN",
                "4 panels for sliding door frame",
                "Article no.:",
                "004.211.85",
                "Width: 49 cm",
                "Height: 2 cm",
                "Length: 107 cm",
                "Weight: 7.15 kg",
                "Package(s): 1",
                "AULI",
                "4 panels for sliding door frame",
                "Article no.:",
                "102.112.76",
                "Width: 53 cm",
                "Height: 2 cm",
                "Length: 108 cm",
                "Weight: 15.30 kg",
                "Package(s): 1",
                "PAX",
                "Pair of sliding door frames w rail",
                "Article no.:",
                "002.224.21",
                "Width: 25 cm",
                "Height: 8 cm",
                "Length: 220 cm",
                "Weight: 17.10 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft opening/closing device",
                "Article no.:",
                "504.437.74",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-opening/closing devices catch the running doors so that they open and close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. This solution will hold at least 120 clothes hangers - and that's just what you will fit on the clothes rails! Turn the panel over to change the look \u2013 each side has a different finish. Go for a unified look or mix. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Two persons are needed for the assembly of this furniture. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 30 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,4 panels for sliding door frame,Product is possible to recycle or use for energy recovery, if available in your community.,Pair of sliding door frames w rail,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/wardrobes/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601-0.JPG",
                "data/wardrobes/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601-1.JPG",
                "data/wardrobes/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601-2.JPG",
                "data/wardrobes/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601-3.JPG",
                "data/wardrobes/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601/pax-mehamn-auli-wardrobe-combination-white-mirror-glass-s79330601-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,4 panels for sliding door frame,Fibreboard, Paper foil,Glass,Pair of sliding door frames w rail,Aluminium, Anodized,Soft opening/closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Wardrobe frame/4 panels for sliding door frame/pair of sliding door frames w rail/soft opening/closing device/clothes rail/mesh basket/pull-out rail for baskets/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "18": {
            "id": 18,
            "prod_name": "PAX / HASVIK",
            "prod_price": "290",
            "prod_desc": "Wardrobe combination, white",
            "prod_dimensions": {
                "Width": "150 cm",
                "Depth": "44 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 18 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "402.119.77",
                "Width: 38 cm",
                "Height: 8 cm",
                "Length: 222 cm",
                "Weight: 29.30 kg",
                "Package(s): 2",
                "HASVIK",
                "Pair of sliding doors",
                "Article no.:",
                "803.911.32",
                "This product has multiple packages.",
                "Width: 79 cm",
                "Height: 5 cm",
                "Length: 201 cm",
                "Weight: 23.20 kg",
                "Package(s): 1",
                "Width: 26 cm",
                "Height: 7 cm",
                "Length: 204 cm",
                "Weight: 5.00 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing device",
                "Article no.:",
                "503.274.54",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.47 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "804.464.55",
                "Width: 33 cm",
                "Height: 4 cm",
                "Length: 71 cm",
                "Weight: 0.99 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "102.573.11",
                "Width: 34 cm",
                "Height: 16 cm",
                "Length: 69 cm",
                "Weight: 1.31 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "602.632.44",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 47 cm",
                "Weight: 0.28 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.95",
                "Width: 35 cm",
                "Height: 2 cm",
                "Length: 73 cm",
                "Weight: 3.20 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Perfect where space is limited since the frame is narrow. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-closing device catches the running doors so that they close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 4 coats or 8 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-hasvik-wardrobe-combination-white-s79384260/pax-hasvik-wardrobe-combination-white-s79384260-0.JPG",
                "data/wardrobes/pax-hasvik-wardrobe-combination-white-s79384260/pax-hasvik-wardrobe-combination-white-s79384260-1.JPG",
                "data/wardrobes/pax-hasvik-wardrobe-combination-white-s79384260/pax-hasvik-wardrobe-combination-white-s79384260-2.JPG",
                "data/wardrobes/pax-hasvik-wardrobe-combination-white-s79384260/pax-hasvik-wardrobe-combination-white-s79384260-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Pair of sliding doors,Board on frame:,Particleboard, Fibreboard, Plastic edging, Acrylic paint,Filling material:,Honeycomb structure paper filling (min. 70% recycled),Cover strip/ Rail:,Aluminium, Anodized,Soft closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Frame:,Fibreboard, Paper foil,Clothes rail:,Steel, Epoxy powder coating,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Wardrobe combination,Wipe clean with a mild soapy solution.,Wardrobe frame/pair of sliding doors/soft closing device/clothes rail/mesh basket/pull-out rail for baskets/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "19": {
            "id": 19,
            "prod_name": "SUNDVIK",
            "prod_price": "150",
            "prod_desc": "Wardrobe, white",
            "prod_dimensions": {
                "Width": "80 cm",
                "Depth": "50 cm",
                "Height": "171 cm",
                "Free height under furniture": "18 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "SUNDVIK",
                "Wardrobe",
                "Article no.:",
                "102.696.96",
                "This product has multiple packages.",
                "Width: 50 cm",
                "Height: 9 cm",
                "Length: 167 cm",
                "Weight: 21.00 kg",
                "Package(s): 1",
                "Width: 52 cm",
                "Height: 10 cm",
                "Length: 82 cm",
                "Weight: 16.60 kg",
                "Package(s): 1"
            ],
            "prod_details": "Deep enough to hold standard-sized adult hangers. Doors with silent soft-closing damper. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail and 1 fixed shelf included. Combine with furniture in SUNDVIK series.",
            "sustainability": "",
            "images": [
                "data/wardrobes/sundvik-wardrobe-white-10269696/sundvik-wardrobe-white-10269696-0.JPG",
                "data/wardrobes/sundvik-wardrobe-white-10269696/sundvik-wardrobe-white-10269696-1.JPG",
                "data/wardrobes/sundvik-wardrobe-white-10269696/sundvik-wardrobe-white-10269696-2.JPG",
                "data/wardrobes/sundvik-wardrobe-white-10269696/sundvik-wardrobe-white-10269696-3.JPG",
                "data/wardrobes/sundvik-wardrobe-white-10269696/sundvik-wardrobe-white-10269696-4.JPG"
            ],
            "materials": "Basematerial/ Side frame/ Drawer front:,Solid pine, Stain, Clear acrylic lacquer,Frame/ Back panel:,Fibreboard, Paper foil,Door:,Solid pine, Solid pine, Stain, Clear acrylic lacquer,Drawer side/ Drawer back:,Particleboard, Plastic foil,Drawer bottom:,Fibreboard, Printed acrylic paint,Bottom panel:,Fibreboard,Stop fitting/ Clothes rail:,Solid pine,Top:,Solid pine, Clear acrylic lacquer, Stain,Shelf:,Solid pine, Clear acrylic lacquer,Wipe clean with a damp cloth.,Wipe clean with a dry cloth."
        },
        "20": {
            "id": 20,
            "prod_name": "TRYSIL",
            "prod_price": "150",
            "prod_desc": "Wardrobe, white/mirror glass",
            "prod_dimensions": {
                "Width": "79 cm",
                "Depth": "61 cm",
                "Height": "202 cm",
                "Plinth, height": "5.7 cm",
                "Max. load/shelf": "20 kg"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "TRYSIL",
                "Wardrobe",
                "Article no.:",
                "103.087.87",
                "This product has multiple packages.",
                "Width: 64 cm",
                "Height: 7 cm",
                "Length: 103 cm",
                "Weight: 18.80 kg",
                "Package(s): 1",
                "Width: 64 cm",
                "Height: 5 cm",
                "Length: 206 cm",
                "Weight: 27.12 kg",
                "Package(s): 1",
                "Width: 64 cm",
                "Height: 4 cm",
                "Length: 206 cm",
                "Weight: 29.90 kg",
                "Package(s): 1"
            ],
            "prod_details": "Sliding doors allow more room for furniture because they don\u2019t take any space to open. You save space with a mirror door, because you don't need a separate mirror. An adjustable shelf make it easy to customise the space according to your needs. If you want to organise inside, you can complement with interior accessories from the SKUBB series. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 adjustable shelf and 1 clothes rail included. Interior accessories  that help you organise inside your wardrobe are sold separately. Combines with other furniture in the TRYSIL series. The clothes rail holds about 20 shirts on hangers.",
            "sustainability": "",
            "images": [
                "data/wardrobes/trysil-wardrobe-white-mirror-glass-10308787/trysil-wardrobe-white-mirror-glass-10308787-0.JPG",
                "data/wardrobes/trysil-wardrobe-white-mirror-glass-10308787/trysil-wardrobe-white-mirror-glass-10308787-1.JPG",
                "data/wardrobes/trysil-wardrobe-white-mirror-glass-10308787/trysil-wardrobe-white-mirror-glass-10308787-2.JPG",
                "data/wardrobes/trysil-wardrobe-white-mirror-glass-10308787/trysil-wardrobe-white-mirror-glass-10308787-3.JPG",
                "data/wardrobes/trysil-wardrobe-white-mirror-glass-10308787/trysil-wardrobe-white-mirror-glass-10308787-4.JPG"
            ],
            "materials": "Top panel/ Side panel/ Bottom panel/ Plinth/ Partition/ Fixed shelf/ Adjustable shelf/ Door:,Particleboard, Paper foil,Back panel:,Fibreboard, Paper foil,Mirror:,Glass,Frame,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth.,Mirror glass,Wipe clean with a cloth dampened in water or window-cleaner.,Wipe dry with a clean cloth."
        },
        "21": {
            "id": 21,
            "prod_name": "PAX",
            "prod_price": "100",
            "prod_desc": "Wardrobe, white/Vikedal mirror glass",
            "prod_dimensions": {
                "Width": "50 cm",
                "Depth": "60 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 5 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 1",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "700.233.19",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 207 cm",
                "Weight: 19.91 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "902.568.93",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 49 cm",
                "Weight: 0.28 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Hinges are needed for this product. They are included in the price but picked up separately. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-vikedal-mirror-glass-s69127493/pax-wardrobe-white-vikedal-mirror-glass-s69127493-0.JPG",
                "data/wardrobes/pax-wardrobe-white-vikedal-mirror-glass-s69127493/pax-wardrobe-white-vikedal-mirror-glass-s69127493-1.JPG",
                "data/wardrobes/pax-wardrobe-white-vikedal-mirror-glass-s69127493/pax-wardrobe-white-vikedal-mirror-glass-s69127493-2.JPG",
                "data/wardrobes/pax-wardrobe-white-vikedal-mirror-glass-s69127493/pax-wardrobe-white-vikedal-mirror-glass-s69127493-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Door,Wipe clean with a cloth dampened in water or window-cleaner.,Wipe dry with a clean cloth.,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/soft closing hinge/clothes rail/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "22": {
            "id": 22,
            "prod_name": "PAX",
            "prod_price": "60",
            "prod_desc": "Wardrobe frame, white",
            "prod_dimensions": {
                "Width": "99.8 cm",
                "Frame, width": "100 cm",
                "Depth": "58.0 cm",
                "Height": "201.2 cm",
                "Frame, depth": "58 cm",
                "Frame, height": "201 cm"
            },
            "packaging": [
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. If you want to organise inside you can complement with interior organisers from the KOMPLEMENT series. Adjustable feet make it possible to compensate any irregularities in the floor. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. If you want to complete your PAX frame with a sliding door, the minimum ceiling height required is 205 cm. Doors, hinges and interiors are sold separately.",
            "sustainability": "At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-frame-white-20214566/pax-wardrobe-frame-white-20214566-0.JPG",
                "data/wardrobes/pax-wardrobe-frame-white-20214566/pax-wardrobe-frame-white-20214566-1.JPG",
                "data/wardrobes/pax-wardrobe-frame-white-20214566/pax-wardrobe-frame-white-20214566-2.JPG"
            ],
            "materials": "Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "23": {
            "id": 23,
            "prod_name": "PAX",
            "prod_price": "665",
            "prod_desc": "Wardrobe, white/Mehamn",
            "prod_dimensions": {
                "Width": "250.0 cm",
                "Depth": "66.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 40 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "602.145.69",
                "Width: 50 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 24.88 kg",
                "Package(s): 2",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.64",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 221 cm",
                "Weight: 41.68 kg",
                "Package(s): 2",
                "PAX",
                "Pair of sliding door frames w rail",
                "Article no.:",
                "802.224.17",
                "Width: 25 cm",
                "Height: 8 cm",
                "Length: 201 cm",
                "Weight: 15.20 kg",
                "Package(s): 1",
                "MEHAMN",
                "4 panels for sliding door frame",
                "Article no.:",
                "904.211.95",
                "Width: 50 cm",
                "Height: 2 cm",
                "Length: 83 cm",
                "Weight: 5.25 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Soft opening/closing device",
                "Article no.:",
                "504.437.74",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "402.568.95",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 74 cm",
                "Weight: 0.43 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "302.467.22",
                "Width: 39 cm",
                "Height: 4 cm",
                "Length: 45 cm",
                "Weight: 4.26 kg",
                "Package(s): 10",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "202.573.15",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 69 cm",
                "Weight: 1.74 kg",
                "Package(s): 6",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 6",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "402.779.92",
                "Width: 36 cm",
                "Height: 2 cm",
                "Length: 48 cm",
                "Weight: 2.00 kg",
                "Package(s): 6",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "902.779.61",
                "Width: 58 cm",
                "Height: 2 cm",
                "Length: 73 cm",
                "Weight: 5.02 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-opening/closing devices catch the running doors so that they open and close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Deep frames that will swallow a lot of clothes. Enough depth to hang clothes on the side and plenty of space in drawers. Lots of drawers which means you can separate everything down to the tiniest sock and save some time looking for stuff. Feeling even more organised? Complement the drawers with KOMPLEMENT boxes, they can be combined to fit perfectly so that you can utilize the drawer fully. Turn the panel over to change the look \u2013 each side has a different finish. Go for a unified look or mix. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 30 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Pair of sliding door frames w rail,Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-mehamn-s19305794/pax-wardrobe-white-mehamn-s19305794-0.JPG",
                "data/wardrobes/pax-wardrobe-white-mehamn-s19305794/pax-wardrobe-white-mehamn-s19305794-1.JPG",
                "data/wardrobes/pax-wardrobe-white-mehamn-s19305794/pax-wardrobe-white-mehamn-s19305794-2.JPG",
                "data/wardrobes/pax-wardrobe-white-mehamn-s19305794/pax-wardrobe-white-mehamn-s19305794-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Pair of sliding door frames w rail,Aluminium, Anodized,4 panels for sliding door frame,Fibreboard, Paper foil,Soft opening/closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Wardrobe frame/shelf/pair of sliding door frames w rail/4 panels for sliding door frame/soft opening/closing device/clothes rail/drawer/mesh basket/pull-out rail for baskets,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "24": {
            "id": 24,
            "prod_name": "SM\u00c5STAD / PLATSA",
            "prod_price": "97",
            "prod_desc": "Wardrobe, white/white",
            "prod_dimensions": {
                "Depth": "55 cm",
                "Height": "123 cm",
                "Width": "60 cm"
            },
            "packaging": [
                "This product comes as 13 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "503.309.46",
                "Width: 56 cm",
                "Height: 7 cm",
                "Length: 127 cm",
                "Weight: 17.00 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Door",
                "Article no.:",
                "904.341.88",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 128 cm",
                "Weight: 7.92 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Top for storage module",
                "Article no.:",
                "504.728.27",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 68 cm",
                "Weight: 3.90 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Clothes rail",
                "Article no.:",
                "503.312.05",
                "Width: 4 cm",
                "Height: 3 cm",
                "Length: 65 cm",
                "Weight: 0.31 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Pull-out rail for baskets",
                "Article no.:",
                "103.311.94",
                "Width: 8 cm",
                "Height: 6 cm",
                "Length: 65 cm",
                "Weight: 0.44 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "903.311.66",
                "Width: 56 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 2.35 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Soft closing hinge",
                "Article no.:",
                "903.828.82",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.11 kg",
                "Package(s): 4",
                "HJ\u00c4LPA",
                "Wire basket",
                "Article no.:",
                "403.311.83",
                "Width: 51 cm",
                "Height: 16 cm",
                "Length: 54 cm",
                "Weight: 1.43 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Hook and clip",
                "Article no.:",
                "104.369.78",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "This wardrobe is adapted to a younger child's height and motor skills so that they can reach and hang back their clothes on their own. The wardrobe has interiors which you can move and adjust based on your child\u2019s needs.  Stands steady also on uneven floors since adjustable feet are included. The doors have soft-closing hinges which make them close softly and quietly.  WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail, 1 shelf, 1 wire basket and 2 L\u00c4TTHET hooks and clip are included. May be completed with HJ\u00c4LPA multi-use hanger. Knobs and handles are sold separately.",
            "sustainability": "",
            "images": [
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s39388321/smastad-platsa-wardrobe-white-white-s39388321-0.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s39388321/smastad-platsa-wardrobe-white-white-s39388321-1.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s39388321/smastad-platsa-wardrobe-white-white-s39388321-2.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door/ top for storage module,Fibreboard, Acrylic paint,Clothes rail,Steel, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Epoxy/polyester powder coating,Wheel:,Acetal plastic,Soft closing hinge,Hinge:,Steel, Copper-plated,Soft closing device:,Acetal plastic,Wire basket,Steel, Epoxy/polyester powder coating,Hook and clip,Steel, Epoxy/polyester powder coating, Epoxy/polyester powder coating,Leg, adjustable,Steel, Polypropylene plastic, Galvanized"
        },
        "25": {
            "id": 25,
            "prod_name": "PAX",
            "prod_price": "305",
            "prod_desc": "Corner wardrobe, white/Fardal Vikedal",
            "prod_dimensions": {
                "Height": "201.0 cm",
                "Width right": "87.9 cm",
                "Width left": "110.5 cm"
            },
            "packaging": [
                "This product comes as 8 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.64",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 221 cm",
                "Weight: 41.68 kg",
                "Package(s): 1",
                "PAX",
                "Add-on corner unit with 4 shelves",
                "Article no.:",
                "403.469.38",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 8 cm",
                "Length: 206 cm",
                "Weight: 21.30 kg",
                "Package(s): 1",
                "Width: 40 cm",
                "Height: 4 cm",
                "Length: 207 cm",
                "Weight: 17.50 kg",
                "Package(s): 1",
                "FARDAL",
                "Door",
                "Article no.:",
                "901.905.24",
                "Width: 51 cm",
                "Height: 2 cm",
                "Length: 206 cm",
                "Weight: 11.93 kg",
                "Package(s): 1",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "700.233.19",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 207 cm",
                "Weight: 19.91 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge f corner section",
                "Article no.:",
                "103.684.89",
                "Width: 27 cm",
                "Height: 5 cm",
                "Length: 30 cm",
                "Weight: 1.36 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "402.568.95",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 74 cm",
                "Weight: 0.43 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 30 shirts on hangers. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,At least 50% (weight) of this product is made from renewable materials.,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.",
            "images": [
                "data/wardrobes/pax-corner-wardrobe-white-fardal-vikedal-s19218339/pax-corner-wardrobe-white-fardal-vikedal-s19218339-0.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-fardal-vikedal-s19218339/pax-corner-wardrobe-white-fardal-vikedal-s19218339-1.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-fardal-vikedal-s19218339/pax-corner-wardrobe-white-fardal-vikedal-s19218339-2.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-fardal-vikedal-s19218339/pax-corner-wardrobe-white-fardal-vikedal-s19218339-3.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-fardal-vikedal-s19218339/pax-corner-wardrobe-white-fardal-vikedal-s19218339-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Add-on corner unit with 4 shelves,Particleboard, Fibreboard, Honeycomb structure paper filling (100% recycled), Plastic edging, Plastic edging, Paper foil,Door,Particleboard, Plastic foil, Plastic edging,Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge f corner section,Plastic parts:,Acetal plastic,Basematerial:,Steel, Nickel-plated,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Wardrobe frame/add-on corner unit with 4 shelves/door/soft closing hinge f corner section/clothes rail,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "26": {
            "id": 26,
            "prod_name": "PAX / FORSAND/VIKEDAL",
            "prod_price": "290",
            "prod_desc": "Wardrobe combination, white stained oak effect/mirror glass",
            "prod_dimensions": {
                "Width": "150.0 cm",
                "Depth": "60.0 cm",
                "Height": "236.4 cm"
            },
            "packaging": [
                "This product comes as 14 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "301.839.89",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 245 cm",
                "Weight: 53.75 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "901.839.91",
                "Width: 61 cm",
                "Height: 7 cm",
                "Length: 245 cm",
                "Weight: 44.16 kg",
                "Package(s): 1",
                "FORSAND",
                "Door",
                "Article no.:",
                "304.349.64",
                "Width: 50 cm",
                "Height: 2 cm",
                "Length: 239 cm",
                "Weight: 10.35 kg",
                "Package(s): 2",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "300.233.21",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 243 cm",
                "Weight: 22.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "302.145.04",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.40 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "102.779.84",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.81",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 237 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.,Soft closing hinge,Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/wardrobes/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311-0.JPG",
                "data/wardrobes/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311-1.JPG",
                "data/wardrobes/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311-2.JPG",
                "data/wardrobes/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311/pax-forsand-vikedal-wardrobe-combination-white-stained-oak-effect-mirror-glass-s69329311-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Board on frame:,Particleboard, Fibreboard, ABS plastic, Paper foil,Filling material:,Honeycomb structure paper filling (100% recycled),Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Wardrobe frame/door/soft closing hinge/clothes rail/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "27": {
            "id": 27,
            "prod_name": "PAX",
            "prod_price": "170",
            "prod_desc": "Wardrobe combination, white",
            "prod_dimensions": {
                "Width": "150.0 cm",
                "Depth": "58.0 cm",
                "Height": "201.0 cm"
            },
            "packaging": [
                "This product comes as 14 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "102.573.06",
                "Width: 44 cm",
                "Height: 16 cm",
                "Length: 54 cm",
                "Weight: 1.24 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. If you want to complete your PAX frame with a sliding door, the minimum ceiling height required is 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-combination-white-s29385672/pax-wardrobe-combination-white-s29385672-0.JPG",
                "data/wardrobes/pax-wardrobe-combination-white-s29385672/pax-wardrobe-combination-white-s29385672-1.JPG",
                "data/wardrobes/pax-wardrobe-combination-white-s29385672/pax-wardrobe-combination-white-s29385672-2.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Wardrobe frame/clothes rail/mesh basket/pull-out rail for baskets/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "28": {
            "id": 28,
            "prod_name": "HAUGA",
            "prod_price": "437",
            "prod_desc": "Wardrobe combination, white",
            "prod_dimensions": {
                "Depth": "55.0 cm",
                "Height": "199.0 cm",
                "Width": "258.0 cm"
            },
            "packaging": [
                "This product comes as 7 packages.",
                "HAUGA",
                "Open wardrobe with 3 drawers",
                "Article no.:",
                "404.569.22",
                "This product has multiple packages.",
                "Width: 45 cm",
                "Height: 16 cm",
                "Length: 74 cm",
                "Weight: 28.60 kg",
                "Package(s): 2",
                "Width: 47 cm",
                "Height: 8 cm",
                "Length: 121 cm",
                "Weight: 23.00 kg",
                "Package(s): 2",
                "HAUGA",
                "Wardrobe with sliding doors",
                "Article no.:",
                "604.569.16",
                "This product has multiple packages.",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 203 cm",
                "Weight: 22.00 kg",
                "Package(s): 1",
                "Width: 62 cm",
                "Height: 6 cm",
                "Length: 204 cm",
                "Weight: 34.00 kg",
                "Package(s): 1",
                "Width: 62 cm",
                "Height: 6 cm",
                "Length: 204 cm",
                "Weight: 34.20 kg",
                "Package(s): 1"
            ],
            "prod_details": "Of course your home should be a safe place for the entire family. That\u2019s why a safety fitting is included so that you can attach the storage unit to the wall. Hide or display your things by combining open and closed storage. You get a good overview and can easily reach your clothes. Perfect for folded as well as long and short hanging garments. You get a handy place to hang your bags, bathrobe and accessories on on the side of the wardrobe by adding SKOGSVIKEN hooks for door. Additional HAUGA shelf can be purchased to customise your storage solution to your personal needs. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Extra shelf is sold separately. The drawer holds about 12 pairs of folded trousers or 20 T-shirts.",
            "sustainability": "Wardrobe with sliding doors,By using sawmill leftovers and scrap wood in the particle board in this product, we make use of whole trees and not only the trunks. That way, we take better care of resources.",
            "images": [
                "data/wardrobes/hauga-wardrobe-combination-white-s79388164/hauga-wardrobe-combination-white-s79388164-0.JPG",
                "data/wardrobes/hauga-wardrobe-combination-white-s79388164/hauga-wardrobe-combination-white-s79388164-1.JPG",
                "data/wardrobes/hauga-wardrobe-combination-white-s79388164/hauga-wardrobe-combination-white-s79388164-2.JPG",
                "data/wardrobes/hauga-wardrobe-combination-white-s79388164/hauga-wardrobe-combination-white-s79388164-3.JPG",
                "data/wardrobes/hauga-wardrobe-combination-white-s79388164/hauga-wardrobe-combination-white-s79388164-4.JPG"
            ],
            "materials": "Open wardrobe with 3 drawers,Side panel/ Drawer front:,Particleboard, Paper foil, Plastic edging,Top panel/ Top shelf/ Back rail/ Bottom panel:,Particleboard, Paper foil,Back panel/ Drawer bottom:,Fibreboard, Acrylic paint,Drawer side/ Drawer back:,Particleboard, Plastic foil,Wardrobe with sliding doors,Side panel:,Particleboard, Paper foil, Plastic edging,Top panel/ Back rail/ Partition/ Bottom panel/ Shelf:,Particleboard, Paper foil,Back panel:,Fibreboard, Acrylic paint,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Open wardrobe with 3 drawers/wardrobe with sliding doors,Wipe clean with a damp cloth.,Wipe dry with a clean cloth."
        },
        "29": {
            "id": 29,
            "prod_name": "SM\u00c5STAD / PLATSA",
            "prod_price": "143",
            "prod_desc": "Wardrobe, white white/with 4 drawers",
            "prod_dimensions": {
                "Depth": "55 cm",
                "Height": "180 cm",
                "Width": "60 cm"
            },
            "packaging": [
                "This product comes as 18 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "503.309.51",
                "Width: 56 cm",
                "Height: 7 cm",
                "Length: 187 cm",
                "Weight: 23.80 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Door",
                "Article no.:",
                "204.341.63",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 98 cm",
                "Weight: 5.80 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Drawer front",
                "Article no.:",
                "004.340.98",
                "Width: 15 cm",
                "Height: 2 cm",
                "Length: 61 cm",
                "Weight: 1.02 kg",
                "Package(s): 2",
                "SM\u00c5STAD",
                "Drawer front",
                "Article no.:",
                "704.341.13",
                "Width: 30 cm",
                "Height: 2 cm",
                "Length: 61 cm",
                "Weight: 1.93 kg",
                "Package(s): 2",
                "HJ\u00c4LPA",
                "Clothes rail",
                "Article no.:",
                "503.312.05",
                "Width: 4 cm",
                "Height: 3 cm",
                "Length: 65 cm",
                "Weight: 0.31 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "903.311.66",
                "Width: 56 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 2.35 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Soft closing hinge",
                "Article no.:",
                "903.828.82",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.11 kg",
                "Package(s): 4",
                "KONSTRUERA",
                "Drawer without front",
                "Article no.:",
                "504.367.78",
                "Width: 53 cm",
                "Height: 3 cm",
                "Length: 55 cm",
                "Weight: 3.13 kg",
                "Package(s): 2",
                "KONSTRUERA",
                "Drawer without front",
                "Article no.:",
                "404.367.74",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 56 cm",
                "Weight: 4.58 kg",
                "Package(s): 2",
                "L\u00c4TTHET",
                "Hook and clip",
                "Article no.:",
                "104.369.78",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "Your child can use this wardrobe for many years since it is deep enough to hold adult-sized hangers and has an interior which you can move as your child grows. Stands steady also on uneven floors since adjustable feet are included. The doors have soft-closing hinges which make them close softly and quietly.  WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. 1 clothes rail, 1 shelf and 2 L\u00c4TTHET hooks and clip are included. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. May be completed with UPPRYMD and RASSLA boxes - perfect for storing small things that have a tendency to disappear. Sold separately. May be completed with H\u00c4NGIG label holder to keep things organised and easier to find. Sold separately. Knobs and handles are sold separately.",
            "sustainability": "",
            "images": [
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-0.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-1.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-2.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-3.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-4.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-5.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976/smastad-platsa-wardrobe-white-white-with-4-drawers-s39389976-6.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door/ drawer front,Fibreboard, Acrylic paint,Clothes rail,Steel, Pigmented epoxy/polyester powder coating,Soft closing hinge,Hinge:,Steel, Copper-plated,Soft closing device:,Acetal plastic,Drawer without front,Drawer side/ Drawer back:,Particleboard, Plastic foil,Drawer bottom:,Fibreboard, Acrylic paint,Hook and clip,Steel, Epoxy/polyester powder coating, Epoxy/polyester powder coating,Leg, adjustable,Steel, Polypropylene plastic, Galvanized"
        },
        "30": {
            "id": 30,
            "prod_name": "PAX / FARDAL/VIKEDAL",
            "prod_price": "390",
            "prod_desc": "Wardrobe combination, high-gloss white/mirror glass",
            "prod_dimensions": {
                "Width": "150.0 cm",
                "Depth": "60.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 21 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.59",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 36.47 kg",
                "Package(s): 1",
                "FARDAL",
                "Door",
                "Article no.:",
                "901.905.24",
                "Width: 51 cm",
                "Height: 2 cm",
                "Length: 206 cm",
                "Weight: 11.93 kg",
                "Package(s): 2",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "700.233.19",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 207 cm",
                "Weight: 19.91 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "302.779.59",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 5",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "902.463.52",
                "Width: 58 cm",
                "Height: 6 cm",
                "Length: 100 cm",
                "Weight: 9.40 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Feeling even more organised? Complement the drawers with KOMPLEMENT boxes, they can be combined to fit perfectly so that you can utilize the drawer fully. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. Open this solution in the PAX planner to change it to fit your needs. Another drawer? Less ones? Add a frame or change doors? No problems. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Hinges are needed for this product. They are included in the price but picked up separately. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,At least 50% (weight) of this product is made from renewable materials.,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.",
            "images": [
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566-0.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566-1.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566-2.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s49395566-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Particleboard, Plastic foil, Plastic edging,Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Door,Wipe clean with a cloth dampened in water or window-cleaner.,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth.,Wardrobe combination,Wipe clean with a mild soapy solution.,Wardrobe frame/pull-out rail for baskets/drawer/soft closing hinge/clothes rail/shelf/mesh basket,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "31": {
            "id": 31,
            "prod_name": "SM\u00c5STAD / PLATSA",
            "prod_price": "93",
            "prod_desc": "Wardrobe, white/white",
            "prod_dimensions": {
                "Depth": "40 cm",
                "Height": "123 cm",
                "Width": "60 cm"
            },
            "packaging": [
                "This product comes as 14 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "303.309.47",
                "Width: 41 cm",
                "Height: 7 cm",
                "Length: 127 cm",
                "Weight: 13.20 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Door",
                "Article no.:",
                "904.341.88",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 128 cm",
                "Weight: 7.92 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Top for storage module",
                "Article no.:",
                "904.728.30",
                "Width: 44 cm",
                "Height: 2 cm",
                "Length: 68 cm",
                "Weight: 2.96 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Hook for clothes rail",
                "Article no.:",
                "904.461.48",
                "Width: 9 cm",
                "Height: 4 cm",
                "Length: 16 cm",
                "Weight: 0.10 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Clothes rail",
                "Article no.:",
                "604.501.27",
                "Width: 6 cm",
                "Height: 3 cm",
                "Length: 58 cm",
                "Weight: 0.70 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Pull-out rail for baskets",
                "Article no.:",
                "303.311.93",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 50 cm",
                "Weight: 0.33 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "003.311.61",
                "Width: 38 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 1.65 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Soft closing hinge",
                "Article no.:",
                "903.828.82",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.11 kg",
                "Package(s): 4",
                "HJ\u00c4LPA",
                "Wire basket",
                "Article no.:",
                "903.311.85",
                "Width: 36 cm",
                "Height: 13 cm",
                "Length: 54 cm",
                "Weight: 1.07 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Hook and clip",
                "Article no.:",
                "104.369.78",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "This wardrobe is adapted to a younger child's height and motor skills so that they can reach and hang back their clothes on their own. The wardrobe has interiors which you can move and adjust based on your child\u2019s needs.  The doors have soft-closing hinges which make them close softly and quietly \u2013 even after a heated argument. Stands steady also on uneven floors since adjustable feet are included. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. 1 clothes rail, 1 shelf, 1 wire basket and 2 L\u00c4TTHET hooks and clip are included. May be completed with HJ\u00c4LPA multi-use hanger. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Knobs and handles are sold separately.",
            "sustainability": "",
            "images": [
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s99390316/smastad-platsa-wardrobe-white-white-s99390316-0.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s99390316/smastad-platsa-wardrobe-white-white-s99390316-1.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-s99390316/smastad-platsa-wardrobe-white-white-s99390316-2.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door/ top for storage module,Fibreboard, Acrylic paint,Hook for clothes rail/ hook and clip,Steel, Epoxy/polyester powder coating, Epoxy/polyester powder coating,Clothes rail/ wire basket,Steel, Epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Epoxy/polyester powder coating,Wheel:,Acetal plastic,Soft closing hinge,Hinge:,Steel, Copper-plated,Soft closing device:,Acetal plastic,Leg, adjustable,Steel, Polypropylene plastic, Galvanized"
        },
        "32": {
            "id": 32,
            "prod_name": "HEMNES",
            "prod_price": "279",
            "prod_desc": "Wardrobe with 2 sliding doors, white stain",
            "prod_dimensions": {
                "Width": "120 cm",
                "Depth": "59 cm",
                "Height": "197 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "HEMNES",
                "Wardrobe with 2 sliding doors",
                "Article no.:",
                "502.512.70",
                "This product has multiple packages.",
                "Width: 57 cm",
                "Height: 10 cm",
                "Length: 199 cm",
                "Weight: 26.20 kg",
                "Package(s): 1",
                "Width: 60 cm",
                "Height: 8 cm",
                "Length: 180 cm",
                "Weight: 27.40 kg",
                "Package(s): 1"
            ],
            "prod_details": "Made of solid wood, which is a hardwearing and warm natural material. Perfect for folded as well as long and short hanging garments. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail, 1 fixed and 1 adjustable shelf included. Knobs included. Interior accessories  that help you organise inside your wardrobe are sold separately.",
            "sustainability": "Renewable material (wood).,We have clear requirements for all the wood we use, including a ban on illegally harvested wood. By 2020, we want all our wood to come from more sustainable sources, defined as certified or recycled.",
            "images": [
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-0.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-1.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-2.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-3.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-4.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-5.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-6.JPG",
                "data/wardrobes/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270/hemnes-wardrobe-with-2-sliding-doors-white-stain-50251270-7.JPG"
            ],
            "materials": "Basematerial/ Door frame/ Door panel:,Solid pine, Stain, Clear acrylic lacquer,Clothes rail:,Solid pine,Back panel:,Fibreboard, Printed acrylic paint,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "33": {
            "id": 33,
            "prod_name": "PAX",
            "prod_price": "120",
            "prod_desc": "2 wardrobe frames, white",
            "prod_dimensions": {
                "Width": "199.6 cm",
                "Depth": "58.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. If you want to organise inside you can complement with interior organisers from the KOMPLEMENT series. Adjustable feet make it possible to compensate any irregularities in the floor. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. If you want to complete your PAX frame with a sliding door, the minimum ceiling height required is 205 cm. Doors and interiors are sold separately. 2 pieces of 75 cm wide frames are included in the combination.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-2-wardrobe-frames-white-s59895257/pax-2-wardrobe-frames-white-s59895257-0.JPG",
                "data/wardrobes/pax-2-wardrobe-frames-white-s59895257/pax-2-wardrobe-frames-white-s59895257-1.JPG",
                "data/wardrobes/pax-2-wardrobe-frames-white-s59895257/pax-2-wardrobe-frames-white-s59895257-2.JPG"
            ],
            "materials": "Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Wardrobe frame,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "34": {
            "id": 34,
            "prod_name": "PAX",
            "prod_price": "380",
            "prod_desc": "Wardrobe, white/Hasvik white",
            "prod_dimensions": {
                "Width": "150 cm",
                "Depth": "66 cm",
                "Height": "236.4 cm"
            },
            "packaging": [
                "This product comes as 21 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.71",
                "Width: 60 cm",
                "Height: 7 cm",
                "Length: 244 cm",
                "Weight: 48.78 kg",
                "Package(s): 2",
                "HASVIK",
                "Pair of sliding doors",
                "Article no.:",
                "403.911.34",
                "This product has multiple packages.",
                "Width: 79 cm",
                "Height: 5 cm",
                "Length: 236 cm",
                "Weight: 26.95 kg",
                "Package(s): 1",
                "Width: 26 cm",
                "Height: 7 cm",
                "Length: 235 cm",
                "Weight: 5.65 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing device",
                "Article no.:",
                "503.274.54",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.47 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "202.573.15",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 69 cm",
                "Weight: 1.74 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "902.779.61",
                "Width: 58 cm",
                "Height: 2 cm",
                "Length: 73 cm",
                "Weight: 5.02 kg",
                "Package(s): 6",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "402.568.95",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 74 cm",
                "Weight: 0.43 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Sliding doors allow more room for furniture because they don\u2019t take any space to open. If you want to organise inside you can complement with interior organisers from the KOMPLEMENT series. Adjustable feet make it possible to compensate any irregularities in the floor. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Interior accessories  that help you organise inside your wardrobe are sold separately. Two persons are needed for the assembly of this furniture. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. The frame can be assembled in an upright position if your ceiling height is a minimum of 237 cm. Follow the assembly instructions in the package. Min. ceiling height required: 240 cm. This furniture must be fixed to the wall with the enclosed wall fastener.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s29180581/pax-wardrobe-white-hasvik-white-s29180581-0.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s29180581/pax-wardrobe-white-hasvik-white-s29180581-1.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s29180581/pax-wardrobe-white-hasvik-white-s29180581-2.JPG",
                "data/wardrobes/pax-wardrobe-white-hasvik-white-s29180581/pax-wardrobe-white-hasvik-white-s29180581-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Pair of sliding doors,Board on frame:,Particleboard, Fibreboard, Plastic edging, Acrylic paint,Filling material:,Honeycomb structure paper filling (min. 70% recycled),Cover strip/ Rail:,Aluminium,Soft closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/pair of sliding doors/soft closing device/mesh basket/pull-out rail for baskets/shelf/clothes rail,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "35": {
            "id": 35,
            "prod_name": "PAX",
            "prod_price": "405",
            "prod_desc": "Corner wardrobe, white/Flisberget light beige",
            "prod_dimensions": {
                "Height": "201.2 cm",
                "Width right": "87.9 cm",
                "Width left": "160.3 cm"
            },
            "packaging": [
                "This product comes as 16 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "602.145.69",
                "Width: 50 cm",
                "Height: 7 cm",
                "Length: 210 cm",
                "Weight: 24.88 kg",
                "Package(s): 1",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.64",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 221 cm",
                "Weight: 41.68 kg",
                "Package(s): 1",
                "PAX",
                "Add-on corner unit with 4 shelves",
                "Article no.:",
                "403.469.38",
                "This product has multiple packages.",
                "Width: 40 cm",
                "Height: 8 cm",
                "Length: 206 cm",
                "Weight: 21.30 kg",
                "Package(s): 1",
                "Width: 40 cm",
                "Height: 4 cm",
                "Length: 207 cm",
                "Weight: 17.50 kg",
                "Package(s): 1",
                "FLISBERGET",
                "Door",
                "Article no.:",
                "003.447.43",
                "Width: 50 cm",
                "Height: 3 cm",
                "Length: 203 cm",
                "Weight: 7.96 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge f corner section",
                "Article no.:",
                "103.684.89",
                "Width: 27 cm",
                "Height: 5 cm",
                "Length: 30 cm",
                "Weight: 1.36 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "402.568.95",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 74 cm",
                "Weight: 0.43 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Shoe shelf",
                "Article no.:",
                "602.572.57",
                "Width: 35 cm",
                "Height: 3 cm",
                "Length: 46 cm",
                "Weight: 1.19 kg",
                "Package(s): 6"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The shoe shelf is of metal and withstands all the dirt and moisture that insists on coming home with you and your shoes when you\u2019ve been outdoors. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 30 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-corner-wardrobe-white-flisberget-light-beige-s99221371/pax-corner-wardrobe-white-flisberget-light-beige-s99221371-0.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-flisberget-light-beige-s99221371/pax-corner-wardrobe-white-flisberget-light-beige-s99221371-1.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-flisberget-light-beige-s99221371/pax-corner-wardrobe-white-flisberget-light-beige-s99221371-2.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-flisberget-light-beige-s99221371/pax-corner-wardrobe-white-flisberget-light-beige-s99221371-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Add-on corner unit with 4 shelves,Particleboard, Fibreboard, Honeycomb structure paper filling (100% recycled), Plastic edging, Plastic edging, Paper foil,Door,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Soft closing hinge f corner section,Plastic parts:,Acetal plastic,Basematerial:,Steel, Nickel-plated,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shoe shelf,Steel, Epoxy/polyester powder coating,Wardrobe frame/add-on corner unit with 4 shelves/door/soft closing hinge/soft closing hinge f corner section/clothes rail/shoe shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "36": {
            "id": 36,
            "prod_name": "TYSSEDAL",
            "prod_price": "249",
            "prod_desc": "Wardrobe, white/mirror glass",
            "prod_dimensions": {
                "Width": "88 cm",
                "Depth": "58 cm",
                "Height": "208 cm"
            },
            "packaging": [
                "This product comes as 3 packages.",
                "TYSSEDAL",
                "Wardrobe",
                "Article no.:",
                "002.981.28",
                "This product has multiple packages.",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 188 cm",
                "Weight: 26.50 kg",
                "Package(s): 1",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 188 cm",
                "Weight: 27.80 kg",
                "Package(s): 1",
                "Width: 61 cm",
                "Height: 10 cm",
                "Length: 94 cm",
                "Weight: 31.30 kg",
                "Package(s): 1"
            ],
            "prod_details": "Of course your home should be a safe place for the entire family. That\u2019s why a safety fitting is included so that you can attach the wardrobe to the wall. Hinges with integrated dampers catch the door and close it slowly, silently and softly. Integrated damper catches the running drawer and closes it slowly, silently and softly. Adjustable feet make it possible to compensate any irregularities in the floor. A groove along the top moulding makes it easy to hang your clothes on the outside of the wardrobe. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 1 clothes rail and 1 adjustable shelf included. The clothes rail holds about 20 shirts on hangers. The drawer holds about 10 pairs of folded trousers or 20 T-shirts. One shelf holds about 15 pairs of folded trousers or 30 T-shirts.",
            "sustainability": "",
            "images": [
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-0.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-1.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-2.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-3.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-4.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-5.JPG",
                "data/wardrobes/tyssedal-wardrobe-white-mirror-glass-00298128/tyssedal-wardrobe-white-mirror-glass-00298128-6.JPG"
            ],
            "materials": "Top/ Front rail/ Back rail/ Drawer front/ Door frame:,Fibreboard, Acrylic paint,Side panel:,Particleboard, Fibreboard, Acrylic paint,Support rail/ Back rail:,Fibreboard,Back panel/ Drawer bottom:,Fibreboard, Paper foil,Back rail:,Solid wood,Leg:,Solid wood, Acrylic paint,Clothes rail:,Solid spruce, Clear acrylic lacquer,Adjustable shelf/ Fixed shelf:,Particleboard, Acrylic paint,Drawer side/ Drawer back:,Particleboard, Plastic foil,Door filling:,Glass,Mirror glass,Wipe clean with a cloth dampened in water or window-cleaner.,Wipe dry with a clean cloth."
        },
        "37": {
            "id": 37,
            "prod_name": "PAX / FARDAL/VIKEDAL",
            "prod_price": "450",
            "prod_desc": "Wardrobe combination, high-gloss white/mirror glass",
            "prod_dimensions": {
                "Width": "200.0 cm",
                "Depth": "60.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 23 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2",
                "FARDAL",
                "Door",
                "Article no.:",
                "901.905.24",
                "Width: 51 cm",
                "Height: 2 cm",
                "Length: 206 cm",
                "Weight: 11.93 kg",
                "Package(s): 3",
                "VIKEDAL",
                "Door",
                "Article no.:",
                "700.233.19",
                "Width: 55 cm",
                "Height: 3 cm",
                "Length: 207 cm",
                "Weight: 19.91 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "002.145.05",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.31 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and it's perfect for outdoor accessories like hats and gloves after not-so sunny days. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. Open this solution in the PAX planner to change it to fit your needs. Another drawer? Less ones? Add a frame or change doors? No problems. A room immediately feels larger, lighter and more spacious by choosing mirror doors. A great way of transforming a narrow hallway or a tiny bedroom. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Hinges are needed for this product. They are included in the price but picked up separately. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Door,At least 50% (weight) of this product is made from renewable materials.,Lead-free mirrors \u2013 No lead added in manufacturing of our mirrors.",
            "images": [
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598-0.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598-1.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598-2.JPG",
                "data/wardrobes/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598/pax-fardal-vikedal-wardrobe-combination-high-gloss-white-mirror-glass-s79395598-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Particleboard, Plastic foil, Plastic edging,Door:,Particleboard, Plastic foil,Mirror:,Glass,Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Wardrobe frame/door/soft closing hinge/clothes rail/shelf/mesh basket/pull-out rail for baskets,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "38": {
            "id": 38,
            "prod_name": "PAX",
            "prod_price": "300",
            "prod_desc": "Corner wardrobe, white/Grimo white",
            "prod_dimensions": {
                "Height": "201.2 cm",
                "Width right": "110.5 cm",
                "Width left": "110.5 cm"
            },
            "packaging": [
                "This product comes as 8 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 1",
                "PAX",
                "Add-on corner unit with 4 shelves",
                "Article no.:",
                "703.469.32",
                "This product has multiple packages.",
                "Width: 59 cm",
                "Height: 7 cm",
                "Length: 200 cm",
                "Weight: 23.50 kg",
                "Package(s): 1",
                "Width: 59 cm",
                "Height: 5 cm",
                "Length: 206 cm",
                "Weight: 24.75 kg",
                "Package(s): 1",
                "GRIMO",
                "Door",
                "Article no.:",
                "403.434.64",
                "Width: 50 cm",
                "Height: 3 cm",
                "Length: 203 cm",
                "Weight: 10.16 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Soft closing hinge f corner section",
                "Article no.:",
                "103.684.89",
                "Width: 27 cm",
                "Height: 5 cm",
                "Length: 30 cm",
                "Weight: 1.36 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-corner-wardrobe-white-grimo-white-s99218509/pax-corner-wardrobe-white-grimo-white-s99218509-0.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-grimo-white-s99218509/pax-corner-wardrobe-white-grimo-white-s99218509-1.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-grimo-white-s99218509/pax-corner-wardrobe-white-grimo-white-s99218509-2.JPG",
                "data/wardrobes/pax-corner-wardrobe-white-grimo-white-s99218509/pax-corner-wardrobe-white-grimo-white-s99218509-3.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Add-on corner unit with 4 shelves,Particleboard, Fibreboard, Honeycomb structure paper filling (100% recycled), Plastic edging, Plastic edging, Paper foil,Door,Door frame:,Fibreboard, Paper foil, Plastic edging,Door panel:,Fibreboard, Paper foil,Soft closing hinge f corner section,Plastic parts:,Acetal plastic,Basematerial:,Steel, Nickel-plated,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Wardrobe frame/add-on corner unit with 4 shelves/door/soft closing hinge f corner section/clothes rail,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "39": {
            "id": 39,
            "prod_name": "SM\u00c5STAD / PLATSA",
            "prod_price": "108",
            "prod_desc": "Wardrobe, white white/with 2 clothes rails",
            "prod_dimensions": {
                "Depth": "55 cm",
                "Height": "180 cm",
                "Width": "60 cm"
            },
            "packaging": [
                "This product comes as 17 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "503.309.51",
                "Width: 56 cm",
                "Height: 7 cm",
                "Length: 187 cm",
                "Weight: 23.80 kg",
                "Package(s): 1",
                "SM\u00c5STAD",
                "Door",
                "Article no.:",
                "204.341.63",
                "Width: 30 cm",
                "Height: 4 cm",
                "Length: 98 cm",
                "Weight: 5.80 kg",
                "Package(s): 2",
                "HJ\u00c4LPA",
                "Clothes rail",
                "Article no.:",
                "503.312.05",
                "Width: 4 cm",
                "Height: 3 cm",
                "Length: 65 cm",
                "Weight: 0.31 kg",
                "Package(s): 2",
                "HJ\u00c4LPA",
                "Hook for clothes rail",
                "Article no.:",
                "904.461.48",
                "Width: 9 cm",
                "Height: 4 cm",
                "Length: 16 cm",
                "Weight: 0.10 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "903.311.66",
                "Width: 56 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 2.35 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Soft closing hinge",
                "Article no.:",
                "903.828.82",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 17 cm",
                "Weight: 0.11 kg",
                "Package(s): 8",
                "L\u00c4TTHET",
                "Hook and clip",
                "Article no.:",
                "104.369.78",
                "Width: 9 cm",
                "Height: 2 cm",
                "Length: 16 cm",
                "Weight: 0.05 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "Your child can use this wardrobe for many years since it is deep enough to hold adult-sized hangers and has an interior which you can move as your child grows. The doors have soft-closing hinges which make them close softly and quietly \u2013 even after a heated argument. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 2 clothes rails, 2 HJ\u00c4LPA hooks for clothes rail and 2 L\u00c4TTHET hooks and clip are included. To organise on the inside, complete with H\u00c4NGIG accessories, HJ\u00c4LPA shelves and wire baskets and UPPRYMD and RASSLA boxes. Sold separately. Knobs and handles are sold separately. Limited space? The wardrobe is also available with a depth of 40 cm.",
            "sustainability": "",
            "images": [
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-0.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-1.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-2.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-3.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-4.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-5.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-6.JPG",
                "data/wardrobes/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272/smastad-platsa-wardrobe-white-white-with-2-clothes-rails-s79389272-7.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door,Fibreboard, Acrylic paint,Clothes rail,Steel, Pigmented epoxy/polyester powder coating,Hook for clothes rail/ hook and clip,Steel, Epoxy/polyester powder coating, Epoxy/polyester powder coating,Soft closing hinge,Hinge:,Steel, Copper-plated,Soft closing device:,Acetal plastic,Leg, adjustable,Steel, Polypropylene plastic, Galvanized"
        },
        "40": {
            "id": 40,
            "prod_name": "PAX",
            "prod_price": "445",
            "prod_desc": "Wardrobe, Mehamn oak effect/light grey",
            "prod_dimensions": {
                "Width": "200.0 cm",
                "Depth": "66.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 20 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2",
                "MEHAMN",
                "4 panels for sliding door frame",
                "Article no.:",
                "004.452.52",
                "Width: 49 cm",
                "Height: 2 cm",
                "Length: 107 cm",
                "Weight: 7.15 kg",
                "Package(s): 2",
                "PAX",
                "Pair of sliding door frames w rail",
                "Article no.:",
                "002.224.21",
                "Width: 25 cm",
                "Height: 8 cm",
                "Length: 220 cm",
                "Weight: 17.10 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft opening/closing device",
                "Article no.:",
                "504.437.74",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-opening/closing devices catch the running doors so that they open and close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Turn the panel over to change the look \u2013 each side has a different finish. Go for a unified look or mix. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Pair of sliding door frames w rail,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/wardrobes/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778-0.JPG",
                "data/wardrobes/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778-1.JPG",
                "data/wardrobes/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778-2.JPG",
                "data/wardrobes/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778-3.JPG",
                "data/wardrobes/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778/pax-wardrobe-mehamn-oak-effect-light-grey-s49305778-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,4 panels for sliding door frame,Fibreboard, Paper foil,Pair of sliding door frames w rail,Aluminium, Anodized,Soft opening/closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Wardrobe frame/4 panels for sliding door frame/pair of sliding door frames w rail/soft opening/closing device/clothes rail/pull-out rail for baskets/mesh basket/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "41": {
            "id": 41,
            "prod_name": "PAX",
            "prod_price": "100",
            "prod_desc": "2 wardrobe frames, white",
            "prod_dimensions": {
                "Width": "149.6 cm",
                "Depth": "58.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "702.145.64",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 221 cm",
                "Weight: 41.68 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. If you want to organise inside you can complement with interior organisers from the KOMPLEMENT series. Adjustable feet make it possible to compensate any irregularities in the floor. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 202 cm. Follow the assembly instructions in the package. If you want to complete your PAX frame with a sliding door, the minimum ceiling height required is 205 cm. Doors and interiors are sold separately. 2 pieces of 75 cm wide frames are included in the combination.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.",
            "images": [
                "data/wardrobes/pax-2-wardrobe-frames-white-s19895264/pax-2-wardrobe-frames-white-s19895264-0.JPG",
                "data/wardrobes/pax-2-wardrobe-frames-white-s19895264/pax-2-wardrobe-frames-white-s19895264-1.JPG",
                "data/wardrobes/pax-2-wardrobe-frames-white-s19895264/pax-2-wardrobe-frames-white-s19895264-2.JPG"
            ],
            "materials": "Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Wardrobe frame,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "42": {
            "id": 42,
            "prod_name": "PAX / HOKKSUND",
            "prod_price": "595",
            "prod_desc": "Wardrobe combination, white/high-gloss light grey",
            "prod_dimensions": {
                "Width": "200.0 cm",
                "Depth": "66.0 cm",
                "Height": "201.2 cm"
            },
            "packaging": [
                "This product comes as 22 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "202.145.66",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 210 cm",
                "Weight: 45.60 kg",
                "Package(s): 2",
                "HOKKSUND",
                "4 panels for sliding door frame",
                "Article no.:",
                "603.823.41",
                "Width: 49 cm",
                "Height: 2 cm",
                "Length: 107 cm",
                "Weight: 7.75 kg",
                "Package(s): 2",
                "PAX",
                "Pair of sliding door frames w rail",
                "Article no.:",
                "002.224.21",
                "Width: 25 cm",
                "Height: 8 cm",
                "Length: 220 cm",
                "Weight: 17.10 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft opening/closing device",
                "Article no.:",
                "504.437.74",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.57",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 3",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "102.573.06",
                "Width: 44 cm",
                "Height: 16 cm",
                "Length: 54 cm",
                "Weight: 1.24 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 5",
                "KOMPLEMENT",
                "Drawer",
                "Article no.:",
                "102.463.08",
                "Width: 49 cm",
                "Height: 6 cm",
                "Length: 58 cm",
                "Weight: 5.92 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Divider for frames",
                "Article no.:",
                "602.463.96",
                "Width: 58 cm",
                "Height: 7 cm",
                "Length: 83 cm",
                "Weight: 12.83 kg",
                "Package(s): 1"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-opening/closing devices catch the running doors so that they open and close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Open this solution in the PAX planner to change it to fit your needs. Another drawer? Less ones? Add a frame or change doors? No problems. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 205 cm. Interior accessories  that help you organise inside your wardrobe are sold separately.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Pair of sliding door frames w rail,The material in this product may be recyclable. Please check the recycling rules in your community and if recycling facilities exist in your area.",
            "images": [
                "data/wardrobes/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865-0.JPG",
                "data/wardrobes/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865-1.JPG",
                "data/wardrobes/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865/pax-hokksund-wardrobe-combination-white-high-gloss-light-grey-s09395865-2.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,4 panels for sliding door frame,Fibreboard, Plastic foil, Plastic foil,Pair of sliding door frames w rail,Aluminium, Anodized,Soft opening/closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Shelf,Particleboard, Paper foil,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Drawer,Drawer:,Particleboard, Paper foil, Plastic edging,Drawer bottom:,Fibreboard, Acrylic paint,Divider for frames,Particle- and fibreboard with honeycomb paper filling (100% recycled paper), Paper foil,Wardrobe combination,Wipe clean with a cloth dampened in water or window-cleaner.,Wardrobe frame/drawer/divider for frames/4 panels for sliding door frame/pair of sliding door frames w rail/soft opening/closing device/clothes rail/shelf/mesh basket/pull-out rail for baskets,Wipe dry with a clean cloth."
        },
        "43": {
            "id": 43,
            "prod_name": "BUSUNGE",
            "prod_price": "99",
            "prod_desc": "Wardrobe, white",
            "prod_dimensions": {
                "Width": "80 cm",
                "Depth": "52 cm",
                "Height": "139 cm"
            },
            "packaging": [
                "This product comes as 2 packages.",
                "BUSUNGE",
                "Wardrobe",
                "Article no.:",
                "203.057.07",
                "This product has multiple packages.",
                "Width: 53 cm",
                "Height: 9 cm",
                "Length: 138 cm",
                "Weight: 18.50 kg",
                "Package(s): 1",
                "Width: 53 cm",
                "Height: 9 cm",
                "Length: 154 cm",
                "Weight: 21.50 kg",
                "Package(s): 1"
            ],
            "prod_details": "You can adjust the height of the clothes rail and shelves as your child grows. The built-in damper makes the doors close slowly, silently and softly. The cutout handles have a transparent plastic base, so they keep out dust and dirt but still give a glimpse of what\u2019s inside.  This wardrobe has softly rounded edges and hidden fittings. Deep enough to hold standard-sized adult hangers. WARNING! TIPPING HAZARD \u2013 Unanchored furniture can tip over. This furniture shall be anchored to the wall with the enclosed safety fitting to prevent it from tipping over. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. 2 adjustable shelves and 1 clothes rail are included; easy to adjust according to need.",
            "sustainability": "Possible to separate for recycling or energy recovery if available in your community.",
            "images": [
                "data/wardrobes/busunge-wardrobe-white-20305707/busunge-wardrobe-white-20305707-0.JPG",
                "data/wardrobes/busunge-wardrobe-white-20305707/busunge-wardrobe-white-20305707-1.JPG"
            ],
            "materials": "Top panel/ Adjustable shelf:,Particleboard, Honeycomb structure paper filling (100% recycled), Fibreboard, Acrylic paint, Plastic edging,Side panel:,Fibreboard, Particleboard, Honeycomb structure paper filling (100% recycled), Fibreboard, Plastic foil, Plastic edging,Bottom panel:,Particleboard, Honeycomb structure paper filling (100% recycled), Fibreboard, Plastic edging, Acrylic paint, Plastic edging,Door:,Particleboard, Acrylic paint, Plastic edging,Back:,Particleboard, Plastic foil, Paper foil,Wipe clean with a damp cloth.,Wipe clean with a dry cloth."
        },
        "44": {
            "id": 44,
            "prod_name": "PAX",
            "prod_price": "485",
            "prod_desc": "Wardrobe, white stained oak effect/Forsand white stained oak effect",
            "prod_dimensions": {
                "Width": "250 cm",
                "Depth": "60 cm",
                "Height": "236.4 cm",
                "Plinth, height": "236 cm"
            },
            "packaging": [
                "This product comes as 30 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "301.839.89",
                "Width: 61 cm",
                "Height: 8 cm",
                "Length: 245 cm",
                "Weight: 53.75 kg",
                "Package(s): 2",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "901.839.91",
                "Width: 61 cm",
                "Height: 7 cm",
                "Length: 245 cm",
                "Weight: 44.16 kg",
                "Package(s): 1",
                "FORSAND",
                "Door",
                "Article no.:",
                "304.349.64",
                "Width: 50 cm",
                "Height: 2 cm",
                "Length: 239 cm",
                "Weight: 10.35 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Soft closing hinge",
                "Article no.:",
                "302.145.04",
                "Width: 25 cm",
                "Height: 3 cm",
                "Length: 27 cm",
                "Weight: 0.40 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "302.568.91",
                "Width: 6 cm",
                "Height: 4 cm",
                "Length: 102 cm",
                "Weight: 0.65 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "002.572.98",
                "Width: 54 cm",
                "Height: 16 cm",
                "Length: 94 cm",
                "Weight: 2.58 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "302.632.45",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 68 cm",
                "Weight: 0.43 kg",
                "Package(s): 4",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.81",
                "Width: 48 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 3.35 kg",
                "Package(s): 5",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "102.779.84",
                "Width: 59 cm",
                "Height: 2 cm",
                "Length: 98 cm",
                "Weight: 7.30 kg",
                "Package(s): 4"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Adjustable feet make it possible to compensate any irregularities in the floor. Hinges with integrated dampers catch the door and close it slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. The frame can be assembled in an upright position if your ceiling height is a minimum of 237 cm. Follow the assembly instructions in the package. Interior accessories  that help you organise inside your wardrobe are sold separately. Knobs and handles are sold separately. Hinges are needed for this product. They are included in the price but picked up separately. The clothes rail holds about 40 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,Soft closing hinge,Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/wardrobes/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095-0.JPG",
                "data/wardrobes/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095-1.JPG",
                "data/wardrobes/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095-2.JPG",
                "data/wardrobes/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095-3.JPG",
                "data/wardrobes/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095/pax-wardrobe-white-stained-oak-effect-forsand-white-stained-oak-effect-s69286095-4.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,Door,Board on frame:,Particleboard, Fibreboard, ABS plastic, Paper foil,Filling material:,Honeycomb structure paper filling (100% recycled),Soft closing hinge,Basematerial:,Steel, Nickel-plated, Copper-plated,Plastic parts:,Acetal plastic,Clothes rail,Steel, Anti-corrosive phosphate coating, Epoxy/polyester powder coating,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Wardrobe,Wipe clean with a mild soapy solution.,Wardrobe frame/door/soft closing hinge/clothes rail/mesh basket/pull-out rail for baskets/shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "45": {
            "id": 45,
            "prod_name": "PLATSA",
            "prod_price": "92",
            "prod_desc": "Wardrobe, white/Fonnes white",
            "prod_dimensions": {
                "Width": "60 cm",
                "Min. width": "95 cm",
                "Max. width": "120 cm",
                "Depth": "42 cm",
                "Height": "181 cm"
            },
            "packaging": [
                "This product comes as 11 packages.",
                "PLATSA",
                "Frame",
                "Article no.:",
                "903.309.54",
                "Width: 41 cm",
                "Height: 7 cm",
                "Length: 187 cm",
                "Weight: 18.70 kg",
                "Package(s): 1",
                "FONNES",
                "Door",
                "Article no.:",
                "403.310.55",
                "Width: 60 cm",
                "Height: 2 cm",
                "Length: 189 cm",
                "Weight: 13.75 kg",
                "Package(s): 1",
                "HJ\u00c4LPA",
                "Standard hinges",
                "Article no.:",
                "603.312.00",
                "Width: 17 cm",
                "Height: 3 cm",
                "Length: 20 cm",
                "Weight: 0.09 kg",
                "Package(s): 4",
                "HJ\u00c4LPA",
                "Shelf",
                "Article no.:",
                "003.311.61",
                "Width: 38 cm",
                "Height: 2 cm",
                "Length: 59 cm",
                "Weight: 1.65 kg",
                "Package(s): 3",
                "L\u00c4TTHET",
                "Clothes rail for frame",
                "Article no.:",
                "703.316.95",
                "Width: 12 cm",
                "Height: 6 cm",
                "Length: 91 cm",
                "Weight: 1.95 kg",
                "Package(s): 1",
                "L\u00c4TTHET",
                "Leg, adjustable",
                "Article no.:",
                "203.311.98",
                "Width: 18 cm",
                "Height: 3 cm",
                "Length: 23 cm",
                "Weight: 0.21 kg",
                "Package(s): 1"
            ],
            "prod_details": "This combination is perfect if you want to use unutilised space between a frame and a wall. Adjustable feet make it possible to compensate any irregularities in the floor. You can organise the inside with interiors from the HJ\u00c4LPA series \u2013 and for the exterior there are smart solutions in the L\u00c4TTHET series. Perfect where space is limited since the frame is narrow. Knobs and handles are sold separately. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail can be adjusted to fit your space, from 35 cm to 60 cm. Two persons are needed for the assembly of this furniture. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. This furniture must be fixed to the wall with the enclosed wall fastener.",
            "sustainability": "",
            "images": [
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-0.JPG",
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-1.JPG",
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-2.JPG",
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-3.JPG",
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-4.JPG",
                "data/wardrobes/platsa-wardrobe-white-fonnes-white-s79203815/platsa-wardrobe-white-fonnes-white-s79203815-5.JPG"
            ],
            "materials": "Frame/ shelf,Fibreboard, Paper foil, Particleboard, Honeycomb structure paper filling (100% recycled),Door,Particleboard, Foil, Clear lacquer,Standard hinges,Steel, Nickel-plated, Copper-plated,Clothes rail for frame,Main parts:,Steel, Pigmented epoxy/polyester powder coating,Plastic parts:,ABS plastic,Leg, adjustable,Steel, Polypropylene plastic, Galvanized,Frame/door/standard hinges/shelf/clothes rail for frame/leg, adjustable,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        },
        "46": {
            "id": 46,
            "prod_name": "PAX / AULI",
            "prod_price": "450",
            "prod_desc": "Wardrobe combination, white/mirror glass",
            "prod_dimensions": {
                "Width": "150.0 cm",
                "Depth": "44.0 cm",
                "Height": "236.4 cm"
            },
            "packaging": [
                "This product comes as 19 packages.",
                "PAX",
                "Wardrobe frame",
                "Article no.:",
                "802.074.93",
                "Width: 38 cm",
                "Height: 7 cm",
                "Length: 245 cm",
                "Weight: 32.35 kg",
                "Package(s): 2",
                "AULI",
                "4 panels for sliding door frame",
                "Article no.:",
                "302.112.75",
                "Width: 62 cm",
                "Height: 2 cm",
                "Length: 83 cm",
                "Weight: 13.60 kg",
                "Package(s): 2",
                "PAX",
                "Pair of sliding door frames w rail",
                "Article no.:",
                "402.502.66",
                "Width: 25 cm",
                "Height: 8 cm",
                "Length: 235 cm",
                "Weight: 17.10 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Soft opening/closing device",
                "Article no.:",
                "504.437.74",
                "Width: 9 cm",
                "Height: 6 cm",
                "Length: 26 cm",
                "Weight: 0.57 kg",
                "Package(s): 1",
                "KOMPLEMENT",
                "Clothes rail",
                "Article no.:",
                "804.464.55",
                "Width: 33 cm",
                "Height: 4 cm",
                "Length: 71 cm",
                "Weight: 0.99 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Mesh basket",
                "Article no.:",
                "102.573.11",
                "Width: 34 cm",
                "Height: 16 cm",
                "Length: 69 cm",
                "Weight: 1.31 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Pull-out rail for baskets",
                "Article no.:",
                "602.632.44",
                "Width: 8 cm",
                "Height: 4 cm",
                "Length: 47 cm",
                "Weight: 0.28 kg",
                "Package(s): 2",
                "KOMPLEMENT",
                "Shelf",
                "Article no.:",
                "702.779.95",
                "Width: 35 cm",
                "Height: 2 cm",
                "Length: 73 cm",
                "Weight: 3.20 kg",
                "Package(s): 5",
                "KOMPLEMENT",
                "Shoe shelf",
                "Article no.:",
                "802.572.61",
                "Width: 35 cm",
                "Height: 3 cm",
                "Length: 71 cm",
                "Weight: 1.78 kg",
                "Package(s): 2"
            ],
            "prod_details": "10 year guarantee. Read about the terms in the guarantee brochure. You can easily adapt this ready-made PAX/KOMPLEMENT combination to suit your needs and taste using the PAX planning tool. Perfect where space is limited since the frame is narrow. Adjustable feet make it possible to compensate any irregularities in the floor. Sliding doors allow more room for furniture because they don\u2019t take any space to open. The soft-opening/closing devices catch the running doors so that they open and close slowly, silently and softly. With the PAX Planner, you can easily complete your combination with integrated lighting. After choosing the light source, the planner will work out which accessories you need to complete the solution. Do you know it's easy as pie to move around the inside organisers after taste, or change them later on? With small changes you can alter the storage solution to fit your clothes, instead of the other way around. The mesh basket allows air to circulate and is perfect for storing your folded clothes, socks or accessories. The shoe shelf is of metal and withstands all the dirt and moisture that insists on coming home with you and your shoes when you\u2019ve been outdoors. The sliding doors do not require knobs or handles. This creates a timeless expression that is easy to combine with different styles. This furniture must be fixed to the wall with the enclosed wall fastener. Different wall materials require different types of fixing devices. Use fixing devices suitable for the walls in your home, sold separately. Two persons are needed for the assembly of this furniture. Min. ceiling height required: 240 cm. Interior accessories  that help you organise inside your wardrobe are sold separately. The clothes rail holds about 4 coats or 8 shirts on hangers.",
            "sustainability": "Wardrobe frame,At least 50% (weight) of this product is made from renewable materials.,4 panels for sliding door frame/pair of sliding door frames w rail,Product is possible to recycle or use for energy recovery, if available in your community.",
            "images": [
                "data/wardrobes/pax-auli-wardrobe-combination-white-mirror-glass-s59330112/pax-auli-wardrobe-combination-white-mirror-glass-s59330112-0.JPG",
                "data/wardrobes/pax-auli-wardrobe-combination-white-mirror-glass-s59330112/pax-auli-wardrobe-combination-white-mirror-glass-s59330112-1.JPG",
                "data/wardrobes/pax-auli-wardrobe-combination-white-mirror-glass-s59330112/pax-auli-wardrobe-combination-white-mirror-glass-s59330112-2.JPG"
            ],
            "materials": "Wardrobe frame,Particleboard, Fibreboard, ABS plastic, Polypropylene plastic, Foil,4 panels for sliding door frame,Glass,Pair of sliding door frames w rail,Door frame/ Cover strip:,Aluminium, Epoxy/polyester powder coating,Rail:,Aluminium, Anodized,Soft opening/closing device,Cover:,ABS plastic,Holder:,Galvanized steel, Galvanized,Mechanism:,Acetal plastic, Reinforced polyamide plastic,Clothes rail,Frame:,Fibreboard, Paper foil,Clothes rail:,Steel, Epoxy powder coating,Mesh basket,Steel, Anti-corrosive phosphate coating, Pigmented epoxy/polyester powder coating,Pull-out rail for baskets,Basematerial:,Steel, Pigmented epoxy/polyester powder coating,Wheel:,Acetal plastic,Shelf,Particleboard, Paper foil,Shoe shelf,Steel, Epoxy/polyester powder coating,Wardrobe frame/pair of sliding door frames w rail/soft opening/closing device/clothes rail/mesh basket/pull-out rail for baskets/shelf/shoe shelf,Wipe clean with a cloth dampened in a mild cleaner.,Wipe dry with a clean cloth."
        }
    }
}